/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Contributor: Kevin Fuchs, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2013-11-08
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmComInterface.communicators;

import eu.intuitel.lpmGeneralInterfaces.ILmsCommunicator;
import eu.intuitel.lpmComInterface.wrappers.IIncomingMsg;
import eu.intuitel.lpmComInterface.wrappers.LmsProfileIn;
import eu.intuitel.lpmComInterface.wrappers.LmsProfileOut;
import eu.intuitel.lpmComInterface.wrappers.UsePerformanceIn;
import eu.intuitel.lpmComInterface.wrappers.UsePerformanceOut;
import eu.intuitel.lpmComInterface.wrappers.LearnerUpdateOut;
import eu.intuitel.lpmComInterface.wrappers.UseEnvironmentIn;
import eu.intuitel.lpmComInterface.wrappers.UseEnvironmentOut;
import java.util.Map;

/**
 * Communicator instance to access LMS services.
 *
 * @author fhe
 */
public class LmsCommunicator extends BaseCommunicator implements ILmsCommunicator {

    @Override
    public Map<String, String> getLmsProfile() {
        IIncomingMsg responseElement = sendAndReceiveAsyncResponse(new LmsProfileOut());
        if (LmsProfileIn.class.isInstance(responseElement)) {
            return ((LmsProfileIn) responseElement).getData();
        }
        return null;
    }

    @Override
    public Map<String, Map<String, String>> getUsePerformanceData(String learnerId) {
        IIncomingMsg responseElement = sendAndReceiveAsyncResponse(new UsePerformanceOut(learnerId));
        if (UsePerformanceIn.class.isInstance(responseElement)) {
            return ((UsePerformanceIn) responseElement).getData();
        }
        return null;
    }

    @Override
    public Map<String, Map<String, String>> getUsePerformanceData(String learnerId, String... loIds) {
        IIncomingMsg responseElement = sendAndReceiveAsyncResponse(new UsePerformanceOut(learnerId, loIds));
        if (UsePerformanceIn.class.isInstance(responseElement)) {
            return ((UsePerformanceIn) responseElement).getData();
        }
        return null;
    }

    @Override
    public Map<String, String> getUseEnvironmentData(String learnerId) {
        IIncomingMsg responseElement = sendAndReceiveAsyncResponse(new UseEnvironmentOut(learnerId));
        if (UseEnvironmentIn.class.isInstance(responseElement)) {
            return ((UseEnvironmentIn) responseElement).getData();
        }
        return null;
    }

    @Override
    public void sendLearnerUpdate() {
        send(new LearnerUpdateOut());
    }
}
