/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Contributor: Kevin Fuchs, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2013-11-08
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmComInterface.communicators;

import eu.intuitel.comm.entities.slomRepo.SlomData;
import eu.intuitel.lpmComInterface.wrappers.IIncomingMsg;
import eu.intuitel.lpmComInterface.wrappers.SlomRequestIn;
import eu.intuitel.lpmComInterface.wrappers.SlomRequestOut;
import eu.intuitel.lpmGeneralInterfaces.ISlomCommunicator;
import java.net.MalformedURLException;
import java.net.URL;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * SLOM communicator instance to access the SLOM data from a remote repository.
 *
 * @author fhe
 */
public class SlomRemoteCommunicator extends BaseCommunicator implements ISlomCommunicator {

    private static final Logger logger = LoggerFactory.getLogger(SlomRemoteCommunicator.class);

    /**
     * Creates a new SLOM communicator to access a remote SLOM repo.
     */
    public SlomRemoteCommunicator() {
    }

    @Override
    public ISlomRefContainer getSlomDataForLo(String loId) {
        if (StringUtils.isBlank(loId)) {
            logger.warn("Could not retrieve SLOM data. The specified Learning Object ID is blank.");
            return null;
        }
        IIncomingMsg responseElement = sendAndReceiveAsyncResponse(new SlomRequestOut(loId));
        if (SlomRequestIn.class.isInstance(responseElement)) {
            SlomData data = ((SlomRequestIn) responseElement).getSlom();
            if (data.getCcmRef() == null || data.getCmRef() == null) {
                if (data.getCcmRef() == null) {
                    logger.warn(String.format("SLOM data incomplete for LO '%s'. No CCM specified.", loId));
                }
                if (data.getCmRef() == null) {
                    logger.warn(String.format("SLOM data incomplete for LO '%s'. No CM specified.", loId));
                }
                return null;
            }
            if (data.getCcmRef().size() <= 0 || data.getCmRef().size() <= 0) {
                if (data.getCcmRef().size() <= 0) {
                    logger.warn(String.format("SLOM data incomplete for LO '%s'. No CCM specified.", loId));
                }
                if (data.getCmRef().size() <= 0) {
                    logger.warn(String.format("SLOM data incomplete for LO '%s'. No CM specified.", loId));
                }
                return null;
            }
            if (data.getCcmRef().size() > 1 || data.getCmRef().size() > 1) {
                if (data.getCcmRef().size() <= 0) {
                    logger.warn(String.format("SLOM data inconclusive for LO '%s'. More than one CCM specified.", loId));
                }
                if (data.getCmRef().size() <= 0) {
                    logger.warn(String.format("SLOM data inconclusive for LO '%s'. More than one CM specified.", loId));
                }
                return null;
            }
            URL ccmUrl;
            try {
                ccmUrl = new URL(data.getCcmRef().get(0).getIri());
            } catch (MalformedURLException ex) {
                logger.error(String.format("Invalid URL given to load SLOM data from for LO '%s': %s", loId, data.getCcmRef().get(0).getIri()), ex);
                return null;
            }
            URL cmUrl;
            try {
                cmUrl = new URL(data.getCmRef().get(0).getIri());
            } catch (MalformedURLException ex) {
                logger.error(String.format("Invalid URL given to load SLOM data from for LO '%s': %s", loId, data.getCcmRef().get(0).getIri()), ex);
                return null;
            }
            return new SlomUrlRefContainer(ccmUrl, cmUrl);
        }
        return null;
    }
}
