/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Contributor: Kevin Fuchs, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2013-11-26
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmComInterface.runnables;

//import eu.intuitel.lpmComInterface.ComTest;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Class which handles user console inputs in a separate Thread.
 *
 * @author fhe
 */
public class UserInputHandler extends BaseHandler {

    private static final Logger logger = LoggerFactory.getLogger(UserInputHandler.class);
    private static final BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
    private boolean isShutdown = false;

    /**
     * Constructor
     *
     * @param sleepDuration Sleep duration between cycles
     * @param isDaemon Set true to make the handler run as a daemon thread
     */
    public UserInputHandler(long sleepDuration, boolean isDaemon) {
        super(sleepDuration, isDaemon);
    }

    @Override
    protected boolean whileLoop() {
        try {
            String command = br.readLine().trim();
            if ("shutdown".equalsIgnoreCase(command)) {
                isShutdown = true;
                return false;
            } else {
                logger.error("Unkown user command: " + command);
                return true;
            }
        } catch (IOException ex) {
            logger.error(String.format("Exception on reading console input in %s.", this.getClass().getSimpleName()), ex);
            return false;
        }
    }

    @Override
    protected void beforeShutdown() {
        try {
            br.close();
        } catch (IOException ex) {
            logger.error("Exception on closing console-reader.", ex);
        }
    }
    
    /**
     * @return Returns true if a shutdown was initiated by the user.
     */
    public boolean isShutdown() {
       return isShutdown; 
    }
}
