/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2013-11-26
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmComInterface.utils;

import java.lang.reflect.InvocationTargetException;

/**
 * Helper class for generics.
 *
 * @author fhe
 */
public class GenericsUtil {

    /**
     * Create a new instance of the given {@code targetClass} with the specified {@code params} and
     * returns it.
     *
     * @param <T> Target class
     * @param targetClass Class of the instance to be created
     * @param params Parameters to be used in the constructor
     * @return New Instance of target class
     * @throws java.lang.NoSuchMethodException 
     * @throws java.lang.InstantiationException 
     * @throws java.lang.IllegalAccessException 
     * @throws java.lang.reflect.InvocationTargetException 
     */
    public static <T> T createWithParameters(Class<T> targetClass, Object[] params)
            throws NoSuchMethodException, InstantiationException, IllegalAccessException, IllegalArgumentException, InvocationTargetException {
        Class[] paramClasses = new Class[params.length];
        for (int i = 0; i < params.length; i++) {
            paramClasses[i] = params[i].getClass();
        }
        return targetClass.getConstructor(paramClasses).newInstance(params);
    }
}
