/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2014-05-15
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmComInterface.wrappers;

import eu.intuitel.CommLayer.CommLibrary.LpmServiceConnection;
import eu.intuitel.comm.entities.exceptions.IntuitelException;
import eu.intuitel.comm.entities.lpm.ReflexOption;
import eu.intuitel.lpmComInterface.utils.UuidGenerator;
import eu.intuitel.lpmGeneralInterfaces.IEngineCommunicator.Option;
import java.util.ArrayList;
import java.util.List;

/**
 * Sends a message to the Engine containing a Reflex.
 *
 * @author fhe
 */
public class ReflexOut implements IOutgoingMsg {

    private final eu.intuitel.comm.entities.lpm.Reflex ITEM;
    private final String MID;

    /**
     * Creates a new reflex message to be send to the INTUITEL Engine.
     *
     * @param learnerId ID of the learner in scope
     * @param mId Message ID of the learner update message which triggered the processing
     * @param abortsRecom Reflex aborts the recommendation process
     * @param courseId ID of the course
     * @param options Options to be set in the reflex msg
     * @param reason Reason of the reflex
     */
    public ReflexOut(String learnerId, String mId, Boolean abortsRecom, String courseId, String reason, List<Option> options) {
        MID = mId;
        ITEM = new eu.intuitel.comm.entities.lpm.Reflex();
        ITEM.setmId(MID);
        ITEM.setuId(learnerId);
        ITEM.setAbortsRecom(abortsRecom);
        ITEM.setCourseId(courseId);
        ITEM.setReflexReason(reason);
        List<ReflexOption> reflexOptions = new ArrayList<>();
        for (Option option : options) {
            ReflexOption reflexOption = new ReflexOption();
            reflexOption.setName(option.getName());
            reflexOption.setValue(option.getValue());
            reflexOption.setTitle(option.getTitle());
            reflexOption.setDescription(option.getDescription());
            reflexOptions.add(reflexOption);
        }
        ITEM.setOptions(reflexOptions);
    }

    @Override
    public String getMID() {
        return MID;
    }

    @Override
    public void send(LpmServiceConnection service) throws IntuitelException {
        service.sendReflex(ITEM);
    }
}
