/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2014-05-16
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmComInterface.wrappers;

import eu.intuitel.comm.entities.lms.Data;
import eu.intuitel.comm.entities.lms.UseEnv;
import java.util.HashMap;
import java.util.Map;

/**
 * Wrapper class for USE environment request, incoming from the LMS.
 *
 * @author fhe
 */
public class UseEnvironmentIn implements IIncomingMsg {

    private final Map<String, String> DATA;
    private final String MID;

    /**
     * Constructor.
     *
     * @param receivedItem USE environment data received from the LMS
     */
    public UseEnvironmentIn(UseEnv receivedItem) {
        MID = receivedItem.getMId();
        Map<String, String> receivedData = new HashMap<>();
        for (Data dataItem : receivedItem.getData()) {
            receivedData.put(dataItem.getName(), dataItem.getValue());
        }
        DATA = receivedData;
    }

    @Override
    public String getMID() {
        return MID;
    }

    /**
     * Returns the received USE environment data as String-Map.
     *
     * @return Empty map if nothing was received-
     */
    public Map<String, String> getData() {
        return DATA;
    }
}
