/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2014-05-15
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmComInterface.wrappers;

import eu.intuitel.CommLayer.CommLibrary.LpmServiceConnection;
import eu.intuitel.comm.entities.exceptions.IntuitelException;
import eu.intuitel.comm.entities.lpm.Data;
import eu.intuitel.comm.entities.lpm.UseEnv;
import eu.intuitel.lpmComInterface.utils.UuidGenerator;
import java.util.ArrayList;
import java.util.List;

/**
 * Wrapper class for USE environment request, to be send to the LMS.
 *
 * @author fhe
 */
public class UseEnvironmentOut implements IOutgoingMsg {

    private final eu.intuitel.comm.entities.lpm.UseEnv ITEM;

    /**
     * Constructor.
     *
     * @param learnerId ID of the learner to get USE environment data for
     */
    public UseEnvironmentOut(String learnerId) {
        UseEnv item = new UseEnv();
        item.setMId(UuidGenerator.generateNewId());
        item.setUId(learnerId);
        item.getData().add(new Data());
        ITEM = item;
    }

    @Override
    public String getMID() {
        return ITEM.getMId();
    }

    @Override
    public void send(LpmServiceConnection service) throws IntuitelException {
        List<UseEnv> list = new ArrayList<>();
        list.add(ITEM);
        service.sendUSEEnvInfo(list);
    }
}
