/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2014-05-08
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmComInterface.wrappers;

import java.util.HashMap;
import java.util.Map;
import eu.intuitel.comm.entities.lms.*;

/**
 * Wrapper class for USE performance request, incoming from the LMS.
 *
 * @author fhe
 */
public class UsePerformanceIn implements IIncomingMsg {

    private final UsePerf response;

    /**
     * Constructor.
     *
     * @param response Response received by the LPM.
     */
    public UsePerformanceIn(UsePerf response) {
        this.response = response;
    }

    @Override
    public String getMID() {
        return response.getMId();
    }

    /**
     * Returns the data received as a nested map, containing the learnerIds in the first level and
     * the scores in the contained map.
     *
     * @return Empty Map if nothing was received.
     */
    public Map<String, Map<String, String>> getData() {
        Map<String, Map<String, String>> useData = new HashMap<>();
        for (UsePerf.LoPerf loPerf : response.getLoPerf()) {
            Map<String, String> scoreData = new HashMap<>();
            for (ScoreType score : loPerf.getScore()) {
                scoreData.put(score.getType(), score.getValue());
            }
            useData.put(loPerf.getLoId(), scoreData);
        }
        return useData;
    }
}
