/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2014-05-08
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmComInterface.wrappers;

import eu.intuitel.CommLayer.CommLibrary.LpmServiceConnection;
import eu.intuitel.comm.entities.exceptions.IntuitelException;
import eu.intuitel.comm.entities.lpm.UsePerf;
import eu.intuitel.lpmComInterface.utils.UuidGenerator;

/**
 * Wrapper class for USE performance request, to be send to the LMS.
 *
 * @author fhe
 */
public class UsePerformanceOut implements IOutgoingMsg {

    private final eu.intuitel.comm.entities.lpm.UsePerf ITEM;

    /**
     * Constructor.
     *
     * @param learnerId Learner for whom the USE request will be send
     */
    public UsePerformanceOut(String learnerId) {
        UsePerf item = new UsePerf();
        item.setMId(UuidGenerator.generateNewId());
        item.setUId(learnerId);
        ITEM = item;
    }

    /**
     * Constructor. USE Performance for specific LOs.
     *
     * @param learnerId Learner for whom the USE request will be send.
     * @param loIds IDs of LOs to request USE data for
     */
    public UsePerformanceOut(String learnerId, String[] loIds) {
        UsePerf item = new UsePerf();
        item.setMId(UuidGenerator.generateNewId());
        item.setUId(learnerId);
        for (String loId : loIds) {
            UsePerf.LoPerf loPerf = new UsePerf.LoPerf();
            loPerf.setLoId(loId);
            item.getLoPerf().add(loPerf);
        }
        ITEM = item;
    }

    @Override
    public String getMID() {
        return ITEM.getMId();
    }

    @Override
    public void send(LpmServiceConnection service) throws IntuitelException {
        service.sendUSEPerfInfo(ITEM);
    }
}
