/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2014-05-06
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmComInterface.utils;

import org.junit.Test;
import static org.junit.Assert.*;
import org.junit.Before;

/**
 * Tests for the command line parser.
 *
 * @author fhe
 */
public class CmdParserTest {

    public CmdParser cmd;
    public static final String validCmdLine;
    public static final String[] validCmdLineArgs;

    static {
        validCmdLine = "-clAddress http://95.211.177.222/IntuitelCommunicationManager/CommunicationManagerService.svc/rest "
                + "-slomRepoAddress ./src/test/resources/slomTestRepository/valid "
                + "-lpmAddress http://localhost:8080/lpm "
                + "-test";
        validCmdLineArgs = validCmdLine.split(" ");
    }

    @Before
    public void setUp() {
        cmd = new CmdParser();
    }

    @Test
    public void testValidArguments() {
        assertTrue("Valid cmdArgs have been rejected.", cmd.parseCmdLine(validCmdLineArgs));
        assertEquals("clAddress parsed unsuccessfully.", validCmdLineArgs[1], cmd.getComLayerAddress().toString());
        assertEquals("slomRepoAddress parsed unsuccessfully.", validCmdLineArgs[3], cmd.getSlomRepoAddress().toString().replace("\\", "/"));
        assertEquals("lpmAddress parsed unsuccessfully.", validCmdLineArgs[5], cmd.getLpmAddress().toString());
        assertTrue("test parsed unsuccessfully.", cmd.isTestMode());
    }

    @Test
    public void testHelpArgument() {
        assertTrue("Help command in cmdLine was not parsed successfully.", cmd.parseCmdLine("-help".split(" ")));
        assertTrue("test parsed unsuccessfully.", cmd.isHelpMode());
    }

    @Test
    public void testInvalidArguments() {
        assertFalse("Invalid cmdline parsed successfully.", cmd.parseCmdLine("foobar".split(" ")));
        assertFalse("Invalid cmdline parsed successfully.", cmd.parseCmdLine("-clAddress -test".split(" ")));
        assertFalse("Invalid cmdline parsed successfully.", cmd.parseCmdLine("-clAddress -dbAddress -dbUser -dbPsw".split(" ")));
    }
}