/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2014-06-25
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmComInterface.wrappers;

import eu.intuitel.comm.entities.exceptions.IntuitelException;
import eu.intuitel.comm.entities.lpm.INTUITEL;
import eu.intuitel.comm.entities.lpm.LearnerState;
import eu.intuitel.comm.entities.lpm.LearnerStateOntology;
import java.io.StringWriter;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Marshaller;
import org.apache.commons.lang.StringUtils;
import org.junit.Test;
import static org.junit.Assert.*;
import org.w3c.dom.Element;

/**
 * Test for the LsoOut message to see whether the data is created correctly.
 *
 * @author Florian Heberle
 */
public class LsoOutTest {

    @Test
    public void testConstructor() {
        try {
            String mId = "0";
            String lId = "1";
            String cId = "2";
            boolean ccmUpdate = true;
            boolean cmUpdate = true;
            LsoOut msg = new LsoOut(mId, lId, cId, ccmUpdate, cmUpdate, lsoExample);
            assertNotNull("Created message was null.", msg);
        } catch (Exception ex) {
            assertNull(ex.getClass().getName() + ": " + ex.getMessage(), ex);
        }
    }

    //Test only for debugging
    //@Test
    public void testDeserializing() {
        try {
            eu.intuitel.comm.entities.lpm.LearnerStateOntology lsoObj = LsoOut.getLsoObj(lsoExample);

            eu.intuitel.comm.entities.lpm.INTUITEL preIntui = new eu.intuitel.comm.entities.lpm.INTUITEL();
            eu.intuitel.comm.entities.lpm.LearnerState preLs = new eu.intuitel.comm.entities.lpm.LearnerState();
            preLs.setLearnerStateOntology(lsoObj);
            preIntui.setLearnerState(Arrays.asList(preLs));

            String serializationRes = eu.intuitel.CommLayer.CommLibrary.SerializationHelper.serialize(preIntui);

            eu.intuitel.comm.entities.lpm.INTUITEL postIntui = Helper.help(serializationRes);
            eu.intuitel.comm.entities.lpm.LearnerState postLs = postIntui.getLearnerState().get(0);
            LearnerStateOntology postLso = postLs.getLearnerStateOntology();

            java.io.StringWriter writer = new java.io.StringWriter();
            javax.xml.transform.Transformer transformer = javax.xml.transform.TransformerFactory.newInstance().newTransformer();
            transformer.transform(new javax.xml.transform.dom.DOMSource(postLso.getContent().get(0)), new javax.xml.transform.stream.StreamResult(writer));
            String xml = writer.toString();

            assertEquals(lsoExample, xml);
        } catch (javax.xml.transform.TransformerConfigurationException ex) {
            assertEquals(null, ex);
        } catch (javax.xml.transform.TransformerException | IntuitelException ex) {
            assertEquals(null, ex);
        }
//        //For debugging:
//        try {
//            java.io.StringWriter writer = new java.io.StringWriter();
//            javax.xml.transform.Transformer transformer = javax.xml.transform.TransformerFactory.newInstance().newTransformer();
//            transformer.transform(new javax.xml.transform.dom.DOMSource(contentElement), new javax.xml.transform.stream.StreamResult(writer));
//            String xml = writer.toString();
//        } catch (javax.xml.transform.TransformerConfigurationException ex) {
//            java.util.logging.Logger.getLogger(LsoOut.class.getName()).log(Level.SEVERE, null, ex);
//        } catch (javax.xml.transform.TransformerException ex) {
//            java.util.logging.Logger.getLogger(LsoOut.class.getName()).log(Level.SEVERE, null, ex);
//        }
    }

    static class Helper extends eu.intuitel.CommLayer.CommLibrary.SerializationHelper {

        //To access the protected deserializing method
        public static eu.intuitel.comm.entities.lpm.INTUITEL help(String value) throws IntuitelException {
            return deserialize(value, eu.intuitel.comm.entities.lpm.INTUITEL.class, eu.intuitel.comm.entities.lpm.INTUITEL.NAMESPACE);
        }
    };

    @Test
    public void testSerializing() {
        try {
            LearnerState ls = new LearnerState();
            ls.setmId("0");
            ls.setuId("1");
            ls.setCourseId("2");
            ls.setCcmUpdateNeeded(true);
            ls.setCmUpdateNeeded(true);
            ls.setLearnerStateOntology(LsoOut.getLsoObj(lsoExample));
            List<LearnerState> lsList = new ArrayList<>();
            lsList.add(ls);
            //Serialize data as it is being done in the CL API.
            INTUITEL intuitel = new INTUITEL();
            intuitel.setLearnerState(lsList);
            JAXBContext context = JAXBContext.newInstance(INTUITEL.class);
            Marshaller marshaller = context.createMarshaller();
            StringWriter stringWriter = new StringWriter();
            marshaller.marshal(intuitel, stringWriter);
            assertFalse("Output was empty.", StringUtils.isBlank(stringWriter.toString()));
        } catch (JAXBException ex) {
            assertNull(ex.getClass().getName() + ": " + ex.getMessage(), ex);
        }
    }

    @Test
    public void testConversion() {
        Element e = LsoOut.getElementFromString(lsoExample);
        assertNotNull("Element was null.", e);
    }

    private static final String lsoExample = "<?xml version=\"1.0\"?>\n"
            + "<rdf:RDF xmlns=\"http://www.intuitel.eu/lsos/0.owl\"\n"
            + "     xml:base=\"http://www.intuitel.eu/lsos/0.owl\"\n"
            + "     xmlns:rdfs=\"http://www.w3.org/2000/01/rdf-schema#\"\n"
            + "     xmlns:intui_LMO=\"http://www.intuitel.eu/public/intui_LM.owl#\"\n"
            + "     xmlns:owl=\"http://www.w3.org/2002/07/owl#\"\n"
            + "     xmlns:xsd=\"http://www.w3.org/2001/XMLSchema#\"\n"
            + "     xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\"\n"
            + "     xmlns:intui_PO=\"http://www.intuitel.eu/public/intui_PO.owl#\">\n"
            + "    <owl:Ontology rdf:about=\"http://www.intuitel.eu/lsos/0.owl\"/>\n"
            + "    \n"
            + "\n"
            + "\n"
            + "    <!-- \n"
            + "    ///////////////////////////////////////////////////////////////////////////////////////\n"
            + "    //\n"
            + "    // Object Properties\n"
            + "    //\n"
            + "    ///////////////////////////////////////////////////////////////////////////////////////\n"
            + "     -->\n"
            + "\n"
            + "    \n"
            + "\n"
            + "\n"
            + "    <!-- http://www.intuitel.eu/public/intui_LM.owl#hasDidacticFactorValue -->\n"
            + "\n"
            + "    <owl:ObjectProperty rdf:about=\"http://www.intuitel.eu/public/intui_LM.owl#hasDidacticFactorValue\"/>\n"
            + "    \n"
            + "\n"
            + "\n"
            + "    <!-- \n"
            + "    ///////////////////////////////////////////////////////////////////////////////////////\n"
            + "    //\n"
            + "    // Classes\n"
            + "    //\n"
            + "    ///////////////////////////////////////////////////////////////////////////////////////\n"
            + "     -->\n"
            + "\n"
            + "    \n"
            + "\n"
            + "\n"
            + "    <!-- http://www.intuitel.eu/public/intui_LM.owl#CurrentLearningPathway -->\n"
            + "\n"
            + "    <owl:Class rdf:about=\"http://www.intuitel.eu/public/intui_LM.owl#CurrentLearningPathway\"/>\n"
            + "    \n"
            + "\n"
            + "\n"
            + "    <!-- http://www.intuitel.eu/public/intui_LM.owl#CurrentLo -->\n"
            + "\n"
            + "    <owl:Class rdf:about=\"http://www.intuitel.eu/public/intui_LM.owl#CurrentLo\"/>\n"
            + "    \n"
            + "\n"
            + "\n"
            + "    <!-- http://www.intuitel.eu/public/intui_LM.owl#LearnerState -->\n"
            + "\n"
            + "    <owl:Class rdf:about=\"http://www.intuitel.eu/public/intui_LM.owl#LearnerState\"/>\n"
            + "    \n"
            + "\n"
            + "\n"
            + "    <!-- http://www.intuitel.eu/public/intui_LM.owl#UnseenLo -->\n"
            + "\n"
            + "    <owl:Class rdf:about=\"http://www.intuitel.eu/public/intui_LM.owl#UnseenLo\"/>\n"
            + "    \n"
            + "\n"
            + "\n"
            + "    <!-- http://www.intuitel.eu/public/testcase01/intui_CCM.owl#HasMicroLpRelation1 -->\n"
            + "\n"
            + "    <owl:Class rdf:about=\"http://www.intuitel.eu/public/testcase01/intui_CCM.owl#HasMicroLpRelation1\">\n"
            + "        <rdfs:subClassOf rdf:resource=\"http://www.intuitel.eu/public/intui_LM.owl#CurrentLearningPathway\"/>\n"
            + "    </owl:Class>\n"
            + "    \n"
            + "\n"
            + "\n"
            + "    <!-- http://www.intuitel.eu/public/testcase01/intui_CM.owl#HasMacroLpRelation1 -->\n"
            + "\n"
            + "    <owl:Class rdf:about=\"http://www.intuitel.eu/public/testcase01/intui_CM.owl#HasMacroLpRelation1\">\n"
            + "        <rdfs:subClassOf rdf:resource=\"http://www.intuitel.eu/public/intui_LM.owl#CurrentLearningPathway\"/>\n"
            + "    </owl:Class>\n"
            + "    \n"
            + "\n"
            + "\n"
            + "    <!-- \n"
            + "    ///////////////////////////////////////////////////////////////////////////////////////\n"
            + "    //\n"
            + "    // Individuals\n"
            + "    //\n"
            + "    ///////////////////////////////////////////////////////////////////////////////////////\n"
            + "     -->\n"
            + "\n"
            + "    \n"
            + "\n"
            + "\n"
            + "    <!-- http://www.intuitel.eu/public/intui_LM.owl#dfConnectivity_Good -->\n"
            + "\n"
            + "    <owl:NamedIndividual rdf:about=\"http://www.intuitel.eu/public/intui_LM.owl#dfConnectivity_Good\"/>\n"
            + "    \n"
            + "\n"
            + "\n"
            + "    <!-- http://www.intuitel.eu/public/intui_LM.owl#dfDifficultyLevel_Beginner -->\n"
            + "\n"
            + "    <owl:NamedIndividual rdf:about=\"http://www.intuitel.eu/public/intui_LM.owl#dfDifficultyLevel_Beginner\"/>\n"
            + "    \n"
            + "\n"
            + "\n"
            + "    <!-- http://www.intuitel.eu/public/intui_LM.owl#dfGender_Female -->\n"
            + "\n"
            + "    <owl:NamedIndividual rdf:about=\"http://www.intuitel.eu/public/intui_LM.owl#dfGender_Female\"/>\n"
            + "    \n"
            + "\n"
            + "\n"
            + "    <!-- http://www.intuitel.eu/public/intui_LM.owl#dfSpokenLanguage_English -->\n"
            + "\n"
            + "    <owl:NamedIndividual rdf:about=\"http://www.intuitel.eu/public/intui_LM.owl#dfSpokenLanguage_English\"/>\n"
            + "    \n"
            + "\n"
            + "\n"
            + "    <!-- http://www.intuitel.eu/public/intui_LM.owl#dfSpokenLanguage_German -->\n"
            + "\n"
            + "    <owl:NamedIndividual rdf:about=\"http://www.intuitel.eu/public/intui_LM.owl#dfSpokenLanguage_German\"/>\n"
            + "    \n"
            + "\n"
            + "\n"
            + "    <!-- http://www.intuitel.eu/public/intui_LM.owl#learnerState -->\n"
            + "\n"
            + "    <owl:NamedIndividual rdf:about=\"http://www.intuitel.eu/public/intui_LM.owl#learnerState\">\n"
            + "        <rdf:type rdf:resource=\"http://www.intuitel.eu/public/intui_LM.owl#LearnerState\"/>\n"
            + "        <intui_LMO:hasDidacticFactorValue rdf:resource=\"http://www.intuitel.eu/public/intui_LM.owl#dfConnectivity_Good\"/>\n"
            + "        <intui_LMO:hasDidacticFactorValue rdf:resource=\"http://www.intuitel.eu/public/intui_LM.owl#dfDifficultyLevel_Beginner\"/>\n"
            + "        <intui_LMO:hasDidacticFactorValue rdf:resource=\"http://www.intuitel.eu/public/intui_LM.owl#dfGender_Female\"/>\n"
            + "        <intui_LMO:hasDidacticFactorValue rdf:resource=\"http://www.intuitel.eu/public/intui_LM.owl#dfSpokenLanguage_English\"/>\n"
            + "        <intui_LMO:hasDidacticFactorValue rdf:resource=\"http://www.intuitel.eu/public/intui_LM.owl#dfSpokenLanguage_German\"/>\n"
            + "    </owl:NamedIndividual>\n"
            + "    \n"
            + "\n"
            + "\n"
            + "    <!-- http://www.intuitel.eu/public/testcase01/intui_CCM.owl#Ko01 -->\n"
            + "\n"
            + "    <owl:NamedIndividual rdf:about=\"http://www.intuitel.eu/public/testcase01/intui_CCM.owl#Ko01\">\n"
            + "        <rdf:type rdf:resource=\"http://www.intuitel.eu/public/intui_LM.owl#CurrentLo\"/>\n"
            + "        <rdf:type rdf:resource=\"http://www.intuitel.eu/public/intui_LM.owl#UnseenLo\"/>\n"
            + "    </owl:NamedIndividual>\n"
            + "    \n"
            + "\n"
            + "\n"
            + "    <!-- http://www.intuitel.eu/public/testcase01/intui_CCM.owl#Ko02 -->\n"
            + "\n"
            + "    <owl:NamedIndividual rdf:about=\"http://www.intuitel.eu/public/testcase01/intui_CCM.owl#Ko02\">\n"
            + "        <rdf:type rdf:resource=\"http://www.intuitel.eu/public/intui_LM.owl#UnseenLo\"/>\n"
            + "    </owl:NamedIndividual>\n"
            + "    \n"
            + "\n"
            + "\n"
            + "    <!-- http://www.intuitel.eu/public/testcase01/intui_CCM.owl#Ko03 -->\n"
            + "\n"
            + "    <owl:NamedIndividual rdf:about=\"http://www.intuitel.eu/public/testcase01/intui_CCM.owl#Ko03\">\n"
            + "        <rdf:type rdf:resource=\"http://www.intuitel.eu/public/intui_LM.owl#UnseenLo\"/>\n"
            + "    </owl:NamedIndividual>\n"
            + "    \n"
            + "\n"
            + "\n"
            + "    <!-- http://www.intuitel.eu/public/testcase01/intui_CCM.owl#Ko04 -->\n"
            + "\n"
            + "    <owl:NamedIndividual rdf:about=\"http://www.intuitel.eu/public/testcase01/intui_CCM.owl#Ko04\">\n"
            + "        <rdf:type rdf:resource=\"http://www.intuitel.eu/public/intui_LM.owl#UnseenLo\"/>\n"
            + "    </owl:NamedIndividual>\n"
            + "    \n"
            + "\n"
            + "\n"
            + "    <!-- http://www.intuitel.eu/public/testcase01/intui_CM.owl#Cc01 -->\n"
            + "\n"
            + "    <owl:NamedIndividual rdf:about=\"http://www.intuitel.eu/public/testcase01/intui_CM.owl#Cc01\">\n"
            + "        <rdf:type rdf:resource=\"http://www.intuitel.eu/public/intui_LM.owl#CurrentLo\"/>\n"
            + "        <rdf:type rdf:resource=\"http://www.intuitel.eu/public/intui_LM.owl#UnseenLo\"/>\n"
            + "    </owl:NamedIndividual>\n"
            + "    \n"
            + "\n"
            + "\n"
            + "    <!-- http://www.intuitel.eu/public/testcase01/intui_CM.owl#Cc02 -->\n"
            + "\n"
            + "    <owl:NamedIndividual rdf:about=\"http://www.intuitel.eu/public/testcase01/intui_CM.owl#Cc02\">\n"
            + "        <rdf:type rdf:resource=\"http://www.intuitel.eu/public/intui_LM.owl#UnseenLo\"/>\n"
            + "    </owl:NamedIndividual>\n"
            + "    \n"
            + "\n"
            + "\n"
            + "    <!-- http://www.intuitel.eu/public/testcase01/intui_CM.owl#Cc03 -->\n"
            + "\n"
            + "    <owl:NamedIndividual rdf:about=\"http://www.intuitel.eu/public/testcase01/intui_CM.owl#Cc03\">\n"
            + "        <rdf:type rdf:resource=\"http://www.intuitel.eu/public/intui_LM.owl#UnseenLo\"/>\n"
            + "    </owl:NamedIndividual>\n"
            + "</rdf:RDF>\n"
            + "\n"
            + "\n"
            + "\n"
            + "<!-- Generated by the OWL API (version 3.4.5-SNAPSHOT) http://owlapi.sourceforge.net -->\n"
            + "";
}
