/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2014-05-12
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmGeneralInterfaces;

import java.util.List;

/**
 * Base Interface for communicators for interaction with the INTUITEL Engine.
 *
 * @author fhe
 */
public interface IEngineCommunicator {

    /**
     * Sends the INTUITEL Engine a reflex message.
     * 
     * @param learnerId ID of the learner
     * @param mId The message ID of the learner update which started this preprocessing job
     * @param abortsRecom The reflex aborts the recommendation process
     * @param courseId ID of the course that the learner is currently learning 
     * @param reason Reason of the reflex
     * @param options Options encoding the reflex data
     */
    public void sendReflex(String learnerId, String mId, Boolean abortsRecom, String courseId, String reason, List<Option> options);

    /**
     * Helper class to encapsulate reflex data.
     */
    public class Option {

        private final String NAME;
        private final String VALUE;
        private final String TITLE;
        private final String DESCRIPTION;

        /**
         * Constructor.
         *
         * @param name Name of the data item
         * @param value Value of the data item
         * @param title Short description of the data item
         * @param description Long description of the data item
         */
        public Option(String name, String value, String title, String description) {
            NAME = name;
            VALUE = value;
            TITLE = title;
            DESCRIPTION = description;
        }

        /**
         * @return Name of the data item.
         */
        public String getName() {
            return NAME;
        }

        /**
         * @return Value of the data item.
         */
        public String getValue() {
            return VALUE;
        }

        /**
         * @return Short description of the data item.
         */
        public String getTitle() {
            return TITLE;
        }

        /**
         * @return Long description of the data item.
         */
        public String getDescription() {
            return DESCRIPTION;
        }
    }

    /**
     * Sends the INTUITEL Engine a Learner-State-Ontology as result of a preprocessing process.
     *
     * @param mId ID of the learner update which lead to this LSO
     * @param lId ID of the learner to whom the LSO belongs
     * @param cId ID of the course in scope
     * @param ccmUpdateNeeded Flag indicating for the Engine that the CCM has changed
     * @param cmUpdateNeeded Flag indicating for the Engine that the CM has changed
     * @param lso Learner State Ontology to be send
     */
    public void sendLso(String mId, String lId, String cId, boolean ccmUpdateNeeded, boolean cmUpdateNeeded, String lso);
}
