/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2014-05-12
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmGeneralInterfaces;

import java.util.Map;

/**
 * Base Interface for communicators for interaction with the LMS.
 *
 * @author fhe
 */
public interface ILmsCommunicator {

    /**
     * Requests and receives the LMS profile as Map of data-value-pairs.
     *
     * @return The received LMS profile information.
     */
    public Map<String, String> getLmsProfile();

    /**
     * Sends a learner update request to the LMS.
     */
    public void sendLearnerUpdate();

    /**
     * Requests and receives the USE performance data for the given learner as key-value-pairs.
     *
     * @param learnerId ID of the learner in scope
     * @return Empty Map in case of error.
     */
    public Map<String, Map<String, String>> getUsePerformanceData(String learnerId);

    /**
     * Requests and receives the USE performance data for the given learner as key-value-pairs.
     *
     * @param learnerId ID of the learner in scope
     * @param loIds LoIDs of KOs to specifically request in this USE request
     * @return Empty Map in case of error.
     */
    public Map<String, Map<String, String>> getUsePerformanceData(String learnerId, String... loIds);

    /**
     * Requests and receives the USE environment data for the given learner as key-value-pairs.
     *
     * @param learnerId ID of the learner in scope
     * @return Empty Map in case of error.
     */
    public Map<String, String> getUseEnvironmentData(String learnerId);
}
