/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2014-05-12
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmGeneralInterfaces;

import java.io.File;
import java.net.URL;

/**
 * Base Interface for communicators for interaction with the SLOM repository.
 *
 * @author fhe
 */
public interface ISlomCommunicator {

    /**
     * Returns a two dimensional String array containing the serialized CCM at index 0 and the
     * serialized CM at index [1], representing the SLOM data of the Learning Object with the
     * specified {@code loId}.
     *
     * @param loId ID of the Learning Object which is currently in scope
     * @return Null on error or if no SLOM data found for the specified {@code loId}
     */
    public ISlomRefContainer getSlomDataForLo(String loId);
    
    /**
     * Interface for SLOM reference containers.
     */
    public interface ISlomRefContainer { }
    
    /**
     * Helper class to store SLOM URL data.
     */
    public class SlomUrlRefContainer implements ISlomRefContainer {
        
        private final URL CCMURL;
        private final URL CMURL;
        
        /**
         * Constructor.
         * 
         * @param ccmUrl URL of the CCM in scope
         * @param cmUrl URL of the CM in scope
         */
        public SlomUrlRefContainer(URL ccmUrl, URL cmUrl) {
            CCMURL = ccmUrl;
            CMURL = cmUrl;
        }

        /**
         * @return URL of the CCM in scope
         */
        public URL getCcmUrl() {
            return CCMURL;
        }

        /**
         * @return URL of the CM in scope
         */
        public URL getCmUrl() {
            return CMURL;
        }
    }
    
    /**
     * Helper class to store SLOM File data.
     */
    public class SlomFileRefContainer implements ISlomRefContainer {
        
        private final File CCMFILE;
        private final File CMFILE;
        
        /**
         * Constructor.
         * 
         * @param ccmFile File of the CCM in scope
         * @param cmFile File of the CM in scope
         */
        public SlomFileRefContainer(File ccmFile, File cmFile) {
            CCMFILE = ccmFile;
            CMFILE = cmFile;
        }

        /**
         * @return File of the CCM in scope
         */
        public File getCcmFile() {
            return CCMFILE;
        }

        /**
         * @return File of the CM in scope
         */
        public File getCmFile() {
            return CMFILE;
        }
    }
}
