package eu.intuitel.types;

/**
 * Author: Ovidiu Serban, o.serban@reading.ac.uk.
 * Version: 1, 25/06/2014
 * Created at Intelligent System Research Laboratory,
 * University of Reading, United Kingdom
 * web: http://www.isr.reading.ac.uk/
 * Copyright may apply to this file
 */
public enum DifficultyLevel {
    Beginner(1, "dfDifficultyLevel_Beginner"),
    Intermediate(2, "dfDifficultyLevel_Intermediate"),
    Advanced(3, "dfDifficultyLevel_Advanced"),
    Unknown(0, "");

    public static final DifficultyLevel DEFAULT = Intermediate;

    private int level;
    private String dfValue;

    DifficultyLevel(int level, String dfValue) {
        this.level = level;
        this.dfValue = dfValue;
    }

    public int getLevel() {
        return level;
    }

    public String getDfValue() {
        return dfValue;
    }

    public static DifficultyLevel getLevel(int level) {
        switch (level) {
            case 1:
                return Beginner;
            case 2:
                return Intermediate;
            case 3:
                return Advanced;
            default:
                return Unknown;
        }
    }

    public static DifficultyLevel getLevel(String dfValue) {
        if (dfValue == null) {
            return Unknown;
        } else {
            dfValue = dfValue.trim();
            switch (dfValue) {
                case "dfDifficultyLevel_Beginner":
                    return Beginner;
                case "dfDifficultyLevel_Intermediate":
                    return Intermediate;
                case "dfDifficultyLevel_Advanced":
                    return Advanced;
                default:
                    return Unknown;
            }
        }
    }

    public static DifficultyLevel increase(DifficultyLevel level) {
        switch (level) {
            case Beginner:
                return Intermediate;
            case Intermediate:
            case Advanced:
                return Advanced;
            default:
                return DEFAULT;
        }
    }

    public static DifficultyLevel decrease(DifficultyLevel level) {
        switch (level) {
            case Intermediate:
            case Beginner:
                return Beginner;
            case Advanced:
                return Intermediate;
            default:
                return DEFAULT;
        }
    }
}