package eu.intuitel.types;

import java.util.Arrays;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * Author: Ovidiu Serban, o.serban@reading.ac.uk.
 * Version: 1, 25/06/2014
 * Created at Intelligent System Research Laboratory,
 * University of Reading, United Kingdom
 * web: http://www.isr.reading.ac.uk/
 * Copyright may apply to this file
 */
public enum Gender {
    Male("male", "dfGender_Male", Arrays.asList("m")),
    Female("female", "dfGender_Female", Arrays.asList("f")),
    Other("other", "dfGender_Other", Arrays.asList("o")),
    Unknown("none", "", Arrays.asList("n"));

    private String label;
    private String dfValue;
    private Set<String> alternativeValues;

    Gender(String label, String dfValue, List<String> alternativeLabels) {
        this.label = label;
        this.dfValue = dfValue;
        this.alternativeValues = new HashSet<>(alternativeLabels);
        this.alternativeValues.add(label);
    }

    public String getLabel() {
        return label;
    }

    public String getDfValue() {
        return dfValue;
    }

    public static Gender getGender(String value) {
        if (value == null) {
            return Unknown;
        }
        value = value.trim();
        if (value.length() == 0) {
            return Unknown;
        }

        for (Gender gender : values()) {
            if (gender.label.equalsIgnoreCase(value) || gender.dfValue.equalsIgnoreCase(value)
                || gender.alternativeValues.contains(value)) {
                return gender;
            }
        }
        return Unknown;
    }
}