/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2014-04-03
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor;

import eu.intuitel.lpmProcessor.models.factories.LearningModelOntologyFactory;
import eu.intuitel.lpmProcessor.models.factories.PedagogicalOntologyFactory;
import eu.intuitel.lpmProcessor.models.owlWrapper.ontologies.LearningModelOntology;
import eu.intuitel.lpmProcessor.models.owlWrapper.ontologies.PedagogicalOntology;
import org.semanticweb.owlapi.apibinding.OWLManager;
import org.semanticweb.owlapi.model.OWLDataFactory;
import org.semanticweb.owlapi.model.OWLOntologyManager;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Central entity to manage the INTUITEL ontologies in the LPM.
 *
 * @author fhe
 */
public final class OntoMngr {

    private static final Logger logger = LoggerFactory.getLogger(LearningModelOntologyFactory.class);
    /**
     * Central ontology manager for working with ontologies.
     */
    public static final OWLOntologyManager MANAGER;
    /**
     * Central data factory for creating statements and OWL objects.
     */
    public static final OWLDataFactory DATAFAC;
    /**
     * Representation of the PO.
     */
    public static final PedagogicalOntology PO;
    /**
     * Representation of the LMO.
     */
    public static final LearningModelOntology LMO;

    static {
        OWLOntologyManager manager = null;
        OWLDataFactory dataFac = null;
        try {
            manager = OWLManager.createOWLOntologyManager();
            dataFac = manager.getOWLDataFactory();
        } catch (Exception ex) {
            logger.error("Exception during initialization of OWL toolset.", ex);
        }
        MANAGER = manager;
        DATAFAC = dataFac;

        PedagogicalOntology po = null;
        try {
            logger.debug("Loading PO");
            po = PedagogicalOntologyFactory.createNewInstance(MANAGER);
            logger.debug(String.format("Loaded PO, version '%s'.", po.getVersion()));
        } catch (Exception ex) {
            logger.error("Exception during initialization of PO.", ex);
        }
        PO = po;

        LearningModelOntology lmo = null;
        try {
            logger.debug("Loading LMO");
            lmo = LearningModelOntologyFactory.createNewInstance(MANAGER);
            logger.debug(String.format("Loaded LMO, version '%s'.", lmo.getVersion()));
        } catch (Exception ex) {
            logger.error("Exception during initialization of LMO.", ex);
        }
        LMO = lmo;
    }
}
