/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Contributor: Ovidiu Serban, University of Reading, www.isr.reading.ac.uk
 * Version: [0.01]
 * Date: 2013-11-05
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.didacticFactors;

import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.utils.DbAccessUtil;
import org.semanticweb.owlapi.model.OWLNamedIndividual;

import java.util.Collection;
import java.util.HashSet;

/**
 * DF Age
 * Categorization of the age group of the learner.
 *
 * @author fhe
 */
public class DfAge extends DidacticFactor {

    private static final String SENIOR = "dfAge_Senior";
    private static final String ADULT = "dfAge_Adult";
    private static final String ADOLESCENT = "dfAge_Adolescent";
    private static final String KID = "dfAge_Kid";
    private static final String CHILD = "dfAge_Child";
    private static final String BABY = "dfAge_Baby";

    /**
     * Constructor
     *
     * @param loadedIndividuals Collection of loaded DF-Individuals.
     * @throws NullPointerException Thrown when loadedIndividuals is null
     * @throws IllegalArgumentException Thrown when loadedIndividuals is empty or if there is a
     * mismatch with the expected DF-individuals.
     */
    public DfAge(Collection<OWLNamedIndividual> loadedIndividuals)
            throws NullPointerException, IllegalArgumentException {
        super(loadedIndividuals);
    }

    @Override
    protected Collection<String> getExpectedIndividualFragments() {
        Collection<String> fragments = new HashSet<>();
        fragments.add(SENIOR);
        fragments.add(ADULT);
        fragments.add(ADOLESCENT);
        fragments.add(KID);
        fragments.add(CHILD);
        fragments.add(BABY);
        return fragments;
    }

    @Override
    public OWLNamedIndividual[] getDfIndividuals(SlomMetadata slom, DbAccessUtil db) {
        Integer learnerAge = db.getLearnerAge();
        if (learnerAge == null) {
            return null;
        } else if (learnerAge > 65) {
            return new OWLNamedIndividual[]{individualsMap.get(SENIOR)};
        } else if (learnerAge > 18) {
            return new OWLNamedIndividual[]{individualsMap.get(ADULT)};
        } else if (learnerAge > 14) {
            return new OWLNamedIndividual[]{individualsMap.get(ADOLESCENT)};
        } else if (learnerAge > 6) {
            return new OWLNamedIndividual[]{individualsMap.get(KID)};
        } else if (learnerAge > 3) {
            return new OWLNamedIndividual[]{individualsMap.get(CHILD)};
        } else {
            return new OWLNamedIndividual[]{individualsMap.get(BABY)};
        }
    }
}
