/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Contributor: Ovidiu Serban, University of Reading, www.isr.reading.ac.uk
 * Version: [0.01]
 * Date: 2013-11-05
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.didacticFactors;

import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.utils.DbAccessUtil;
import org.semanticweb.owlapi.model.OWLNamedIndividual;

import java.util.Collection;
import java.util.HashSet;

/**
 * DF battery level
 * Statement about the current battery level of the device the learner uses for learning.
 *
 * @author fhe
 */
public class DfBattery extends DidacticFactor {

    private static final String OK = "dfBattery_OK";
    private static final String LOW = "dfBattery_Low";
    private static final String VERYLOW = "dfBattery_VeryLow";

    /**
     * Constructor
     *
     * @param loadedIndividuals Collection of loaded DF-Individuals.
     * @throws NullPointerException Thrown when loadedIndividuals is null
     * @throws IllegalArgumentException Thrown when loadedIndividuals is empty or if there is a
     * mismatch with the expected DF-individuals.
     */
    public DfBattery(Collection<OWLNamedIndividual> loadedIndividuals)
            throws NullPointerException, IllegalArgumentException {
        super(loadedIndividuals);
    }

    @Override
    protected Collection<String> getExpectedIndividualFragments() {
        Collection<String> fragments = new HashSet<>();
        fragments.add(OK);
        fragments.add(LOW);
        fragments.add(VERYLOW);
        return fragments;
    }

    @Override
    public OWLNamedIndividual[] getDfIndividuals(SlomMetadata slom, DbAccessUtil db) {
        Integer status = db.getBatteryLevel();
        if (status == null) {
            return null;
        } else if (status > 20) {
            return new OWLNamedIndividual[]{individualsMap.get(OK)};
        } else if (status > 10) {
            return new OWLNamedIndividual[]{individualsMap.get(LOW)};
        } else {
            return new OWLNamedIndividual[]{individualsMap.get(VERYLOW)};
        }
    }
}
