/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Contributor: Alexander Streicher, Fraunhofer IOSB, www.iosb.fraunhofer.de
 * Contributor: Ovidiu Serban, University of Reading, www.isr.reading.ac.uk
 * Version: [0.01]
 * Date: 2014-02-26
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.didacticFactors;

import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.utils.DbAccessUtil;
import org.semanticweb.owlapi.model.OWLNamedIndividual;

import java.util.Collection;
import java.util.HashSet;
import java.util.Objects;

/**
 * DF blind
 * Categorization of whether the learner can only use KOs that are marked as suitable for blind
 * people.
 *
 * @author stc
 */
public class DfBlind extends DidacticFactor {

    private static final String BLIND = "dfBlind_IsBlind";

    /**
     * Constructor
     *
     * @param loadedIndividuals Collection of loaded DF-Individuals.
     * @throws NullPointerException Thrown when loadedIndividuals is null
     * @throws IllegalArgumentException Thrown when loadedIndividuals is empty or if there is a
     * mismatch with the expected DF-individuals.
     */
    public DfBlind(Collection<OWLNamedIndividual> loadedIndividuals)
            throws NullPointerException, IllegalArgumentException {
        super(loadedIndividuals);
    }

    @Override
    protected Collection<String> getExpectedIndividualFragments() {
        Collection<String> fragments = new HashSet<>();
        fragments.add(BLIND);
        return fragments;
    }

    @Override
    public OWLNamedIndividual[] getDfIndividuals(SlomMetadata slom, DbAccessUtil db) {
        Boolean blind = db.isLearnerBlind();
        if (Objects.equals(blind, Boolean.TRUE)) {
            return new OWLNamedIndividual[]{individualsMap.get(BLIND)};
        }
        return null;
    }
}
