/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 11.06.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.didacticFactors;

import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.ConceptContainer;
import eu.intuitel.lpmProcessor.utils.CompletionUtil;
import eu.intuitel.lpmProcessor.utils.DbAccessUtil;
import java.util.Collection;
import java.util.HashSet;
import org.semanticweb.owlapi.model.OWLNamedIndividual;

/**
 * Df current CC completion
 * Statement about the completion of the current CC based on the completion of the mLP.
 *
 * @author Florian Heberle
 */
public class DfCurrentCcCompletion extends DidacticFactor {

    private static final String THIRDTHIRD = "dfCurrentCcCompletion_ThirdThird";
    private static final String SECONDTHIRD = "dfCurrentCcCompletion_SecondThird";
    private static final String FIRSTTHIRD = "dfCurrentCcCompletion_FirstThird";

    /**
     * Constructor
     *
     * @param loadedIndividuals Collection of loaded DF-Individuals.
     * @throws NullPointerException Thrown when loadedIndividuals is null
     * @throws IllegalArgumentException Thrown when loadedIndividuals is empty or if there is a
     * mismatch with the expected DF-individuals.
     */
    public DfCurrentCcCompletion(Collection<OWLNamedIndividual> loadedIndividuals)
            throws NullPointerException, IllegalArgumentException {
        super(loadedIndividuals);
    }

    @Override
    protected Collection<String> getExpectedIndividualFragments() {
        Collection<String> fragments = new HashSet<>();
        fragments.add(THIRDTHIRD);
        fragments.add(SECONDTHIRD);
        fragments.add(FIRSTTHIRD);
        return fragments;
    }

    @Override
    public OWLNamedIndividual[] getDfIndividuals(SlomMetadata slom, DbAccessUtil db) {
        ConceptContainer cc = db.getLastConceptContainer();
        //Determine the maximum %-value of a completed mLP sequence of the current CC
        Integer value = CompletionUtil.getCcCompletion(cc, slom, db.getCompletedKOs());
        if (value == null) {
            return null;
        } else if (value >= 66) {
            return new OWLNamedIndividual[]{individualsMap.get(THIRDTHIRD)};
        } else if (value >= 33) {
            return new OWLNamedIndividual[]{individualsMap.get(SECONDTHIRD)};
        } else {
            return new OWLNamedIndividual[]{individualsMap.get(FIRSTTHIRD)};
        }
    }
}
