/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 11.06.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.didacticFactors;

import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.utils.DbAccessUtil;
import java.util.Collection;
import java.util.HashSet;
import org.semanticweb.owlapi.model.OWLNamedIndividual;

/**
 * DF device horizontal resolution
 * Categorization of the horizontal size of the learner's device screen.
 *
 * @author Florian Heberle
 */
public class DfDeviceHorizontalResolution extends DidacticFactor {

    private static final String SMALL = "dfDeviceHorizontalResolution_Small";
    private static final String MEDIUM = "dfDeviceHorizontalResolution_Medium";
    private static final String LARGE = "dfDeviceHorizontalResolution_Large";

    /**
     * Constructor
     *
     * @param loadedIndividuals Collection of loaded DF-Individuals.
     * @throws NullPointerException Thrown when loadedIndividuals is null
     * @throws IllegalArgumentException Thrown when loadedIndividuals is empty or if there is a
     * mismatch with the expected DF-individuals.
     */
    public DfDeviceHorizontalResolution(Collection<OWLNamedIndividual> loadedIndividuals)
            throws NullPointerException, IllegalArgumentException {
        super(loadedIndividuals);
    }

    @Override
    protected Collection<String> getExpectedIndividualFragments() {
        Collection<String> fragments = new HashSet<>();
        fragments.add(SMALL);
        fragments.add(MEDIUM);
        fragments.add(LARGE);
        return fragments;
    }

    @Override
    public OWLNamedIndividual[] getDfIndividuals(SlomMetadata slom, DbAccessUtil db) {
        Integer res = db.getHorizontalDeviceResolution();
        if (res == null) {
            return null;
        } else if (res <= 800) {
            return new OWLNamedIndividual[]{individualsMap.get(SMALL)};
        } else if (res <= 1280) {
            return new OWLNamedIndividual[]{individualsMap.get(MEDIUM)};
        } else {
            return new OWLNamedIndividual[]{individualsMap.get(LARGE)};
        }
    }
}
