/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 11.06.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.didacticFactors;

import eu.intuitel.types.Gender;
import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.utils.DbAccessUtil;
import org.semanticweb.owlapi.model.OWLNamedIndividual;

import java.util.Collection;
import java.util.HashSet;

/**
 * DF Gender
 * Statement about the learner's gender.
 *
 * @author Florian Heberle
 */
public class DfGender extends DidacticFactor {

//    private static final String MALE = "dfGender_Male";
//    private static final String FEMALE = "dfGender_Female";
//    private static final String OTHER = "dfGender_Other";
    /**
     * Constructor
     *
     * @param loadedIndividuals Collection of loaded DF-Individuals.
     * @throws NullPointerException Thrown when loadedIndividuals is null
     * @throws IllegalArgumentException Thrown when loadedIndividuals is empty or if there is a
     * mismatch with the expected DF-individuals.
     */
    public DfGender(Collection<OWLNamedIndividual> loadedIndividuals)
            throws NullPointerException, IllegalArgumentException {
        super(loadedIndividuals);
    }

    @Override
    protected Collection<String> getExpectedIndividualFragments() {
        Collection<String> fragments = new HashSet<>();
        fragments.add(Gender.Male.getDfValue());
        fragments.add(Gender.Female.getDfValue());
        fragments.add(Gender.Other.getDfValue());
        return fragments;
    }

    @Override
    public OWLNamedIndividual[] getDfIndividuals(SlomMetadata slom, DbAccessUtil db) {
        Gender gender = db.getLearnerGender();
        if (gender != null) {
            return new OWLNamedIndividual[]{individualsMap.get(gender.getDfValue())};
        } else {
            return null;
        }
    }
}
