/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 11.06.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.didacticFactors;

import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.utils.DbAccessUtil;
import eu.intuitel.types.InteractionWillingness;
import java.util.Collection;
import java.util.HashSet;
import org.semanticweb.owlapi.model.OWLNamedIndividual;

/**
 * DF interaction willingness
 * Statement about whether the learner is willing to interact with peers or not.
 *
 * @author Florian Heberle
 */
public class DfInteractionWillingness extends DidacticFactor {

    private static final String WILLING = "dfInteractionWillingness_Willing";
    private static final String UNWILLING = "dfInteractionWillingness_Unwilling";

    /**
     * Constructor
     *
     * @param loadedIndividuals Collection of loaded DF-Individuals.
     * @throws NullPointerException Thrown when loadedIndividuals is null
     * @throws IllegalArgumentException Thrown when loadedIndividuals is empty or if there is a
     * mismatch with the expected DF-individuals.
     */
    public DfInteractionWillingness(Collection<OWLNamedIndividual> loadedIndividuals)
            throws NullPointerException, IllegalArgumentException {
        super(loadedIndividuals);
    }

    @Override
    protected Collection<String> getExpectedIndividualFragments() {
        Collection<String> fragments = new HashSet<>();
        fragments.add(WILLING);
        fragments.add(UNWILLING);
        return fragments;
    }

    @Override
    public OWLNamedIndividual[] getDfIndividuals(SlomMetadata slom, DbAccessUtil db) {

        //TODO: Calculate this based on the learner's recent LO choices (i.e. from this session)
        //If there are more than one recommendations, did the learner choose the one that required interaction?
        InteractionWillingness willingness = db.getInteractionWillingness();
        if (willingness == InteractionWillingness.Willing) {
            return new OWLNamedIndividual[]{individualsMap.get(WILLING)};
        } else if (willingness == InteractionWillingness.Unwilling) {
            return new OWLNamedIndividual[]{individualsMap.get(UNWILLING)};
        }
        return null; //Unknown value
    }
}
