/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 11.06.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.didacticFactors;

import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.utils.DbAccessUtil;
import java.util.Collection;
import java.util.HashSet;
import org.semanticweb.owlapi.model.OWLNamedIndividual;

/**
 * DF Noise
 * Ranking of the environmental noise level the learner is currently exposed.
 *
 * @author Florian Heberle
 */
public class DfNoise extends DidacticFactor {

    private static final String QUIET = "dfNoise_Quiet";
    private static final String GOOD = "dfNoise_Good";
    private static final String LOUD = "dfNoise_Loud";
    private static final String TOOLOUD = "dfNoise_TooLoud";

    /**
     * Constructor
     *
     * @param loadedIndividuals Collection of loaded DF-Individuals.
     * @throws NullPointerException Thrown when loadedIndividuals is null
     * @throws IllegalArgumentException Thrown when loadedIndividuals is empty or if there is a
     * mismatch with the expected DF-individuals.
     */
    public DfNoise(Collection<OWLNamedIndividual> loadedIndividuals)
            throws NullPointerException, IllegalArgumentException {
        super(loadedIndividuals);
    }

    @Override
    protected Collection<String> getExpectedIndividualFragments() {
        Collection<String> fragments = new HashSet<>();
        fragments.add(QUIET);
        fragments.add(GOOD);
        fragments.add(LOUD);
        fragments.add(TOOLOUD);
        return fragments;
    }

    @Override
    public OWLNamedIndividual[] getDfIndividuals(SlomMetadata slom, DbAccessUtil db) {
        Integer noise = db.getNoise();
        if (noise == null) {
            return null;
        } else if (noise > 120) {
            return new OWLNamedIndividual[]{individualsMap.get(TOOLOUD)};
        } else if (noise > 70) {
            return new OWLNamedIndividual[]{individualsMap.get(LOUD)};
        } else if (noise > 50) {
            return new OWLNamedIndividual[]{individualsMap.get(GOOD)};
        } else {
            return new OWLNamedIndividual[]{individualsMap.get(QUIET)};
        }
    }
}
