/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 11.06.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.didacticFactors;

import eu.intuitel.types.Language;
import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.utils.DbAccessUtil;
import org.semanticweb.owlapi.model.OWLNamedIndividual;

import java.util.Collection;
import java.util.HashSet;
import java.util.Set;

/**
 * DF spoken language
 * Statement about with languages the learner is capable of speaking.
 *
 * @author Florian Heberle
 */
public class DfSpokenLanguage extends DidacticFactor {

    /**
     * Constructor
     *
     * @param loadedIndividuals Collection of loaded DF-Individuals.
     * @throws NullPointerException Thrown when loadedIndividuals is null
     * @throws IllegalArgumentException Thrown when loadedIndividuals is empty or if there is a
     * mismatch with the expected DF-individuals.
     */
    public DfSpokenLanguage(Collection<OWLNamedIndividual> loadedIndividuals)
            throws NullPointerException, IllegalArgumentException {
        super(loadedIndividuals);
    }

    @Override
    protected Collection<String> getExpectedIndividualFragments() {
        Collection<String> fragments = new HashSet<>();
        fragments.add(Language.German.getDfValue());
        fragments.add(Language.English.getDfValue());
        fragments.add(Language.Spanish.getDfValue());
        fragments.add(Language.Italian.getDfValue());
        fragments.add(Language.Hebrew.getDfValue());
        return fragments;
    }

    @Override
    public OWLNamedIndividual[] getDfIndividuals(SlomMetadata slom, DbAccessUtil db) {
        Collection<Language> langInputs = db.getLearnerLanguages();
        if (langInputs == null) {
            return null;
        } else if (langInputs.isEmpty()) {
            return null;
        }
        Set<OWLNamedIndividual> langOutputs = new HashSet<>();
        for (Language langInput : langInputs) {
            OWLNamedIndividual item = individualsMap.get(langInput.getDfValue());
            if (item != null) {
                langOutputs.add(item);
            }
        }
        return langOutputs.toArray(new OWLNamedIndividual[langOutputs.size()]);
    }
}
