/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 25.06.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.didacticFactors;

import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.KnowledgeObject;
import eu.intuitel.lpmProcessor.utils.DbAccessUtil;
import java.util.Collection;
import java.util.HashSet;
import org.semanticweb.owlapi.model.OWLNamedIndividual;

/**
 * DF test score
 * Ranking about how the learner has performed on this test on occasions.
 *
 * @author Florian Heberle
 */
public class DfTestScore extends DidacticFactor {

    private static final String VERYGOOD = "dfTestScore_VeryGood";
    private static final String GOOD = "dfTestScore_Good";
    private static final String BAD = "dfTestScore_Bad";

    /**
     * Constructor
     *
     * @param loadedIndividuals Collection of loaded DF-Individuals.
     * @throws NullPointerException Thrown when loadedIndividuals is null
     * @throws IllegalArgumentException Thrown when loadedIndividuals is empty or if there is a
     * mismatch with the expected DF-individuals.
     */
    public DfTestScore(Collection<OWLNamedIndividual> loadedIndividuals)
            throws NullPointerException, IllegalArgumentException {
        super(loadedIndividuals);
    }

    @Override
    protected Collection<String> getExpectedIndividualFragments() {
        Collection<String> fragments = new HashSet<>();
        fragments.add(VERYGOOD);
        fragments.add(GOOD);
        fragments.add(BAD);
        return fragments;
    }

    @Override
    public OWLNamedIndividual[] getDfIndividuals(SlomMetadata slom, DbAccessUtil db) {
        KnowledgeObject ko = db.getLastKnowledgeObject();
        if (ko == null) {
            return null;
        }
        if (ko.getKnowledgeType() == null) {
            return null;
        }
        if (!ko.getKnowledgeType().isAutomaticallyAssessedTest()) {
            return null;
        }
        Integer grade = db.getKoCompletionGrade(ko.getIriAsString());
        if (grade == null) {
            return null;
        } else if (grade <= 2) {
            return new OWLNamedIndividual[]{individualsMap.get(VERYGOOD)};
        } else if (grade <= 4) {
            return new OWLNamedIndividual[]{individualsMap.get(GOOD)};
        } else if (grade <= 6) {
            return new OWLNamedIndividual[]{individualsMap.get(BAD)};
        }
        return null;
    }
}
