/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 11.06.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.didacticFactors;

import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.utils.DbAccessUtil;
import java.util.Collection;
import java.util.HashSet;
import org.semanticweb.owlapi.model.OWLNamedIndividual;

/**
 * DF time period since last login
 * Statement about the timespan between when the learner last logged in and the current learning
 * session.
 *
 * @author Florian Heberle
 */
public class DfTimePeriodSinceLastLogin extends DidacticFactor {

    private static final String LONGAGO = "dfTimePeriodSinceLastLogin_LongAgo";
    private static final String RECENTLY = "dfTimePeriodSinceLastLogin_Recently";

    /**
     * Constructor
     *
     * @param loadedIndividuals Collection of loaded DF-Individuals.
     * @throws NullPointerException Thrown when loadedIndividuals is null
     * @throws IllegalArgumentException Thrown when loadedIndividuals is empty or if there is a
     * mismatch with the expected DF-individuals.
     */
    public DfTimePeriodSinceLastLogin(Collection<OWLNamedIndividual> loadedIndividuals)
            throws NullPointerException, IllegalArgumentException {
        super(loadedIndividuals);
    }

    @Override
    protected Collection<String> getExpectedIndividualFragments() {
        Collection<String> fragments = new HashSet<>();
        fragments.add(LONGAGO);
        fragments.add(RECENTLY);
        return fragments;
    }

    @Override
    public OWLNamedIndividual[] getDfIndividuals(SlomMetadata slom, DbAccessUtil db) {
        Long lastLogin = db.getLastLoginTime();
        if (lastLogin == null) {
            return null;
        }
        Long currentLogin = db.getCurrentLoginTime();
        if (currentLogin == null) {
            return null;
        }
        if ((lastLogin - currentLogin) / 1000 / 60 / 60 / 24 >= 14) {
            return new OWLNamedIndividual[]{individualsMap.get(LONGAGO)};
        } else {
            return new OWLNamedIndividual[]{individualsMap.get(RECENTLY)};
        }
    }
}
