/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Contributor: Ovidiu Serban, University of Reading, www.isr.reading.ac.uk
 * Version: [0.01]
 * Date: 2013-11-05
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.didacticFactors;

import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.utils.DbAccessUtil;
import java.util.Collection;
import java.util.HashSet;
import org.semanticweb.owlapi.model.OWLNamedIndividual;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Determines which Didactic Factor individuals apply for the current learner.
 *
 * @author fhe
 */
public class DidacticFactorApplicator {

    private static final Logger logger = LoggerFactory.getLogger(DidacticFactorApplicator.class);

    /**
     * Returns a collection of DF-Individuals that apply for the given learner in the current
     * learning situation.
     *
     * @param dfsToTest List of DFs to be tested
     * @param slom SLOM metadata
     * @param learnerId ID of the learner in scope
     * @param db DB interface
     * @return Empty collection if no DFs apply.
     */
    public static Collection<OWLNamedIndividual> applyDidacticFactors(Collection<DidacticFactor> dfsToTest,
            SlomMetadata slom, String learnerId, DbAccessUtil db) {
        try {
            Collection<OWLNamedIndividual> dfIndividuals = new HashSet<>();
            for (DidacticFactor df : dfsToTest) {
                OWLNamedIndividual[] values = df.getDfIndividuals(slom, db);
                if (values != null) {
                    for (OWLNamedIndividual value : values) {
                        if (value != null) {
                            dfIndividuals.add(value);
                        }
                    }
                }
            }
            return dfIndividuals;
        } catch (Exception ex) {
            logger.error("Error during DF calculation: ", ex);
            return new HashSet<>();
        }
    }
}
