/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2013-11-18
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.lpMetric;

import eu.intuitel.lpmProcessor.models.LpEvaluationResult;
import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.models.owlWrapper.abstractTypes.LearningPathway;
import eu.intuitel.lpmProcessor.utils.DbAccessUtil;
import java.util.Collection;

/**
 * Interface for LP selection metrics.
 *
 * @author fhe
 */
public interface ILpMetric {

    /**
     * Returns the method of this metric.
     *
     * @return Value to differentiate the different selection methods
     */
    public LpEvaluationResult.EvaluationMethod getMethod();

    /**
     * Returns the most suitable LPs for the given learner.
     *
     * @param slom SLOM metadata to be inspected
     * @param db Communication interface for the user database
     * @param lpClass Class of LPs to inspect
     * @return Empty collection if no LP could be determined.
     */
    public Collection<? extends LearningPathway> getLp(SlomMetadata slom, DbAccessUtil db, Class<? extends LearningPathway> lpClass);
}
