/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2013-11-19
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.lpMetric;

import eu.intuitel.lpmProcessor.models.LpEvaluationResult;
import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.models.owlWrapper.abstractTypes.LearningPathway;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.MicroLearningPathway;
import eu.intuitel.lpmProcessor.utils.DbAccessUtil;
import java.util.Collection;
import java.util.HashSet;

/**
 * Selects a LP via the availability of LPs (i.e. if only one is available, this will be selected).
 *
 * @author fhe
 */
public class LpMetricAvailability implements ILpMetric {

    @Override
    public LpEvaluationResult.EvaluationMethod getMethod() {
        return LpEvaluationResult.EvaluationMethod.Unique;
    }

    @Override
    public Collection<? extends LearningPathway> getLp(SlomMetadata slom, DbAccessUtil db, Class<? extends LearningPathway> lpClass) {
        Collection<? extends LearningPathway> inspectionSet = lpClass == MicroLearningPathway.class ? slom.getMicroLps() : slom.getMacroLps();
        if (inspectionSet.size() == 1) {
            return inspectionSet;
        }
        return new HashSet<>();
    }
}
