/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2013-11-19
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.lpMetric;

import eu.intuitel.lpmProcessor.models.LpEvaluationResult;
import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.models.owlWrapper.abstractTypes.LearningPathway;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.MicroLearningPathway;
import eu.intuitel.lpmProcessor.utils.DbAccessUtil;
import java.util.Collection;
import java.util.HashSet;

/**
 * Selects a LP based on the coverage of LOs for the given learner.
 *
 * @author fhe
 */
public class LpMetricCoverage implements ILpMetric {

    @Override
    public LpEvaluationResult.EvaluationMethod getMethod() {
        return LpEvaluationResult.EvaluationMethod.Coverage;
    }

    @Override
    public Collection<? extends LearningPathway> getLp(SlomMetadata slom, DbAccessUtil db, Class<? extends LearningPathway> lpClass) {
        LearningPathway selection = null;
        int maxCoverage = 0;
        for (LearningPathway lp : lpClass == MicroLearningPathway.class ? slom.getMicroLps() : slom.getMacroLps()) {
            int coverage = lp.getCoverage(slom);
            if (coverage >= maxCoverage) {
                selection = lp;
                maxCoverage = coverage;
            }
        }
        Collection<LearningPathway> result = new HashSet<>();
        result.add(selection);
        return result;
    }
}
