/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2013-11-19
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.lpMetric;

import eu.intuitel.lpmProcessor.models.LpEvaluationResult;
import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.models.owlWrapper.abstractTypes.LearningPathway;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.MicroLearningPathway;
import eu.intuitel.lpmProcessor.utils.DbAccessUtil;
import java.util.Collection;
import java.util.HashSet;

/**
 * Selects a LP based on the popularity (i.e. how many learners have chosen it).
 *
 * @author fhe
 */
public class LpMetricPopularity implements ILpMetric {

    @Override
    public LpEvaluationResult.EvaluationMethod getMethod() {
        return LpEvaluationResult.EvaluationMethod.Popularity;
    }

    @Override
    public Collection<? extends LearningPathway> getLp(SlomMetadata slom, DbAccessUtil db, Class<? extends LearningPathway> lpClass) {
        Collection<LearningPathway> results = new HashSet<>();
        int maxPopularity = Integer.MIN_VALUE;
        for (LearningPathway lp : lpClass == MicroLearningPathway.class ? slom.getMicroLps() : slom.getMacroLps()) {
            int currentPopularity = db.getPopularityOfLp(lp);
            if (currentPopularity > maxPopularity) {
                results.clear();
                results.add(lp);
                maxPopularity = currentPopularity;
            } else if (currentPopularity == maxPopularity) {
                results.add(lp);
            }
        }
        return results;
    }
}
