/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2013-11-19
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.lpReevaluation;

import eu.intuitel.lpmProcessor.models.owlWrapper.abstractTypes.LearningObject;
import eu.intuitel.lpmProcessor.models.owlWrapper.abstractTypes.LearningPathway;
import eu.intuitel.lpmProcessor.utils.DbAccessUtil;
import java.util.List;

/**
 * LP re-evaluation criterion that inspects the timespan since the last re-evaluation.
 *
 * @author fhe
 */
public class LpReevaluationCriterionTime implements ILpReevaluationCriterion {

    /**
     * The timespan as long after which a re-evaluation should be triggered.
     */
    private static final long THRESHOLD = 3600000;

    @Override
    public boolean fulfillsCriterion(DbAccessUtil db, LearningPathway lp, List<? extends LearningObject> history) {
        Long time = db.getTimeSinceLastLpEvaluation();
        if (time == null) {
            return false;
        } else if (time < THRESHOLD) {
            return true;
        }
        return false;
    }
}
