/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2014-03-04
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.models.factories;

import eu.intuitel.lpmProcessor.OntoMngr;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.ConceptContainer;
import eu.intuitel.lpmProcessor.models.owlWrapper.ontologies.PedagogicalOntology;
import eu.intuitel.lpmProcessor.utils.OwlUtil;
import java.util.HashSet;
import java.util.Set;
import org.semanticweb.owlapi.model.OWLNamedIndividual;
import org.semanticweb.owlapi.model.OWLOntology;
import org.semanticweb.owlapi.reasoner.OWLReasoner;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Factory class for loading of Concept Containers from a CM.
 *
 * @author fhe
 */
public class ConceptContainerFactory {

    private static final Logger logger = LoggerFactory.getLogger(ConceptContainerFactory.class);

    /**
     * Determines all CCs from the given CM and returns them as a Set.
     *
     * @param cmOnto CM ontology representation
     * @param cmReasoner An OWL reasoner for the given CM
     * @return Empty Set if no CCs could be found.
     */
    public static Set<ConceptContainer> createCcSet(OWLOntology cmOnto, OWLReasoner cmReasoner) {
        try {
            Set<ConceptContainer> ccSet = new HashSet<>();
            for (OWLNamedIndividual ccIndividual : OwlUtil.getNamedIndividualsOfClass(cmReasoner, PedagogicalOntology.CC_CLASS, false)) {

                String title = OwlUtil.getAnnotationPropertyValue(cmOnto, ccIndividual,
                        OwlUtil.getAnnotationProperty("http://dublincore.org/documents/dces/", "title", OntoMngr.DATAFAC));
                String description = OwlUtil.getAnnotationPropertyValue(cmOnto, ccIndividual,
                        OwlUtil.getAnnotationProperty("http://dublincore.org/documents/dces/", "description", OntoMngr.DATAFAC));

                ConceptContainer cc = new ConceptContainer(ccIndividual, ccSet.size() + 1, title, description);
                ccSet.add(cc);
            }
            return ccSet;
        } catch (Exception ex) {
            logger.error("Exception while loading ConceptContainers.", ex);
            return new HashSet<>();
        }
    }
}
