/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2013-02-27
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.models.factories;

import eu.intuitel.lpmProcessor.models.owlWrapper.ontologies.PedagogicalOntology;
import eu.intuitel.lpmProcessor.utils.OwlUtil;
import java.net.URISyntaxException;
import org.semanticweb.owlapi.model.IRI;
import org.semanticweb.owlapi.model.OWLAnnotationProperty;
import org.semanticweb.owlapi.model.OWLOntology;
import org.semanticweb.owlapi.model.OWLOntologyCreationException;
import org.semanticweb.owlapi.model.OWLOntologyManager;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Factory class to load the Pedagogical Ontology from the project resources.
 *
 * @author fhe
 */
public class PedagogicalOntologyFactory {

    private static final Logger logger = LoggerFactory.getLogger(PedagogicalOntologyFactory.class);
    private static final String LOCAL_PO_FILENAME = "intui_PO.owl";

    /**
     * Loads the Pedagogical Ontology from project resources via the given ontology objects.
     *
     * @param manager OWLOntologyManager to be used for loading the PO
     * @return Null in case of exception.
     */
    public static PedagogicalOntology createNewInstance(OWLOntologyManager manager) {
        try {
            IRI localIri = IRI.create(Thread.currentThread().getContextClassLoader().getResource(LOCAL_PO_FILENAME));
            OWLOntology onto = manager.loadOntologyFromOntologyDocument(localIri);
            OWLAnnotationProperty versionProp = OwlUtil.getAnnotationProperty("http://www.w3.org/2002/07/owl#", "versionInfo", manager.getOWLDataFactory());
            String versionPropValue = OwlUtil.getAnnotationPropertyValue(onto, versionProp);
            return new PedagogicalOntology(onto, versionPropValue);
        } catch (URISyntaxException ex) {
            logger.error("URI-Exception while loading the Pedagogical Ontology", ex);
        } catch (OWLOntologyCreationException ex) {
            logger.error("Ontology-Exception while loading the Pedagogical Ontology", ex);
        }
        return null;
    }

    /**
     * Returns the location from where the PO was loaded.
     *
     * @return String containing the filepath.
     */
    public static String getPoLocation() {
        return Thread.currentThread().getContextClassLoader().getResource(LOCAL_PO_FILENAME).toString();
    }
}
