/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2013-11-05
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.models.owlWrapper.abstractTypes;

import org.semanticweb.owlapi.model.IRI;
import org.semanticweb.owlapi.model.OWLObject;

/**
 * Basic interface for ontology wrapper objects for elements in the SLOM content regime.
 *
 * @author fhe
 */
public interface IOntologyObject {

    /**
     * Returns the original object that is represented by this wrapper.
     *
     * @return The original OWL representation of the object
     */
    public OWLObject getOntoObj();

    /**
     * Tests whether the IRI of this object is identical to the given one.
     *
     * @param iri String representation of the IRI to compare
     * @return True if equal
     */
    public boolean hasSameIri(String iri);

    /**
     * Tests whether the IRI of this object is identicial to the given one.
     *
     * @param iri IRI to compare
     * @return True if equal
     */
    public boolean hasSameIri(IRI iri);

    /**
     * Returns the IRI of the represented object as string.
     *
     * @return IRI as String
     */
    public String getIriAsString();

    /**
     * Returns the IRI of the represented object.
     *
     * @return IRI of the OWL object
     */
    public IRI getIri();

    /**
     * Returns a String representation of this object.
     *
     * @return String representation of this object
     */
    @Override
    public String toString();
}
