/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Contributor: Alexander Streicher, Fraunhofer IOSB, www.iosb.fraunhofer.de
 * Version: [0.01]
 * Date: 2013-11-05
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes;

import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.models.owlWrapper.abstractTypes.LearningObject;
import eu.intuitel.lpmProcessor.models.owlWrapper.abstractTypes.LearningPathway;
import java.util.Collection;
import java.util.Set;
import org.semanticweb.owlapi.model.OWLNamedIndividual;

/**
 * Wrapper class for a Concept Container.
 *
 * @author fhe
 */
public class ConceptContainer extends LearningObject {

    /**
     * Creates a new Concept Container.
     *
     * @param cc Ontology object representing this CC
     * @param numericId SLOM-unique numeric identifier of this CC
     * @param title The dc:title of this element
     * @param description The dc:description of this element
     */
    public ConceptContainer(OWLNamedIndividual cc, int numericId, String title, String description) {
        super(cc, numericId, title, description);
    }

    /**
     * Returns all KOs that reference on this CC.
     *
     * @param slom SLOM object which contains this CC
     * @return Null in case no references are available.
     */
    public Collection<KnowledgeObject> getReferencedKos(SlomMetadata slom) {
        return slom.getReferences(this);
    }

    @Override
    public Set<ConceptContainer> getDirectSucessorsFor(LearningPathway lp) {
        return LearningObject.getAsSubtypedSet(getLpReferences(lp, successors), ConceptContainer.class);
    }

    @Override
    public Set<ConceptContainer> getDirectPredecessorsFor(LearningPathway lp) {
        return LearningObject.getAsSubtypedSet(getLpReferences(lp, predecessor), ConceptContainer.class);
    }
}
