/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2014-03-04
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes;

import eu.intuitel.lpmProcessor.models.owlWrapper.abstractTypes.IOntologyObject;
import eu.intuitel.lpmProcessor.utils.OwlUtil;
import org.semanticweb.owlapi.model.IRI;
import org.semanticweb.owlapi.model.OWLIndividual;
import org.semanticweb.owlapi.model.OWLObject;

/**
 * Class to wrap the preferred location of Knowledge Objects.
 *
 * @author fhe
 */
public class Location implements IOntologyObject {

    protected final OWLIndividual ontoObj;
    protected final double latitude;
    protected final double longitude;
    protected final int margin;

    /**
     * Creates a new Location instance.
     *
     * @param ontoObj Original OWL element of the Location
     * @param latitude The latitude of the preferred location
     * @param longitude The longitude of the preferred location
     * @param margin The 'allowed' error margin of the preferred location
     */
    public Location(OWLIndividual ontoObj, double latitude, double longitude, int margin) {
        this.ontoObj = ontoObj;
        this.latitude = latitude;
        this.longitude = longitude;
        this.margin = margin;
    }

    /**
     * Returns the latitude of the preferred location of the KO.
     *
     * @return Decimal value &gt= 0 and &lt= 90
     */
    public double getLatitude() {
        return latitude;
    }

    /**
     * Returns the longitude of the preferred location of the KO.
     *
     * @return Decimal value &gt= 0 and &lt= 180
     */
    public double getLongitude() {
        return longitude;
    }

    /**
     * Returns the error margin that is 'allowed'. I.e. in which a learner will be rated as being at
     * the location.
     *
     * @return Integer value >0
     */
    public int getMargin() {
        return margin;
    }

    @Override
    public OWLObject getOntoObj() {
        return ontoObj;
    }

    @Override
    public boolean hasSameIri(String iri) {
        return OwlUtil.getIriAsString(ontoObj).equals(iri);
    }

    @Override
    public boolean hasSameIri(IRI iri) {
        return OwlUtil.getIriAsString(ontoObj).equals(OwlUtil.getIriAsString(iri));
    }

    @Override
    public String getIriAsString() {
        return OwlUtil.getIriAsString(ontoObj);
    }

    @Override
    public IRI getIri() {
        return OwlUtil.getIri(ontoObj);
    }
}
