/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2013-11-05
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.models.reflex;

import eu.intuitel.lpmGeneralInterfaces.IEngineCommunicator;
import eu.intuitel.lpmGeneralInterfaces.IEngineCommunicator.Option;
import java.util.ArrayList;
import java.util.List;
import org.apache.commons.lang3.Validate;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Abstract base class for reflex messages being send to the RR.
 *
 * @author fhe
 */
public abstract class Reflex {

    private static final Logger logger = LoggerFactory.getLogger(Reflex.class);
    private final String MID;
    private final String LID;
    private final String CID;
    private final boolean ABORTS;
    private final String REASON;
    protected final List<Option> OPTIONS;

    /**
     * Constructor.
     *
     * @param mId Message ID of the learner update that triggered the reflex
     * @param lId Learner ID who triggered the learner update
     * @param cId Course ID of the course the learner is currently learning on
     * @param aborts Boolean value indicating whether the reflex aborts the recommendation creation
     */
    protected Reflex(String mId, String lId, String cId, boolean aborts) {
        Validate.notBlank(mId);
        MID = mId;
        Validate.notBlank(lId);
        LID = lId;
        CID = cId;
        ABORTS = aborts;
        REASON = this.getClass().getSimpleName().replaceAll("Reflex", "");
        OPTIONS = new ArrayList<>();
    }

    @Override
    public String toString() {
        return REASON;
    }

    /**
     * Returns a boolean value indicating whether the condition aborts the process or not.
     *
     * @return True = abort, false = continue.
     */
    public boolean getAbortsFlag() {
        return ABORTS;
    }

    /**
     * Sends the reflex with the given communicator instance.
     *
     * @param com Communicator to use for sending the reflex
     */
    public void send(IEngineCommunicator com) {
        if (com == null) {
            logger.error(String.format("Cannot send reflex '%s'. Communcator instance is null.", REASON));
        } else {
            com.sendReflex(LID, MID, ABORTS, CID, REASON, OPTIONS);
        }
    }
}
