/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 30.06.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.models.reflex;

import eu.intuitel.lpmGeneralInterfaces.IEngineCommunicator.Option;
import eu.intuitel.lpmProcessor.models.LpEvaluationResult;
import java.util.Set;
import org.apache.commons.lang3.Validate;

/**
 * Reflex message being triggered when the system determines that there are other, better LPs for
 * the learner.
 *
 * @author Florian Heberle
 */
public class ReflexMicroLpEval extends Reflex implements ILearnerReflex {

    /**
     * Constructor.
     *
     * @param mId Message ID of the learner update that triggered the reflex
     * @param lId Learner ID who triggered the learner update
     * @param cId Course ID of the course the learner is currently learning on
     * @param lps LP evaluation results
     */
    public ReflexMicroLpEval(String mId, String lId, String cId, Set<LpEvaluationResult> lps) {
        super(mId, lId, cId, false);
        Validate.notEmpty(lps);
        for (LpEvaluationResult lp : lps) {
            OPTIONS.add(new Option(lp.getEvaluationMethod().toString(), lp.getDeterminedLp().getIriAsString(),
                    lp.getTitle(), lp.getDescription()));
        }
    }
}
