/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 24.06.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.models.reflex;

import eu.intuitel.lpmGeneralInterfaces.IEngineCommunicator.Option;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.ConceptContainer;
import java.util.Collection;

/**
 * Reflex message being triggered when the LPM determined multiple possible CCs for the current LU.
 *
 * @author Florian Heberle
 */
public class ReflexMultipleCurrentCc extends Reflex implements ILearnerReflex {

    /**
     * Constructor.
     *
     * @param mId Message ID of the learner update that triggered the reflex
     * @param lId Learner ID who triggered the learner update
     * @param cId Course ID of the course the learner is currently learning on
     * @param ccs Possible CCs between which the LPM could not decide
     */
    public ReflexMultipleCurrentCc(String mId, String lId, String cId, Collection<ConceptContainer> ccs) {
        super(mId, lId, cId, true);
        for (ConceptContainer cc : ccs) {
            OPTIONS.add(new Option("possibleCCs", cc.getIriAsString(), cc.getTitle(), cc.getDescription()));
        }
    }
}
