/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 30.07.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.didacticFactors;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import static org.junit.Assert.*;
import org.junit.Test;

/**
 * Test for DfComparativeCourseTimeTest
 *
 * @author Florian Heberle
 */
public class DfComparativeCourseTimeTest {

    @Test
    public void testGetValue() {
        Collection<Long> learnerSessionLengths = new ArrayList<>();
        Collection<Collection<Long>> peersSessionLengths = new ArrayList<>();

        assertEquals(null, DfComparativeCourseTime.getValue(null, null));
        assertEquals(null, DfComparativeCourseTime.getValue(learnerSessionLengths, null));
        assertEquals(null, DfComparativeCourseTime.getValue(null, peersSessionLengths));

        peersSessionLengths.add(new ArrayList<Long>());
        assertEquals(null, DfComparativeCourseTime.getValue(null, null));
        assertEquals(null, DfComparativeCourseTime.getValue(learnerSessionLengths, null));
        assertEquals(null, DfComparativeCourseTime.getValue(null, peersSessionLengths));
        peersSessionLengths.clear();

        learnerSessionLengths = createSessionLengthCollection(new Long(10));
        assertEquals(null, DfComparativeCourseTime.getValue(learnerSessionLengths, null));

        peersSessionLengths.add(createSessionLengthCollection(new Long(10)));
        assertEquals(new Long(1000 / ((10) / 1)), DfComparativeCourseTime.getValue(learnerSessionLengths, peersSessionLengths));

        peersSessionLengths.add(createSessionLengthCollection(new Long(10)));
        assertEquals(new Long(1000 / ((10 + 10) / 2)), DfComparativeCourseTime.getValue(learnerSessionLengths, peersSessionLengths));

        peersSessionLengths.add(createSessionLengthCollection(new Long(20), new Long(20)));
        assertEquals(new Long(1000 / ((10 + 10 + 20 + 20) / 3)), DfComparativeCourseTime.getValue(learnerSessionLengths, peersSessionLengths));

        learnerSessionLengths = createSessionLengthCollection(new Long(10), new Long(20));
        assertEquals(new Long(3000 / ((10 + 10 + 20 + 20) / 3)), DfComparativeCourseTime.getValue(learnerSessionLengths, peersSessionLengths));
    }

    private Collection<Long> createSessionLengthCollection(Long... lengths) {
        Collection<Long> val = new ArrayList<>();
        if (lengths == null || lengths.length == 0) {
            return val;
        }
        val.addAll(Arrays.asList(lengths));
        return val;
    }
}
