/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 05.08.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.didacticFactors;

import eu.intuitel.lpmProcessor.didacticFactors.DfKnowledgeTypePreference.KT;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.ConceptContainer;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.KnowledgeObject;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.KnowledgeType;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import org.apache.commons.lang3.tuple.Pair;
import static org.junit.Assert.*;
import org.junit.Test;
import org.semanticweb.owlapi.model.OWLClass;
import uk.ac.manchester.cs.owl.owlapi.OWLNamedIndividualImpl;

/**
 * Test for DfKnowledgeTypePreference
 *
 * @author Florian Heberle
 */
public class DfKnowledgeTypePreferenceTest {

    private static int ctr = 1;

    @Test
    public void testGetValue() {
        KnowledgeObject ko01 = createKo(KnowledgeType.PLANNEDCOOPERATION); //coop
        KnowledgeObject ko02 = createKo(KnowledgeType.ASSIGNMENTINTERACTIVEAUTOMATICASSESSMENT); //interactive
        KnowledgeObject ko03 = createKo(KnowledgeType.ACTIONRECEPTIVE); //receptive
        KnowledgeObject ko04 = createKo(KnowledgeType.PLANNEDCOOPERATION); //coop

        List<Pair<List<KnowledgeObject>, KnowledgeObject>> recomSelections = new ArrayList<>();
        List<KnowledgeObject> recoms = new ArrayList<>();
        recoms.add(ko01);
        recoms.add(ko02);
        recoms.add(ko03);

        //1. step - no data 
        assertEquals(null, DfKnowledgeTypePreference.getValue(recomSelections));

        //2. step - first result should be made available
        recomSelections.add(Pair.of(recoms, ko01)); //learner chose ko01 - cooperative one
        assertEquals(KT.Cooperative, DfKnowledgeTypePreference.getValue(recomSelections));

        //2. step - Should be inconclusive, coop=1 and interactive=1
        recomSelections.add(Pair.of(recoms, ko02)); //learner chose ko02 - interactive one
        assertEquals(null, DfKnowledgeTypePreference.getValue(recomSelections));

        //3. step - interactive should be selected, because it was chosen twice now
        recomSelections.add(Pair.of(recoms, ko02)); //learner chose ko02 - interactive one again
        assertEquals(KT.Interactive, DfKnowledgeTypePreference.getValue(recomSelections));

        //4. step - learner disregards the recommendation and chooses another KO.
        //Interactive should be preserved, because the last step is not regarded in the inspection
        //Only steps which are in line with recoms should be considered.
        recomSelections.add(Pair.of(recoms, ko04));  //learner chose ko04 - coop again
        assertEquals(KT.Interactive, DfKnowledgeTypePreference.getValue(recomSelections));
    }

    private KnowledgeObject createKo(OWLClass ktClass) {
        KnowledgeObject ko = new KnowledgeObject(
                new OWLNamedIndividualImpl(null), //OWLNamedIndividual ko, 
                ctr, //int numericId, 
                new HashSet<ConceptContainer>(), //Set<ConceptContainer> references, 
                null, //String linkedLmsElement,
                null, //Integer difficultyLevel, 
                null, //Integer eqfLevel, 
                null, //Integer minimalHeight, 
                null, //Integer minimalWidth,
                null, //Integer recommendedAge, 
                null, //Integer recommendedHeight, 
                null, //Integer recommendedWidth, 
                null, //Integer digitalSize,
                null, //Long estimatedLearningTime, 
                null, //Locale language, 
                null, //Boolean subtiles, 
                null, //Boolean suitableForBlind,
                null, //Boolean suitableForDeaf, 
                null, //Boolean suitableForMute, 
                null, //Location location,
                KtHelper.createInstance(ktClass), //KnowledgeType knowledgeType, 
                null, //MediaType mediaType,
                null, //String title, 
                null //String description
        );
        ctr++;
        return ko;
    }

    static class KtHelper extends KnowledgeType {

        protected KtHelper(OWLClass type) {
            super(type, null);
        }

        public static KnowledgeType createInstance(OWLClass owlClass) {
            return (KnowledgeType) new KtHelper(owlClass);
        }
    }
}
