/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 05.08.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.didacticFactors;

import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.KnowledgeObject;
import eu.intuitel.lpmProcessor.test.mocks.SlomTestData04;
import java.util.ArrayList;
import java.util.List;
import static org.junit.Assert.*;
import org.junit.Test;

/**
 * Test for DfRecentLearningPace
 *
 * @author Florian Heberle
 */
public class DfRecentLearningPaceTest {

    @Test
    public void testFilterKos() {
        SlomTestData04 slomData = SlomTestData04.getInstance();
        List<KnowledgeObject> kosToFilter = new ArrayList<>();

        List<KnowledgeObject> filteredKos = DfRecentLearningPace.filterKos(kosToFilter, Integer.MAX_VALUE);
        assertEquals(0, filteredKos.size());

        kosToFilter.add(slomData.getKo01());
        kosToFilter.add(slomData.getKo02());
        kosToFilter.add(slomData.getKo03());
        kosToFilter.add(slomData.getKo04());
        kosToFilter.add(slomData.getKo04());
        kosToFilter.add(slomData.getKo05());
        kosToFilter.add(slomData.getKo06());
        kosToFilter.add(slomData.getKo06());
        kosToFilter.add(slomData.getKo06());
        kosToFilter.add(slomData.getKo07());
        kosToFilter.add(slomData.getKo08());

        filteredKos = DfRecentLearningPace.filterKos(kosToFilter, Integer.MAX_VALUE);
        assertEquals(8, filteredKos.size());
        assertEquals(slomData.getKo01(), filteredKos.get(0));
        assertEquals(slomData.getKo02(), filteredKos.get(1));
        assertEquals(slomData.getKo03(), filteredKos.get(2));
        assertEquals(slomData.getKo04(), filteredKos.get(3));
        assertEquals(slomData.getKo05(), filteredKos.get(4));
        assertEquals(slomData.getKo06(), filteredKos.get(5));
        assertEquals(slomData.getKo07(), filteredKos.get(6));
        assertEquals(slomData.getKo08(), filteredKos.get(7));

        filteredKos = DfRecentLearningPace.filterKos(kosToFilter, 3);
        assertEquals(3, filteredKos.size());
        assertEquals(slomData.getKo01(), filteredKos.get(0));
        assertEquals(slomData.getKo02(), filteredKos.get(1));
        assertEquals(slomData.getKo03(), filteredKos.get(2));
    }

    @Test
    public void testGetValue() {
        List<Long> actualLearningTimes = new ArrayList<>();
        List<Long> estLearningTimes = new ArrayList<>();
        assertEquals(null, DfRecentLearningPace.getValue(actualLearningTimes, estLearningTimes));

        actualLearningTimes.add(new Long(100));
        estLearningTimes.add(new Long(100));
        assertEquals(new Integer(100), DfRecentLearningPace.getValue(actualLearningTimes, estLearningTimes));

        actualLearningTimes.add(new Long(300));
        estLearningTimes.add(new Long(100));
        assertEquals(new Integer(200), DfRecentLearningPace.getValue(actualLearningTimes, estLearningTimes));

        actualLearningTimes.add(new Long(0));
        estLearningTimes.add(new Long(600));
        assertEquals(new Integer(50), DfRecentLearningPace.getValue(actualLearningTimes, estLearningTimes));
    }
}
