/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2014-03-12
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.lpMetric;

import eu.intuitel.db.access.DbAccessException;
import eu.intuitel.lpmProcessor.LpmProcessorTest;
import eu.intuitel.lpmProcessor.models.owlWrapper.abstractTypes.LearningObject;
import eu.intuitel.lpmProcessor.models.owlWrapper.abstractTypes.LearningPathway;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.MacroLearningPathway;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.MicroLearningPathway;
import eu.intuitel.lpmProcessor.test.mocks.SlomTestData01;
import eu.intuitel.lpmProcessor.test.mocks.SlomTestData02;
import eu.intuitel.lpmProcessor.test.mocks.SlomTestData03;
import eu.intuitel.lpmProcessor.test.mocks.SlomTestData04;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import org.junit.AfterClass;
import static org.junit.Assert.*;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Test for the history walker metric for LP selection.
 *
 * @author fhe
 */
public class LpMetricHistoryWalkerTest {

    private static final Logger LOGGER = LoggerFactory.getLogger(LpMetricHistoryWalkerTest.class);
    private static LpMetricHistoryWalker metric;

    @BeforeClass
    public static void beforeClass() {
        LOGGER.info("Starting tests.");
    }

    @AfterClass
    public static void afterClass() {
        LOGGER.info("Finished tests.");
    }

    @Before
    public void setUpClass() {
        metric = new LpMetricHistoryWalker();
    }

    @Test
    public void testGetLp_01_01() throws DbAccessException {
        SlomTestData01 slomData = SlomTestData01.getInstance();
        List<LearningObject> lHistory = new ArrayList<>();
        lHistory.add(slomData.getKo01());
        lHistory.add(slomData.getKo02());
        Collection<? extends LearningPathway> resultLps = metric.getLp(slomData.getSlom(), lHistory, MicroLearningPathway.class);
        assertNotNull("LP collection has falsely been returned as null.", resultLps);
        assertFalse("LP has falsely been returned with no elements.", resultLps.isEmpty());
        LpMetricHypercubeTest.testForLpsInResult(slomData.getSlom(), MicroLearningPathway.class, resultLps, new String[]{"#HasMicroLpRelation1"});
    }

    @Test
    public void testGetLp_01_02() throws DbAccessException {
        SlomTestData01 slomData = SlomTestData01.getInstance();
        List<LearningObject> lHistory = new ArrayList<>();
        lHistory.add(slomData.getKo02());
        lHistory.add(slomData.getKo01());
        Collection<? extends LearningPathway> resultLps = metric.getLp(slomData.getSlom(), lHistory, MicroLearningPathway.class);
        assertNotNull("LP collection has falsely been returned as null.", resultLps);
        assertFalse("LP has falsely been returned with no elements.", resultLps.isEmpty());
        LpMetricHypercubeTest.testForLpsInResult(slomData.getSlom(), MicroLearningPathway.class, resultLps, new String[]{"#HasMicroLpRelation2"});
    }

    @Test
    public void testGetLp_02() throws DbAccessException {
        SlomTestData02 slomData = SlomTestData02.getInstance();
        List<LearningObject> lHistory = new ArrayList<>();
        lHistory.add(slomData.getKo01());
        lHistory.add(slomData.getKo02());
        Collection<? extends LearningPathway> resultLps = metric.getLp(slomData.getSlom(), lHistory, MicroLearningPathway.class);
        assertNotNull("LP collection has falsely been returned as null.", resultLps);
        assertFalse("LP has falsely been returned with no elements.", resultLps.isEmpty());
        LpMetricHypercubeTest.testForLpsInResult(slomData.getSlom(), MicroLearningPathway.class, resultLps, new String[]{"#HasMicroLpRelation1"});
    }

    @Test
    public void testGetLp_03_1() throws DbAccessException {
        SlomTestData03 slomData = SlomTestData03.getInstance();
        List<LearningObject> lHistory = new ArrayList<>();
        lHistory.add(slomData.getKo01());
        lHistory.add(slomData.getKo03());
        Collection<? extends LearningPathway> resultLps = metric.getLp(slomData.getSlom(), lHistory, MicroLearningPathway.class);
        assertNotNull("LP collection has falsely been returned as null.", resultLps);
        assertFalse("LP has falsely been returned with no elements.", resultLps.isEmpty());
        LpMetricHypercubeTest.testForLpsInResult(slomData.getSlom(), MicroLearningPathway.class, resultLps, new String[]{"#HasMicroLpRelation1"});
    }

    @Test
    public void testGetLp_03_2() throws DbAccessException {
        SlomTestData03 slomData = SlomTestData03.getInstance();
        List<LearningObject> lHistory = new ArrayList<>();
        lHistory.add(slomData.getKo01());
        lHistory.add(slomData.getKo04());
        Collection<? extends LearningPathway> resultLps = metric.getLp(slomData.getSlom(), lHistory, MicroLearningPathway.class);
        assertNotNull("LP collection has falsely been returned as null.", resultLps);
        assertFalse("LP has falsely been returned with no elements.", resultLps.isEmpty());
        LpMetricHypercubeTest.testForLpsInResult(slomData.getSlom(), MicroLearningPathway.class, resultLps, new String[]{"#HasMicroLpRelation2"});
    }

    @Test
    public void testGetLp_04() throws DbAccessException {
        SlomTestData04 slomData = SlomTestData04.getInstance();
        List<LearningObject> lHistory = new ArrayList<>();
        lHistory.add(slomData.getCc04());
        lHistory.add(slomData.getCc05());
        Collection<? extends LearningPathway> resultLps = metric.getLp(slomData.getSlom(), lHistory, MacroLearningPathway.class);
        assertNotNull("LP collection has falsely been returned as null.", resultLps);
        assertFalse("LP has falsely been returned with no elements.", resultLps.isEmpty());
        LpMetricHypercubeTest.testForLpsInResult(slomData.getSlom(), MacroLearningPathway.class, resultLps, new String[]{"#HasMacroLpRelation2"});
    }
}
