/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2014-03-18
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.lpMetric;

import eu.intuitel.db.access.DbAccessException;
import eu.intuitel.db.access.DbAccessor;
import eu.intuitel.lpmProcessor.TestCommons;
import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.models.owlWrapper.abstractTypes.LearningPathway;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.MicroLearningPathway;
import eu.intuitel.lpmProcessor.test.mocks.SlomTestData01;
import eu.intuitel.lpmProcessor.utils.DbAccessUtil;
import java.util.Collection;
import org.junit.After;
import org.junit.AfterClass;
import static org.junit.Assert.*;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Tests for the LP popularity metric.
 *
 * @author fhe
 */
public class LpMetricPopularityTest {

    private static final Logger LOGGER = LoggerFactory.getLogger(LpMetricPopularityTest.class);
    private static LpMetricPopularity metric;
    private static SlomMetadata slom;
    private static LearningPathway lp1;
    private static LearningPathway lp2;

    @BeforeClass
    public static void setUpClass() {
        LOGGER.info("Starting tests.");

        SlomTestData01 slomData = SlomTestData01.getInstance();
        slom = slomData.getSlom();
        lp1 = slomData.getMicroLp01();
        lp2 = slomData.getMicroLp02();
    }

    @AfterClass
    public static void afterClass() {
        LOGGER.info("Finished tests.");
    }

    @Before
    public void setUpTest() {
        metric = new LpMetricPopularity();
        TestCommons.clearDataStorage();
    }

    @After
    public void afterTest() {
        TestCommons.clearDataStorage();
    }

    @Test
    public void testGetLp_1() throws DbAccessException {
        DbAccessor accessor = TestCommons.getAccessor();
        DbAccessUtil db = new DbAccessUtil("testLearnerId", accessor, slom);
        accessor.storeMicroLpSelection("testLearnerId", lp1.getIriAsString(), slom.getCourseId());
        accessor.storeMicroLpSelection("testLearnerId2", lp2.getIriAsString(), slom.getCourseId());
        accessor.storeMicroLpSelection("testLearnerId3", lp2.getIriAsString(), slom.getCourseId());
        accessor.storeMicroLpData(lp1.getIriAsString(), slom.getCourseId(), null, null);
        accessor.storeMicroLpData(lp2.getIriAsString(), slom.getCourseId(), null, null);

        Collection<? extends LearningPathway> resultLps = metric.getLp(slom, db, MicroLearningPathway.class);
        assertNotNull("LP collection has falsely been returned as null.", resultLps);
        assertFalse("LP has falsely been returned with no elements.", resultLps.isEmpty());
        assertEquals("The resultset does not contain the expected amount of LPs", 1, resultLps.size());
        assertTrue("The resultset does not contain the expected LP.", resultLps.contains(lp2));
    }

    @Test
    public void testGetLp_2() throws DbAccessException {
        DbAccessor accessor = TestCommons.getAccessor();
        DbAccessUtil db = new DbAccessUtil("testLearnerId", accessor, slom);
        accessor.storeMicroLpSelection("testLearnerId", lp1.getIriAsString(), slom.getCourseId());
        accessor.storeMicroLpSelection("testLearnerId2", lp1.getIriAsString(), slom.getCourseId());
        accessor.storeMicroLpSelection("testLearnerId3", lp2.getIriAsString(), slom.getCourseId());
        accessor.storeMicroLpData(lp1.getIriAsString(), slom.getCourseId(), null, null);
        accessor.storeMicroLpData(lp2.getIriAsString(), slom.getCourseId(), null, null);

        Collection<? extends LearningPathway> resultLps = metric.getLp(slom, db, MicroLearningPathway.class);
        assertNotNull("LP collection has falsely been returned as null.", resultLps);
        assertFalse("LP has falsely been returned with no elements.", resultLps.isEmpty());
        assertEquals("The resultset does not contain the expected amount of LPs", 1, resultLps.size());
        assertTrue("The resultset does not contain the expected LP.", resultLps.contains(lp1));
    }

    @Test
    public void testGetLp_3() throws DbAccessException {
        DbAccessor accessor = TestCommons.getAccessor();
        DbAccessUtil db = new DbAccessUtil("testLearnerId", accessor, slom);
        accessor.storeMicroLpSelection("testLearnerId", lp1.getIriAsString(), slom.getCourseId());
        accessor.storeMicroLpSelection("testLearnerId2", lp1.getIriAsString(), slom.getCourseId());
        accessor.storeMicroLpSelection("testLearnerId3", lp2.getIriAsString(), slom.getCourseId());
        accessor.storeMicroLpSelection("testLearnerId4", lp2.getIriAsString(), slom.getCourseId());
        accessor.storeMicroLpData(lp1.getIriAsString(), slom.getCourseId(), null, null);
        accessor.storeMicroLpData(lp2.getIriAsString(), slom.getCourseId(), null, null);

        Collection<? extends LearningPathway> resultLps = metric.getLp(slom, db, MicroLearningPathway.class);
        assertNotNull("LP collection has falsely been returned as null.", resultLps);
        assertFalse("LP has falsely been returned with no elements.", resultLps.isEmpty());
        assertEquals("The resultset does not contain the expected amount of LPs", 2, resultLps.size());
        assertTrue("The resultset does not contain the expected LP.", resultLps.contains(lp2));
        assertTrue("The resultset does not contain the expected LP.", resultLps.contains(lp1));
    }
}
