/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2014-05-20
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.lpReevaluation;

import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.KnowledgeObject;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.MicroLearningPathway;
import eu.intuitel.lpmProcessor.test.mocks.SlomTestData01;
import java.util.ArrayList;
import java.util.List;
import org.junit.AfterClass;
import static org.junit.Assert.*;
import org.junit.BeforeClass;
import org.junit.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Tests for the deviation criterion.
 *
 * @author Florian Heberle
 */
public class LpReevaluationCriterionDeviationTest {

    private static final Logger LOGGER = LoggerFactory.getLogger(LpReevaluationCriterionDeviationTest.class);
    private static SlomMetadata slom;
    private static MicroLearningPathway lp;
    private static KnowledgeObject ko1;
    private static KnowledgeObject ko2;
    private static KnowledgeObject ko3;
    private static KnowledgeObject ko4;
    private final LpReevaluationCriterionDeviation eval;

    public LpReevaluationCriterionDeviationTest() {
        eval = new LpReevaluationCriterionDeviation();
    }

    @BeforeClass
    public static void beforeClass() {
        LOGGER.info("Starting tests.");

        SlomTestData01 slomData = SlomTestData01.getInstance();
        slom = slomData.getSlom();
        lp = slomData.getMicroLp01();
        ko1 = slomData.getKo01();
        ko2 = slomData.getKo02();
        ko3 = slomData.getKo03();
        ko4 = slomData.getKo04();
    }

    @AfterClass
    public static void afterClass() {
        LOGGER.info("Finished tests.");
    }

    @Test
    public void testFulfillsCriterionInvalid() {
        assertFalse("Criterion was met, although it was expected to fail.", eval.fulfillsCriterion(lp, null, null));
        List<List<KnowledgeObject>> steps = new ArrayList<>();
        List<KnowledgeObject> history = new ArrayList<>();
        assertFalse("Criterion was met, although it was expected to fail.", eval.fulfillsCriterion(lp, null, steps));
        assertFalse("Criterion was met, although it was expected to fail.", eval.fulfillsCriterion(lp, history, null));
        assertFalse("Criterion was met, although it was expected to fail.", eval.fulfillsCriterion(lp, history, steps));
        steps.add(new ArrayList<KnowledgeObject>());
        assertFalse("Criterion was met, although it was expected to fail.", eval.fulfillsCriterion(lp, history, steps));
    }

    @Test
    public void testFulfillsCriterionShouldFail() {
        List<KnowledgeObject> recoms1 = new ArrayList<>();
        recoms1.add(ko4);
        List<KnowledgeObject> recoms2 = new ArrayList<>();
        recoms2.add(ko3);
        List<KnowledgeObject> recoms3 = new ArrayList<>();
        recoms3.add(ko2);
        List<KnowledgeObject> recoms4 = new ArrayList<>();
        recoms4.add(ko1);
        List<List<KnowledgeObject>> steps = new ArrayList<>();
        steps.add(recoms1);
        steps.add(recoms2);
        steps.add(recoms3);
        steps.add(recoms4);

        List<KnowledgeObject> history = new ArrayList<>();
        history.add(ko1);
        history.add(ko2);
        history.add(ko3);
        history.add(ko4);
        assertFalse("Criterion was met, although it was expected to fail.", eval.fulfillsCriterion(lp, history, steps));
    }

    @Test
    public void testFulfillsCriterionShouldSucceed() {
        List<KnowledgeObject> recoms1 = new ArrayList<>();
        recoms1.add(ko1);
        List<KnowledgeObject> recoms2 = new ArrayList<>();
        recoms2.add(ko2);
        List<KnowledgeObject> recoms3 = new ArrayList<>();
        recoms3.add(ko3);
        List<KnowledgeObject> recoms4 = new ArrayList<>();
        recoms4.add(ko4);
        List<List<KnowledgeObject>> steps = new ArrayList<>();
        steps.add(recoms1);
        steps.add(recoms2);
        steps.add(recoms3);
        steps.add(recoms4);

        List<KnowledgeObject> history = new ArrayList<>();
        history.add(ko1);
        history.add(ko2);
        history.add(ko3);
        history.add(ko4);
        assertTrue("Criterion was not met, although it was expected to succeed.", eval.fulfillsCriterion(lp, history, steps));
    }
}
