/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2013-11-20
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes;

import eu.intuitel.lpmProcessor.OntoMngr;
import eu.intuitel.lpmProcessor.models.owlWrapper.ontologies.PedagogicalOntology;
import org.junit.AfterClass;
import org.junit.Test;
import static org.junit.Assert.*;
import org.junit.BeforeClass;
import org.semanticweb.owlapi.model.OWLNamedIndividual;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Tests for KT creation.
 *
 * @author fhe
 */
public class KnowledgeTypeTest {

    private static final Logger LOGGER = LoggerFactory.getLogger(KnowledgeTypeTest.class);

    @BeforeClass
    public static void beforeClass() {
        LOGGER.info("Starting tests.");
    }

    @AfterClass
    public static void afterClass() {
        LOGGER.info("Finished tests.");
    }

    @Test
    public void testGetSuperTypes() {
        KnowledgeType testType = null;
        for (OWLNamedIndividual i : OntoMngr.PO.getOntoObj().getIndividualsInSignature()) {
            if (i.getIRI().toString().equalsIgnoreCase(PedagogicalOntology.BASE_IRI + "ktFormulateQuestionsPrinciple")) {
                testType = KnowledgeType.createInstance(i);
                break;
            }
        }
        assertNotNull("Test KT is null.", testType);
        assertEquals("More than the expected amount of super types returned for test KT.", 1, testType.getSuperTypes(true).size());
        assertEquals("Not enough super types returned for test KT.", 3, testType.getSuperTypes(false).size());
    }

    @Test
    public void testGetSubTypes() {
        KnowledgeType testType = null;
        for (OWLNamedIndividual i : OntoMngr.PO.getOntoObj().getIndividualsInSignature()) {
            if (i.getIRI().toString().equalsIgnoreCase(PedagogicalOntology.BASE_IRI + "ktActionReceptive")) {
                testType = KnowledgeType.createInstance(i);
                break;
            }
        }
        assertNotNull("Test KT is null.", testType);
        assertEquals("More than the expected amount of sub types returned for test KT.", 5, testType.getSubTypes(true).size());
        assertEquals("Not enough sub types returned for test KT.", 8, testType.getSubTypes(false).size());
    }
}
