/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2013-11-05
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.test.mocks;

import eu.intuitel.lpmGeneralInterfaces.IEngineCommunicator;
import eu.intuitel.lpmProcessor.models.owlWrapper.ontologies.LearnerStateOntology;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import org.apache.commons.lang.StringUtils;

/**
 * Mock class for testing the engine communication.
 * All return values are accessible via public variables.
 *
 * @author fhe
 */
public class ComEngineMock implements IEngineCommunicator {

    public ArrayList<String> reflexMsgs = new ArrayList<>();
    public String lso;

    public ComEngineMock() {
    }

    /**
     * Returns the reflexes send to the Engine.
     *
     * @return May be empty, but never null.
     */
    public Collection<String> getReflexes() {
        return reflexMsgs;
    }

    /**
     * Returns the LSO which has been send to the Engine.
     *
     * @return May be null.
     */
    public LearnerStateOntology getLso() {
        if (StringUtils.isBlank(lso)) {
            return null;
        }
        return LearnerStateOntology.deserialize(lso);
    }

    @Override
    public void sendReflex(String learnerId, String mId, Boolean abortsRecom, String courseId, String reason, List<Option> options) {
        reflexMsgs.add(String.format("%s, %s, %s, %s, %s", learnerId, mId, abortsRecom, courseId, reason, options));
    }

    @Override
    public void sendLso(String mId, String lId, String cId, boolean ccmUpdateNeeded, boolean cmUpdateNeeded, String lso) {
        this.lso = lso;
    }
}
