/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 23.07.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.test.mocks;

import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.ConceptContainer;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.KnowledgeObject;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.MacroLearningPathway;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.MicroLearningPathway;
import static org.junit.Assert.*;

/**
 * Helper class to access data from SLOM test data case01.<br/>
 * microLp01: 1>2 & 3>4<br/>
 * microLp02: 4>3 & 2>1<br/>
 * macroLp01: 1>2
 *
 * @author Florian Heberle
 */
public class SlomTestData01 extends SlomTestDataBase {

    private static final SlomTestData01 INSTANCE;
    private static final SlomMetadata SLOM;
    private static final String CCM = BASEPATH + "valid/case01/intuitel/intui_CCM.owl";
    private static final String CM = BASEPATH + "valid/case01/intuitel/intui_CM.owl";
    private static final String MSG = "Loading TestFile01";

    private static final KnowledgeObject KO1;
    private static final KnowledgeObject KO2;
    private static final KnowledgeObject KO3;
    private static final KnowledgeObject KO4;
    private static final ConceptContainer CC1;
    private static final ConceptContainer CC2;
    private static final ConceptContainer CC3;
    private static final MicroLearningPathway MICROLP1;
    private static final MicroLearningPathway MICROLP2;
    private static final MacroLearningPathway MACROLP1;

    static {
        INSTANCE = new SlomTestData01();
        assertNotNull(INSTANCE);

        SLOM = loadSlom(CCM, CM, MSG);
        KO1 = getKo(SLOM, SLOM.getCcm().getIriAsString() + "#Ko01", SlomTestData01.class);
        KO2 = getKo(SLOM, SLOM.getCcm().getIriAsString() + "#Ko02", SlomTestData01.class);
        KO3 = getKo(SLOM, SLOM.getCcm().getIriAsString() + "#Ko03", SlomTestData01.class);
        KO4 = getKo(SLOM, SLOM.getCcm().getIriAsString() + "#Ko04", SlomTestData01.class);
        CC1 = getCc(SLOM, SLOM.getCm().getIriAsString() + "#Cc01", SlomTestData01.class);
        CC2 = getCc(SLOM, SLOM.getCm().getIriAsString() + "#Cc02", SlomTestData01.class);
        CC3 = getCc(SLOM, SLOM.getCm().getIriAsString() + "#Cc03", SlomTestData01.class);
        MICROLP1 = getMicroLp(SLOM, SLOM.getCcm().getIriAsString() + "#HasMicroLpRelation1", SlomTestData01.class);
        MICROLP2 = getMicroLp(SLOM, SLOM.getCcm().getIriAsString() + "#HasMicroLpRelation2", SlomTestData01.class);
        MACROLP1 = getMacroLp(SLOM, SLOM.getCm().getIriAsString() + "#HasMacroLpRelation1", SlomTestData01.class);
    }

    protected SlomTestData01() {
    }

    public static SlomTestData01 getInstance() {
        return INSTANCE;
    }

    public SlomMetadata getSlom() {
        return SLOM;
    }

    /**
     * Assigned to CC01.
     *
     * @return Ko01
     */
    public KnowledgeObject getKo01() {
        return KO1;
    }

    /**
     * Assigned to CC01.
     *
     * @return Ko02
     */
    public KnowledgeObject getKo02() {
        return KO2;
    }

    /**
     * Assigned to CC02.
     *
     * @return Ko03
     */
    public KnowledgeObject getKo03() {
        return KO3;
    }

    /**
     * Assigned to CC02.
     *
     * @return Ko04
     */
    public KnowledgeObject getKo04() {
        return KO4;
    }

    /**
     * Connected to Ko01 and Ko02
     *
     * @return Cc01
     */
    public ConceptContainer getCc01() {
        return CC1;
    }

    /**
     * Connected to Ko03 and Ko04
     *
     * @return Cc02
     */
    public ConceptContainer getCc02() {
        return CC2;
    }

    /**
     * Connected to no KOs.
     *
     * @return Cc02
     */
    public ConceptContainer getCc03() {
        return CC3;
    }

    public MicroLearningPathway getMicroLp01() {
        return MICROLP1;
    }

    public MicroLearningPathway getMicroLp02() {
        return MICROLP2;
    }

    public MacroLearningPathway getMacroLp01() {
        return MACROLP1;
    }

    @Override
    public String getCcmFilePath() {
        return CCM;
    }

    @Override
    public String getCmFilePath() {
        return CM;
    }
}
