/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 23.07.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.test.mocks;

import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.ConceptContainer;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.KnowledgeObject;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.MacroLearningPathway;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.MicroLearningPathway;
import static org.junit.Assert.*;

/**
 * Helper class to access data from SLOM test data case03.<br/>
 * microLp01-1: 1>2>4<br/>
 * microLp01-2: 1>3>4<br/>
 * microLp02: 1>4>5<br/>
 * macroLp01: 1>2<br/>
 *
 * @author Florian Heberle
 */
public class SlomTestData03 extends SlomTestDataBase {

    private static final SlomTestData03 INSTANCE;
    private static final SlomMetadata SLOM;
    private static final String CCM = BASEPATH + "valid/case03/intuitel/intui_CCM.owl";
    private static final String CM = BASEPATH + "valid/case03/intuitel/intui_CM.owl";
    private static final String MSG = "Loading TestFile03";

    private static final KnowledgeObject KO1;
    private static final KnowledgeObject KO2;
    private static final KnowledgeObject KO3;
    private static final KnowledgeObject KO4;
    private static final KnowledgeObject KO5;
    private static final ConceptContainer CC1;
    private static final ConceptContainer CC2;
    private static final ConceptContainer CC3;
    private static final MicroLearningPathway MICROLP1;
    private static final MicroLearningPathway MICROLP2;
    private static final MacroLearningPathway MACROLP1;

    static {
        INSTANCE = new SlomTestData03();
        assertNotNull(INSTANCE);
        SLOM = loadSlom(CCM, CM, MSG);
        KO1 = getKo(SLOM, SLOM.getCcm().getIriAsString() + "#Ko01", SlomTestData03.class);
        KO2 = getKo(SLOM, SLOM.getCcm().getIriAsString() + "#Ko02", SlomTestData03.class);
        KO3 = getKo(SLOM, SLOM.getCcm().getIriAsString() + "#Ko03", SlomTestData03.class);
        KO4 = getKo(SLOM, SLOM.getCcm().getIriAsString() + "#Ko04", SlomTestData03.class);
        KO5 = getKo(SLOM, SLOM.getCcm().getIriAsString() + "#Ko05", SlomTestData03.class);
        CC1 = getCc(SLOM, SLOM.getCm().getIriAsString() + "#Cc01", SlomTestData03.class);
        CC2 = getCc(SLOM, SLOM.getCm().getIriAsString() + "#Cc02", SlomTestData03.class);
        CC3 = getCc(SLOM, SLOM.getCm().getIriAsString() + "#Cc03", SlomTestData03.class);
        MICROLP1 = getMicroLp(SLOM, SLOM.getCcm().getIriAsString() + "#HasMicroLpRelation1", SlomTestData03.class);
        MICROLP2 = getMicroLp(SLOM, SLOM.getCcm().getIriAsString() + "#HasMicroLpRelation2", SlomTestData03.class);
        MACROLP1 = getMacroLp(SLOM, SLOM.getCm().getIriAsString() + "#HasMacroLpRelation1", SlomTestData03.class);
    }

    protected SlomTestData03() {
    }

    public static SlomTestData03 getInstance() {
        return INSTANCE;
    }

    public SlomMetadata getSlom() {
        return SLOM;
    }

    public KnowledgeObject getKo01() {
        return KO1;
    }

    public KnowledgeObject getKo02() {
        return KO2;
    }

    public KnowledgeObject getKo03() {
        return KO3;
    }

    public KnowledgeObject getKo04() {
        return KO4;
    }

    public KnowledgeObject getKo05() {
        return KO5;
    }

    public ConceptContainer getCc01() {
        return CC1;
    }

    public ConceptContainer getCc02() {
        return CC2;
    }

    public ConceptContainer getCc03() {
        return CC3;
    }

    public MicroLearningPathway getMicroLp01() {
        return MICROLP1;
    }

    public MicroLearningPathway getMicroLp02() {
        return MICROLP2;
    }

    public MacroLearningPathway getMacroLp01() {
        return MACROLP1;
    }

    @Override
    public String getCcmFilePath() {
        return CCM;
    }

    @Override
    public String getCmFilePath() {
        return CM;
    }
}
