/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 23.07.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.test.mocks;

import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.ConceptContainer;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.KnowledgeObject;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.MacroLearningPathway;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.MicroLearningPathway;
import static org.junit.Assert.*;

/**
 * Helper class to access data from SLOM test data case04.<br/>
 * macroLp01-1: 1>2>5<br/>
 * macroLp01-2: 1>3>5<br/>
 * macroLp02: 1>4>5<br/>
 *
 * @author Florian Heberle
 */
public class SlomTestData04 extends SlomTestDataBase {

    private static final SlomTestData04 INSTANCE;
    private static final SlomMetadata SLOM;
    private static final String CCM = BASEPATH + "valid/case04/intuitel/intui_CCM.owl";
    private static final String CM = BASEPATH + "valid/case04/intuitel/intui_CM.owl";
    private static final String MSG = "Loading TestFile04";

    private static final KnowledgeObject KO1;
    private static final KnowledgeObject KO2;
    private static final KnowledgeObject KO3;
    private static final KnowledgeObject KO4;
    private static final KnowledgeObject KO5;
    private static final KnowledgeObject KO6;
    private static final KnowledgeObject KO7;
    private static final KnowledgeObject KO8;
    private static final KnowledgeObject KO9;
    private static final KnowledgeObject KO10;
    private static final KnowledgeObject KO11;
    private static final ConceptContainer CC1;
    private static final ConceptContainer CC2;
    private static final ConceptContainer CC3;
    private static final ConceptContainer CC4;
    private static final ConceptContainer CC5;
    private static final MicroLearningPathway MICROLP1;
    private static final MacroLearningPathway MACROLP1;
    private static final MacroLearningPathway MACROLP2;

    static {
        INSTANCE = new SlomTestData04();
        assertNotNull(INSTANCE);
        SLOM = loadSlom(CCM, CM, MSG);
        KO1 = getKo(SLOM, SLOM.getCcm().getIriAsString() + "#Ko01", SlomTestData04.class);
        KO2 = getKo(SLOM, SLOM.getCcm().getIriAsString() + "#Ko02", SlomTestData04.class);
        KO3 = getKo(SLOM, SLOM.getCcm().getIriAsString() + "#Ko03", SlomTestData04.class);
        KO4 = getKo(SLOM, SLOM.getCcm().getIriAsString() + "#Ko04", SlomTestData04.class);
        KO5 = getKo(SLOM, SLOM.getCcm().getIriAsString() + "#Ko05", SlomTestData04.class);
        KO6 = getKo(SLOM, SLOM.getCcm().getIriAsString() + "#Ko06", SlomTestData04.class);
        KO7 = getKo(SLOM, SLOM.getCcm().getIriAsString() + "#Ko07", SlomTestData04.class);
        KO8 = getKo(SLOM, SLOM.getCcm().getIriAsString() + "#Ko08", SlomTestData04.class);
        KO9 = getKo(SLOM, SLOM.getCcm().getIriAsString() + "#Ko09", SlomTestData04.class);
        KO10 = getKo(SLOM, SLOM.getCcm().getIriAsString() + "#Ko10", SlomTestData04.class);
        KO11 = getKo(SLOM, SLOM.getCcm().getIriAsString() + "#Ko11", SlomTestData04.class);
        CC1 = getCc(SLOM, SLOM.getCm().getIriAsString() + "#Cc01", SlomTestData04.class);
        CC2 = getCc(SLOM, SLOM.getCm().getIriAsString() + "#Cc02", SlomTestData04.class);
        CC3 = getCc(SLOM, SLOM.getCm().getIriAsString() + "#Cc03", SlomTestData04.class);
        CC4 = getCc(SLOM, SLOM.getCm().getIriAsString() + "#Cc04", SlomTestData04.class);
        CC5 = getCc(SLOM, SLOM.getCm().getIriAsString() + "#Cc05", SlomTestData04.class);
        MICROLP1 = getMicroLp(SLOM, SLOM.getCcm().getIriAsString() + "#HasMicroLpRelation1", SlomTestData04.class);
        MACROLP1 = getMacroLp(SLOM, SLOM.getCm().getIriAsString() + "#HasMacroLpRelation1", SlomTestData04.class);
        MACROLP2 = getMacroLp(SLOM, SLOM.getCm().getIriAsString() + "#HasMacroLpRelation2", SlomTestData04.class);
    }

    protected SlomTestData04() {
    }

    public static SlomTestData04 getInstance() {
        return INSTANCE;
    }

    public SlomMetadata getSlom() {
        return SLOM;
    }

    /**
     * Ref on CC01
     *
     * @return KO01
     */
    public KnowledgeObject getKo01() {
        return KO1;
    }

    /**
     * Ref on CC01
     *
     * @return KO02
     */
    public KnowledgeObject getKo02() {
        return KO2;
    }

    /**
     * Ref on CC02
     *
     * @return KO03
     */
    public KnowledgeObject getKo03() {
        return KO3;
    }

    /**
     * Ref on CC02
     *
     * @return KO04
     */
    public KnowledgeObject getKo04() {
        return KO4;
    }

    /**
     * Ref on CC03
     *
     * @return KO05
     */
    public KnowledgeObject getKo05() {
        return KO5;
    }

    /**
     * Ref on CC03
     *
     * @return KO05
     */
    public KnowledgeObject getKo06() {
        return KO6;
    }

    /**
     * Ref on CC04
     *
     * @return KO07
     */
    public KnowledgeObject getKo07() {
        return KO7;
    }

    /**
     * Ref on CC04
     *
     * @return KO08
     */
    public KnowledgeObject getKo08() {
        return KO8;
    }

    /**
     * Ref on CC04
     *
     * @return KO09
     */
    public KnowledgeObject getKo09() {
        return KO9;
    }

    /**
     * Ref on CC05
     *
     * @return KO10
     */
    public KnowledgeObject getKo10() {
        return KO10;
    }

    /**
     * Ref on CC05
     *
     * @return KO11
     */
    public KnowledgeObject getKo11() {
        return KO11;
    }

    public ConceptContainer getCc01() {
        return CC1;
    }

    public ConceptContainer getCc02() {
        return CC2;
    }

    public ConceptContainer getCc03() {
        return CC3;
    }

    public ConceptContainer getCc04() {
        return CC4;
    }

    public ConceptContainer getCc05() {
        return CC5;
    }

    public MicroLearningPathway getMicroLp01() {
        return MICROLP1;
    }

    public MacroLearningPathway getMacroLp01() {
        return MACROLP1;
    }

    public MacroLearningPathway getMacroLp02() {
        return MACROLP2;
    }

    @Override
    public String getCcmFilePath() {
        return CCM;
    }

    @Override
    public String getCmFilePath() {
        return CM;
    }
}
