/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 23.07.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.test.mocks;

import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.models.factories.SlomFactory;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.ConceptContainer;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.KnowledgeObject;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.MacroLearningPathway;
import eu.intuitel.lpmProcessor.models.owlWrapper.concreteTypes.MicroLearningPathway;
import java.io.File;
import static org.junit.Assert.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 *
 * @author Florian Heberle
 */
public abstract class SlomTestDataBase {

    private static final Logger LOGGER = LoggerFactory.getLogger(SlomTestDataBase.class);
    public static final String BASEPATH = "../LpmComInterface/src/test/resources/slomTestRepository/";

    protected static SlomMetadata loadSlom(String ccmPath, String cmPath, String loadingMsg) {
        try {
            LOGGER.debug(loadingMsg);
            return SlomFactory.createNewInstance(new File(ccmPath), new File(cmPath));
        } catch (Exception ex) {
            assertNotNull(String.format("Exception on loading SLOM data for CCM '%s' and CM '%s'.", ccmPath, cmPath), ex);
            return null;
        }
    }

    protected static <T extends SlomTestDataBase> KnowledgeObject getKo(SlomMetadata slom, String iri, Class<T> clazz) {
        assertNotNull(slom);
        KnowledgeObject item = slom.getKoByIri(iri);
        assertNotNull(String.format("KnowledgeObject '%s' missing for SLOM element '%s'.", iri, clazz.getName()), item);
        return item;
    }

    protected static <T extends SlomTestDataBase> ConceptContainer getCc(SlomMetadata slom, String iri, Class<T> clazz) {
        assertNotNull(slom);
        ConceptContainer item = slom.getCcByIri(iri);
        assertNotNull(String.format("ConceptContainer '%s' missing for SLOM element '%s'.", iri, clazz.getClass().getName()), item);
        return item;
    }

    protected static <T extends SlomTestDataBase> MicroLearningPathway getMicroLp(SlomMetadata slom, String iri, Class<T> clazz) {
        assertNotNull(slom);
        MicroLearningPathway item = slom.getMicroLp(iri);
        assertNotNull(String.format("MicroLearningPathway '%s' missing for SLOM element '%s'.", iri, clazz.getClass().getName()), item);
        return item;
    }

    protected static <T extends SlomTestDataBase> MacroLearningPathway getMacroLp(SlomMetadata slom, String iri, Class<T> clazz) {
        assertNotNull(slom);
        MacroLearningPathway item = slom.getMacroLp(iri);
        assertNotNull(String.format("MacroLearningPathway '%s' missing for SLOM element '%s'.", iri, clazz.getClass().getName()), item);
        return item;
    }

    public abstract String getCcmFilePath();

    public abstract String getCmFilePath();
}
