/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 23.07.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.test.mocks;

import eu.intuitel.lpmProcessor.models.SlomMetadata;
import static org.junit.Assert.*;

/**
 * Helper class to access data from SLOM test data case01.<br/>
 * microLp01: 1>2 & 3>4<br/>
 * microLp02: 4>3 & 2>1<br/>
 * macroLp01: 1>2
 *
 * @author Florian Heberle
 */
public class SlomTestDataUvie extends SlomTestDataBase {

    private static final SlomTestDataUvie INSTANCE;
    private static final SlomMetadata SLOM;
    private static final String CCM = BASEPATH + "authentic/uvie/intuitel/intui_CCM.owl";
    private static final String CM = BASEPATH + "authentic/uvie/intuitel/intui_CM.owl";
    private static final String MSG = "Loading UVIE test data";

    static {
        INSTANCE = new SlomTestDataUvie();
        assertNotNull(INSTANCE);

        SLOM = loadSlom(CCM, CM, MSG);
    }

    protected SlomTestDataUvie() {
    }

    public static SlomTestDataUvie getInstance() {
        return INSTANCE;
    }

    public SlomMetadata getSlom() {
        return SLOM;
    }

    @Override
    public String getCcmFilePath() {
        return CCM;
    }

    @Override
    public String getCmFilePath() {
        return CM;
    }
}
