/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 2014-03-12
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.utils;

import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.models.owlWrapper.abstractTypes.LearningPathway;
import eu.intuitel.lpmProcessor.test.mocks.SlomTestData01;
import eu.intuitel.lpmProcessor.test.mocks.SlomTestData02;
import eu.intuitel.lpmProcessor.test.mocks.SlomTestData03;
import eu.intuitel.lpmProcessor.test.mocks.SlomTestData04;
import eu.intuitel.lpmProcessor.test.mocks.SlomTestDataUvie;
import eu.intuitel.lpmProcessor.test.mocks.SlomTestDataVeggieSoup;
import java.io.File;
import org.junit.AfterClass;
import static org.junit.Assert.*;
import org.junit.BeforeClass;
import org.junit.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Debugger test for the visualization of LPs.
 * The algorithm produces a GraphViz-File, which can be used to create a graphical representation of
 * given LPs. To create the output, execute "dot -Tsvg INPUTFILE.gv > OUTPUTFILE.svg" in commandline
 * or execute the created batch file. This requires GraphViz to be installed on the system.
 *
 * @author fhe
 */
public class LpGrapherUtilTest {

    private static final Logger LOGGER = LoggerFactory.getLogger(LpGrapherUtilTest.class);
    private final String baseDir = System.getProperty("java.io.tmpdir") + "\\LP-graphs\\%s";

    @BeforeClass
    public static void beforeClass() {
        LOGGER.info("Starting tests.");
    }

    @AfterClass
    public static void afterClass() {
        LOGGER.info("Finished tests.");
    }

    @Test
    public void testCreateGraph_UVIE() {
        SlomMetadata slom = SlomTestDataUvie.getInstance().getSlom();
        String dir = String.format(baseDir, "UVIE");
        testIndividualLps(slom, dir);
        testSlom(slom, dir);
    }

    @Test
    public void testCreateGraph_Case01() {
        SlomMetadata slom = SlomTestData01.getInstance().getSlom();
        String dir = String.format(baseDir, "case01");
        testIndividualLps(slom, dir);
        testSlom(slom, dir);
    }

    @Test
    public void testCreateGraph_Case02() {
        SlomMetadata slom = SlomTestData02.getInstance().getSlom();
        String dir = String.format(baseDir, "case02");
        testIndividualLps(slom, dir);
        testSlom(slom, dir);
    }

    @Test
    public void testCreateGraph_Case03() {
        SlomMetadata slom = SlomTestData03.getInstance().getSlom();
        String dir = String.format(baseDir, "case03");
        testIndividualLps(slom, dir);
        testSlom(slom, dir);
    }

    @Test
    public void testCreateGraph_Case04() {
        SlomMetadata slom = SlomTestData04.getInstance().getSlom();
        String dir = String.format(baseDir, "case04");
        testIndividualLps(slom, dir);
        testSlom(slom, dir);
    }

    @Test
    public void testCreateGraph_Veggie() {
        SlomMetadata slom = SlomTestDataVeggieSoup.getInstance().getSlom();
        String dir = String.format(baseDir, "VeggieSoup");
        testIndividualLps(slom, dir);
        testSlom(slom, dir);
    }

    private void testIndividualLps(SlomMetadata slom, String outputDir) {
        for (LearningPathway lp : slom.getMacroLps()) {
            assertTrue(String.format("Visualization of %s failed.", lp.getIri().getFragment()),
                    LpGrapherUtil.createGraph(lp, new File(outputDir)));

        }
        for (LearningPathway lp : slom.getMicroLps()) {
            assertTrue(String.format("Visualization of %s failed.", lp.getIri().getFragment()),
                    LpGrapherUtil.createGraph(lp, new File(outputDir)));
        }
    }

    private void testSlom(SlomMetadata slom, String outputDir) {
        assertTrue(String.format("Visualization of %s failed.", slom.toString()),
                LpGrapherUtil.createGraph(slom, new File(outputDir)));
    }
}
