/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 29.07.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.lpmProcessor.utils;

import eu.intuitel.lpmProcessor.models.SlomMetadata;
import eu.intuitel.lpmProcessor.models.owlWrapper.ontologies.PedagogicalOntology;
import eu.intuitel.lpmProcessor.test.mocks.SlomTestDataUvie;
import java.io.BufferedWriter;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.io.Writer;
import java.util.HashMap;
import java.util.Map;
import org.apache.commons.lang3.tuple.Pair;
import static org.junit.Assert.*;
import org.junit.Test;
import org.semanticweb.owlapi.model.OWLOntology;

/**
 * Test for the SLOM extender util.
 *
 * @author Florian Heberle
 */
public class SlomExtenderUtilTest {

    @Test
    public void testExtendUvie() {
        SlomMetadata slom = SlomTestDataUvie.getInstance().getSlom();
        Pair<OWLOntology, OWLOntology> extendedOntos = SlomExtenderUtil.extendWithLpStarters(
                slom.getCm().getOntoObj(),
                slom.getMacroLps(),
                slom.getCcm().getOntoObj(),
                slom.getMicroLps());
        assertNotNull(extendedOntos);
        extendedOntos = SlomExtenderUtil.extendWithLpEnders(
                extendedOntos.getLeft(),
                slom.getMacroLps(),
                extendedOntos.getRight(),
                slom.getMicroLps());
        assertNotNull(extendedOntos);

        Map<String, String> prefixes = new HashMap<>();
        prefixes.put("intui_PO", PedagogicalOntology.BASE_IRI);
        assertTrue(saveAsFile(
                System.getProperty("java.io.tmpdir") + "\\uvie_CM_WithFirstLastLpElements.owl",
                OwlUtil.toXml(extendedOntos.getLeft(), prefixes)));
        assertTrue(saveAsFile(
                System.getProperty("java.io.tmpdir") + "\\uvie_CCM_WithFirstLastLpElements.owl",
                OwlUtil.toXml(extendedOntos.getRight(), prefixes)));
    }

    private boolean saveAsFile(String filepath, String content) {
        Writer out = null;
        try {
            out = new BufferedWriter(
                    new OutputStreamWriter(
                            new FileOutputStream(filepath),
                            "UTF-8"));
            out.write(content);
        } catch (IOException ex) {
            assertEquals(null, ex);
            return false;
        } finally {
            if (out != null) {
                try {
                    out.close();
                } catch (IOException ex) {
                    //noop
                }
            }
        }
        return true;
    }
}
