/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Ovidiu Serban, University of Reading, United Kingdom, http://www.isr.reading.ac.uk/
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 11.07.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.db.access;

import eu.intuitel.types.DifficultyLevel;
import eu.intuitel.types.EqfLevel;
import org.junit.After;
import org.junit.BeforeClass;
import org.junit.Test;

import static org.junit.Assert.*;

/**
 * Various learner preference related tests.
 *
 * @author Florian Heberle
 */
public class LearnerPreferenceTest {

    private static final String ID = "TESTLEARNER_PREF";
    private static final String ID2 = "TESTLEARNER_PREF2";
    private static final EqfLevel EQF = EqfLevel.LVL4;
    private static final DifficultyLevel DIFFICULTY = DifficultyLevel.Intermediate;
    private static final String COURSEID = "LPREFC";
    private static DbAccessor db;

    @BeforeClass
    public static void setup() {
        db = TestCommons.getAccessor();
    }

    @After
    public void cleanUp() {
        db.clearDataStorage();
    }

    @Test
    public void testSessionData() {
        assertTrue(db.storeLearnerPreference(ID, COURSEID, EQF, DIFFICULTY));
        assertTrue(EQF.equals(db.getPreferredEqfLevel(ID, COURSEID)));
        assertTrue(DIFFICULTY.equals(db.getPreferredDifficultyLevel(ID, COURSEID)));
    }

    @Test
    public void testDifficultySetters() {
        assertTrue(db.storeLearnerPreference(ID, COURSEID, EQF, DifficultyLevel.Unknown));
        assertTrue(db.increasePreferredDifficulty(ID, COURSEID));
        assertEquals(DifficultyLevel.DEFAULT, db.getPreferredDifficultyLevel(ID, COURSEID));
        assertTrue(db.decreasePreferredDifficulty(ID, COURSEID));
        assertEquals(DifficultyLevel.Beginner, db.getPreferredDifficultyLevel(ID, COURSEID));
    }

    @Test
    public void testInvalidSessionData() {
        assertNull(db.getPreferredEqfLevel(ID2, COURSEID));
        assertNull(db.getPreferredDifficultyLevel(ID2, COURSEID));
    }
}
