/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Contributor: Ovidiu Serban, University of Reading, www.reading.ac.uk
 * Version: [0.01]
 * Date: 17.07.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.db.access;

import eu.intuitel.types.Culture;
import eu.intuitel.types.Gender;
import eu.intuitel.types.Language;
import java.util.Collection;
import org.junit.AfterClass;
import static org.junit.Assert.*;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 * Learner related tests.
 *
 * @author Florian Heberle
 */
public class LearnerTest {

    private static final String LID = "LEARNERTEST_ID";
    private static final String LID2 = "LEARNERTEST_ID2";
    private static final String NAME = "Horst";
    private static final Integer AGE = 23;
    private static final Gender GENDER = Gender.Female;
    private static final Culture CULTURE = Culture.European;
    private static final Boolean BLIND = true;
    private static final Boolean MUTE = true;
    private static final Boolean DEAF = true;
    private static final Language[] LANGS = new Language[]{Language.English, Language.German};
    private static DbAccessor db;

    @BeforeClass
    public static void setup() {
        db = TestCommons.getAccessor();
    }

    @AfterClass
    public static void cleanUp() {
        db.removeLearner(LID);
    }

    @Test
    public void testLearnerData() {
        assertTrue(db.storeLearner(LID, NAME, GENDER, AGE, CULTURE, BLIND, MUTE, DEAF, LANGS));
        assertEquals(NAME, db.getLearnerName(LID));
        assertEquals(AGE, db.getLearnerAge(LID));
        assertTrue(GENDER.equals(db.getLearnerGender(LID)));
        assertEquals(CULTURE, db.getLearnerCulture(LID));
        assertEquals(BLIND, db.isLearnerBlind(LID));
        assertEquals(DEAF, db.isLearnerDeaf(LID));
        assertEquals(MUTE, db.isLearnerMute(LID));
        Collection<Language> langs = db.getLearnerLanguages(LID);
        for (Language lang : LANGS) {
            assertTrue(langs.contains(lang));
        }
    }

    @Test
    public void testSetLearnerData() {
        assertTrue(db.storeLearner(LID, NAME, GENDER, AGE, CULTURE, BLIND, MUTE, DEAF, LANGS));
        db.setLearnerAge(LID, 5);
        db.setLearnerGender(LID, Gender.Male);

        assertEquals(5, db.getLearnerAge(LID).intValue());
        assertTrue(Gender.Male.equals(db.getLearnerGender(LID)));
    }

    @Test
    public void testInvalidLearnerData() {
        assertNull(db.getLearnerName(LID2));
        assertNull(db.getLearnerAge(LID2));
        assertNull(db.getLearnerGender(LID2));
        assertNull(db.getLearnerCulture(LID2));
        assertNull(db.isLearnerBlind(LID2));
        assertNull(db.isLearnerDeaf(LID2));
        assertNull(db.isLearnerMute(LID2));
        assertTrue(db.getLearnerLanguages(LID2).isEmpty());
    }
}
