/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Ovidiu Serban, University of Reading, United Kingdom, http://www.isr.reading.ac.uk/
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 06.06.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.db.access;

import org.junit.AfterClass;
import static org.junit.Assert.*;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 * Various learning history related tests.
 *
 * @author Ovidiu Serban
 * @author Florian Heberle
 */
public class LearningHistoryTests {

    private static final String KO1_IRI = "TEST_LH_ko1IRI";
    private static final String KO1_LMSID = "TEST_LH_ko1LmsId";
    private static final String KO2_IRI = "TEST_LH_ko2IRI";
    private static final String KO2_LMSID = "TEST_LH_ko2LmsId";
    private static final String KO3_IRI = "TEST_LH_ko3IRI";
    private static final String KO3_LMSID = "TEST_LH_ko3LmsId";
    private static final String KO4_IRI = "TEST_LH_ko4IRI";
    private static final String KO4_LMSID = "TEST_LH_ko4LmsId";
    private static final String CC1_IRI = "TEST_LH_cc1IRI";
    private static final String CC2_IRI = "TEST_LH_cc2IRI";
    private static final String CC3_IRI = "TEST_LH_cc3IRI";
    private static final String COURSEID = "LHISTC";
    private static final String L1 = "TEST_LH_learner1";
    private static final String L2 = "TEST_LH_learner2";
    private static final String L3 = "TEST_LH_learner3";
    private static final String L4 = "TEST_LH_learner4";
    private static final long TIMESTAMP = System.currentTimeMillis();
    private static DbAccessor db;

    @BeforeClass
    public static void setup() throws DbAccessException, InterruptedException {
        db = TestCommons.getAccessor();

        //Login learners
        assertTrue(db.loginUser(L1, COURSEID));
        assertTrue(db.loginUser(L2, COURSEID));
        assertTrue(db.loginUser(L3, COURSEID));
        assertTrue(db.loginUser(L4, COURSEID));

        //Add learning steps
        assertTrue(db.storeLearningStep(L1, COURSEID, KO1_IRI, CC1_IRI, TIMESTAMP));
        Thread.sleep(50);
        assertTrue(db.storeLearningStep(L2, COURSEID, KO2_IRI, CC2_IRI, TIMESTAMP));
        Thread.sleep(50);
        assertTrue(db.storeLearningStep(L3, COURSEID, KO3_IRI, CC3_IRI, TIMESTAMP));
        Thread.sleep(50);
        assertTrue(db.storeLearningStep(L4, COURSEID, KO1_IRI, CC3_IRI, TIMESTAMP));
        assertTrue(db.storeLearningStep(L4, COURSEID, KO2_IRI, CC3_IRI, TIMESTAMP + 50));
        assertTrue(db.storeLearningStep(L4, COURSEID, KO3_IRI, CC3_IRI, TIMESTAMP + 100));

        //Add completion stati
        assertTrue(db.storeKoCompletionGrade(L1, COURSEID, KO1_IRI, 1));
        Thread.sleep(50);
        assertTrue(db.storeKoCompletionSeenPercentage(L1, COURSEID, KO2_IRI, 100));
        Thread.sleep(50);
        assertTrue(db.storeKoCompletionTextualCompletion(L1, COURSEID, KO3_IRI, 100));
        Thread.sleep(50);
        assertTrue(db.storeKoCompletionAccessed(L1, COURSEID, KO4_IRI, false));
        Thread.sleep(50);
        assertTrue(db.storeCcCompletion(L1, COURSEID, CC1_IRI, true));
        
        //Store LP evaluation incident
        db.storeLpEvaluationIncident(L1, COURSEID);

        //Store LO data
        assertTrue(db.storeKoData(KO1_IRI, COURSEID, "", "", KO1_LMSID));
        assertTrue(db.storeKoData(KO2_IRI, COURSEID, "", "", KO2_LMSID));
        assertTrue(db.storeKoData(KO3_IRI, COURSEID, "", "", KO3_LMSID));
        assertTrue(db.storeKoData(KO4_IRI, COURSEID, "", "", KO4_LMSID));
        assertTrue(db.storeCcData(CC1_IRI, COURSEID, "", ""));
        assertTrue(db.storeCcData(CC2_IRI, COURSEID, "", ""));
        assertTrue(db.storeCcData(CC3_IRI, COURSEID, "", ""));
    }

    @AfterClass
    public static void cleanup() throws DbAccessException {
        db.removeKoData(KO1_IRI);
        db.removeKoData(KO2_IRI);
        db.removeKoData(KO3_IRI);
        db.removeCcData(CC1_IRI);
        db.removeCcData(CC2_IRI);
        db.removeCcData(CC3_IRI);
        
        db.removeLastLearningStep(L1, COURSEID);
        db.removeLastLearningStep(L2, COURSEID);
        db.removeLastLearningStep(L3, COURSEID);
        db.removeLastLearningStep(L4, COURSEID);
        db.removeLastLearningStep(L4, COURSEID);
        db.removeLastLearningStep(L4, COURSEID);

        db.removeLastSession(L1, COURSEID);
        db.removeLastSession(L2, COURSEID);
        db.removeLastSession(L3, COURSEID);
        db.removeLastSession(L4, COURSEID);
    }

    @Test
    public void testGetLastLoDataOfL1() {
        String lastIri = db.getLastKnowledgeObjectIri(L1);
        assertNotNull("Last IRI was null.", lastIri);
        assertEquals("Last IRI did not match.", KO1_IRI, lastIri);
         lastIri = db.getLastKnowledgeObjectIri(L1, COURSEID);
        assertNotNull("Last IRI was null.", lastIri);
        assertEquals("Last IRI did not match.", KO1_IRI, lastIri);
        String lastLmsId = db.getLastKnowledgeObjectLmsId(L1);
        assertNotNull("Last LmsId was null", lastLmsId);
        assertEquals("Last LmsId did not match.", KO1_LMSID, lastLmsId);
        String lastCcIri = db.getLastConceptContainerIri(L1);
        assertNotNull("Last CcIri was null", lastCcIri);
        assertEquals("Last CcIri did not match.", CC1_IRI, lastCcIri);
    }

    @Test
    public void testGetLastLoDataOfL4() {
        String lastIri = db.getLastKnowledgeObjectIri(L4);
        assertNotNull("Last IRI was null.", lastIri);
        assertEquals("Last IRI did not match.", KO3_IRI, lastIri);
        lastIri = db.getLastKnowledgeObjectIri(L4, COURSEID);
        assertNotNull("Last IRI was null.", lastIri);
        assertEquals("Last IRI did not match.", KO3_IRI, lastIri);
        String lastLmsId = db.getLastKnowledgeObjectLmsId(L4);
        assertNotNull("Last LmsId was null", lastLmsId);
        assertEquals("Last LmsId did not match.", KO3_LMSID, lastLmsId);
        lastLmsId = db.getLastKnowledgeObjectLmsId(L4, COURSEID);
        assertNotNull("Last LmsId was null", lastLmsId);
        assertEquals("Last LmsId did not match.", KO3_LMSID, lastLmsId);
        String lastCcIri = db.getLastConceptContainerIri(L4);
        assertNotNull("Last CcIri was null", lastCcIri);
        assertEquals("Last CcIri did not match.", CC3_IRI, lastCcIri);
    }

    @Test
    public void testKoCompletionStatus() {
        assertEquals(new Integer(100), db.getKoCompletionStatus(L1, KO1_IRI));
        assertEquals(new Integer(1), db.getKoCompletionGrade(L1, KO1_IRI));
        assertEquals(null, db.getKoCompletionGrade(L1, KO4_IRI));
        
        assertEquals(new Integer(100), db.getKoCompletionStatus(L1, KO2_IRI));
        assertEquals(new Integer(100), db.getKoCompletionSeenPercentage(L1, KO2_IRI));
        assertEquals(null, db.getKoCompletionSeenPercentage(L1, KO4_IRI));

        assertEquals(new Integer(100), db.getKoCompletionStatus(L1, KO3_IRI));
        assertEquals(new Integer(100), db.getKoCompletionTextualCompletion(L1, KO3_IRI));
        assertEquals(null, db.getKoCompletionTextualCompletion(L1, KO4_IRI));
        
        assertEquals(null, db.getKoCompletionStatus(L1, KO4_IRI));
        assertEquals(false, db.getKoCompletionAccessed(L1, KO4_IRI));
        
        assertEquals(null, db.getKoCompletionStatus(L1, "gswghkjsdfgl"));
    }
    
    @Test
    public void testCcCompletionStatus() {
        assertTrue(db.getCcCompletionStatus(L1, CC1_IRI));
        assertFalse(db.getCcCompletionStatus(L1, CC2_IRI));
        assertFalse(db.getCcCompletionStatus(L1, "sadgsag"));
    }

    @Test
    public void testTimeData() {
        assertEquals(new Long(50), db.getLearningTime(L4, KO1_IRI));
        assertEquals(new Long(50), db.getLearningTime(L4, KO2_IRI));
        assertEquals(new Long(0), db.getLearningTime(L4, KO3_IRI));
    }

    @Test
    public void testHistory() {
        assertEquals(1, db.getHistoryOfKOs(L1, COURSEID).size());
        assertEquals(1, db.getHistoryOfKOs(L1, COURSEID, 1).size());
        assertEquals(1, db.getHistoryOfKOs(L1, COURSEID, 2).size());

        assertEquals(1, db.getHistoryOfCCs(L1, COURSEID).size());
        assertEquals(1, db.getHistoryOfCCs(L1, COURSEID, 1).size());
        assertEquals(1, db.getHistoryOfCCs(L1, COURSEID, 2).size());

        assertEquals(3, db.getHistoryOfKOs(L4, COURSEID).size());
        assertEquals(1, db.getHistoryOfKOs(L4, COURSEID, 1).size());
        assertEquals(2, db.getHistoryOfKOs(L4, COURSEID, 2).size());
        assertEquals(3, db.getHistoryOfKOs(L4, COURSEID, 3).size());
        assertEquals(3, db.getHistoryOfKOs(L4, COURSEID, 4).size());

        assertEquals(3, db.getHistoryOfCCs(L4, COURSEID).size());
        assertEquals(1, db.getHistoryOfCCs(L4, COURSEID, 1).size());
        assertEquals(2, db.getHistoryOfCCs(L4, COURSEID, 2).size());
        assertEquals(3, db.getHistoryOfCCs(L4, COURSEID, 3).size());
        assertEquals(3, db.getHistoryOfCCs(L4, COURSEID, 4).size());
    }

    @Test
    public void testLpEval() {
        assertNotNull(db.getTimeSinceLastLpEvaluation(L1, COURSEID));
        assertNull(db.getTimeSinceLastLpEvaluation(L2, COURSEID));
        assertNotNull(db.getStepsSinceLastLpEvaluation(L1, COURSEID));
        assertNull(db.getStepsSinceLastLpEvaluation(L2, COURSEID));
    }
}
