/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Contributor: Ovidiu Serban, University of Reading, www.reading.ac.uk
 * Version: [0.01]
 * Date: 17.07.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.db.access;

import eu.intuitel.types.ComStyle;
import eu.intuitel.types.LoreLvl;
import eu.intuitel.types.MediaLvl;
import eu.intuitel.types.NameFormality;
import eu.intuitel.types.UseLvl;
import org.junit.AfterClass;
import static org.junit.Assert.*;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 * Tests for LMS parameter storage and retrieval.
 *
 * @author Florian Heberle
 */
public class LmsParametersTest {

    private static final String ID = "1";
    private static final String NAME = "2";
    private static final String TYPE = "3";
    private static final MediaLvl MEDIALVL = MediaLvl.Audio;
    private static final LoreLvl LORELVL = LoreLvl.EmulateViaTug;
    private static final UseLvl USELVL = UseLvl.Normal;
    private static final NameFormality NAMEFORM = NameFormality.Forename;
    private static final ComStyle COMSTYLE = ComStyle.Push;
    private static DbAccessor db;

    @BeforeClass
    public static void setup() {
        db = TestCommons.getAccessor();
    }

    @AfterClass
    public static void cleanUp() {
        db.removeLastLmsParameters();
    }

    @Test
    public void test() {
        assertTrue(db.storeLmsProperties(ID, NAME, TYPE, MEDIALVL, LORELVL, USELVL, NAMEFORM, COMSTYLE));
        assertEquals(NAME, db.getLmsName());
        assertEquals(TYPE, db.getLmsType());
        assertEquals(ID, db.getLmsId());
        assertTrue(MEDIALVL.equals(db.getLmsMediaLvl()));
        assertTrue(LORELVL.equals(db.getLmsLoreLvl()));
        assertTrue(USELVL.equals(db.getLmsUseLvl()));
        assertTrue(NAMEFORM.equals(db.getLmsNameFormality()));
        assertTrue(COMSTYLE.equals(db.getLmsComStyle()));
    }
}
