/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Ovidiu Serban, University of Reading, United Kingdom, http://www.isr.reading.ac.uk/
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 22.07.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.db.access;

import java.util.List;
import org.junit.AfterClass;
import static org.junit.Assert.*;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 * Tests for the correct determining of completed LOs.
 * 
 * @author Florian Heberle
 */
public class LoCompletionTest {

    private static DbAccessor db;
    private static final String LID1 = "LoCompTestLearnerId";
    private static final String LID2 = "LoCompTestLearnerId2";
    private static final String LID3 = "LoCompTestLearnerId3";
    private static final String COURSEID = "COMPC";
    private static final String KOIRI1 = "LoComTestKoIri1";
    private static final String KOIRI2 = "LoComTestKoIri2";
    private static final String CCIRI1 = "LoComTestCcIri1";
    private static final String CCIRI2 = "LoComTestCcIri2";

    @BeforeClass
    public static void setup() throws DbAccessException {
        db = TestCommons.getAccessor();
        assertTrue(db.loginUser(LID1, COURSEID));
        
        assertTrue(db.storeLearningStep(LID1, COURSEID, KOIRI1, CCIRI1, System.currentTimeMillis()));
        assertTrue(db.storeLearningStep(LID1, COURSEID, KOIRI2, CCIRI1, System.currentTimeMillis() + 100));
        assertTrue(db.storeLearningStep(LID1, COURSEID, KOIRI1, CCIRI1, System.currentTimeMillis() + 200));
        
        assertTrue(db.loginUser(LID2, COURSEID));
        assertTrue(db.storeLearningStep(LID2, COURSEID, KOIRI1, CCIRI1, System.currentTimeMillis()));
        assertTrue(db.storeLearningStep(LID2, COURSEID, KOIRI1, CCIRI2, System.currentTimeMillis() + 100));
        assertTrue(db.storeLearningStep(LID2, COURSEID, KOIRI1, CCIRI1, System.currentTimeMillis() + 200));
        
        assertTrue(db.storeCcCompletion(LID2, COURSEID, CCIRI1, true));
        
        assertTrue(db.storeKoData(KOIRI1, COURSEID, "", "", ""));
        assertTrue(db.storeKoData(KOIRI2, COURSEID, "", "", ""));
        assertTrue(db.storeCcData(CCIRI1, COURSEID, "", ""));
        assertTrue(db.storeCcData(CCIRI2, COURSEID, "", ""));
    }

    @AfterClass
    public static void cleanup() throws DbAccessException {
        db.removeLastLearningStep(LID1, COURSEID);
        db.removeLastLearningStep(LID1, COURSEID);
        db.removeLastLearningStep(LID1, COURSEID);
        db.removeLastSession(LID1, COURSEID);
        db.removeLastLearningStep(LID2, COURSEID);
        db.removeLastLearningStep(LID2, COURSEID);
        db.removeLastLearningStep(LID2, COURSEID);
        db.removeLastSession(LID2, COURSEID);
        db.removeCcData(CCIRI1);
        db.removeCcData(CCIRI2);
        db.removeKoData(KOIRI1);
        db.removeKoData(KOIRI2);
    }   

    @Test
    public void testCompletion1() {
        List<String> completedKos = db.getCompletedKOs(LID1, COURSEID);
        assertNotNull(completedKos);
        assertFalse(completedKos.isEmpty());
        assertEquals(2, completedKos.size());
        assertTrue(completedKos.contains(KOIRI1));
        assertTrue(completedKos.contains(KOIRI2));
        
        List<String> completedCcs = db.getCompletedCcs(LID1, COURSEID);
        assertNotNull(completedCcs);
        assertTrue(completedCcs.isEmpty());
    }
    
    @Test
    public void testCompletion2() {
        List<String> completedKos = db.getCompletedKOs(LID2, COURSEID);
        assertNotNull(completedKos);
        assertFalse(completedKos.isEmpty());
        assertEquals(1, completedKos.size());
        assertTrue(completedKos.contains(KOIRI1));
        
        List<String> completedCcs = db.getCompletedCcs(LID2, COURSEID);
        assertNotNull(completedCcs);
        assertFalse(completedCcs.isEmpty());
        assertEquals(1, completedCcs.size());
        assertTrue(completedCcs.contains(CCIRI1));
    }
    
    @Test
    public void testCompletion3() {
        List<String> completedKos = db.getCompletedKOs(LID3, COURSEID);
        assertNotNull(completedKos);
        assertTrue(completedKos.isEmpty());
        List<String> completedCcs = db.getCompletedCcs(LID3, COURSEID);
        assertNotNull(completedCcs);
        assertTrue(completedCcs.isEmpty());
    }
}
