/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Ovidiu Serban, University of Reading, United Kingdom, http://www.isr.reading.ac.uk/
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 23.07.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.db.access;

import java.util.Collection;
import org.junit.AfterClass;
import static org.junit.Assert.*;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 * Tests for peer related data retrieval.
 * 
 * @author Florian Heberle
 */
public class PeerDataTests {
    
    private static final String LID = "TESTLEARNER_PeerData1";
    private static final String LID2 = "TESTLEARNER_PeerData2";
    private static final String LID3 = "TESTLEARNER_PeerData3";
    private static final String COURSEID = "PEER";
    private static DbAccessor db;

    @BeforeClass
    public static void setup() throws InterruptedException {
        db = TestCommons.getAccessor();
        assertTrue(db.loginUser(LID, COURSEID));
        assertTrue(db.loginUser(LID2, COURSEID));
        Thread.sleep(100);
        assertTrue(db.logoutUser(LID2));
        assertTrue(db.loginUser(LID3, COURSEID));
        Thread.sleep(100);
        assertTrue(db.logoutUser(LID3));
        assertTrue(db.loginUser(LID3, COURSEID));
        Thread.sleep(100);
        assertTrue(db.logoutUser(LID3));
    }
    
    @AfterClass
    public static void cleanUp() {
        db.removeLastSession(LID, COURSEID);
        db.removeLastSession(LID2, COURSEID);
        db.removeLastSession(LID3, COURSEID);
        db.removeLastSession(LID3, COURSEID);
    }
    
    @Test 
    public void testGetPeerIds() {
        Collection<String> peerIds = db.getPeerIds(LID, COURSEID);
        assertNotNull(peerIds);
        assertFalse(peerIds.isEmpty());
        assertEquals(2, peerIds.size());
        assertTrue(peerIds.contains(LID2));
        assertTrue(peerIds.contains(LID3));
        assertFalse(peerIds.contains(LID));
    }
    
    @Test
    public void testGetPeerSessionLengths() {
        Collection<Collection<Long>> peerSessionLengths = db.getPeerSessionLengths(LID, COURSEID);
        assertNotNull(peerSessionLengths);
        assertFalse(peerSessionLengths.isEmpty());
        assertEquals(2, peerSessionLengths.size());
        
        boolean hasOneSessionFound = false;
        boolean hasTwoSessionsFound = false;
        for(Collection<Long> sessionLengths : peerSessionLengths) {
            assertNotNull(sessionLengths);
            assertFalse(sessionLengths.isEmpty());
            if(sessionLengths.size() == 1) {
                hasOneSessionFound = true;
            } else if(sessionLengths.size() == 2) {
                hasTwoSessionsFound = true;
            } else {
                assertEquals(null, sessionLengths.size());
            }
            for(Long sessionLength : sessionLengths) {
                assertNotNull(sessionLength);
                assertTrue(sessionLength > 0);
            }
        }
        assertTrue(hasOneSessionFound);
        assertTrue(hasTwoSessionsFound);
    }
}
