/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 24.07.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.db.access;

import static org.junit.Assert.*;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.After;
import org.junit.Test;

/**
 * Tests for data manipulation methods of the RR.
 *
 * @author Florian Heberle
 */
public class RrManipulationTests {

    private static final String LID = "RRTEST_LID";
    private static final String COURSEID = "RRTC";
    private static final String KOIRI1 = "RRTEST_KOIRI1";
    private static final String KOIRI2 = "RRTEST_KOIRI2";
    private static final String KOIRI3 = "RRTEST_KOIRI3";
    private static final String CCIRI1 = "RRTEST_CCIRI1";
    private static final String CCIRI2 = "RRTEST_CCIRI2";
    private static DbAccessor db;

    @BeforeClass
    public static void setup() {
        db = TestCommons.getAccessor();
    }

    @Before
    public void beforeTest() {
        assertTrue(db.storeKoData(KOIRI1, COURSEID, KOIRI1, "", ""));
        assertTrue(db.storeKoData(KOIRI2, COURSEID, KOIRI2, "", ""));
        assertTrue(db.storeKoData(KOIRI3, COURSEID, KOIRI3, "", ""));
        assertTrue(db.storeCcData(CCIRI1, COURSEID, CCIRI1, ""));
        assertTrue(db.storeCcData(CCIRI2, COURSEID, CCIRI2, ""));
        assertTrue(db.loginUser(LID, COURSEID));

        //Test-scenario: KO1, KO2 belong to CC1 and KO3 to CC2
    }

    @After
    public void afterTest() {
        db.clearDataStorage();
    }

    @Test
    public void testResetOneStep() throws InterruptedException {
        assertTrue(db.storeLearningStep(LID, COURSEID, KOIRI1, CCIRI1, System.currentTimeMillis()));
        assertTrue(db.storeKoCompletionGrade(LID, COURSEID, KOIRI1, 1));
        Thread.sleep(100);

        assertEquals(new Integer(1), db.getKoCompletionGrade(LID, KOIRI1));
        assertEquals(null, db.getKoCompletionGrade(LID, KOIRI2));
        assertEquals(null, db.getKoCompletionGrade(LID, KOIRI3));
        assertEquals(false, db.getCcCompletionStatus(LID, CCIRI1));
        assertEquals(false, db.getCcCompletionStatus(LID, CCIRI2));

        Thread.sleep(100);
        assertTrue(db.resetCcScore(LID, COURSEID, CCIRI1));
        assertEquals(null, db.getKoCompletionGrade(LID, KOIRI1));
        assertEquals(null, db.getKoCompletionGrade(LID, KOIRI2));
        assertEquals(null, db.getKoCompletionGrade(LID, KOIRI3));
        assertEquals(false, db.getCcCompletionStatus(LID, CCIRI1));
        assertEquals(false, db.getCcCompletionStatus(LID, CCIRI2));
    }

    @Test
    public void testResetTwoSteps() throws InterruptedException {
        assertTrue(db.storeLearningStep(LID, COURSEID, KOIRI1, CCIRI1, System.currentTimeMillis()));
        assertTrue(db.storeKoCompletionGrade(LID, COURSEID, KOIRI1, 1));
        Thread.sleep(100);
        assertTrue(db.storeLearningStep(LID, COURSEID, KOIRI2, CCIRI1, System.currentTimeMillis()));
        assertTrue(db.storeKoCompletionGrade(LID, COURSEID, KOIRI2, 2));
        assertTrue(db.storeCcCompletion(LID, COURSEID, CCIRI1, true));

        assertEquals(new Integer(1), db.getKoCompletionGrade(LID, KOIRI1));
        assertEquals(new Integer(2), db.getKoCompletionGrade(LID, KOIRI2));
        assertEquals(null, db.getKoCompletionGrade(LID, KOIRI3));
        assertEquals(true, db.getCcCompletionStatus(LID, CCIRI1));
        assertEquals(false, db.getCcCompletionStatus(LID, CCIRI2));

        Thread.sleep(100);
        assertTrue(db.resetCcScore(LID, COURSEID, CCIRI1));
        assertEquals(null, db.getKoCompletionGrade(LID, KOIRI1));
        assertEquals(null, db.getKoCompletionGrade(LID, KOIRI2));
        assertEquals(null, db.getKoCompletionGrade(LID, KOIRI3));
        assertEquals(false, db.getCcCompletionStatus(LID, CCIRI1));
        assertEquals(false, db.getCcCompletionStatus(LID, CCIRI2));
    }

    @Test
    public void testResetThreeSteps() throws InterruptedException {
        assertTrue(db.storeLearningStep(LID, COURSEID, KOIRI1, CCIRI1, System.currentTimeMillis()));
        assertTrue(db.storeKoCompletionGrade(LID, COURSEID, KOIRI1, 1));
        Thread.sleep(100);
        assertTrue(db.storeLearningStep(LID, COURSEID, KOIRI2, CCIRI1, System.currentTimeMillis()));
        assertTrue(db.storeKoCompletionGrade(LID, COURSEID, KOIRI2, 2));
        assertTrue(db.storeCcCompletion(LID, COURSEID, CCIRI1, true));
        Thread.sleep(100);
        assertTrue(db.storeLearningStep(LID, COURSEID, KOIRI3, CCIRI2, System.currentTimeMillis()));
        assertTrue(db.storeKoCompletionGrade(LID, COURSEID, KOIRI3, 3));
        assertTrue(db.storeCcCompletion(LID, COURSEID, CCIRI2, true));

        assertEquals(new Integer(1), db.getKoCompletionGrade(LID, KOIRI1));
        assertEquals(new Integer(2), db.getKoCompletionGrade(LID, KOIRI2));
        assertEquals(new Integer(3), db.getKoCompletionGrade(LID, KOIRI3));
        assertEquals(true, db.getCcCompletionStatus(LID, CCIRI1));
        assertEquals(true, db.getCcCompletionStatus(LID, CCIRI2));

        Thread.sleep(100);
        assertTrue(db.resetCcScore(LID, COURSEID, CCIRI2));
        assertEquals(new Integer(1), db.getKoCompletionGrade(LID, KOIRI1));
        assertEquals(new Integer(2), db.getKoCompletionGrade(LID, KOIRI2));
        assertEquals(null, db.getKoCompletionGrade(LID, KOIRI3));
        assertEquals(true, db.getCcCompletionStatus(LID, CCIRI1));
        assertEquals(false, db.getCcCompletionStatus(LID, CCIRI2));

        //Only CC2 is resetted, i.e. CC1 and connected KOs must be preserved.
        
        //Last KO still has to be the last KO of before the reset!
        assertEquals(KOIRI3, db.getLastKnowledgeObjectIri(LID, COURSEID));
    }

    @Test
    public void testLoDescription() {
        assertEquals(KOIRI1, db.getKoTitle(KOIRI1));
        assertEquals(CCIRI1, db.getCcTitle(CCIRI1));
    }
}
