/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Ovidiu Serban, University of Reading, United Kingdom, http://www.isr.reading.ac.uk/
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 21.07.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.db.access;

import eu.intuitel.db.model.ConceptContainer;
import eu.intuitel.db.model.KnowledgeObject;
import eu.intuitel.db.model.MacroLearningPathway;
import eu.intuitel.db.model.MicroLearningPathway;
import org.junit.AfterClass;
import static org.junit.Assert.*;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 * Various SLOM data related tests.
 */
public class SlomDataTest {

    private static final String COURSE = "SLOMC";
    private static final String KO_IRI = "1iri";
    private static final String KO_TITLE = "1title";
    private static final String KO_DESC = "1desc";
    private static final String KO_LMSID = "1id";
    private static final String CC_IRI = "2iri";
    private static final String CC_TITLE = "2title";
    private static final String CC_DESC = "2desc";
    private static final String MICROLP_IRI = "3iri";
    private static final String MICROLP_TITLE = "3title";
    private static final String MICROLP_DESC = "3desc";
    private static final String MACROLP_IRI = "4iri";
    private static final String MACROLP_TITLE = "4title";
    private static final String MACROLP_DESC = "4desc";
    private static DbAccessor db;

    @BeforeClass
    public static void setup() throws DbAccessException {
        db = TestCommons.getAccessor();
    }

    @AfterClass
    public static void cleanup() throws DbAccessException {
        db.removeKoData(KO_IRI);
        db.removeCcData(CC_IRI);
        db.removeMicroLpData(MICROLP_IRI);
        db.removeMacroLpData(MACROLP_IRI);
    }

    @Test
    public void testInvalid() {
        assertNull(db.getKoData(Double.toString(Math.PI)));
        assertNull(db.getCcData(Double.toString(Math.PI)));
        assertNull(db.getMicroLpData(Double.toString(Math.PI)));
        assertNull(db.getMacroLpData(Double.toString(Math.PI)));
    }

    @Test
    public void testKoData() {
        assertTrue(db.storeKoData(KO_IRI, COURSE, KO_TITLE, KO_DESC, KO_LMSID));
        KnowledgeObject ko = db.getKoData(KO_IRI);
        assertNotNull(ko);
        assertEquals(KO_IRI, ko.getIri());
        assertEquals(COURSE, ko.getCourseId());
        assertEquals(KO_TITLE, ko.getTitle());
        assertEquals(KO_DESC, ko.getDescription());
        assertEquals(KO_LMSID, ko.getLmsId());
    }

    @Test
    public void testCcData() {
        assertTrue(db.storeCcData(CC_IRI, COURSE, CC_TITLE, CC_DESC));
        ConceptContainer cc = db.getCcData(CC_IRI);
        assertNotNull(cc);
        assertEquals(CC_IRI, cc.getIri());
        assertEquals(COURSE, cc.getCourseId());
        assertEquals(CC_TITLE, cc.getTitle());
        assertEquals(CC_DESC, cc.getDescription());
    }

    @Test
    public void testMicroLpData() {
        assertTrue(db.storeMicroLpData(MICROLP_IRI, COURSE, MICROLP_TITLE, MICROLP_DESC));
        MicroLearningPathway lp = db.getMicroLpData(MICROLP_IRI);
        assertNotNull(lp);
        assertEquals(MICROLP_IRI, lp.getIri());
        assertEquals(COURSE, lp.getCourseId());
        assertEquals(MICROLP_TITLE, lp.getTitle());
        assertEquals(MICROLP_DESC, lp.getDescription());
    }

    @Test
    public void testMacroLpData() {
        assertTrue(db.storeMacroLpData(MACROLP_IRI, COURSE, MACROLP_TITLE, MACROLP_DESC));
        MacroLearningPathway lp = db.getMacroLpData(MACROLP_IRI);
        assertNotNull(lp);
        assertEquals(MACROLP_IRI, lp.getIri());
        assertEquals(COURSE, lp.getCourseId());
        assertEquals(MACROLP_TITLE, lp.getTitle());
        assertEquals(MACROLP_DESC, lp.getDescription());
    }
}
