/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 10.07.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.db.access;

import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Class containing variables to use in all tests.
 *
 * @author Florian Heberle
 */
public class TestCommons {

    private static final Logger logger = LoggerFactory.getLogger(TestCommons.class);
    private static final DbAccessor DB;

    static {
        DbAccessor tmp = null;
        try {
            //tmp = DbAccessor.createHibernateDbAccessor();
            tmp = DbAccessor.createCachedDbAccessor();
        } catch (DbAccessException ex) {
            logger.error("Could not initialize DB accessor.", ex);
        }
        DB = tmp;
    }

    /**
     * Private constructor - only static data.
     */
    private TestCommons() {
    }

    /**
     * Returnes the DbAccessor to use for storing and retrieveing data from the DB.
     *
     * @return DbAccessor-instance, assertion check fails if creation failed.
     */
    public static DbAccessor getAccessor() {
        assertNotNull(DB);
        assertTrue(DB.isConnectionEstablished());
        return DB;
    }
}
