/**
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Ovidiu Serban, University of Reading, United Kingdom, http://www.isr.reading.ac.uk/
 * Contributor: Florian Heberle, University of Applied Sciences Karlsruhe, www.hs-karlsruhe.de
 * Version: [0.01]
 * Date: 11.07.2014
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */
package eu.intuitel.db.access;

import eu.intuitel.types.ConnectionType;
import org.junit.AfterClass;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNull;
import static org.junit.Assert.assertTrue;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 * Various time-dependent session data tests.
 *
 * @author Florian Heberle
 */
public class TimedependentSessionDataTest {

    private static final String ID = "TESTLEARNER_TIMEDATA";
    private static final String ID2 = "TESTLEARNER_TIMEDATA2";
    private static final Integer BATTERY = 99;
    private static final Integer NOISE = 25;
    private static final Integer CONSTAB = 80;
    private static final ConnectionType CONTYPE = ConnectionType.Lte;
    private static final String COURSEID = "TDSDATC";
    private static DbAccessor db;

    @BeforeClass
    public static void setup() {
        db = TestCommons.getAccessor();
    }

    @AfterClass
    public static void cleanUp() {
        db.removeLastSession(ID, COURSEID);
    }

    @Test
    public void testSessionData() {
        assertTrue(db.loginUser(ID, COURSEID));
        assertTrue(db.storeTimedependentSessionData(ID, BATTERY, CONTYPE, CONSTAB, NOISE));
        assertEquals(BATTERY, db.getBatteryLevel(ID));
        assertEquals(NOISE, db.getNoiseLevel(ID));
        assertTrue(CONTYPE.equals(db.getConnectionType(ID)));
        assertTrue(CONSTAB.equals(db.getConnectionStability(ID)));
    }

    @Test
    public void testInvalidSessionData() {
        assertNull(db.getBatteryLevel(ID2));
        assertNull(db.getNoiseLevel(ID2));
        assertNull(db.getConnectionType(ID2));
        assertNull(db.getConnectionStability(ID2));
    }
}
