package eu.intuitel.querybuilder.console;

import eu.intuitel.comm.entities.qb.QueryBuilderOutput;
import eu.intuitel.querybuilder.core.QueryBuilder;
import eu.intuitel.querybuilder.core.QueryBuilderException;
import org.apache.commons.cli.*;
import org.semanticweb.owlapi.io.FileDocumentSource;

import javax.xml.stream.XMLStreamException;
import java.io.File;
import java.io.IOException;
import java.nio.file.Path;
import java.nio.file.Paths;

import org.apache.logging.log4j.Logger;
import org.apache.logging.log4j.LogManager;

/**
 * QueryBuilderConsole.
 *
 * @author Matthias Stumpp (stumpp@fzi.de)
 */
public class QueryBuilderConsole {

    private static final Logger logger = LogManager.getLogger(QueryBuilder.class.getName());

    public static void main(String[] args) throws IOException, XMLStreamException {

        // create Options object
        Options options = new Options();

        // add options
        options.addOption("i", true, "input learner state ontology");
        options.addOption("o", true, "querybuilder output file ");

        CommandLineParser parser = new BasicParser();
        CommandLine cmd = null;
        try {
            cmd = parser.parse(options, args);
        } catch (ParseException e1) {
            e1.printStackTrace();
        }

        if (cmd == null) {
            logger.warn("Unable to instantiate CommandLineParser");
            return;
        }

        File inputFile = null;
        if (cmd.hasOption("i")) {
            inputFile = new File(cmd.getOptionValue("i"));
            if (!inputFile.exists()) {
                logger.warn("Learner state ontology does not exist");
                return;
            }
        } else {
            logger.warn("Please provide a learner state ontology");
            return;
        }

        File outputFile = null;
        if (cmd.hasOption("o")) {
            outputFile = new File(cmd.getOptionValue("o"));
        } else {
            Path p = Paths.get(inputFile.getAbsolutePath());
            Path folder = p.getParent();
            outputFile = new File(folder + "/queryBuilderOutput.xml");
        }

        FileDocumentSource fDS = new FileDocumentSource(inputFile);

        // call the querybuilder
        QueryBuilderOutput output = null;
        try {
            output = QueryBuilder.getInstance().build(fDS);
        } catch (QueryBuilderException e) {
            logger.info(e.getMessage());
        }

        logger.info(output.toString());

        /*
        try {
            // Pretty print the document to System.out
            OutputFormat format = OutputFormat.createPrettyPrint();
            XMLWriter writer = new XMLWriter(System.out, format);
            LOGGER.info("QueryBuilder Output");
            LOGGER.info("===================");
            writer.write(doc);
            LOGGER.info("===================");

            FileWriter fileWriter = new FileWriter(outputFile);
            writer = new XMLWriter(fileWriter);
            writer.write(doc);
            writer.close();
            LOGGER.info("QueryBuilder output written to: " + outputFile);

        } catch (IOException e) {
            LOGGER.warning("Unable to write QueryBuilder output");
        }*/
    }

}
