package eu.intuitel.querybuilder.service;

import eu.intuitel.CommLayer.CommLibrary.IntuitelService;
import eu.intuitel.CommLayer.CommLibrary.services.qb.QueryBuilderService;
import eu.intuitel.comm.services.IQueryBuilderConnnection;
import eu.intuitel.comm.services.IQueryBuilderListener;
import eu.intuitel.CommLayer.CommLibrary.IntuitelServiceConnection;

import java.io.IOException;
import java.net.URI;
import java.util.LinkedList;
import java.util.List;

/**
 * AbstractCommunicationLayer.
 *
 * @author Matthias Stumpp (stumpp@fzi.de)
 */
public abstract class AbstractCommunicationLayer extends IntuitelServiceConnection
        implements IQueryBuilderConnnection {
    private final List<CommunicationEventListener> listeners = new LinkedList<CommunicationEventListener>();

    public abstract void OpenBasic(URI uri, URI intuitelGateway) throws IOException;

    public abstract void OpenAdvanced(String username, String password, String xmppServer,
                                      int xmppServerPort, String tsbUsername) throws IOException;

    public abstract void Close();

    public void addCommunicationLayerEventListener(CommunicationEventListener listener) {
        synchronized (listeners) {
            listeners.add(listener);
        }
    }

    public void removeCommunicationLayerEventListener(CommunicationEventListener listener) {
        synchronized (listeners) {
            listeners.remove(listener);
        }
    }

    protected void fireOpenEvent(AbstractCommunicationLayer instance) {
        synchronized (listeners) {
            for (CommunicationEventListener listener : listeners) {
                listener.onOpen(instance);
            }
        }
    }

    protected void fireCloseEvent(AbstractCommunicationLayer instance) {
        synchronized (listeners) {
            for (CommunicationEventListener listener : listeners) {
                listener.onClose(instance);
            }
        }
    }

    protected final java.util.logging.Logger getLogger() {
        return java.util.logging.Logger.getLogger(this.getClass().getName());
    }

    @Override
    protected final Class<? extends IntuitelService> getServiceClass() {
        return QueryBuilderService.class;
    }

    public abstract void setQueryBuilderListener(IQueryBuilderListener listener);

    @Override
    public abstract void sendReasoningResults(eu.intuitel.comm.entities.qb.ReasoningResults reasoningResults) throws eu.intuitel.comm.entities.exceptions.IntuitelException;

    @Override
    public abstract void onNewLearnerStates(java.util.List<eu.intuitel.comm.entities.lpm.LearnerState> list);

}
