package eu.intuitel.querybuilder.service;

import eu.intuitel.CommLayer.CommLibrary.QueryBuilderServiceConnection;
import eu.intuitel.comm.entities.exceptions.IntuitelException;
import eu.intuitel.comm.entities.lpm.LearnerState;
import eu.intuitel.comm.entities.qb.QueryBuilderOutput;
import eu.intuitel.comm.entities.qb.ReasoningResults;
import eu.intuitel.comm.services.IQueryBuilderListener;

import java.io.IOException;
import java.net.URI;
import java.util.List;

/**
 * CommunicationLayerDelegate.
 *
 * @author Matthias Stumpp (stumpp@fzi.de)
 */
public class CommunicationLayerDelegate extends AbstractCommunicationLayer {

    public static final CommunicationLayerDelegate instance = new CommunicationLayerDelegate();

    private QueryBuilderServiceConnection connection = QueryBuilderServiceConnection.getInstance();

    private volatile boolean opened = false;

    protected CommunicationLayerDelegate() {
    }

    public void OpenBasic(URI uri, URI intuitelGateway) throws IOException {
        if (!opened) {
            connection.OpenBasic(uri, intuitelGateway);
            opened = true;
            fireOpenEvent(this);
        }
    }

    public void OpenAdvanced(String username, String password, String xmppServer,
                             int xmppServerPort, String tsbUsername) throws IOException {
        if (!opened) {
            connection.OpenAdvanced(username, password, xmppServer, xmppServerPort, tsbUsername);
            opened = true;
            fireOpenEvent(this);
        }
    }

    public void Close() {
        if (opened) {
            connection.Close();
            opened = false;
            fireCloseEvent(this);
        }
    }

    @Override
    public void setQueryBuilderListener(IQueryBuilderListener listener) {
        connection.setQueryBuilderListener(listener);
    }

    @Override
    public void sendReasoningResults(ReasoningResults reasoningResults) throws IntuitelException {
        connection.sendReasoningResults(reasoningResults);
    }

    @Override
    public void sendQueryBuilderOutput(QueryBuilderOutput queryBuilderOutput) throws IntuitelException {
        connection.sendQueryBuilderOutput(queryBuilderOutput);
    }

    @Override
    public void onNewLearnerStates(List<LearnerState> list) {
        connection.onNewLearnerStates(list);
    }

}
