package eu.intuitel.querybuilder.service.mockup;

import eu.intuitel.comm.entities.exceptions.IntuitelException;
import eu.intuitel.comm.entities.lpm.LearnerState;
import eu.intuitel.comm.entities.qb.QueryBuilderOutput;
import eu.intuitel.comm.entities.qb.ReasoningResults;
import eu.intuitel.comm.services.IQueryBuilderListener;
import eu.intuitel.querybuilder.service.AbstractCommunicationLayer;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import java.io.IOException;
import java.net.URI;
import java.util.List;

/**
 * MockupQBServiceConnection.
 *
 * @author Matthias Stumpp (stumpp@fzi.de)
 */
public class MockupQBServiceConnection extends AbstractCommunicationLayer {

    public static final MockupQBServiceConnection instance = new MockupQBServiceConnection();

    private static final Logger logger = LogManager.getLogger(MockupQBServiceConnection.class.getName());

    private IQueryBuilderListener queryBuilderListener;

    private MockupConnectionListener mockupConnectionListener;

    private volatile boolean opened = false;

    private MockupQBServiceConnection() {
    }

    public void OpenBasic(URI uri, URI intuitelGateway) throws IOException {
        if (!opened) {
            opened = true;
            logger.info("Open mockup connection with: uri=" + uri + " gateway=" + intuitelGateway);
            fireOpenEvent(this);
        }
    }

    public void OpenAdvanced(String username, String password, String xmppServer, int xmppServerPort,
                             String tsbUsername) throws IOException {
        if (!opened) {
            opened = true;
            logger.info("Open mockup connection with:" + " username=" + username + " password=" + password +
                    " xmppServer=" + xmppServer + " xmppPort=" + xmppServerPort + " tsbUsername=" + tsbUsername);
            fireOpenEvent(this);
        }
    }

    public void Close() {
        if (opened) {
            logger.info("Closing mockup connection");
            opened = false;
            fireCloseEvent(this);
        }
    }

    @Override
    public void setQueryBuilderListener(IQueryBuilderListener listener) {
        this.queryBuilderListener = listener;
    }

    public void setMockupConnectionListener(MockupConnectionListener mockupConnectionListener) {
        this.mockupConnectionListener = mockupConnectionListener;
    }

    private void fireReasoningResultsUpdate(ReasoningResults reasoningResults) {
        if (this.mockupConnectionListener != null) {
            mockupConnectionListener.reasoningResultsUpdated(reasoningResults);
        }
    }

    private void fireQueryBuilderOutputUpdate(QueryBuilderOutput queryBuilderOutput) {
        if (this.mockupConnectionListener != null) {
            mockupConnectionListener.queryBuilderOutputUpdated(queryBuilderOutput);
        }
    }

    @Override
    public void sendReasoningResults(ReasoningResults reasoningResults) throws IntuitelException {
        if (reasoningResults != null)
            logger.info(reasoningResults.toString());
        fireReasoningResultsUpdate(reasoningResults);
    }

    @Override
    public void sendQueryBuilderOutput(QueryBuilderOutput queryBuilderOutput) throws IntuitelException {
        if (queryBuilderOutput != null)
            logger.info(queryBuilderOutput.toString());
        fireQueryBuilderOutputUpdate(queryBuilderOutput);
    }

    @Override
    public void onNewLearnerStates(List<LearnerState> list) {
        if (this.queryBuilderListener != null) {
            this.queryBuilderListener.onNewLearnerStates(list);
        }
    }

}