package eu.intuitel.querybuilder.core;

import eu.intuitel.comm.entities.lpm.LearnerState;
import eu.intuitel.comm.entities.lpm.LearnerStateOntology;
import eu.intuitel.comm.entities.qb.QueryBuilderOutput;
import eu.intuitel.querybuilder.util.QueryBuilderUtilException;
import org.junit.Ignore;
import org.junit.Test;
import org.semanticweb.owlapi.io.OWLOntologyDocumentSource;
import org.semanticweb.owlapi.io.StreamDocumentSource;

import java.io.*;
import java.util.ArrayList;
import java.util.List;

import org.apache.logging.log4j.Logger;
import org.apache.logging.log4j.LogManager;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

/**
 * QueryBuilderTest.
 *
 * @author Matthias Stumpp (stumpp@fzi.de)
 */
public class QueryBuilderTest {

    /*
     * Absolute path to Learner State Ontology
     */
    private static final String LSO = "intui_LSO_all_included.owl";

    /*
     * Logger
     */
    private static final Logger logger = LogManager.getLogger(QueryBuilderTest.class.getName());

    @Test
    public void test1() throws QueryBuilderUtilException, QueryBuilderException {

        QueryBuilder qb = QueryBuilder.getInstance();
        assertNotNull(qb);
    }

    @Test
    public void test2() throws QueryBuilderUtilException, QueryBuilderException {

        int numThreads = 3;
        QueryBuilder qb = QueryBuilder.getInstance(numThreads);
        assertNotNull(qb);
    }

    @Test(expected = QueryBuilderException.class)
    public void test3() throws QueryBuilderUtilException, QueryBuilderException {

        QueryBuilder qb = QueryBuilder.getInstance();
        assertNotNull(qb);
        LearnerState ls = null;
        qb.build(ls);
    }

    @Test
    public void test4() throws QueryBuilderUtilException, QueryBuilderException {

        InputStream is = QueryBuilderTest.class.getResourceAsStream(LSO);
        OWLOntologyDocumentSource learnerStateOnt = new StreamDocumentSource(is);

        QueryBuilder qb = QueryBuilder.getInstance();
        QueryBuilderOutput output = qb.build(learnerStateOnt);
        assertNotNull(qb);
    }

    @Ignore
    @Test
    public void test5() throws QueryBuilderUtilException, QueryBuilderException, IOException, SAXException {

        InputStream is = QueryBuilderTest.class.getResourceAsStream(LSO);
        java.util.Scanner s = new java.util.Scanner(is).useDelimiter("\\A");
        String str = s.hasNext() ? s.next() : "";

        LearnerState ls = new LearnerState();
        ls.setCourseId("1");
        ls.setmId("2");
        ls.setuId("3");

        LearnerStateOntology lso = new LearnerStateOntology();
        ls.setLearnerStateOntology(lso);

        DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
        DocumentBuilder builder = null;
        try {
            builder = factory.newDocumentBuilder();
        } catch (ParserConfigurationException e) {
            e.printStackTrace();
        }

        InputSource iS = new InputSource();
        iS.setCharacterStream(new StringReader(str));
        Document doc = builder.parse(iS);
        Element elem = (Element) doc.getFirstChild();
        assertNotNull(elem);

        List<Element> content = new ArrayList<>();
        content.add(elem);
        lso.setContent(content);

        QueryBuilder qb = QueryBuilder.getInstance();
        QueryBuilderOutput output = qb.build(ls);
        assertNotNull(qb);

        assertEquals("1", output.getCourseId());
        assertEquals("2", output.getmId());
        assertEquals("3", output.getuId());
    }

}