package eu.intuitel.querybuilder.core.testsuite;

import eu.intuitel.comm.entities.qb.QueryBuilderOutput;

import eu.intuitel.querybuilder.core.QueryBuilder;
import eu.intuitel.querybuilder.core.QueryBuilderException;
import eu.intuitel.querybuilder.util.QueryBuilderUtil;
import eu.intuitel.querybuilder.util.QueryBuilderUtilException;
import org.apache.logging.log4j.LogManager;
import org.custommonkey.xmlunit.DetailedDiff;
import org.custommonkey.xmlunit.Diff;
import org.custommonkey.xmlunit.ElementNameAndAttributeQualifier;
import org.custommonkey.xmlunit.XMLUnit;
import org.junit.AfterClass;
import org.junit.BeforeClass;
import org.semanticweb.owlapi.io.FileDocumentSource;
import org.semanticweb.owlapi.io.OWLOntologyDocumentSource;
import org.xml.sax.SAXException;

import java.io.File;
import java.io.IOException;
import java.util.List;

import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

import org.apache.logging.log4j.Logger;

/**
 * TestSuite.
 *
 * @author Matthias Stumpp (stumpp@fzi.de)
 */
public class TestSuite {

    private final static String rootTestSuiteDir = "/Users/matthiasstumpp/Dropbox/Projekte/FZI/INTUITEL/WP05/QueryBuilder/src/test/resources/eu/intuitel/querybuilder/testsuite/";

    /*
     * Logger
     */
    private static final Logger logger = LogManager.getLogger(TestSuite.class.getName());

    @BeforeClass
    public static void startServer()  {
        try {
            //FileServer.run();
            logger.info("server running");
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @AfterClass
    public static void shutdownServer()  {
        try {
            //FileServer.stop();
            logger.info("server stopped");
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    //@Test
    public void testSuite() throws IOException, SAXException, QueryBuilderUtilException {

        // iterate over folder
        File rootFolder = new File(rootTestSuiteDir);
        if (!rootFolder.exists() || !rootFolder.isDirectory()) {
            return;
        }

        File[] tests = rootFolder.listFiles();
        File[] testFiles;
        File ont = null;
        File xml = null;
        for (File file : tests) {
            if (file.isDirectory()) {
                testFiles = file.listFiles();
                for (File testFile : testFiles) {
                    if (getExtension(testFile).equalsIgnoreCase("owl")) {
                        ont = testFile;
                    } else if (getExtension(testFile).equalsIgnoreCase("xml")) {
                        xml = testFile;
                    }
                }
            }
        }

        assertNotNull(ont);
        assertNotNull(xml);

        // call the querybuilder
        OWLOntologyDocumentSource learnerStateOnt = new FileDocumentSource(ont);
        assertNotNull(learnerStateOnt);
        QueryBuilderOutput currentOutput = null;
        try {
            currentOutput = QueryBuilder.getInstance().build(learnerStateOnt);
        } catch (QueryBuilderException e) {
            logger.info(e.getMessage());
        }
        assertNotNull(currentOutput);
        //LOGGER.info(QueryBuilderUtil.asString(currentOutput, QueryBuilderOutput.class, true));

        // expected output
        QueryBuilderOutput expectedOutput = QueryBuilderUtil.fromFile(xml, QueryBuilderOutput.class);
        assertNotNull(expectedOutput);
        logger.info(QueryBuilderUtil.asString(expectedOutput, QueryBuilderOutput.class, true));

        logger.info("=============");

        String current = QueryBuilderUtil.asString(currentOutput, QueryBuilderOutput.class, true);
        //LOGGER.info(current);
        String expected = QueryBuilderUtil.asString(expectedOutput, QueryBuilderOutput.class, true);
        //LOGGER.info(expected);

        XMLUnit.setIgnoreWhitespace(true);
        XMLUnit.setIgnoreAttributeOrder(true);

        DetailedDiff diff = new DetailedDiff(XMLUnit.compareXML(expected, current));
        diff.overrideElementQualifier(new ElementNameAndAttributeQualifier());
        List<?> allDifferences = diff.getAllDifferences();

        //Diff myDiff = new Diff(expected, current);
        assertTrue("XML similar " + diff.toString(), diff.similar());
    }

    //@Test
    public void test() throws IOException, SAXException {

        String myControlXML =
                "<struct><int>3</int><boolean>false</boolean></struct>";
        String myTestXML =
                "<struct><boolean>false</boolean><int>3</int></struct>";
        Diff myDiff = new Diff(myControlXML, myTestXML);
        assertTrue("XML similar " + myDiff.toString(),
                myDiff.similar());
        //assertTrue("XML identical " + myDiff.toString(),
        //        myDiff.identical());
    }

    private static String getExtension(File file) {
        String extension = "";
        String fileName = file.getAbsolutePath();

        int i = fileName.lastIndexOf('.');
        if (i > 0) {
            extension = fileName.substring(i + 1);
        }

        return extension;
    }

}
