/*
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Ovidiu Serban, ISR Laboratory, University of Reading, UK, http://www.isr.reading.ac.uk/
 * Version: 1.00
 * Date: 2014/7/25
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */

package edu.uk.reading.communication.connection;

import eu.intuitel.CommLayer.CommLibrary.RecommendationRewriterServiceConnection;
import eu.intuitel.comm.entities.exceptions.IntuitelException;
import eu.intuitel.comm.entities.lpm.Reflex;
import eu.intuitel.comm.entities.qb.QueryBuilderOutput;
import eu.intuitel.comm.entities.rr.Learner;
import eu.intuitel.comm.entities.rr.TugAck;
import eu.intuitel.comm.services.IRecommendationRewriterListener;

import java.io.IOException;
import java.net.URI;
import java.util.List;

public class CommunicationLayerDelegate extends AbstractCommunicationLayer {
    public static final CommunicationLayerDelegate instance = new CommunicationLayerDelegate();

    private RecommendationRewriterServiceConnection connection = RecommendationRewriterServiceConnection.getInstance();

    protected CommunicationLayerDelegate() {
    }

    public void OpenBasicDelegate(URI uri, URI intuitelGateway) throws IOException {
        connection.OpenBasic(uri, intuitelGateway);
    }

    public void OpenAdvancedDelegate(String username, String password, String xmppServer,
                                     int xmppServerPort, String tsbUsername) throws IOException {
        connection.OpenAdvanced(username, password, xmppServer, xmppServerPort, tsbUsername);
    }

    public void CloseDelegate() {
        connection.Close();
    }

    public void setRrListener(IRecommendationRewriterListener listener) {
        connection.setRrListener(listener);
    }

    public void onNewLores(List<eu.intuitel.comm.entities.lms.Lore> lores) {
        connection.onNewLores(lores);
    }

    public void onNewTugs(List<eu.intuitel.comm.entities.lms.Tug> tugs) {
        connection.onNewTugs(tugs);
    }

    public void sendLearnerUpdate(List<Learner> learners) throws IntuitelException {
        connection.sendLearnerUpdate(learners);
    }

    public void sendLearnerUpdate(Learner learner) throws IntuitelException {
        connection.sendLearnerUpdate(learner);
    }

    public void sendTugAck(TugAck tugAck) throws IntuitelException {
        connection.sendTugAck(tugAck);
    }

    public void onNewReflexes(List<Reflex> reflexes) {
        connection.onNewReflexes(reflexes);
    }

    public void onNewQueryBuilderOutput(List<QueryBuilderOutput> queryBuilderOutputs) {
        connection.onNewQueryBuilderOutput(queryBuilderOutputs);
    }

    public boolean isContinuousResponse() {
        return true;
    }
}
