/*
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Ovidiu Serban, ISR Laboratory, University of Reading, UK, http://www.isr.reading.ac.uk/
 * Version: 1.00
 * Date: 2014/7/25
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */

package edu.uk.reading.communication.connection.mockup;

import edu.uk.reading.communication.connection.AbstractCommunicationLayer;
import eu.intuitel.comm.entities.exceptions.IntuitelException;
import eu.intuitel.comm.entities.lpm.Reflex;
import eu.intuitel.comm.entities.qb.QueryBuilderOutput;
import eu.intuitel.comm.entities.rr.Learner;
import eu.intuitel.comm.entities.rr.TugAck;
import eu.intuitel.comm.services.IRecommendationRewriterListener;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;
import java.net.URI;
import java.util.List;

public class MockupRRServiceConnection extends AbstractCommunicationLayer {
    public static final MockupRRServiceConnection instance = new MockupRRServiceConnection();

    private static Logger logger = LoggerFactory.getLogger(MockupRRServiceConnection.class);

    private IRecommendationRewriterListener recommendationRewriterListener;
    private MockupConnectionListener mockupConnectionListener;

    private MockupRRServiceConnection() {
    }

    public void OpenBasicDelegate(URI uri, URI intuitelGateway) throws IOException {
        logger.info("Open mockup connection with: uri=" + uri + " gateway=" + intuitelGateway);
    }

    public void OpenAdvancedDelegate(String username, String password, String xmppServer, int xmppServerPort,
                                     String tsbUsername) throws IOException {
        logger.info("Open mockup connection with:" + " username=" + username + " password=" + password +
                    " xmppServer=" + xmppServer + " xmppPort=" + xmppServerPort + " tsbUsername=" + tsbUsername);
    }

    public void CloseDelegate() {
        logger.info("Closing mockup connection");
    }

    public void setRrListener(IRecommendationRewriterListener listener) {
        this.recommendationRewriterListener = listener;
    }

    public void setMockupConnectionListener(MockupConnectionListener mockupConnectionListener) {
        this.mockupConnectionListener = mockupConnectionListener;
    }

    private void fireTugAck(TugAck tugAck) {
        if (this.mockupConnectionListener != null) {
            mockupConnectionListener.tugAckUpdated(tugAck);
        }
    }

    private void fireLearnerUpdate(Learner learner) {
        if (this.mockupConnectionListener != null) {
            mockupConnectionListener.learnerUpdated(learner);
        }
    }

    public void sendLearnerUpdate(List<Learner> learners) throws IntuitelException {
        for (Learner learner : learners) {
            logger.info(learner.toString());
            fireLearnerUpdate(learner);
        }
    }

    public void sendLearnerUpdate(Learner learner) throws IntuitelException {
        logger.info(learner.toString());
        fireLearnerUpdate(learner);
    }

    public void sendTugAck(TugAck tugAck) throws IntuitelException {
        logger.info(tugAck.toString());
        fireTugAck(tugAck);
    }

    public void onNewLores(List<eu.intuitel.comm.entities.lms.Lore> lores) {
        if (this.recommendationRewriterListener != null) {
            this.recommendationRewriterListener.onNewLores(lores);
        }
    }

    public void onNewTugs(List<eu.intuitel.comm.entities.lms.Tug> tugs) {
        if (this.recommendationRewriterListener != null) {
            this.recommendationRewriterListener.onNewTugs(tugs);
        }
    }

    public void onNewReflexes(List<Reflex> reflexes) {
        if (this.recommendationRewriterListener != null) {
            this.recommendationRewriterListener.onNewReflexes(reflexes);
        }
    }

    public void onNewQueryBuilderOutput(List<QueryBuilderOutput> queryBuilderOutputs) {
        if (this.recommendationRewriterListener != null) {
            this.recommendationRewriterListener.onNewQueryBuilderOutput(queryBuilderOutputs);
        }
    }

    public boolean isContinuousResponse() {
        return false;
    }
}
