/*
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Ovidiu Serban, ISR Laboratory, University of Reading, UK, http://www.isr.reading.ac.uk/
 * Contributor: Andrea Zielinski, IOSB Fraunhofer, Germany, http://www.iosb.fraunhofer.de/
 * Version: 1.00
 * Date: 2014/7/3
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */

package eu.intuitel.config;

import eu.intuitel.util.DfReader;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.File;
import java.io.FileInputStream;
import java.util.Properties;

public class ConfigurationLoader {
    public static final String DATA_DIR = "data";
    public static final String DF_WEIGHTS_DIR = "dfWeights";
    public static final String DF_WEIGHTS_FILE = "dfRelativeWeights.csv";
    public static final String DF_DEGREE_DIR = "dfDegreeOfMatch";

    public static Properties properties;

    public static final Logger logger = LoggerFactory.getLogger(ConfigurationLoader.class);

    private static boolean modelsLoaded = false;

    public static boolean loadRankingModels(File rankingModelName) throws Exception {
        if (!rankingModelName.canRead()) {
            logger.error("Cannot read file/folder: " + rankingModelName);
            return false;
        }

        properties = new Properties();
        properties.load(new FileInputStream(rankingModelName));

        File parentDataDir = new File(rankingModelName.getParentFile(), DATA_DIR);
        if (!parentDataDir.canRead()) {
            logger.error("Cannot read file/folder: " + parentDataDir);
            return false;
        }

        File dfWeights = new File(parentDataDir, DF_WEIGHTS_DIR);
        if (!dfWeights.canRead()) {
            logger.error("Cannot read file/folder: " + dfWeights);
            return false;
        }

        File dfWeightsFile = new File(dfWeights, DF_WEIGHTS_FILE);
        if (!dfWeightsFile.canRead()) {
            logger.error("Cannot read file/folder: " + dfWeightsFile);
            return false;
        }

        try {
            DfReader.readDFWeights(dfWeightsFile);
        } catch (Throwable e) {
            logger.error("Cannot load the DF Weights: " + dfWeightsFile, e);
            return false;
        }

        File dfDegreeOfMatch = new File(parentDataDir, DF_DEGREE_DIR);
        if (!dfDegreeOfMatch.canRead()) {
            logger.error("Cannot read file/folder: " + dfDegreeOfMatch);
            return false;
        }

        File[] directoryListing = dfDegreeOfMatch.listFiles();
        if (directoryListing != null) {
            for (File child : directoryListing) {
                try {
                    DfReader.readDFMap(child);
                } catch (Throwable e) {
                    logger.error("Cannot load the DF Map: " + child, e);
                    return false;
                }
            }
        }
        logger.info("Ranking model loaded successfully!");
        modelsLoaded = true;
        return true;
    }

    public static boolean isModelConfigured() {
        return properties != null && !properties.isEmpty() && modelsLoaded;
    }
}
