package eu.intuitel.util;

import com.google.common.collect.HashBasedTable;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.text.NumberFormat;
import java.text.ParseException;
import java.util.HashMap;
import java.util.Locale;

public class DfReader {
    private static final String CSV_SEPARATOR = ";";

    public static HashBasedTable<String, String, Double> hashBasedTable = HashBasedTable.create();
    public static HashMap<String, Integer> DFWeights = new HashMap<>();
    public static HashMap<String, String> DFKeysValues = new HashMap<>();
    public static HashMap<String, String> DFCorrespondences = new HashMap<>();
    public static Integer Max_DfValue = 0;

    public static final Logger logger = LoggerFactory.getLogger(DfReader.class);

    public static void readDFMap(File inputFile) throws IOException, ParseException {
        String[][] data = new String[10][10];
        BufferedReader br = new BufferedReader(new FileReader(inputFile));
        String line;
        Integer i = 0;
        String DFname;
        while ((line = br.readLine()) != null) {
            String[] row = line.split(CSV_SEPARATOR);

            for (int j = 0; j < row.length; j++) {
                data[j][i] = row[j];
                if ((j > 0) & (i > 0)) {
                    String newcell = data[j][i];
                   // NumberFormat nf = NumberFormat.getInstance();
                    
                    NumberFormat nf = NumberFormat.getInstance(Locale.GERMAN);
                    
                    double val = nf.parse(newcell).doubleValue();

                    hashBasedTable.put(data[0][i], data[j][0], val);

                    DFKeysValues.put(data[j][0], data[0][0]);

                    DfTable df = new DfTable();
                    DFname = data[0][0];
                    df.setDFDegree(DFname, hashBasedTable);

                    DFCorrespondences.put(data[0][i], data[i][0]);
                }
            } // for
            i = i + 1;
        } // while

        try {
            br.close();
        } catch (IOException e) {
            logger.error("Error while loading the DF Map!", e);
        }
    }

    public static void readDFRelativeWeights(File inputFile)
            throws IOException, ParseException {
        String[][] dataW = new String[2][50];

        BufferedReader br = new BufferedReader(new FileReader(inputFile));
        String line;

        Integer i = 0;
        while ((line = br.readLine()) != null) {
            String[] row = line.split(CSV_SEPARATOR);

            for (int j = 0; j < row.length; j++) {
                dataW[j][i] = row[j];
                if ((j > 0) & (i > 0)) {
                    String newcell = dataW[j][i];
                    NumberFormat nf = NumberFormat.getInstance();
                    int value = (int) nf.parse(newcell).doubleValue();

                    // filter for learner-specific DFWeights
                    DFWeights.put(dataW[0][i], value);

                    DfTable df = new DfTable();
                    df.setDFWeights(inputFile.getName(), value);
                }
            } // for

            i = i + 1;
        } // while

        try {
            br.close();
        } catch (IOException e) {
            logger.error("Error while loading the DF Map Relative weights!", e);
        }
    }

    public static void readDFWeights(File inputFile) throws IOException,
                                                            ParseException {
        String[][] dataW = new String[2][50];

        BufferedReader br = new BufferedReader(new FileReader(inputFile));
        String line;

        Integer temp_Max_DfValue = 0;
        Integer i = 0;
        while ((line = br.readLine()) != null) {
            String[] row = line.split(CSV_SEPARATOR);

            for (int j = 0; j < row.length; j++) {
                dataW[j][i] = row[j];
                if ((j > 0) & (i > 0)) {
                    String newcell = dataW[j][i];
                    NumberFormat nf = NumberFormat.getInstance();
                    int value = (int) nf.parse(newcell).doubleValue();

                    DFWeights.put(dataW[0][i], value);

                    temp_Max_DfValue = temp_Max_DfValue + value;

                    DfTable df = new DfTable();
                    df.setDFWeights(inputFile.getName(), value);
                }
            } // for

            i = i + 1;
        } // while
        Max_DfValue = temp_Max_DfValue;

        try {
            br.close();
        } catch (IOException e) {
            logger.error("Error while loading the DF Weights!", e);
        }
    }
}