/*
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Andrea Zielinski, IOSB Fraunhofer, Germany, http://www.iosb.fraunhofer.de/
 * Contributor: Ovidiu Serban, ISR Laboratory, University of Reading, UK, http://www.isr.reading.ac.uk/
 * Version: 1.00
 * Date: 2014/7/3
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */

package eu.intuitel.util;

import eu.intuitel.comm.entities.qb.QueryBuilderOutput;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.HashMap;
import java.util.List;

public class HardRanking {
    private static Logger logger = LoggerFactory.getLogger(HardRanking.class);

    public static HashMap<String, Double> getHardResults(QueryBuilderOutput QB, List<String> ListSuccs) {
        HashMap<String, Double> dict = new HashMap<>();
        for (String lmsID : ListSuccs) {
            // Set of KOs which meet the hard criterion for the DF
            List<String> DFs_SCs = eu.intuitel.util.ParseQBResult.getHardCriterialmsID_DFs(QB, lmsID);
            List<String> DFs_SCVs = eu.intuitel.util.ParseQBResult.getHardCriterialmsID_DFValues(QB, lmsID);

            logger.debug("KOs which meet DF (DFs_SCs):" + DFs_SCs);
            logger.debug("KOs which meet DF (DFs_SCVs):" + DFs_SCVs);

            // for all DF_Names
            if (DFs_SCs != null && DFs_SCVs != null) {
                for (String s : DFs_SCs) {
                    String DFValue = eu.intuitel.util.ParseQBResult.getDidacticFactors_DFValue_ByName(QB, s);
                    if (DFValue != null) {
                        logger.debug("DFName=" + s + " DFValue=" + DFValue);
                        String suitedKO = DfReader.DFCorrespondences.get(DFValue);
                        logger.debug(" suitedKO: " + suitedKO);
                        if (DFs_SCVs.contains(suitedKO)) {
                            dict.put(lmsID, 100.0);
                        }
                    } else {
                        logger.error("ERROR: NULL DF Value for Name=" + s);
                    }
                }
            } else {
                logger.error("ERROR: NULL DFsSCs or DFsSCVs for lmsID=" + lmsID);
            }
        }

        return dict;
    }
}

