package eu.intuitel.util;

/*
 * Creator: INTUITEL Consortium, www.intuitel.eu
 * Contributor: Andrea Zielinski, IOSB Fraunhofer, Germany, http://www.iosb.fraunhofer.de/
 * Contributor: Ovidiu Serban, University of Reading, UK, http://isr.reading.ac.uk/
 * Version: 1.01
 * Date: 2014/7/3
 * Copyright: Copyright (C) INTUITEL Consortium
 * License: The license that applies to this file has not yet been determined
 */

import eu.intuitel.comm.entities.qb.*;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.File;
import java.util.*;

public class ParseQBResult {
	private static final Logger logger = LoggerFactory
			.getLogger(ParseQBResult.class);

	public static List<String> getDirectSuccessorslmsID(QueryBuilderOutput QB) {
		List<KnowledgeObject> dirSuccs = null;
		List<String> dirSucclmsID_List = new ArrayList<>();

		String dirSuccLmsID = null;

		dirSuccs = QB.getCurrentKnowledgeObject().getDirectSuccessors()
				.getKnowledgeObject();

		for (KnowledgeObject dirSucc : dirSuccs) {
			dirSuccLmsID = dirSucc.getLmsID();
			dirSucclmsID_List.add(dirSuccLmsID);
		}

		return dirSucclmsID_List;
	}

	public static List<String> getAllSuccessorslmsID(QueryBuilderOutput QB) {
		List<KnowledgeObject> dirSuccs = null;
		List<String> dirSucclmsID_List = new ArrayList<>();

		String dirSuccLmsID = null;

		dirSuccs = QB.getCurrentKnowledgeObject().getAllSuccessors()
				.getKnowledgeObject();

		for (KnowledgeObject dirSucc : dirSuccs) {
			dirSuccLmsID = dirSucc.getLmsID();
			dirSucclmsID_List.add(dirSuccLmsID);
		}
		return dirSucclmsID_List;
	}

	public static List<String> getSuccessorsOfPreviouslmsID(
			QueryBuilderOutput QB) {
		List<KnowledgeObject> dirSuccs = null;
		List<String> dirSucclmsID_List = new ArrayList<>();

		String dirSuccLmsID = null;

		
		if (QB.getPreviousKnowledgeObject() != null) {

			dirSuccs = QB.getPreviousKnowledgeObject().getDirectSuccessors()
					.getKnowledgeObject();

			for (KnowledgeObject dirSucc : dirSuccs) {
				dirSuccLmsID = dirSucc.getLmsID();
				dirSucclmsID_List.add(dirSuccLmsID);
			}
		}// if

		return dirSucclmsID_List;
	}

	public static List<String> getHardCriterialmsID(QueryBuilderOutput QB) {
		List<String> HardCriterionIri_List = new ArrayList<>();
		if (QB.getCriteria() != null) {
			if (QB.getCriteria().getHardCriterion() != null) {

				List<HardCriterion> hard = QB.getCriteria().getHardCriterion();
				hard.removeAll(Collections.singleton(null));

				for (HardCriterion aHard : hard) {
					String HC_Iri = aHard.getIri();

					HardCriterionIri_List.add(HC_Iri);
				}
			}
		}
		return HardCriterionIri_List;
	}

	// New
	public static List<String> getHardCriterialmsID_DFs(QueryBuilderOutput QB,
			String IRI) {
		List<String> listDFs = new ArrayList<>();

		if (QB.getCriteria() != null) {
			if (QB.getCriteria().getHardCriterion() != null) {

				List<HardCriterion> hard = QB.getCriteria().getHardCriterion();
				hard.removeAll(Collections.singleton(null));

				for (HardCriterion HC : hard) {
					String HC_Iri = HC.getIri();

					List<KnowledgeObject> KOs = HC.getKnowledgeObject();

					for (KnowledgeObject KO : KOs) {
						String myIRI = KO.getLmsID();

						if (myIRI.equalsIgnoreCase(IRI)) {
							String item = DfReader.DFKeysValues.get(HC_Iri);

							if (!listDFs.contains(item)) {
								listDFs.add(item);
							}
						}
					}
				}
			}
		}
		return listDFs;
	}

	// New
	public static List<String> getHardCriterialmsID_DFValues(
			QueryBuilderOutput QB, String lmsID) {
		List<String> listDFValues = new ArrayList<>();

		if (QB.getCriteria() != null) {
			if (QB.getCriteria().getHardCriterion() != null) {

				List<HardCriterion> hard = QB.getCriteria().getHardCriterion();
				hard.removeAll(Collections.singleton(null));

				for (HardCriterion HC : hard) {
					String HC_Iri = HC.getIri();
					List<KnowledgeObject> KOs = HC.getKnowledgeObject();

					for (KnowledgeObject KO : KOs) {
						String myIRI = KO.getLmsID();

						if (myIRI.equalsIgnoreCase(lmsID)) {
							if (!listDFValues.contains(HC_Iri)) {
								listDFValues.add(HC_Iri);
							}
						}
					}
				}
			}
		}
		return listDFValues;
	}

	// new
	public static List<String> getSoftCriterialmsID_DFs(QueryBuilderOutput QB,
			String IRI) {
		List<String> listDFs = new ArrayList<>();

		if (QB.getCriteria() != null) {
			if (QB.getCriteria().getSoftCriterion() != null) {
				List<SoftCriterion> soft = QB.getCriteria().getSoftCriterion();
				soft.removeAll(Collections.singleton(null));

				for (SoftCriterion SC : soft) {
					String SC_Iri = SC.getIri();
					List<KnowledgeObject> KOs = SC.getKnowledgeObject();

					for (KnowledgeObject KO : KOs) {
						String myIRI = KO.getLmsID();

						if (myIRI.equalsIgnoreCase(IRI)) {
							String item = DfReader.DFKeysValues.get(SC_Iri);

							if (!listDFs.contains(item)) {
								listDFs.add(item);
							}
						}
					}
				}
			}
		}
		return listDFs;
	}

	public static List<String> getSoftCriterialmsID_DFValues(
			QueryBuilderOutput QB, String lmsID) {
		List<String> listDFValues = new ArrayList<>();

		if (QB.getCriteria() != null) {
			if (QB.getCriteria().getSoftCriterion() != null) {
				List<SoftCriterion> soft = QB.getCriteria().getSoftCriterion();
				soft.removeAll(Collections.singleton(null));

				for (SoftCriterion SC : soft) {
					String SC_Iri = SC.getIri();
					List<KnowledgeObject> KOs = SC.getKnowledgeObject();

					for (KnowledgeObject KO : KOs) {
						String myIRI = KO.getLmsID();

						if (myIRI.equalsIgnoreCase(lmsID)) {
							if (!listDFValues.contains(SC_Iri)) {
								listDFValues.add(SC_Iri);
							}
						}
					}
				}
			}
		}

		return listDFValues;
	}

	public static String getSoftCriterialmsID_DFName_ByValue(
			QueryBuilderOutput QB, String lmsID, String DFValue) {
		String DFName = null;

		if (QB.getCriteria() != null) {
			if (QB.getCriteria().getSoftCriterion() != null) {
				List<SoftCriterion> soft = QB.getCriteria().getSoftCriterion();
				soft.removeAll(Collections.singleton(null));

				for (SoftCriterion SC : soft) {
					String DF_Value = SC.getIri();

					if (DF_Value.equalsIgnoreCase(DFValue)) {
						DFName = DfReader.DFKeysValues.get(DFValue);
					}
				}
			}
		}

		if (DFName == null) {
			DFName = "";
		}

		return DFName;
	}

	public static Set<String> getIntersectionlmsIDs(
			List<String> ListSuccessors, List<String> ListHardCriteria) {
		Set<String> intersection = null;
		try {
			intersection = new HashSet<>(ListSuccessors);
			intersection.retainAll(ListHardCriteria);
		} catch (NumberFormatException e) {
			logger.error("Problem with the data format: " + e.getMessage(), e);
		}
		return intersection;
	}

	public static List<String> getDidacticFactorsByName(QueryBuilderOutput QB) {
		List<String> DFlist = new ArrayList<>();

		if (QB.getDidacticFactors() != null) {
			if (QB.getDidacticFactors().getDidacticFactor() != null) {

				List<DidacticFactor> dida = QB.getDidacticFactors()
						.getDidacticFactor();
				dida.removeAll(Collections.singleton(null));

				for (DidacticFactor aDida : dida) {
					String DF_Name = aDida.getName();
					DFlist.add(DF_Name);
				}
			}
		}
		return DFlist;
	}

	public static List<String> getDidacticFactorsByValue(QueryBuilderOutput QB) {
		List<String> DFlist = new ArrayList<>();

		if (QB.getDidacticFactors() != null) {
			if (QB.getDidacticFactors().getDidacticFactor() != null) {

				List<DidacticFactor> dida = QB.getDidacticFactors()
						.getDidacticFactor();
				dida.removeAll(Collections.singleton(null));

				for (DidacticFactor aDida : dida) {
					String DF_Value = aDida.getValue();
					DFlist.add(DF_Value);
				}
			}
		}
		return DFlist;
	}

	public static List<QueryBuilderOutput> readDOM(String fileName)
			throws Exception {

		File file = new File(fileName);

		List<String> errors = new LinkedList<>();

		List<QueryBuilderOutput> doc = eu.intuitel.util.MessageUtils
				.parseQueryBuilderOutput(file, "inform-ir0", errors);

		System.out.println(" Errors " + errors);

		return doc;
	}

	public static String getDidacticFactors_DFValue_ByName(
			QueryBuilderOutput QB, String DFName) {
		String DF_Value = null;
		if (QB.getDidacticFactors() != null) {
			if (QB.getDidacticFactors().getDidacticFactor() != null) {
				List<DidacticFactor> dida = QB.getDidacticFactors()
						.getDidacticFactor();
				dida.removeAll(Collections.singleton(null));

				for (DidacticFactor DF : dida) {
					String DF_Name = DF.getName();

					if (DF_Name.equalsIgnoreCase(DFName))
						DF_Value = DF.getValue();
				}
			}
		}

		if (DF_Value == null) {
			DF_Value = "";
		}

		return DF_Value;
	}
}
