/*
 * Copyright (C) 2013, FZI Forschungszentrum Informatik
 *
 * Modifications to the initial code base are copyright of their
 * respective authors, or their employers as appropriate. Authorship
 * of the modifications may be determined from the ChangeLog placed at
 * the end of this file.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3.0 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package de.fzi.herakles.analyser.impl;

import java.util.HashSet;
import java.util.Set;

import org.semanticweb.owlapi.model.OWLOntology;

import de.fzi.herakles.analyser.Analyser;
import de.fzi.herakles.registry.ServerRegistry;
import de.fzi.owllink.reasoner.server.entities.ReasonerType;

/**
 * Creates exactly one Analyser instance for each {@link OWLOntology} and
 * {@link ServerRegistry} reverence combination.
 * 
 * @author Marcel Weigel
 * 
 */
public class AnalyserFactory {
	
	private static AnalyserFactory analyserFactory;

	private Set<AnalyserAbst> analysers;

	private AnalyserFactory() {
		this.analysers = new HashSet<AnalyserAbst>();
	}

	/**
	 * Get an unique AnalyserFactory instance.
	 * 
	 * @return AnalyserFacotry
	 */
	public static AnalyserFactory getInstance() {
		if (analyserFactory == null) {
			analyserFactory = new AnalyserFactory();
		}
		return analyserFactory;
	}

	/**
	 * Creates exactly one Analyser instance for each {@link OWLOntology} and
	 * {@link ServerRegistry} reverence combination.
	 * 
	 * @param ontology
	 *            OWLOntology
	 * @param serverRegistry
	 *            ServerRegistry
	 * @return Analyser
	 */
	public Analyser getAnalyser( OWLOntology ontology, ServerRegistry serverRegistry, Set<String> excludedReasonerTypeIds ) {

		AnalyserAbst analyser = null;
		for (AnalyserAbst analyserTmp : this.analysers) {
			if (analyserTmp.getOntology() == ontology && analyserTmp.getServerRegistry() == serverRegistry) {
				analyser = analyserTmp;
			}
		}
		if (analyser == null) {
			analyser = new AnalyserImpl(ontology, serverRegistry, excludedReasonerTypeIds);
			this.analysers.add(analyser);
		}
		return analyser;
	}

}
