/*
 * Copyright (C) 2013, FZI Forschungszentrum Informatik
 *
 * Modifications to the initial code base are copyright of their
 * respective authors, or their employers as appropriate. Authorship
 * of the modifications may be determined from the ChangeLog placed at
 * the end of this file.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3.0 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package de.fzi.herakles.analyser.impl;

import java.util.HashSet;
import java.util.Set;

import org.semanticweb.owlapi.model.OWLOntology;

import de.fzi.herakles.registry.ServerAdapter;
import de.fzi.herakles.registry.ServerRegistry;
import de.fzi.owllink.reasoner.server.entities.ReasonerType;

/**
 * Package private Analyser implementation class.
 * 
 * @author Marcel Weigel
 * 
 */
class AnalyserImpl extends AnalyserAbst {

	AnalyserImpl(OWLOntology ontology, ServerRegistry serverRegistry, Set<String> excludedReasonerTypeIds) {
		super(ontology, serverRegistry, excludedReasonerTypeIds);
	}

	/**
	 * Simple implementation of the interface method. Combine all reasonerTypes
	 * of all {@link ServerAdapter} that are registered in the
	 * {@link ServerRegistry}.
	 */
	public Set<ReasonerType> getSuitableReasonerTypes() {
		Set<ReasonerType> suitableReasonerTypes = new HashSet<ReasonerType>();
		for (ServerAdapter serverAdapter : this.serverRegistry.getServerAdapters()) {
			Set<ReasonerType> reasonerTypes = serverAdapter.getAvailableReasonerTypes();
			
			for(ReasonerType reasonerType : reasonerTypes) {
				if(!isReasonerTypeExcluded(reasonerType)) {
					suitableReasonerTypes.add(reasonerType);
				}
			}
		}

		return suitableReasonerTypes;
	}

}
