/*
 * Copyright (C) 2013, FZI Forschungszentrum Informatik
 *
 * Modifications to the initial code base are copyright of their
 * respective authors, or their employers as appropriate. Authorship
 * of the modifications may be determined from the ChangeLog placed at
 * the end of this file.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3.0 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package de.fzi.herakles.executor.impl;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.TimeoutException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import de.fzi.herakles.job.Job;
import de.fzi.herakles.job.response.Response;
import de.fzi.herakles.registry.ReasonerAdapter;
import de.fzi.herakles.registry.ReasonerRegistry;

/**
 * 
 * @author Marcel Weigel
 * 
 */
class DefaultExecutor extends ExecutorAbst {

	private final static Log LOG = LogFactory.getLog(DefaultExecutor.class);

	DefaultExecutor(ReasonerRegistry reasonerRegistry, long timeOut) {
		super(reasonerRegistry, timeOut);
	}

	public <T> T execute( final Job<T> job ) throws TimeoutException, ExecutorException {
		Set<ReasonerAdapter> idleReasonerAdapters = this.reasonerRegistry.getIdleReasonerAdapters();
		if(idleReasonerAdapters.isEmpty()) {
			String str = "No reasoner is idle!";
			LOG.info(str);
			throw new ExecutorException(str);
		}
		for (final ReasonerAdapter reasonerAdapter : idleReasonerAdapters) {
			startJobThread(job, reasonerAdapter);
		}

//		while(!job.successfulResponseAvailable() && !job.allResponsesFailed()) {	
//		}
		while(!job.allResponsesAvailable()) {	
			try {
				Thread.sleep(10);
			} catch (InterruptedException e) {}
		}
		try {
			Thread.sleep(10);
		} catch (InterruptedException e) {}
		
		if(LOG.isInfoEnabled())
			LOG.info(String.format("Execute was finished, successfully finished: %d and failed finished %d.", job.getResponsesSuccessfullyFinishedCount(), job.getResponsesFailedFinishedCount()));
		List<Response<T>> responses = job.getSuccessfullResponses();
		if(responses.isEmpty()) {
			LOG.info("No response has finished successfully.");
			Map<String, Throwable> reasonerExceptionMap = new HashMap<String, Throwable>();
			for(Response<T> response : job.getResponses()) {
				reasonerExceptionMap.put(response.getSource().getReasonerType().getName(), response.getException());
			}
			throw new ExecutorException(reasonerExceptionMap);
		}
		
		Response<T> firstResponse = responses.iterator().next();
		if(LOG.isInfoEnabled())
			LOG.info(String.format("First reasoner how has fnished was %s.", firstResponse.getSource().getReasonerType().getName()));

		return firstResponse.getResult();
	}
}
