package de.fzi.herakles.executor.impl;

import java.util.HashSet;
import java.util.Set;
import java.util.concurrent.TimeoutException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import de.fzi.herakles.executor.Executor;
import de.fzi.herakles.job.Job;
import de.fzi.herakles.registry.ReasonerAdapter;
import de.fzi.herakles.registry.ReasonerRegistry;

public abstract class ExecutorAbst implements Executor {

	private final static Log LOG = LogFactory.getLog(ExecutorAbst.class);

	protected long timeOut;

	protected ReasonerRegistry reasonerRegistry;

	private Set<Thread> executeThreads = new HashSet<Thread>();

	ExecutorAbst(ReasonerRegistry reasonerRegistry, long timeOut) {
		guard_ExecutorAbst(reasonerRegistry, timeOut);

		this.reasonerRegistry = reasonerRegistry;
		this.timeOut = timeOut;
	}

	private void guard_ExecutorAbst( ReasonerRegistry reasonerRegistry, long timeOut ) {
		if (reasonerRegistry == null) {
			final String errStr = "ReasonerRegistry is null.";
			LOG.fatal(errStr);
			throw new NullPointerException(errStr);
		}
		if (timeOut <= 0) {
			if (LOG.isWarnEnabled())
				LOG.warn(String.format("Timeout value %d is to small.", timeOut));
		}
	}

	public ReasonerRegistry getReasonerRegistry() {
		return this.reasonerRegistry;
	}

	public abstract <T> T execute( Job<T> job ) throws TimeoutException, ExecutorException;

	protected <T> void startJobThread( final Job<T> job, final ReasonerAdapter reasonerAdapter ) {
		Thread thread = new Thread() {
			@Override
			public void run() {
				job.execute(reasonerAdapter);
			}
		};
		thread.start();
		this.executeThreads.add(thread);
	}

	public void interrupt() {
		for (Thread thread : this.executeThreads) {
			thread.interrupt();
		}
	}

}
