/*
 * Copyright (C) 2013, FZI Forschungszentrum Informatik
 *
 * Modifications to the initial code base are copyright of their
 * respective authors, or their employers as appropriate. Authorship
 * of the modifications may be determined from the ChangeLog placed at
 * the end of this file.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3.0 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package de.fzi.herakles.executor.impl;

import java.util.HashSet;
import java.util.Set;

import de.fzi.herakles.executor.Executor;
import de.fzi.herakles.registry.ReasonerRegistry;

/**
 * 
 * @author Marcel Weigel
 * 
 */
public abstract class ExecutorFactoryAbst {

	protected static ExecutorFactoryAbst executorFactory;

	protected Set<ExecutorAbst> executors;

	protected ExecutorFactoryAbst() {
		this.executors = new HashSet<ExecutorAbst>();
	}

	public Executor getExecutor( ReasonerRegistry reasonerRegistry, long timeOut ) {
		ExecutorAbst executor = null;
		for (ExecutorAbst ex : this.executors) {
			if (ex.getReasonerRegistry() == reasonerRegistry) {
				executor = ex;
			}
		}
		if (executor == null) {
			executor = getConcretExecutor(reasonerRegistry, timeOut);
			this.executors.add(executor);
		}
		return executor;
	}

	protected abstract ExecutorAbst getConcretExecutor( ReasonerRegistry reasonerRegistry, long timeOut );
}
