/*
 * Copyright (C) 2013, FZI Forschungszentrum Informatik
 *
 * Modifications to the initial code base are copyright of their
 * respective authors, or their employers as appropriate. Authorship
 * of the modifications may be determined from the ChangeLog placed at
 * the end of this file.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3.0 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package de.fzi.herakles.job.impl;

import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.Map;
import java.util.Map.Entry;

import de.fzi.herakles.job.Job;
import de.fzi.herakles.job.request.Request;

/**
 * 
 * @author Marcel Weigel
 * 
 */
public class JobManager implements JobListener {

	private final static int MAX_JOB_COUNT = 100;

	private static JobManager jobManager;

	private Map<Job<?>, JobStatistic> jobs;

	private JobManager() {
		this.jobs = new HashMap<Job<?>, JobStatistic>();
	}

	public static JobManager getInstance() {
		if (jobManager == null) {
			jobManager = new JobManager();
		}
		return jobManager;
	}

	@SuppressWarnings("unchecked")
	public <T> Job<T> getJob( Method method, Object[] params ) {
		Job<T> job = null;
		for (Job<?> j : this.jobs.keySet()) {
			Request request = j.getRequest();
			if (request.getMethod().equals(method) && request.getParams().equals(params)) {
				job = (Job<T>) j;
			}
		}
		if (job == null) {
			cleanUpJobMap();
			job = new JobImpl<T>(this, method, params);
			this.jobs.put(job, new JobStatistic());
		}

		return job;
	}

	public void executeCalled( Job<?> job ) {
		if (this.jobs.containsKey(job)) {
			JobStatistic jobStatistic = this.jobs.get(job);
			jobStatistic.isCalled();
		}
	}

	private void cleanUpJobMap() {
		if (this.jobs.size() > MAX_JOB_COUNT) {
			Integer lowestExecuteCalledCount = -1;
			Job<?> usedLessFrequentlyJob = null;
			for (Entry<Job<?>, JobStatistic> jobEntry : this.jobs.entrySet()) {
				Integer executeCalledCount = jobEntry.getValue().getExecuteCalledCount();
				if (executeCalledCount < lowestExecuteCalledCount) {
					lowestExecuteCalledCount = executeCalledCount;
					usedLessFrequentlyJob = jobEntry.getKey();
				}
			}
			if (usedLessFrequentlyJob != null) {
				this.jobs.remove(usedLessFrequentlyJob);
			}
		}
	}
}
