/*
 * Copyright (C) 2013, FZI Forschungszentrum Informatik
 *
 * Modifications to the initial code base are copyright of their
 * respective authors, or their employers as appropriate. Authorship
 * of the modifications may be determined from the ChangeLog placed at
 * the end of this file.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3.0 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package de.fzi.herakles.job.request.impl;

import java.lang.reflect.Method;
import java.util.HashSet;
import java.util.Set;

import de.fzi.herakles.job.request.Request;

/**
 * 
 * @author Marcel Weigel
 * 
 */
public class RequestFactory {

	private static RequestFactory requestFactory;

	private Set<Request> requests;

	private RequestFactory() {
		this.requests = new HashSet<Request>();
	}

	public static RequestFactory getInstance() {
		if (requestFactory == null) {
			requestFactory = new RequestFactory();
		}
		return requestFactory;
	}

	public Request getRequest( Method method, Object[] param ) {
		Request request = null;
		for (Request re : this.requests) {
			if (re.getMethod().equals(method) && (re.getParams() == param || re.getParams().equals(param))) {
				request = re;
			}
		}
		if (request == null) {
			request = new RequestImpl(method, param);
			this.requests.add(request);
		}
		return request;
	}
}
