/*
 * Copyright (C) 2013, FZI Forschungszentrum Informatik
 *
 * Modifications to the initial code base are copyright of their
 * respective authors, or their employers as appropriate. Authorship
 * of the modifications may be determined from the ChangeLog placed at
 * the end of this file.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3.0 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package de.fzi.herakles.job.request.impl;

import java.lang.reflect.Method;

import de.fzi.herakles.job.request.Request;

/**
 * 
 * @author Marcel Weigel
 * 
 */
public class RequestImpl implements Request {

	private Method method;

	private Object[] params;

	RequestImpl(Method method, Object[] params) {
		this.method = method;
		this.params = params;
	}

	public Object[] getParams() {
		return params;
	}

	public Method getMethod() {
		return method;
	}

	@Override
	public boolean equals( Object obj ) {
		if (obj == null)
			return false;
		if (obj == this)
			return true;
		if (!(obj instanceof RequestImpl))
			return false;

		RequestImpl re = (RequestImpl) obj;
		return (this.method == re.method || this.method != null && this.method.equals(re.method))
				&& (this.params == re.params || isParamsEquals(this.params, re.params));
	}
	
	private boolean isParamsEquals(Object[] thisParams, Object[] params) {
		if(thisParams == null || params == null) 
			return false;
		if(thisParams.length != params.length)
			return false;
		for(int i=0; i<thisParams.length; i++)
			if(!thisParams[i].equals(params[i]))
				return false;
		return true;
	}

	@Override
	public int hashCode() {
		int hash = 7;
		hash = 31 * hash + (this.method == null ? 0 : this.method.hashCode());
		hash = 31 * hash + (this.params == null ? 0 : getParamsHashCode(this.params));
		return hash;
	}
	
	private int getParamsHashCode(Object[] params) {
		if(params == null) 
			return 0;
		return params.length;
	}
	
	@Override
	public String toString() {
		String[] classPath = RequestImpl.class.getName().split("\\.");
		StringBuilder sb = new StringBuilder();
		if(this.params != null) {
			for(Object o : this.params) {
				sb.append(o);
				sb.append(", ");
			}
			if(sb.length() != 0) {
				sb.deleteCharAt(sb.length()-2);
				sb.deleteCharAt(sb.length()-1);
			}
		} else {
			sb.append("null");
		}
		return String.format("%s(method=%s(%s))", classPath[classPath.length-1], this.method.getName(), sb.toString());
	}

}
