/*
 * Copyright (C) 2013, FZI Forschungszentrum Informatik
 *
 * Modifications to the initial code base are copyright of their
 * respective authors, or their employers as appropriate. Authorship
 * of the modifications may be determined from the ChangeLog placed at
 * the end of this file.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3.0 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package de.fzi.herakles.job.response.impl;

import java.util.HashSet;
import java.util.Set;

import de.fzi.herakles.job.response.Response;
import de.fzi.herakles.registry.ReasonerAdapter;

/**
 * 
 * @author Marcel Weigel
 * 
 */
public class ResponseFactory {

	private static ResponseFactory responseFactory;

	private Set<Response<? extends Object>> respones;

	public ResponseFactory() {
		this.respones = new HashSet<Response<?>>();
	}

	public static ResponseFactory getInstance() {
		if (responseFactory == null) {
			responseFactory = new ResponseFactory();
		}
		return responseFactory;
	}

	@SuppressWarnings("unchecked")
	public <T extends Object> Response<T> getResponse( ReasonerAdapter source, T result ) {
		Response<T> response = null;
		for (Response<?> re : this.respones) {
			if (re.getSource().equals(source) 
					&& (re.getResult() == result || (re.getResult() != null && re.getResult().equals(result)))) {
				response = (Response<T>) re;
			}
		}
		if (response == null) {
			response = new ResponseImpl<T>(source, result);
			this.respones.add(response);
		}
		return response;
	}

	@SuppressWarnings("unchecked")
	public <T> Response<T> getResponse( ReasonerAdapter source, Throwable exception ) {
		Response<T> response = null;
		for (Response<?> re : this.respones) {
			if (re.getSource().equals(source) 
					&& (re.getException() == exception || (re.getException() != null && re.getException().equals(exception)))) {
				response = (Response<T>) re;
			}
		}
		if (response == null) {
			response = new ResponseImpl<T>(source, exception);
			this.respones.add(response);
		}
		return response;
	}
}
