/*
 * Copyright (C) 2013, FZI Forschungszentrum Informatik
 *
 * Modifications to the initial code base are copyright of their
 * respective authors, or their employers as appropriate. Authorship
 * of the modifications may be determined from the ChangeLog placed at
 * the end of this file.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3.0 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package de.fzi.herakles.job.response.impl;

import de.fzi.herakles.job.response.Response;
import de.fzi.herakles.registry.ReasonerAdapter;

/**
 * 
 * @author Marcel Weigel
 * 
 */
public class ResponseImpl<T> implements Response<T> {

	private ReasonerAdapter source;

	private T result;

	private Throwable exception;

	ResponseImpl(ReasonerAdapter source, T result) {
		this.source = source;
		this.result = result;
		this.exception = null;
	}

	ResponseImpl(ReasonerAdapter source, Throwable exception) {
		this.source = source;
		this.result = null;
		this.exception = exception;
	}

	public T getResult() {
		return result;
	}

	public boolean isFailed() {
		return this.exception != null;
	}

	public ReasonerAdapter getSource() {
		return source;
	}

	public Throwable getException() {
		return exception;
	}

	@SuppressWarnings("unchecked")
	@Override
	public boolean equals( Object obj ) {
		if (obj == null)
			return false;
		if (obj == this)
			return true;
		if (!(obj instanceof ResponseImpl<?>))
			return false;

		ResponseImpl<T> re = (ResponseImpl<T>) obj;
		return (this.source == re.source || this.source != null && this.source.equals(re.source))
				&& (this.result == re.result || this.result != null && this.result.equals(re.result))
				&& (this.exception == re.exception || this.exception != null && this.exception.equals(re.exception));
	}

	@Override
	public int hashCode() {
		int hash = 7;
		hash = 31 * hash + (this.source == null ? 0 : this.source.hashCode());
		hash = 31 * hash + (this.result == null ? 0 : this.result.hashCode());
		hash = 31 * hash + (this.exception == null ? 0 : this.exception.hashCode());
		return hash;
	}
	
	@Override
	public String toString() {
		String[] classPath = Response.class.getName().split("\\.");
		if(!isFailed()) 
			return String.format("%s(source=%s, result=%s)", classPath[classPath.length-1], this.source, this.result);
		else
			return String.format("%s(source=%s, exception=%s)", classPath[classPath.length-1], this.source, this.exception);
	}
}
