/*
 * Copyright (C) 2013, FZI Forschungszentrum Informatik
 *
 * Modifications to the initial code base are copyright of their
 * respective authors, or their employers as appropriate. Authorship
 * of the modifications may be determined from the ChangeLog placed at
 * the end of this file.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3.0 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package de.fzi.herakles.loader.impl;

import java.util.Set;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import de.fzi.herakles.loader.Loader;
import de.fzi.herakles.registry.ReasonerRegistry;
import de.fzi.herakles.registry.ServerRegistry;
import de.fzi.owllink.reasoner.server.entities.Owner;
import de.fzi.owllink.reasoner.server.entities.ReasonerType;

/**
 * Abstract Loader class that provides the {@link ServerRegistry} and the
 * {@link ReasonerRegistry} and the {@link Owner} package private get-method for
 * the {@link LoaderFactory} class.
 * 
 * @author Marcel Weigel
 * 
 */
public abstract class LoaderAbst implements Loader {

	private final static Log LOG = LogFactory.getLog(LoaderAbst.class);

	protected ServerRegistry serverRegistry;

	protected ReasonerRegistry reasonerRegistry;

	protected Owner owner;

	LoaderAbst(ServerRegistry serverRegistry, ReasonerRegistry reasonerRegistry, Owner owner) {
		guard_LoaderAbst(serverRegistry, reasonerRegistry, owner);

		this.serverRegistry = serverRegistry;
		this.reasonerRegistry = reasonerRegistry;
		this.owner = owner;
	}

	private void guard_LoaderAbst( ServerRegistry serverRegistry, ReasonerRegistry reasonerRegistry, Owner owner ) {
		if (serverRegistry == null) {
			final String errStr = "ServerRegistry is null.";
			LOG.fatal(errStr);
			throw new NullPointerException(errStr);
		}
		if (reasonerRegistry == null) {
			final String errStr = "ReasonerRegistry is null.";
			LOG.fatal(errStr);
			throw new NullPointerException(errStr);
		}
		if (owner == null) {
			final String errStr = "Owner is null.";
			LOG.fatal(errStr);
			throw new NullPointerException(errStr);
		}
	}

	ServerRegistry getServerRegistry() {
		return serverRegistry;
	}

	ReasonerRegistry getReasonerRegistry() {
		return reasonerRegistry;
	}

	Owner getOwner() {
		return owner;
	}

	public abstract void updateReasonerRegistry( Set<ReasonerType> reasonerTypes );

}
