/*
 * Copyright (C) 2013, FZI Forschungszentrum Informatik
 *
 * Modifications to the initial code base are copyright of their
 * respective authors, or their employers as appropriate. Authorship
 * of the modifications may be determined from the ChangeLog placed at
 * the end of this file.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3.0 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package de.fzi.herakles.loader.impl;

import java.util.HashSet;
import java.util.Set;

import de.fzi.herakles.loader.Loader;
import de.fzi.herakles.registry.ReasonerRegistry;
import de.fzi.herakles.registry.ServerRegistry;
import de.fzi.owllink.reasoner.server.entities.Owner;

/**
 * Create exaklty one Loader for each {@link ServerRegistry} and
 * {@link ReasonerRegistr}y and {@link Owner} reverence combination.
 * 
 * @author Marcel Weigel
 * 
 */
public class LoaderFactory {
	
	private static LoaderFactory loaderFactory;

	private Set<LoaderAbst> loaders;

	private LoaderFactory() {
		this.loaders = new HashSet<LoaderAbst>();
	}

	/**
	 * Get an unique LoaderFactory instance.
	 * 
	 * @return LoaderFacotry
	 */
	public static LoaderFactory getInstance() {
		if (loaderFactory == null) {
			loaderFactory = new LoaderFactory();
		}
		return loaderFactory;
	}

	/**
	 * Create exaklty one Loader for each {@link ServerRegistry} and
	 * {@link ReasonerRegistr}y and {@link Owner} reverence combination.
	 * 
	 * @param serverRegistry
	 *            ServerRegistry
	 * @param reasonerRegistry
	 *            ReasonerRegistry
	 * @param owner
	 *            Owner
	 * @return Loader
	 */
	public Loader getLoader( ServerRegistry serverRegistry, ReasonerRegistry reasonerRegistry, Owner owner ) {
		LoaderAbst loader = null;
		for (LoaderAbst loaderTmp : this.loaders) {
			if (loaderTmp.getServerRegistry() == serverRegistry && loaderTmp.getReasonerRegistry() == reasonerRegistry
					&& loaderTmp.getOwner() == owner) {
				loader = loaderTmp;
			}
		}
		if (loader == null) {
			loader = new LoaderImpl(serverRegistry, reasonerRegistry, owner);
			this.loaders.add(loader);
		}
		return loader;
	}
}
