/*
 * Copyright (C) 2013, FZI Forschungszentrum Informatik
 *
 * Modifications to the initial code base are copyright of their
 * respective authors, or their employers as appropriate. Authorship
 * of the modifications may be determined from the ChangeLog placed at
 * the end of this file.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3.0 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package de.fzi.herakles.loader.impl;

import java.util.Set;

import de.fzi.herakles.registry.ReasonerRegistry;
import de.fzi.herakles.registry.ServerAdapter;
import de.fzi.herakles.registry.ServerRegistry;
import de.fzi.owllink.reasoner.server.entities.Owner;
import de.fzi.owllink.reasoner.server.entities.ReasonerType;

/**
 * Package private Loader implementation class.
 * 
 * @author Marcel Weigel
 * 
 */
class LoaderImpl extends LoaderAbst {

	LoaderImpl(ServerRegistry serverRegistry, ReasonerRegistry reasonerRegistry, Owner owner) {
		super(serverRegistry, reasonerRegistry, owner);
	}

	/**
	 * Simple implementation of the interface method. Start on every
	 * {@link ServerAdapter} witch are registered in the {@link ServerRegistry}
	 * for every {@link ReasonerType} one reasoner.
	 */
	public void updateReasonerRegistry( Set<ReasonerType> reasonerTypes ) {
		for (ServerAdapter serverAdapter : this.serverRegistry.getServerAdapters()) {
			Set<ReasonerType> availableReasonerTyps = serverAdapter.getAvailableReasonerTypes();

			for (ReasonerType suitableReasonerType : reasonerTypes) {
				if (containsReasonerType(availableReasonerTyps, suitableReasonerType)) {
					serverAdapter.startReasoner(suitableReasonerType, this.owner, this.reasonerRegistry);
				}
			}
		}
	}

	private boolean containsReasonerType( Set<ReasonerType> reasonerTypes, ReasonerType reasonerType ) {
		for (ReasonerType r : reasonerTypes) {
			if (r.equals(reasonerType)) {
				return true;
			}
		}
		return false;
	}

}
