package de.fzi.herakles.main;

import java.io.File;
import java.net.MalformedURLException;
import java.net.URISyntaxException;
import java.net.URL;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Set;

import org.semanticweb.owlapi.apibinding.OWLManager;
import org.semanticweb.owlapi.model.IRI;
import org.semanticweb.owlapi.model.OWLAxiom;
import org.semanticweb.owlapi.model.OWLClass;
import org.semanticweb.owlapi.model.OWLClassExpression;
import org.semanticweb.owlapi.model.OWLOntology;
import org.semanticweb.owlapi.model.OWLOntologyCreationException;
import org.semanticweb.owlapi.model.OWLOntologyManager;
import org.semanticweb.owlapi.owllink.OWLlinkReasoner;
import org.semanticweb.owlapi.owllink.OWLlinkReasonerConfiguration;
import org.semanticweb.owlapi.reasoner.BufferingMode;
import org.semanticweb.owlapi.reasoner.Node;
import org.semanticweb.owlapi.reasoner.OWLReasoner;
import org.semanticweb.owlapi.reasoner.OWLReasonerConfiguration;

import de.fzi.herakles.reasoner.HeraklesReasonerConfiguration;
import de.fzi.herakles.reasoner.HeraklesReasonerFactory;
import de.fzi.herakles.registry.ReasonerAdapter;
import de.fzi.herakles.registry.ReasonerRegistry;
import de.fzi.herakles.registry.ServerAdapter;
import de.fzi.herakles.registry.impl.ReasonerRegistryFactory;
import de.fzi.herakles.registry.impl.ServerAdapterFactory;
import de.fzi.owllink.reasoner.server.entities.Owner;
import de.fzi.owllink.reasoner.server.entities.ReasonerType;

public class HeraklesMain {
	/**
	 * @param args
	 * @throws MalformedURLException 
	 * @throws OWLOntologyCreationException 
	 */
	public static void main(String[] args) throws MalformedURLException, OWLOntologyCreationException {
//		OWLOntology ontology = getPizzaOntology();
		OWLOntologyManager manager = OWLManager.createOWLOntologyManager();
//		
		OWLOntology ontology = manager.createOntology(IRI.create("tutorial"));
		
		Set<URL> serverUrls = new HashSet<URL>();

		serverUrls.add(new URL("http://localhost:8080/"));

		HeraklesReasonerConfiguration reasonerConfiguration = new HeraklesReasonerConfiguration(serverUrls);
		
		HeraklesReasonerFactory factory = HeraklesReasonerFactory.getInstance();
		
		OWLlinkReasoner reasoner = factory.createNonBufferingReasoner(ontology, reasonerConfiguration);
		
//		Set<OWLClass> classes = getClasses(reasoner);
		
		Node<OWLClass> owlClasses = reasoner.getTopClassNode();
		
//		Set<OWLClassExpression> owlClassExpressions = owlClasses.iterator().next().getSubClasses(ontology);
		
		System.out.println(owlClasses.getSize());
		
		OWLClass A = manager.getOWLDataFactory().getOWLClass(IRI.create("http://tutorial#A"));
		OWLClass B = manager.getOWLDataFactory().getOWLClass(IRI.create("http://tutorial#B"));
		OWLAxiom a = manager.getOWLDataFactory().getOWLSubClassOfAxiom(A, B);
		manager.addAxiom(ontology, a);
		
		System.out.println(owlClasses.getSize());
		
	}
	
	private static OWLOntology getEmptyOntology() {
		OWLOntologyManager owlOntologyManager = OWLManager.createOWLOntologyManager();
		OWLOntology owlOntology = null;
		try {
			owlOntology = owlOntologyManager.createOntology();
		} catch (OWLOntologyCreationException e) {
			e.printStackTrace();
		}
		return owlOntology;
	}
	
	private static OWLOntology getPizzaOntology() {
		OWLOntologyManager owlOntologyManager = OWLManager.createOWLOntologyManager();
		OWLOntology owlOntology = null;
		try {
			URL url = HeraklesMain.class.getClassLoader().getResource("de/fzi/herakles/main/pizza.owl");
			File file = new File(url.toURI());
			owlOntology = owlOntologyManager.loadOntologyFromOntologyDocument(file);
		} catch (OWLOntologyCreationException e) {
			e.printStackTrace();
		} catch (URISyntaxException e) {
			e.printStackTrace();
		}
		return owlOntology;
	}
	
	private static Set<OWLClass> getClasses(OWLReasoner owlReasoner) {
		Set<OWLClass> classes = new HashSet<OWLClass>();
		
		Node<OWLClass> topClass = owlReasoner.getTopClassNode();
		 
		getClassesStep(topClass, owlReasoner, classes);
		
		return classes;
	}
	
	private static void getClassesStep(Node<OWLClass> parent, OWLReasoner owlReasoner, Set<OWLClass> classes) {
		for (Iterator<OWLClass> it = parent.getEntities().iterator(); it.hasNext();) {
			OWLClass cls = it.next();
			classes.add(cls);
		}
		
		Set<Node<OWLClass>> childes = owlReasoner.getSubClasses(parent.getRepresentativeElement(), true).getNodes();
		
		for (Node<OWLClass> child : childes) {
			getClassesStep(child, owlReasoner, classes);
		} 
	} 

}
