/*
 * Copyright (C) 2013, FZI Forschungszentrum Informatik
 *
 * Modifications to the initial code base are copyright of their
 * respective authors, or their employers as appropriate. Authorship
 * of the modifications may be determined from the ChangeLog placed at
 * the end of this file.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3.0 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package de.fzi.herakles.reasoner;

import java.net.URL;
import java.util.HashSet;
import java.util.Set;

import org.semanticweb.owlapi.reasoner.FreshEntityPolicy;
import org.semanticweb.owlapi.reasoner.IndividualNodeSetPolicy;
import org.semanticweb.owlapi.reasoner.NullReasonerProgressMonitor;
import org.semanticweb.owlapi.reasoner.ReasonerProgressMonitor;
import org.semanticweb.owlapi.reasoner.SimpleConfiguration;

/**
 * 
 * @author Marcel Weigel
 * 
 */
public class HeraklesReasonerConfiguration extends SimpleConfiguration {

	private Set<URL> serverUrls = new HashSet<URL>();
	
	private Set<String> excludedReasonerTypeIds = new HashSet<String>();

	public HeraklesReasonerConfiguration(ReasonerProgressMonitor progressMonitor, Set<URL> serverUrls,
			IndividualNodeSetPolicy individualNodeSetPolicy) {
		super(progressMonitor, FreshEntityPolicy.DISALLOW, Long.MAX_VALUE, individualNodeSetPolicy);
		this.serverUrls = serverUrls;
	}
	
	public HeraklesReasonerConfiguration(ReasonerProgressMonitor progressMonitor, Set<URL> serverUrls, Set<String> excludedReasonerTypeIds,
			IndividualNodeSetPolicy individualNodeSetPolicy) {
		super(progressMonitor, FreshEntityPolicy.DISALLOW, Long.MAX_VALUE, individualNodeSetPolicy);
		this.excludedReasonerTypeIds = excludedReasonerTypeIds;
		this.serverUrls = serverUrls;
	}

	public HeraklesReasonerConfiguration(Set<URL> serverUrls, IndividualNodeSetPolicy policy) {
		this(new NullReasonerProgressMonitor(), serverUrls, policy);
	}
	
	public HeraklesReasonerConfiguration(Set<URL> serverUrls, Set<String> excludedReasonerTypeIds, IndividualNodeSetPolicy policy) {
		this(new NullReasonerProgressMonitor(), serverUrls, excludedReasonerTypeIds, policy);
	}

	public HeraklesReasonerConfiguration(Set<URL> serverUrls) {
		this(serverUrls, IndividualNodeSetPolicy.BY_SAME_AS);
	}
	
	public HeraklesReasonerConfiguration(Set<URL> serverUrls, Set<String> excludedReasonerTypeIds) {
		this(serverUrls, excludedReasonerTypeIds, IndividualNodeSetPolicy.BY_SAME_AS);
	}

	public Set<URL> getServerUrls() {
		return serverUrls;
	}

	public Set<String> getExcludedReasonerTypeIds() {
		return excludedReasonerTypeIds;
	}
}
