/*
 * Copyright (C) 2013, FZI Forschungszentrum Informatik
 *
 * Modifications to the initial code base are copyright of their
 * respective authors, or their employers as appropriate. Authorship
 * of the modifications may be determined from the ChangeLog placed at
 * the end of this file.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3.0 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package de.fzi.herakles.registry;

import org.semanticweb.owlapi.model.OWLOntology;

import de.fzi.herakles.job.Job;
import de.fzi.owllink.reasoner.server.entities.Owner;
import de.fzi.owllink.reasoner.server.entities.ReasonerType;

/**
 * A ReasonerAdapter maps a OwlLinkReasoner which is running on a OwlLinkServer.
 * 
 * @author Marcel Weigel
 * 
 */
public interface ReasonerAdapter {

	/**
	 * Get the ServerAdapter on which it was started on.
	 * 
	 * @return ServerAdapter
	 */
	ServerAdapter getServerAdapter();

	/**
	 * Get the port of the ReasonerAdapter.
	 * 
	 * @return port
	 */
	int getPort();

	/**
	 * Get the owner of the ReasonerAdapter.
	 * 
	 * @return owner
	 */
	Owner getOwner();

	/**
	 * Get the reasoner type of the ReasonerAdapter.
	 * 
	 * @return ReasonerType
	 */
	ReasonerType getReasonerType();

	/**
	 * Get the ontology of the ReasonerAdapter.
	 * 
	 * @return OwlOntology
	 */
	OWLOntology getOntology();

	/**
	 * Check if the ReasonerAdpter is busy.
	 * 
	 * @return True if the ReasonerAdpater is busy.
	 * 
	 */
	boolean isBusy();

	/**
	 * Execute a job on a ReasonerAdapter.
	 * 
	 * @param job
	 *            Job
	 */
	<T> void invoke( Job<T> job );

}
