/*
 * Copyright (C) 2013, FZI Forschungszentrum Informatik
 *
 * Modifications to the initial code base are copyright of their
 * respective authors, or their employers as appropriate. Authorship
 * of the modifications may be determined from the ChangeLog placed at
 * the end of this file.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3.0 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package de.fzi.herakles.registry;

import java.util.Set;

/**
 * The ServerRegister registered all {@link ServerAdapter} which was set in a
 * configuration.
 * 
 * @author Marcel Weigel
 * 
 */
public interface ServerRegistry {

	/**
	 * Get a set of all ServerAdapters which are registered on the
	 * ServerRegistry.
	 * 
	 * @return Set of ServerAdapter.
	 */
	Set<ServerAdapter> getServerAdapters();

	/**
	 * Get one ServerAdapter which given host and port.
	 * 
	 * @param host
	 *            host name
	 * @param port
	 *            port
	 * @return ServeraAdapter
	 */
	ServerAdapter getServerAdapter( String host, int port );

	/**
	 * Check if the ServerApdater with host and port was registered.
	 * 
	 * @param host
	 *            host name
	 * @param port
	 *            port
	 * @return True if the ServerAdpater was registered.
	 */
	boolean isServerAdapterRegistered( String host, int port );

	/**
	 * Create a ServerAdapter with host and port and add it to the
	 * ServerRegistry
	 * 
	 * @param host
	 *            host name
	 * @param port
	 *            port
	 */
	void createAndAddServerAdatper( String host, int port );

	/**
	 * Remove the ServerAdapter with host and port.
	 * 
	 * @param host
	 *            host name
	 * @param port
	 *            port
	 */
	void removeServerAdapter( String host, int port );

	/**
	 * Get the number of registered ServerAdapters on the registry.
	 * 
	 * @return Number of ServerAdapters.
	 */
	int countServerAdapters();

	/**
	 * Check if the ServerRegistry is empty.
	 * 
	 * @return True if empty.
	 */
	boolean isEmpty();

}
