/*
* Copyright (C) 2013, FZI Forschungszentrum Informatik
*
* Modifications to the initial code base are copyright of their
* respective authors, or their employers as appropriate. Authorship
* of the modifications may be determined from the ChangeLog placed at
* the end of this file.
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 3.0 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/
package de.fzi.herakles.registry.impl;

import java.util.HashSet;
import java.util.Set;

import org.semanticweb.owlapi.model.OWLOntology;
import org.semanticweb.owlapi.reasoner.BufferingMode;

import de.fzi.herakles.registry.ReasonerRegistry;

/**
 * Factory to create {@link ReasonerRegistry} instances. 
 * @author Marcel Weigel
 *
 */
public class ReasonerRegistryFactory {
	
	private static ReasonerRegistryFactory reasonerRegistryFactory;
	
	private Set<ReasonerRegistryImpl> reasonerRegistrys;
	
	private ReasonerRegistryFactory() {
		this.reasonerRegistrys = new HashSet<ReasonerRegistryImpl>();
	}
	
	/**
	 * Gets the instance of this factory.
	 * @return Instance of this factory
	 */
	public static ReasonerRegistryFactory getInstance() {
		if(reasonerRegistryFactory == null) {
			reasonerRegistryFactory = new ReasonerRegistryFactory();
		}
		return reasonerRegistryFactory;
	}
	
	/**
	 * Gets an instance of a {@link ReasonerRegistry} for the given ontology and buffering mode.
	 * If such an instance already exists, it will be returned, and no new instance will be created.
	 * @param ontology Ontology
	 * @param bufferingMode Buffering mode
	 * @return Reasoner registry instance
	 */
	public ReasonerRegistry getReasonerRegistry(OWLOntology ontology, BufferingMode bufferingMode) {
		ReasonerRegistryImpl reasonerRegistry = null;
		for(ReasonerRegistryImpl reasonerRegistryTmp : this.reasonerRegistrys) {
			if(reasonerRegistryTmp.getOntology() != null && reasonerRegistryTmp.getOntology().equals(ontology) &&
					reasonerRegistryTmp.getBufferingMode() != null && reasonerRegistryTmp.getBufferingMode().equals(bufferingMode)) {
				reasonerRegistry = reasonerRegistryTmp;
			}
		}
		if(reasonerRegistry == null) {
			reasonerRegistry = new ReasonerRegistryImpl(ontology, bufferingMode);
			this.reasonerRegistrys.add(reasonerRegistry);
		}
		return reasonerRegistry;
	}

}
