/*
* Copyright (C) 2013, FZI Forschungszentrum Informatik
*
* Modifications to the initial code base are copyright of their
* respective authors, or their employers as appropriate. Authorship
* of the modifications may be determined from the ChangeLog placed at
* the end of this file.
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 3.0 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/
package de.fzi.herakles.registry.impl;

import java.util.HashSet;
import java.util.Set;

import org.semanticweb.owlapi.model.OWLOntology;
import org.semanticweb.owlapi.reasoner.BufferingMode;

import de.fzi.herakles.registry.ReasonerAdapter;
import de.fzi.herakles.registry.ReasonerRegistry;
import de.fzi.herakles.registry.ServerAdapter;
import de.fzi.owllink.reasoner.server.entities.Owner;
import de.fzi.owllink.reasoner.server.entities.ReasonerType;

/**
 * 
 * @author Marcel Weigel
 *
 */
class ReasonerRegistryImpl implements ReasonerRegistry {
	
	private Set<ReasonerAdapter> reasonerAdapters;
	
	private ReasonerAdapterFactory reasonerAdapterFactory;
	
	private OWLOntology ontology;
	
	private BufferingMode bufferingMode;
	
	private int countReasonerAdapters;

	ReasonerRegistryImpl(OWLOntology ontology, BufferingMode bufferingMode) {		
		this.ontology = ontology;
		
		this.bufferingMode = bufferingMode;
		
		this.reasonerAdapters = new HashSet<ReasonerAdapter>();
		this.countReasonerAdapters = 0;
		
		this.reasonerAdapterFactory = ReasonerAdapterFactory.getInstance();
	}
	
	OWLOntology getOntology() {
		return ontology;
	}

	BufferingMode getBufferingMode() {
		return bufferingMode;
	}

	public Set<ReasonerAdapter> getReasonerAdapters() {
		return reasonerAdapters;
	}
	
	public Set<ReasonerAdapter> getReasonerAdapters(ServerAdapter serverAdapter) {
		Set<ReasonerAdapter> reasonerAdapters = new HashSet<ReasonerAdapter>();
		for(ReasonerAdapter reasonerAdapter : this.reasonerAdapters) {
			if(reasonerAdapter.getServerAdapter().equals(serverAdapter)) {
				reasonerAdapters.add(reasonerAdapter);
			}
		}
		return reasonerAdapters;
	}

	public ReasonerAdapter getReasonerAdapter(ServerAdapter serverAdapter, int port) {
		for(ReasonerAdapter reasonerAdapter : this.reasonerAdapters) {
			if(reasonerAdapter.getPort() == port &&
					reasonerAdapter.getServerAdapter().equals(serverAdapter)) {
				return reasonerAdapter;
			}
		}
		return null;
	}

	public boolean existsReasonerAdapter(ServerAdapter serverAdapter, int port) {
		for(ReasonerAdapter reasonerAdapter : this.reasonerAdapters) {
			if(reasonerAdapter.getServerAdapter().equals(serverAdapter) &&
					reasonerAdapter.getPort() == port) {
				return true;
			}
		}
		return false;
	}

	public int countReasonerAdapters() {
		return this.countReasonerAdapters;
	}

	public ReasonerAdapter createAndAddReasonerAdapter(ServerAdapter serverAdapter, int port, Owner owner, ReasonerType reasonerType) {
		ReasonerAdapter reasonerAdapter = this.reasonerAdapterFactory.getReasonerAdapter(serverAdapter, port, owner, reasonerType, this.ontology, this.bufferingMode);
		
		this.reasonerAdapters.add(reasonerAdapter);
		this.countReasonerAdapters++;
		
		return reasonerAdapter;
	}

	public void removeReasonerAdapter(ReasonerAdapter reasonerAdapter) {
		this.reasonerAdapters.remove(reasonerAdapter);
		this.countReasonerAdapters--;
	}

	public Set<ReasonerAdapter> getIdleReasonerAdapters() {
		Set<ReasonerAdapter> idleReasonerAdapters = new HashSet<ReasonerAdapter>();
		for(ReasonerAdapter reasonerAdapter : this.reasonerAdapters) {
			if(!reasonerAdapter.isBusy()) {
				idleReasonerAdapters.add(reasonerAdapter);
			}
		}
		return idleReasonerAdapters;
	}

	public void removeAllReasonerAdapters(Set<ReasonerAdapter> reasonerAdapters) {
		this.reasonerAdapters.removeAll(reasonerAdapters);
		this.countReasonerAdapters = 0;
	}

	public boolean isEmpty() {
		return this.reasonerAdapters.isEmpty();
	}

}
