/*
 * Copyright (C) 2013, FZI Forschungszentrum Informatik
 *
 * Modifications to the initial code base are copyright of their
 * respective authors, or their employers as appropriate. Authorship
 * of the modifications may be determined from the ChangeLog placed at
 * the end of this file.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3.0 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package de.fzi.herakles.registry.impl;

import java.util.HashSet;
import java.util.Set;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import de.fzi.herakles.registry.ServerAdapter;

/**
 * 
 * @author Marcel Weigel
 * 
 */
public class ServerAdapterFactory {

	private final static Log LOG = LogFactory.getLog(ServerAdapterFactory.class);

	private static final int MIN_PORT_NUMBER = 1024;
	private static final int MAX_PORT_NUMBER = 65535;

	private static ServerAdapterFactory serverAdapterFactory;

	private Set<ServerAdapter> serverAdapters;

	private ServerAdapterFactory() {
		this.serverAdapters = new HashSet<ServerAdapter>();
	}

	public static ServerAdapterFactory getInstance() {
		if (serverAdapterFactory == null) {
			serverAdapterFactory = new ServerAdapterFactory();
		}
		return serverAdapterFactory;
	}

	public ServerAdapter getServerAdapter( String host, int port ) {
		guard_getServerAdapter(host, port);

		ServerAdapter serverAdapter = null;
		for (ServerAdapter sa : this.serverAdapters) {
			if (sa.getHost().equals(host) && sa.getPort() == port) {
				serverAdapter = sa;
			}
		}
		if (serverAdapter == null) {
			serverAdapter = new ServerAdapterImpl(host, port);
			this.serverAdapters.add(serverAdapter);
		}
		return serverAdapter;
	}

	private void guard_getServerAdapter( String host, int port ) {
		if (host == null) {
			final String errStr = "Host name is null.";
			LOG.error(errStr);
			throw new NullPointerException(errStr);
		}
		if (host.isEmpty()) {
			final String errStr = "Host name is empty.";
			LOG.error(errStr);
			throw new IllegalArgumentException(errStr);
		}
		if (!(MIN_PORT_NUMBER <= port && port <= MAX_PORT_NUMBER)) {
			final String errStr = String.format("Port %04d has wrong range.", port);
			LOG.error(errStr);
			throw new IllegalArgumentException(errStr);
		}
	}

}
