/*
* Copyright (C) 2013, FZI Forschungszentrum Informatik
*
* Modifications to the initial code base are copyright of their
* respective authors, or their employers as appropriate. Authorship
* of the modifications may be determined from the ChangeLog placed at
* the end of this file.
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 3.0 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/
package de.fzi.herakles.registry.impl;

import de.fzi.herakles.registry.ServerRegistry;

/**
 * Factory to create {@link ServerRegistry} instances.
 * @author Marcel Weigel
 *
 */
public class ServerRegistryFactory {
	
	private static ServerRegistryFactory serverRegistryFactory;
	
	private ServerRegistry serverRegistry;
	
	private ServerRegistryFactory() {
	}
	
	/**
	 * Gets the instance of this factory.
	 * @return Instance of this factory
	 */
	public static ServerRegistryFactory getInstance() {
		if(serverRegistryFactory == null) {
			serverRegistryFactory = new ServerRegistryFactory();
		}
		return serverRegistryFactory;
	}
	
	/**
	 * Gets a instance of {@link ServerRegsitry}. If such an instance already exists, it will be returned, and no new instance will be created.
	 * @return ServerRegistry
	 */
	public ServerRegistry getServerRegistry() {
		if(this.serverRegistry == null) {
			this.serverRegistry = new ServerRegistryImpl();
		}
		return this.serverRegistry;
	}
	
}
