/*
 * Copyright (C) 2013, FZI Forschungszentrum Informatik
 *
 * Modifications to the initial code base are copyright of their
 * respective authors, or their employers as appropriate. Authorship
 * of the modifications may be determined from the ChangeLog placed at
 * the end of this file.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3.0 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package de.fzi.herakles.registry.impl;

import java.util.HashSet;
import java.util.Set;

import de.fzi.herakles.registry.ServerAdapter;
import de.fzi.herakles.registry.ServerRegistry;

/**
 * 
 * @author Marcel Weigel
 * 
 */
class ServerRegistryImpl implements ServerRegistry {

	private Set<ServerAdapter> serverAdapters;

	private int countServerAdapters;

	ServerRegistryImpl() {
		this.serverAdapters = new HashSet<ServerAdapter>();
		this.countServerAdapters = 0;
	}

	public Set<ServerAdapter> getServerAdapters() {
		return this.serverAdapters;
	}

	public ServerAdapter getServerAdapter( String host, int port ) {
		for (ServerAdapter serverAdapter : this.serverAdapters) {
			if (serverAdapter.getPort() == port && serverAdapter.getHost().equals(host)) {
				return serverAdapter;
			}
		}
		return null;
	}

	public boolean isServerAdapterRegistered( String host, int port ) {
		for (ServerAdapter serverAdapter : this.serverAdapters) {
			if (serverAdapter.getPort() == port && serverAdapter.getHost().equals(host)) {
				return true;
			}
		}
		return false;
	}

	public void createAndAddServerAdatper( String host, int port ) {
		ServerAdapter serverAdapter = ServerAdapterFactory.getInstance().getServerAdapter(host, port);

		this.serverAdapters.add(serverAdapter);
		this.countServerAdapters++;
	}

	public void removeServerAdapter( String host, int port ) {
		ServerAdapter serverAdapter = getServerAdapter(host, port);

		if (serverAdapter != null) {
			this.serverAdapters.remove(serverAdapter);
			this.countServerAdapters--;
		}
	}

	public int countServerAdapters() {
		return this.countServerAdapters;
	}

	public boolean isEmpty() {
		return this.serverAdapters.isEmpty();
	}
}
