package de.fzi.herakles.analyser;

import static org.junit.Assert.*;

import java.util.HashSet;
import java.util.Set;

import org.junit.Before;
import org.junit.Test;
import org.semanticweb.owlapi.apibinding.OWLManager;
import org.semanticweb.owlapi.model.IRI;
import org.semanticweb.owlapi.model.OWLOntology;
import org.semanticweb.owlapi.model.OWLOntologyCreationException;
import org.semanticweb.owlapi.model.OWLOntologyManager;

import de.fzi.herakles.analyser.impl.AnalyserFactory;
import de.fzi.herakles.mockups.ServerRegistryMock;
import de.fzi.herakles.registry.ServerRegistry;

public class AnalyserFactoryTest {
	
	private OWLOntologyManager owlOntologyManager;
	
	@Before
    public void setUp() {
		this.owlOntologyManager = OWLManager.createOWLOntologyManager();
    }

	@Test
	public void singeltonInstanceTest() {
		AnalyserFactory instance1 = AnalyserFactory.getInstance();
		
		assertNotNull(instance1);
		
		AnalyserFactory instance2 = AnalyserFactory.getInstance();
		
		assertNotNull(instance2);
		
		assertSame(instance1, instance2);
	}
	
	@Test
	public void getAnalyserSingeltonTest() throws OWLOntologyCreationException {
		OWLOntology ontology1 = this.owlOntologyManager.createOntology(IRI.create("TestOntology1"));
		OWLOntology ontology2 = this.owlOntologyManager.createOntology(IRI.create("TestOntology2"));
		
		assertNotNull(ontology1);
		assertNotNull(ontology2);
		
		assertNotSame(ontology1, ontology2);
		
		ServerRegistry serverRegistry1 = new ServerRegistryMock();	
		ServerRegistry serverRegistry2 = new ServerRegistryMock();
		
		assertNotNull(serverRegistry1);
		assertNotNull(serverRegistry2);

		assertNotSame(serverRegistry1, serverRegistry2);
		
		Set<String> excludedReasonerTypeIds = new HashSet<String>();

		Analyser analyser1 = AnalyserFactory.getInstance().getAnalyser(ontology1, serverRegistry1, excludedReasonerTypeIds);
		Analyser analyser2 = AnalyserFactory.getInstance().getAnalyser(ontology1, serverRegistry2, excludedReasonerTypeIds);
		Analyser analyser3 = AnalyserFactory.getInstance().getAnalyser(ontology2, serverRegistry1, excludedReasonerTypeIds);
		Analyser analyser4 = AnalyserFactory.getInstance().getAnalyser(ontology2, serverRegistry2, excludedReasonerTypeIds);

		assertNotNull(analyser1);
		assertNotNull(analyser2);
		assertNotNull(analyser3);
		assertNotNull(analyser4);
		
		assertNotSame(analyser1, analyser2);
		assertNotSame(analyser1, analyser3);
		assertNotSame(analyser1, analyser4);
		
		Analyser analyser1Same = AnalyserFactory.getInstance().getAnalyser(ontology1, serverRegistry1, excludedReasonerTypeIds);
		
		assertNotNull(analyser1Same);

		assertSame(analyser1, analyser1Same);
	}


}
