package de.fzi.herakles.integration;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.fail;

import java.io.File;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.net.MalformedURLException;
import java.net.URISyntaxException;
import java.net.URL;
import java.util.HashSet;
import java.util.Set;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import org.semanticweb.owlapi.apibinding.OWLManager;
import org.semanticweb.owlapi.model.AxiomType;
import org.semanticweb.owlapi.model.IRI;
import org.semanticweb.owlapi.model.OWLAxiom;
import org.semanticweb.owlapi.model.OWLClass;
import org.semanticweb.owlapi.model.OWLClassExpression;
import org.semanticweb.owlapi.model.OWLDataFactory;
import org.semanticweb.owlapi.model.OWLDataProperty;
import org.semanticweb.owlapi.model.OWLDataPropertyExpression;
import org.semanticweb.owlapi.model.OWLNamedIndividual;
import org.semanticweb.owlapi.model.OWLObjectProperty;
import org.semanticweb.owlapi.model.OWLObjectPropertyExpression;
import org.semanticweb.owlapi.model.OWLOntology;
import org.semanticweb.owlapi.model.OWLOntologyCreationException;
import org.semanticweb.owlapi.model.OWLOntologyManager;
import org.semanticweb.owlapi.owllink.OWLlinkHTTPXMLReasonerFactory;
import org.semanticweb.owlapi.owllink.OWLlinkReasoner;
import org.semanticweb.owlapi.owllink.OWLlinkReasonerConfiguration;
import org.semanticweb.owlapi.owllink.server.OWLlinkServer;
import org.semanticweb.owlapi.owllink.server.serverfactory.OWLlinkServerFactory;
import org.semanticweb.owlapi.reasoner.InferenceType;
import org.semanticweb.owlapi.reasoner.OWLReasoner;
import org.semanticweb.owlapi.reasoner.OWLReasonerFactory;
import org.semanticweb.owlapi.util.AxiomTypeProvider;

import uk.ac.manchester.cs.factplusplus.owlapiv3.FaCTPlusPlusReasonerFactory;
import uk.ac.manchester.cs.owl.owlapi.OWLDataFactoryImpl;

import de.fzi.herakles.main.HeraklesMain;
import de.fzi.herakles.reasoner.HeraklesReasoner;
import de.fzi.herakles.reasoner.HeraklesReasonerConfiguration;
import de.fzi.herakles.reasoner.HeraklesReasonerFactory;
import de.fzi.owllink.reasoner.server.reasoner.StopableFaCTServerFactory;
import de.fzi.owllink.reasoner.server.reasoner.StopableHermiTServerFactory;

public class ReasonerIntegration {
	
	private final static Log LOG = LogFactory.getLog(HeraklesReasoner.class);
	
	private final static String METHODE_REFENCE_CLASS = "org.semanticweb.owlapi.owllink.OWLlinkReasoner";
	
	private OWLDataFactory df = new OWLDataFactoryImpl();
	
	private final String defaultBase = "http://www.w3.org/2002/07/owl";
	
	private final String base = "http://www.pizza.com/ontologies/pizza.owl";
	
	private static OWLOntology ontology;
	
	private static OWLlinkServer owlLinkServer;
	
	private static OWLlinkReasoner reasonerHerakles;
	private static OWLlinkReasoner reasonerLink;
	private static OWLReasoner reasoner;
	
//	private static OWLReasonerFactory reasonerFactory = new StructuralReasonerFactory();
//	private static OWLlinkServerFactory owlLinkServerFactory = new StopableStructuralServerFactory();
//	private static Set<String> reasonerTypeIds = new HashSet<String>() {
//						private static final long serialVersionUID = 1L;
//							{
//								add("HermiT");
//								add("FaCT");
//								add("Pellet"); 
//							}
//						};
						
	private static OWLReasonerFactory reasonerFactory = new org.semanticweb.HermiT.Reasoner.ReasonerFactory();
	private static OWLlinkServerFactory owlLinkServerFactory = new StopableHermiTServerFactory();
	private static Set<String> reasonerTypeIds = new HashSet<String>() {
						private static final long serialVersionUID = 1L;
							{
								add("Structural");
								add("FaCT");
								add("Pellet"); 
							}
						};
						
//	private static OWLReasonerFactory reasonerFactory = new FaCTPlusPlusReasonerFactory();
//	private static OWLlinkServerFactory owlLinkServerFactory = new StopableFaCTServerFactory();
//	private static Set<String> reasonerTypeIds = new HashSet<String>() {
//						private static final long serialVersionUID = 1L;
//							{
//								add("Structural");
//								add("HermiT");
//								add("Pellet"); 
//							}
//						};
	
	private static OWLOntology getPizzaOntology() {
		OWLOntologyManager owlOntologyManager = OWLManager.createOWLOntologyManager();
		OWLOntology owlOntology = null;
		try {
			URL url = HeraklesMain.class.getClassLoader().getResource("de/fzi/herakles/main/pizza.owl");
			File file = new File(url.toURI());
			owlOntology = owlOntologyManager.loadOntologyFromOntologyDocument(file);
		} catch (OWLOntologyCreationException e) {
			e.printStackTrace();
		} catch (URISyntaxException e) {
			e.printStackTrace();
		}
		return owlOntology;
	}
	
	@BeforeClass
	public static void setUpBeforeClass() throws MalformedURLException {
		ontology = getPizzaOntology();
		
		createReasonerHerakles();	
		
		createReasonerLink();

		createReasoner();
	}

	private static void createReasoner() {
		reasoner = reasonerFactory.createNonBufferingReasoner(ontology);
	}

	private static void createReasonerLink() {
		final String address = "localhost";
		final int port = 4242;
		
		owlLinkServer = owlLinkServerFactory.createServer(port);
		
		owlLinkServer.run();
		
		URL reasonerUrl = null;
		try {
			reasonerUrl = new URL(String.format("http://%s:%04d", address, port));
		} catch (MalformedURLException e) {}

		OWLlinkReasonerConfiguration owlLinkreasonerConfiguration = new OWLlinkReasonerConfiguration(reasonerUrl);
		
		OWLlinkHTTPXMLReasonerFactory owlReasonerFactory = new OWLlinkHTTPXMLReasonerFactory();

		reasonerLink = owlReasonerFactory.createNonBufferingReasoner(ontology, owlLinkreasonerConfiguration);
		
	}

	private static void createReasonerHerakles() throws MalformedURLException {
		Set<URL> serverUrls = new HashSet<URL>();
		serverUrls.add(new URL("http://localhost:8080/"));
		
		HeraklesReasonerConfiguration reasonerConfiguration = new HeraklesReasonerConfiguration(serverUrls, reasonerTypeIds);
		
		HeraklesReasonerFactory factory = HeraklesReasonerFactory.getInstance();	
		reasonerHerakles = factory.createNonBufferingReasoner(ontology, reasonerConfiguration);
	}
	
	
	
	@AfterClass
	public static void tearDownClass() throws InterruptedException {
		reasonerHerakles.interrupt();
		
		owlLinkServer.stop();
	}
	
	@Before
	public void setUp() throws MalformedURLException {
		System.out.println("***************Start Check***************");
	}
	
	@After
	public void tearDown() {
		System.out.println("***************End Check***************");
	}
	
	private <T> void invoke( String methodName ) {
		invoke(methodName, null, null);
	}
	
	@SuppressWarnings("unchecked")
	private <T> void invoke( String methodName, Class<?>[] paramTypes, Object[] params ) {

		
		System.out.printf("Calling method: %s()", methodName);
		System.out.println();
		System.out.print("Params: ");
		if(params != null) {
			for(Object object : params) {
				System.out.print(object + ", ");
			}
		}
		System.out.println();

		
		Method method = getMethod(methodName, paramTypes);
		
		T result = null;
		T resultLink = null;
		T resultHerakles = null;
		try {

			result = (T) method.invoke(reasoner, params);
			resultLink = (T) method.invoke(reasonerLink, params);
			resultHerakles = (T) method.invoke(reasonerHerakles, params);

		} catch (IllegalAccessException e) {
			final String errStr = String.format("Invoke methode %s() has failied becouse no acess rights.", method.getName());
			LOG.fatal(errStr);
			fail(errStr);
		} catch (IllegalArgumentException e) {
			final String errStr = String.format("Invoke methode %s() has failied becouse wrong arguments.", method.getName());
			LOG.fatal(errStr);
			fail(errStr);
		} catch (InvocationTargetException e) {
			if(LOG.isInfoEnabled()) 
				LOG.info(String.format("Invoke methode %s() has failied becouse exception throw: %s.", method.getName(), e.getTargetException().getMessage()));
		}
		
		check(result, resultLink, resultHerakles);
	}
	
	private <T> void check(T expected, T expectedLink,  T actual) {
//		System.out.println("Expected: ");
//		System.out.println(expected);
		
		System.out.println("ExpectedLink: ");
		System.out.println(expectedLink);
		
		System.out.println("Actual: ");
		System.out.println(actual);
		
//		assertNotNull(expected);
//		assertNotNull(expectedLink);
//		assertNotNull(actual);
		
//		assertEquals(expected, actual);
		assertEquals(expectedLink, actual);
	}
	
	private Method getMethod( String methodName, Class<?>[] paramTypes ) {
		Method method = null;
		try {
			Class<?> clazz = Class.forName(METHODE_REFENCE_CLASS);

			method = clazz.getMethod(methodName, paramTypes);

		} catch (ClassNotFoundException e) {
			final String errStr = String.format("Could not find %s class.", METHODE_REFENCE_CLASS);
			LOG.fatal(errStr);
			fail(errStr);
		} catch (NoSuchMethodException e) {
			final String errStr = String.format("No such method in %s class.", METHODE_REFENCE_CLASS);
			LOG.fatal(errStr);
			fail(errStr);
		}
		return method;
	}

	
//	@Test
//	public void testHeraklesReasoner() {
//		fail("Not yet implemented");
//	}

//	@Test
//	public void testHandleChangesSetOfOWLAxiomSetOfOWLAxiom() {
//		fail("Not yet implemented");
//	}

	@Test
	public void testGetBottomClassNode() {
		invoke("getBottomClassNode");
	}

	@Test
	public void testGetBottomDataPropertyNode() {
		invoke("getBottomDataPropertyNode");
	}

	@Test
	public void testGetBottomObjectPropertyNode() {
		invoke("getBottomObjectPropertyNode");
	}

	@Test
	public void testGetDataPropertyDomains() {
		OWLDataProperty owlDataProperty = df.getOWLDataProperty(IRI.create(base + "#hasCalorificContentValue"));
		
		invoke("getDataPropertyDomains", new Class[] {OWLDataProperty.class, boolean.class}, new Object[] {owlDataProperty, true});
	}

	@Test
	public void testGetDataPropertyValues() {
		OWLNamedIndividual owlNamedIndividual = df.getOWLNamedIndividual(IRI.create(base + "#ExampleAmericanHot"));
		OWLDataProperty owlDataProperty = df.getOWLDataProperty(IRI.create(base + "#hasCalorificContentValue"));

		invoke("getDataPropertyValues", new Class[] {OWLNamedIndividual.class, OWLDataProperty.class}, new Object[] {owlNamedIndividual, owlDataProperty});
	}

	@Test
	public void testGetDifferentIndividuals() {
		OWLNamedIndividual owlNamedIndividual = df.getOWLNamedIndividual(IRI.create(base + "#ExampleAmericanHot"));
		
		invoke("getDifferentIndividuals", new Class[] {OWLNamedIndividual.class}, new Object[] {owlNamedIndividual});
	}

	@Test
	public void testGetDisjointClasses() {
		OWLClass owlClass = df.getOWLClass(IRI.create(base + "#CheeseTopping"));
		
		invoke("getDisjointClasses", new Class[] {OWLClassExpression.class}, new Object[] {owlClass});
	}

	@Test
	public void testGetDisjointDataProperties() {
		OWLDataProperty owlDataProperty = df.getOWLDataProperty(IRI.create(base + "#hasCalorificContentValue"));
		
		invoke("getDisjointDataProperties", new Class[] {OWLDataPropertyExpression.class}, new Object[] {owlDataProperty});
	}

	@Test
	public void testGetDisjointObjectProperties() {
		OWLObjectProperty owlObjectProperty = df.getOWLObjectProperty(IRI.create(base + "#hasIngredient"));
		
		invoke("getDisjointObjectProperties", new Class[] {OWLObjectPropertyExpression.class}, new Object[] {owlObjectProperty});
	}

	@Test
	public void testGetEquivalentClasses() {
		OWLClass owlClass = df.getOWLClass(IRI.create(base + "#CheesyPizza"));
		
		invoke("getEquivalentClasses", new Class[] {OWLClassExpression.class}, new Object[] {owlClass});
	}

	@Test
	public void testGetEquivalentDataProperties() {
		OWLDataProperty owlDataProperty = df.getOWLDataProperty(IRI.create(base + "#hasCalorificContentValue"));
		
		invoke("getEquivalentDataProperties", new Class[] {OWLDataProperty.class}, new Object[] {owlDataProperty});
	}

	@Test
	public void testGetEquivalentObjectProperties() {
		OWLObjectProperty owlObjectProperty = df.getOWLObjectProperty(IRI.create(base + "#hasIngredient"));
		
		invoke("getEquivalentObjectProperties", new Class[] {OWLObjectPropertyExpression.class}, new Object[] {owlObjectProperty});
	}

	@Test
	public void testGetInstances() {
		OWLClass owlClass = df.getOWLClass(IRI.create(base + "#Country"));
		
		invoke("getInstances", new Class[] {OWLClassExpression.class, boolean.class}, new Object[] {owlClass, true});
	}

	@Test
	public void testGetInverseObjectProperties() {
		OWLObjectProperty owlObjectProperty = df.getOWLObjectProperty(IRI.create(base + "#hasBase"));

		invoke("getInverseObjectProperties", new Class[] {OWLObjectPropertyExpression.class}, new Object[] {owlObjectProperty});
	}

	@Test
	public void testGetObjectPropertyDomains() {
		OWLObjectProperty owlObjectProperty = df.getOWLObjectProperty(IRI.create(base + "#hasBase"));
		
		invoke("getObjectPropertyDomains", new Class[] {OWLObjectPropertyExpression.class, boolean.class}, new Object[] {owlObjectProperty, true});
		
	}

	@Test
	public void testGetObjectPropertyRanges() {
		OWLObjectProperty owlObjectProperty = df.getOWLObjectProperty(IRI.create(base + "#hasBase"));
		
		invoke("getObjectPropertyRanges", new Class[] {OWLObjectPropertyExpression.class, boolean.class}, new Object[] {owlObjectProperty, true});
	}

	@Test
	public void testGetObjectPropertyValues() {
		OWLNamedIndividual owlNamedIndividual = df.getOWLNamedIndividual(IRI.create(base + "#ExampleAmericanHot"));
		OWLObjectProperty owlObjectProperty = df.getOWLObjectProperty(IRI.create(base + "#hasBase"));
		
		invoke("getObjectPropertyValues", new Class[] {OWLNamedIndividual.class, OWLObjectPropertyExpression.class}, new Object[] {owlNamedIndividual, owlObjectProperty});
	}

//	@Test
//	public void testGetPrecomputableInferenceTypes() {
//		fail("Not yet implemented");
//	}

//	@Test
//	public void testGetReasonerName() {
//		fail("Not yet implemented");
//	}

//	@Test
//	public void testGetReasonerVersion() {
//		fail("Not yet implemented");
//	}

	@Test
	public void testGetSameIndividuals() {
		OWLNamedIndividual owlNamedIndividual = df.getOWLNamedIndividual(IRI.create(base + "#ExampleAmericanHot"));

		invoke("getSameIndividuals", new Class[] {OWLNamedIndividual.class}, new Object[] {owlNamedIndividual});
	}

	@Test
	public void testGetSubClasses() {
		OWLClass owlClass = df.getOWLClass(IRI.create(base + "#PizzaTopping"));
		
		invoke("getSubClasses", new Class[] {OWLClassExpression.class, boolean.class}, new Object[] {owlClass, true});
	}

	@Test
	public void testGetSubDataProperties() {
		OWLDataProperty owlDataProperty = df.getOWLDataProperty(IRI.create(defaultBase + "#topDataProperty"));
		
		invoke("getSubDataProperties", new Class[] {OWLDataProperty.class, boolean.class}, new Object[] {owlDataProperty, true});
	}

	@Test
	public void testGetSubObjectProperties() {	
		OWLObjectProperty owlObjectProperty = df.getOWLObjectProperty(IRI.create(defaultBase + "#hasIngredient"));
		
		invoke("getSubObjectProperties", new Class[] {OWLObjectPropertyExpression.class, boolean.class}, new Object[] {owlObjectProperty, true});
	}

	@Test
	public void testGetSuperClasses() {
		OWLClass owlClass = df.getOWLClass(IRI.create(base + "#PizzaTopping"));
		
		invoke("getSuperClasses", new Class[] {OWLClassExpression.class, boolean.class}, new Object[] {owlClass, true});
	}

	@Test
	public void testGetSuperDataProperties() {
		OWLDataProperty owlDataProperty = df.getOWLDataProperty(IRI.create(base + "#hasCalorificContentValue"));
		
		invoke("getSuperDataProperties", new Class[] {OWLDataProperty.class, boolean.class}, new Object[] {owlDataProperty, true});
	}

	@Test
	public void testGetSuperObjectProperties() {
		OWLObjectProperty owlObjectProperty = df.getOWLObjectProperty(IRI.create(base + "#hasIngredient"));
		
		invoke("getSuperObjectProperties", new Class[] {OWLObjectPropertyExpression.class, boolean.class}, new Object[] {owlObjectProperty, true});
	}

	@Test
	public void testGetTopClassNode() {
		invoke("getTopClassNode");
	}

	@Test
	public void testGetTopDataPropertyNode() {
		invoke("getTopDataPropertyNode");
	}

	@Test
	public void testGetTopObjectPropertyNode() {
		invoke("getTopObjectPropertyNode");
	}

	@Test
	public void testGetTypes() {
		OWLNamedIndividual owlNamedIndividual = df.getOWLNamedIndividual(IRI.create(base + "#ExampleAmericanHot"));

		invoke("getTypes", new Class[] {OWLNamedIndividual.class, boolean.class}, new Object[] {owlNamedIndividual, true});
	}

	@Test
	public void testGetUnsatisfiableClasses() {
		invoke("getUnsatisfiableClasses");
	}

//	@Test
//	public void testInterrupt() {
//		fail("Not yet implemented");
//	}

	@Test
	public void testIsConsistent() {
		invoke("isConsistent");
	}

	@Test
	public void testIsEntailedOWLAxiom() {
		Set<OWLAxiom> owlAxioms = ontology.getAxioms();
		OWLAxiom owlAxiom = owlAxioms.iterator().next();
		
		invoke("isEntailed", new Class[] {OWLAxiom.class}, new Object[] {owlAxiom});
	}

	@Test
	public void testIsEntailedSetOfQextendsOWLAxiom() {
		Set<OWLAxiom> owlAxioms = ontology.getAxioms();
		
		invoke("isEntailed", new Class[] {Set.class}, new Object[] {owlAxioms});
	}

	@Test
	public void testIsEntailmentCheckingSupported() {
		Set<OWLAxiom> owlAxioms = ontology.getAxioms();
		OWLAxiom owlAxiom = owlAxioms.iterator().next();
		
		AxiomType<?> axiomType = new AxiomTypeProvider().getAxiomType(owlAxiom);
		
		invoke("isEntailmentCheckingSupported", new Class[] {AxiomType.class}, new Object[] {axiomType});
	}

	@Test
	public void testIsPrecomputed() {
		InferenceType inferenceType = InferenceType.CLASS_ASSERTIONS;
		
		invoke("isPrecomputed", new Class[] {InferenceType.class}, new Object[] {inferenceType});
	}

	@Test
	public void testIsSatisfiable() {
		OWLClass owlClass = df.getOWLClass(IRI.create(base + "#PizzaTopping"));
		
		invoke("isSatisfiable", new Class[] {OWLClassExpression.class}, new Object[] {owlClass});
	}

//	@Test
//	public void testPrecomputeInferences() {
//		fail("Not yet implemented");
//	}

//	@Test
//	public void testAnswerRequestOfR() {
//		fail("Not yet implemented");
//	}

//	@Test
//	public void testAnswerRequestArray() {
//		fail("Not yet implemented");
//	}
	
}
