package de.fzi.herakles.job.impl;

import static org.junit.Assert.*;

import java.lang.reflect.Method;
import org.junit.Test;

import de.fzi.herakles.job.Job;

public class JobImplTest {
	
	class JobListenerMock implements JobListener {
		public void executeCalled( Job<?> job ) {}
	}
	
	class MethodeCallTestClass {
		public void restMethod() {};
		public void restMethod1() {};
		public void restMethod2() {};
	}
	
	private JobListenerMock jobListener = new JobListenerMock();
	private JobListenerMock jobListener1 = new JobListenerMock();
	private JobListenerMock jobListener2 = new JobListenerMock();
	
	private Method getMethod( String methodName, Class<?>[] paramTypes ) {
		Method method = null;
		try {
			Class<?> clazz = MethodeCallTestClass.class;

			method = clazz.getMethod(methodName, paramTypes);
		} catch (Exception e) {}
		return method;
	}

	@Test
	public void testString() {
		JobImpl<MethodeCallTestClass> jobImpl = new JobImpl<MethodeCallTestClass>(jobListener, getMethod("restMethod", null), null);
		
		System.out.println(jobImpl);
	}
	
	@Test
	public void testConstructor() {
		JobImpl<MethodeCallTestClass> jobImpl = new JobImpl<MethodeCallTestClass>(jobListener, getMethod("restMethod", null), null);
		
		assertNotNull(jobImpl);
	}
	
	@Test
	public void testEquals() {
		JobImpl<MethodeCallTestClass> jobImpl1 = new JobImpl<MethodeCallTestClass>(jobListener, getMethod("restMethod", null), null);
		JobImpl<MethodeCallTestClass> jobImpl2 = new JobImpl<MethodeCallTestClass>(jobListener, getMethod("restMethod", null), null);
		JobImpl<MethodeCallTestClass> jobImpl3 = new JobImpl<MethodeCallTestClass>(jobListener1, getMethod("restMethod1", null), null);
		JobImpl<MethodeCallTestClass> jobImpl4 = new JobImpl<MethodeCallTestClass>(jobListener2, getMethod("restMethod2", null), null);
		
		assertNotNull(jobImpl1);
		assertNotNull(jobImpl2);
		assertNotNull(jobImpl3);
		assertNotNull(jobImpl4);
		
		assertTrue(jobImpl1.equals(jobImpl1));
		assertTrue(jobImpl1.equals(jobImpl2));
		assertFalse(jobImpl1.equals(jobImpl3));
		assertFalse(jobImpl1.equals(jobImpl4));
		
		assertEquals(jobImpl1.hashCode(), jobImpl1.hashCode());
		assertEquals(jobImpl1.hashCode(), jobImpl2.hashCode());
		assertNotSame(jobImpl1.hashCode(), jobImpl3.hashCode());
		assertNotSame(jobImpl1.hashCode(), jobImpl4.hashCode());
	}

}
