package de.fzi.herakles.job.request.impl;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertNotSame;
import static org.junit.Assert.assertTrue;

import java.lang.reflect.Method;

import org.junit.Test;

public class RequestImplTest {
	
	class MethodeCallTestClass {
		public void testMethod() {};
		public void testMethod(String str) {};
		public void testMethod(String str, int integer) {};
	}
	
	private Method getMethod( String methodName, Class<?>[] paramTypes ) {
		Method method = null;
		try {
			Class<?> clazz = MethodeCallTestClass.class;

			method = clazz.getMethod(methodName, paramTypes);
		} catch (Exception e) {}
		return method;
	}
	
	@Test
	public void testString() {
		RequestImpl requestImpl1 = new RequestImpl(getMethod("testMethod", new Class[] {}), null);
		RequestImpl requestImpl2 = new RequestImpl(getMethod("testMethod", new Class[] {String.class}), new Object[] {"Hallo"});
		RequestImpl requestImpl3 = new RequestImpl(getMethod("testMethod", new Class[] {String.class, int.class}), new Object[] {"Hallo", 1337});
		
		System.out.println(requestImpl1);
		System.out.println(requestImpl2);
		System.out.println(requestImpl3);
	}
	
	@SuppressWarnings("deprecation")
	@Test
	public void testConstructor() {
		Method method1 = getMethod("testMethod", new Class[] {});
		Method method2 = getMethod("testMethod", new Class[] {String.class});
		Method method3 = getMethod("testMethod", new Class[] {String.class, int.class});
		Method method4 = getMethod("testMethod", new Class[] {int.class});
		
		Object[] params1 = null;
		Object[] params2 = new Object[] {"Hallo"};
		Object[] params3 = new Object[] {"Hallo", 1337};
		Object[] params4 = new Object[] {1337};
		
		RequestImpl requestImpl1 = new RequestImpl(method1, params1);
		RequestImpl requestImpl2 = new RequestImpl(method2, params2);
		RequestImpl requestImpl3 = new RequestImpl(method3, params3);
		RequestImpl requestImpl4 = new RequestImpl(method4, params4);
		
		assertNotNull(requestImpl1);
		assertNotNull(requestImpl2);
		assertNotNull(requestImpl3);
		assertNotNull(requestImpl4);
		
		assertEquals(requestImpl1.getMethod(), method1);
		assertEquals(requestImpl2.getMethod(), method2);
		assertEquals(requestImpl3.getMethod(), method3);
		assertEquals(requestImpl4.getMethod(), method4);
		
		assertEquals(requestImpl1.getParams(), params1);
		assertEquals(requestImpl2.getParams(), params2);
		assertEquals(requestImpl3.getParams(), params3);
		assertEquals(requestImpl4.getParams(), params4);
	}
	
	@Test
	public void testEquals() {
		Method method1 = getMethod("testMethod", new Class[] {});
		Method method2 = getMethod("testMethod", new Class[] {String.class});
		Method method3 = getMethod("testMethod", new Class[] {String.class, int.class});
		Method method4 = getMethod("testMethod", new Class[] {String.class, int.class});
		
		Object[] params1 = null;
		Object[] params2 = new Object[] {"Hallo"};
		Object[] params3 = new Object[] {"Hallo", 1337};
		Object[] params4 = new Object[] {"Hallo", 1337};
		
		RequestImpl requestImpl1 = new RequestImpl(method1, params1);
		RequestImpl requestImpl2 = new RequestImpl(method2, params2);
		RequestImpl requestImpl3 = new RequestImpl(method3, params3);
		RequestImpl requestImpl4 = new RequestImpl(method4, params4);
		
		assertNotNull(requestImpl1);
		assertNotNull(requestImpl2);
		assertNotNull(requestImpl3);
		assertNotNull(requestImpl4);
		
		assertTrue(requestImpl3.equals(requestImpl3));
		assertTrue(requestImpl3.equals(requestImpl4));
		assertFalse(requestImpl3.equals(requestImpl1));
		assertFalse(requestImpl3.equals(requestImpl2));
		
		assertEquals(requestImpl3.hashCode(), requestImpl3.hashCode());
		assertEquals(requestImpl3.hashCode(), requestImpl4.hashCode());
		assertNotSame(requestImpl3.hashCode(), requestImpl1.hashCode());
		assertNotSame(requestImpl3.hashCode(), requestImpl2.hashCode());
	}

}
