/**
 * 
 */
package de.fzi.herakles.registry.impl;

import static org.junit.Assert.*;

import org.junit.Before;
import org.junit.Test;
import org.semanticweb.owlapi.apibinding.OWLManager;
import org.semanticweb.owlapi.model.IRI;
import org.semanticweb.owlapi.model.OWLOntology;
import org.semanticweb.owlapi.model.OWLOntologyCreationException;
import org.semanticweb.owlapi.model.OWLOntologyManager;
import org.semanticweb.owlapi.reasoner.BufferingMode;

import de.fzi.herakles.mockups.ServerAdapterMock;
import de.fzi.herakles.registry.ReasonerAdapter;
import de.fzi.herakles.registry.ServerAdapter;
import de.fzi.herakles.registry.impl.ReasonerAdapterFactory;
import de.fzi.owllink.reasoner.server.entities.Capability;
import de.fzi.owllink.reasoner.server.entities.Owner;
import de.fzi.owllink.reasoner.server.entities.ReasonerType;
import de.fzi.owllink.reasoner.server.entities.Version;

/**
 * @author luckfish
 *
 */
public class ReasonerAdapterFactoryTest {
	
	private OWLOntologyManager owlOntologyManager;
	
	@Before
    public void setUp() {
		this.owlOntologyManager = OWLManager.createOWLOntologyManager();
    }

	@Test
	public void singeltonInstanceTest() throws OWLOntologyCreationException {
		
		OWLOntology ontology1 = this.owlOntologyManager.createOntology(IRI.create("TestOntology1"));
		OWLOntology ontology2 = this.owlOntologyManager.createOntology(IRI.create("TestOntology2"));
		
		assertNotNull(ontology1);
		assertNotNull(ontology2);
		
		BufferingMode bufferingMode1 = BufferingMode.BUFFERING;
		BufferingMode bufferingMode2 = BufferingMode.NON_BUFFERING;
		
		assertNotNull(bufferingMode1);
		assertNotNull(bufferingMode2);
		
		assertNotSame(ontology1, ontology2);
		assertNotSame(bufferingMode1, bufferingMode2);
		
		ReasonerAdapterFactory instance1 = ReasonerAdapterFactory.getInstance();
		
		assertNotNull(instance1);
		
		ReasonerAdapterFactory instance2 = ReasonerAdapterFactory.getInstance();
		
		assertNotNull(instance2);		
		
		assertSame(instance1, instance2);
	}
	
	@Test
	public void getReasonerAdapterSingeltonTest() throws OWLOntologyCreationException {
		
		OWLOntology ontology = this.owlOntologyManager.createOntology(IRI.create("TestCase"));
		BufferingMode bufferingMode = BufferingMode.BUFFERING;
		Owner owner = new Owner("ReasonerAdapterFactoryTest", "localhost");
		
		assertNotNull(ontology);
		assertNotNull(bufferingMode);
		
		ReasonerType reasonerType1 = new ReasonerType("Hermit", "Hermit", new Version(0, 0, 0, 0), new Capability());
		ReasonerType reasonerType2 = new ReasonerType("FaCTPP", "FaCTPP", new Version(0, 0, 0, 0), new Capability());
		
		assertNotNull(reasonerType1);
		assertNotNull(reasonerType2);
		
		assertNotSame(reasonerType1, reasonerType2);
		
		ServerAdapter serverAdapter1 = new ServerAdapterMock();
		ServerAdapter serverAdapter2 = new ServerAdapterMock();
		
		assertNotNull(serverAdapter1);
		assertNotNull(serverAdapter2);
		
		assertNotSame(serverAdapter1, serverAdapter2);
		
		ReasonerAdapter reasonerRegistry1 = ReasonerAdapterFactory.getInstance().getReasonerAdapter(serverAdapter1, 8099, owner, reasonerType1, ontology, bufferingMode);
		ReasonerAdapter reasonerRegistry2 = ReasonerAdapterFactory.getInstance().getReasonerAdapter(serverAdapter2, 8099, owner, reasonerType1, ontology, bufferingMode);
		ReasonerAdapter reasonerRegistry3 = ReasonerAdapterFactory.getInstance().getReasonerAdapter(serverAdapter1, 7090, owner, reasonerType1, ontology, bufferingMode);
		ReasonerAdapter reasonerRegistry4 = ReasonerAdapterFactory.getInstance().getReasonerAdapter(serverAdapter1, 8099, owner, reasonerType2, ontology, bufferingMode);
		
		assertNotNull(reasonerRegistry1);
		assertNotNull(reasonerRegistry2);
		assertNotNull(reasonerRegistry3);
		assertNotNull(reasonerRegistry4);
		
		assertNotSame(reasonerRegistry1, reasonerRegistry2);
		assertNotSame(reasonerRegistry1, reasonerRegistry3);
		assertNotSame(reasonerRegistry1, reasonerRegistry4);
		
		ReasonerAdapter reasonerRegistry1Same = ReasonerAdapterFactory.getInstance().getReasonerAdapter(serverAdapter1, 8099, owner, reasonerType1, ontology, bufferingMode);
		
		assertSame(reasonerRegistry1, reasonerRegistry1Same);
		
		ReasonerAdapter reasonerRegistry4Same = ReasonerAdapterFactory.getInstance().getReasonerAdapter(serverAdapter1, 8099, owner, reasonerType2, ontology, bufferingMode);
		
		assertSame(reasonerRegistry4, reasonerRegistry4Same);
	}

}
