package de.fzi.herakles.registry.impl;

import static org.junit.Assert.*;

import org.junit.Before;
import org.junit.Test;
import org.semanticweb.owlapi.apibinding.OWLManager;
import org.semanticweb.owlapi.model.IRI;
import org.semanticweb.owlapi.model.OWLOntology;
import org.semanticweb.owlapi.model.OWLOntologyCreationException;
import org.semanticweb.owlapi.model.OWLOntologyManager;
import org.semanticweb.owlapi.reasoner.BufferingMode;

import de.fzi.herakles.registry.ReasonerRegistry;
import de.fzi.herakles.registry.impl.ReasonerRegistryFactory;

/**
 * @author luckfish
 *
 */
public class ReasonerRegistryFactoryTest {
	
	private OWLOntologyManager owlOntologyManager;
	
	@Before
    public void setUp() {
		this.owlOntologyManager = OWLManager.createOWLOntologyManager();
    }

	@Test
	public void singeltonInstanceTest() {
		ReasonerRegistryFactory instance1 = ReasonerRegistryFactory.getInstance();
		
		assertNotNull(instance1);
		
		ReasonerRegistryFactory instance2 = ReasonerRegistryFactory.getInstance();
		
		assertNotNull(instance2);
		
		assertSame(instance1, instance2);
	}
	
	@Test
	public void getReasonerRegistrySingeltonTest() throws OWLOntologyCreationException {
		
		OWLOntology ontology1 = this.owlOntologyManager.createOntology(IRI.create("TestOntology1"));
		OWLOntology ontology2 = this.owlOntologyManager.createOntology(IRI.create("TestOntology2"));
		
		assertNotNull(ontology1);
		assertNotNull(ontology2);
		
		BufferingMode bufferingMode1 = BufferingMode.BUFFERING;
		BufferingMode bufferingMode2 = BufferingMode.NON_BUFFERING;
		
		assertNotNull(bufferingMode1);
		assertNotNull(bufferingMode2);
		
		assertNotSame(ontology1, ontology2);
		assertNotSame(bufferingMode1, bufferingMode2);
		
		ReasonerRegistry reasonerRegistry1 = ReasonerRegistryFactory.getInstance().getReasonerRegistry(ontology1, bufferingMode1);	
		ReasonerRegistry reasonerRegistry2 = ReasonerRegistryFactory.getInstance().getReasonerRegistry(ontology1, bufferingMode2);
		ReasonerRegistry reasonerRegistry3 = ReasonerRegistryFactory.getInstance().getReasonerRegistry(ontology2, bufferingMode2);
		ReasonerRegistry reasonerRegistry4 = ReasonerRegistryFactory.getInstance().getReasonerRegistry(ontology2, bufferingMode1);
		
		assertNotNull(reasonerRegistry1);
		assertNotNull(reasonerRegistry2);
		assertNotNull(reasonerRegistry3);
		assertNotNull(reasonerRegistry4);
		
		assertNotSame(reasonerRegistry1, reasonerRegistry2);
		assertNotSame(reasonerRegistry1, reasonerRegistry3);
		assertNotSame(reasonerRegistry1, reasonerRegistry4);
		
		ReasonerRegistry reasonerRegistry1Same = ReasonerRegistryFactory.getInstance().getReasonerRegistry(ontology1, bufferingMode1);
			
		assertNotNull(reasonerRegistry1Same);
		
		assertNotSame(reasonerRegistry1, reasonerRegistry1Same);
	}

}
