package de.fzi.owllink.reasoner.server.classloader;

import java.util.HashSet;
import java.util.Set;

import de.fzi.owllink.reasoner.server.entities.Capability;
import de.fzi.owllink.reasoner.server.entities.ReasonerType;
import de.fzi.owllink.reasoner.server.entities.Version;
import de.fzi.owllink.reasoner.server.manager.ConfigurationException;
import de.fzi.owllink.reasoner.server.reasoner.ExtendedOWLlinkServerFactory;

public class ReasonerTypeLoader {

	private Classloader classlaoder;
	
	private Set<ReasonerType> reasonerTypes;
	
	public ReasonerTypeLoader(Classloader classloader) {
		this.classlaoder = classloader;
	}
	
	public Set<ReasonerType> getReasonerTypes() {
		if(this.reasonerTypes == null) {
			this.reasonerTypes = loadReasonerTypes();
		}
		return this.reasonerTypes;
	}
	
	private Set<ReasonerType> loadReasonerTypes() {
		Set<ReasonerType> reasonerTypes = new HashSet<ReasonerType>();
		Set<String> reasonerIds = this.classlaoder.getAllReasonerIds();
		
		for(String reasonerId : reasonerIds) {
			try {
				ExtendedOWLlinkServerFactory owlLinkServerFactory = this.classlaoder.getInstance(reasonerId);
				String name = owlLinkServerFactory.getName();
				Version version = owlLinkServerFactory.getVersion();
				Capability capability = owlLinkServerFactory.getCapability();
				reasonerTypes.add(new ReasonerType(reasonerId, name, version, capability));
			} catch (ConfigurationException e) {
				e.printStackTrace();
			}
		}
		return reasonerTypes;
	}	
}
