/*
* Copyright (C) 2013, FZI Forschungszentrum Informatik
*
* Modifications to the initial code base are copyright of their
* respective authors, or their employers as appropriate. Authorship
* of the modifications may be determined from the ChangeLog placed at
* the end of this file.
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 3.0 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/
package de.fzi.owllink.reasoner.server.entities;

import java.net.InetAddress;
import java.net.UnknownHostException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * 
 * @author Marcel Weigel
 *
 */
public class Owner {
	
	private final static Log LOG = LogFactory.getLog(Owner.class);

	private final String name;
	private final String host;

	public Owner(String name) {
		this.name = name;

		String host = "0.0.0.0";
		try {
			host = InetAddress.getLocalHost().getHostAddress();
		} catch (UnknownHostException e) {
			LOG.error("Counld not find any host address.");
		}
		this.host = host;
	}
	
	public Owner(String name, String host) {
		this.name = name;
		this.host = host;
	}

	public String getName() {
		return name;
	}

	public String getHost() {
		return host;
	}
	
	@Override
	public boolean equals(Object obj) {
		if(obj == null)
			return false;
		if(obj == this)
			return true;
		if(!(obj instanceof Owner)) 
			return false;
		
		Owner rhs = (Owner) obj;
		return (this.name == rhs.name || this.name != null && this.name.equals(rhs.name)) &&
				(this.host == rhs.host || this.host != null && this.host.equals(rhs.host));
	}
	
	@Override
	public int hashCode() {
		int hash = 7;
		hash = 31 * hash + (this.name == null ? 0 : this.name.hashCode());
		hash = 31 * hash + (this.host == null ? 0 : this.host.hashCode());
		return hash;
	}
	
	@Override
	public String toString() {
		String[] classPath = Owner.class.getName().split("\\.");
		return String.format("%s(name=%s, host=%s)", classPath[classPath.length-1], this.name, this.host);
	}
	
	public boolean isValid() {
		return this.name != null && !this.name.isEmpty() &&
				this.host != null && !this.host.isEmpty();
	}
}
