
/*
* Copyright (C) 2013, FZI Forschungszentrum Informatik
*
* Modifications to the initial code base are copyright of their
* respective authors, or their employers as appropriate. Authorship
* of the modifications may be determined from the ChangeLog placed at
* the end of this file.
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 3.0 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/
package de.fzi.owllink.reasoner.server.entities;

/**
 * 
 * @author Marcel Weigel
 *
 */
public class ReasonerType {
	
	private final String id;
	private final String name;
	private final Version version;
	private final Capability capability;

	public ReasonerType(String id, String name, Version version, Capability capability) {
		this.id = id;
		this.name = name;
		this.version = version;
		this.capability = capability;
	}

	public String getId() {
		return id;
	}

	public String getName() {
		return name;
	}

	public Version getVersion() {
		return version;
	}

	public Capability getCapability() {
		return capability;
	}
	
	@Override
	public boolean equals(Object obj) {
		if(obj == null)
			return false;
		if(obj == this)
			return true;
		if(!(obj instanceof ReasonerType)) 
			return false;
		
		ReasonerType rhs = (ReasonerType) obj;
		return (this.id == rhs.id || this.id != null && this.id.equals(rhs.id)) &&
				(this.name == rhs.name || this.name != null && this.name.equals(rhs.name)) &&
				(this.version == rhs.version || this.version != null && this.version.equals(rhs.version)) &&
				(this.capability == rhs.capability || this.capability != null && this.capability.equals(rhs.capability));
	}

	@Override
	public int hashCode() {
		int hash = 7;
		hash = 31 * hash + (this.id == null ? 0 : this.id.hashCode());
		hash = 31 * hash + (this.name == null ? 0 : this.name.hashCode());
		hash = 31 * hash + (this.version == null ? 0 : this.version.hashCode());
		hash = 31 * hash + (this.capability == null ? 0 : this.capability.hashCode());
		return hash;
	}

	@Override
	public String toString() {
		String[] classPath = ReasonerType.class.getName().split("\\.");
		return String.format("%s(id=%s, name=%s, version=%s)", classPath[classPath.length-1], this.id, this.name, this.version);
	}

	public boolean isValid() {
		return this.id != null && !this.id.isEmpty() &&
				this.name != null && !this.name.isEmpty() &&
				this.version != null &&
				this.capability != null;
	}
	
}
