/*
* Copyright (C) 2013, FZI Forschungszentrum Informatik
*
* Modifications to the initial code base are copyright of their
* respective authors, or their employers as appropriate. Authorship
* of the modifications may be determined from the ChangeLog placed at
* the end of this file.
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 3.0 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/
package de.fzi.owllink.reasoner.server.httpxmlserver;

import java.net.BindException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.mortbay.http.HttpContext;
import org.mortbay.http.HttpHandler;
import org.mortbay.http.HttpServer;
import org.mortbay.http.SocketListener;
import org.mortbay.util.MultiException;
import org.semanticweb.owlapi.owllink.server.OWLlinkHTTPXMLServer;
import org.semanticweb.owlapi.owllink.server.OWLlinkReasonerConfiguration;
import org.semanticweb.owlapi.reasoner.OWLReasonerFactory;

/**
 * 
 * @author Marcel Weigel
 *
 */
public class StopableOWLlinkHTTPXMLServer extends OWLlinkHTTPXMLServer {
	private static final long serialVersionUID = 281957914801651099L;
	
	private final static Log LOG = LogFactory.getLog(StopableOWLlinkHTTPXMLServer.class);
	
	private HttpServer httpServer;
	private SocketListener listener;
	
	private int port;
	
	private boolean isStarted;

	public StopableOWLlinkHTTPXMLServer(OWLReasonerFactory reasonerFactory,
			OWLlinkReasonerConfiguration configuration, int port) {
		super(reasonerFactory, configuration, port);
		this.isStarted = false;
		this.port = port;
	}
	
	@Override
	public void run() {
		if(isStarted())
			return;
        try {
        	this.httpServer = new HttpServer();

            this.listener = new SocketListener();

            this.listener.setHost("localhost");
            this.listener.setPort(this.port);
            this.listener.setMinThreads(2);
            this.listener.setMaxThreads(10);
            this.httpServer.addListener(this.listener); 
            
            if(this.getHttpContext() == null) {
            	HttpContext httpContect = this.httpServer.addContext("/");
            	httpContect.addHandler(this);
            } else {
            	this.httpServer.addContext(this.getHttpContext());
            }

            this.httpServer.start();
            
            this.isStarted = true;
        }
        catch (Exception e) {
            if (e instanceof MultiException && ((MultiException) e).getException(0) instanceof BindException) {
            	LOG.error("Cannot start server. Port " + port + " is already in use!");
            } else {
                e.printStackTrace();
            }
            this.isStarted = false;
        }
	}
	
	@Override
	public void stop() throws InterruptedException {
		super.stop();

		shutDown();
	}

	public void shutDown() {
		if(this.httpServer != null) {
			if(this.httpServer.isStarted()) {
				try {
					this.httpServer.stop();
					
					if(this.httpServer == null) {
						return;
					}

					this.httpServer.removeContext(this.getHttpContext());
					this.httpServer.removeListener(this.listener);

					try {
						this.httpServer.destroy();
					} catch(java.lang.IllegalStateException e) {
//						LOG.error("Try to destry server throws exception IllegalStateException: " + e.getMessage());
					}
					
					this.httpServer = null;
					
					this.isStarted = false;
				} catch (InterruptedException e) {
					System.err.println("Cannot stop server!");
					this.isStarted = true;
				}		
			}
		}
	}

	@Override
	public boolean isStarted() {
		return this.isStarted;
	}
}
