/*
* Copyright (C) 2013, FZI Forschungszentrum Informatik
*
* Modifications to the initial code base are copyright of their
* respective authors, or their employers as appropriate. Authorship
* of the modifications may be determined from the ChangeLog placed at
* the end of this file.
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 3.0 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/
package de.fzi.owllink.reasoner.server.manager;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.util.HashSet;
import java.util.Properties;
import java.util.Set;

/**
 * 
 * @author Marcel Weigel
 *
 */
public class OwlLinkServerManagerFactory {
	
	private static OwlLinkServerManagerFactory owlLinkServerManagerFactory;
	
	private static Set<OwlLinkServerManagerImpl> owlLinkServerManagers;
	
	private OwlLinkServerManagerFactory() {
		owlLinkServerManagers = new HashSet<OwlLinkServerManagerImpl>();
	}
	
	public static OwlLinkServerManagerFactory getInstance() {
		if(owlLinkServerManagerFactory == null) {
			owlLinkServerManagerFactory = new OwlLinkServerManagerFactory();
		}
		return owlLinkServerManagerFactory;
	}
	
	public OwlLinkServerManager getOwlLinkServerManagerInstance(String hostAddress) {
		OwlLinkServerManagerImpl owlLinkServerManager = null;
		Properties properties = getProperties();
		for(OwlLinkServerManagerImpl tempOwlLinkServerManager : owlLinkServerManagers) {
			if(tempOwlLinkServerManager.getProperties() == properties) {
				owlLinkServerManager = tempOwlLinkServerManager;
			}
		}
		if(owlLinkServerManager == null) {
			owlLinkServerManager = new OwlLinkServerManagerImpl(hostAddress, properties);
			owlLinkServerManagers.add(owlLinkServerManager);
		}
		return owlLinkServerManager;
	}
	
	public OwlLinkServerManager getOwlLinkServerManagerInstance(String hostAddress, Properties properties) {
		OwlLinkServerManagerImpl owlLinkServerManager = null;
		for(OwlLinkServerManagerImpl tempOwlLinkServerManager : owlLinkServerManagers) {
			if(tempOwlLinkServerManager.getProperties() == properties) {
				owlLinkServerManager = tempOwlLinkServerManager;
			}
		}
		if(owlLinkServerManager == null) {
			owlLinkServerManager = new OwlLinkServerManagerImpl(hostAddress, properties);
			owlLinkServerManagers.add(owlLinkServerManager);
		}
		return owlLinkServerManager;
	}
	
	private static Properties getProperties() {
		Properties properties = new Properties();
		try {
			InputStream inputStream = OwlLinkServerManagerFactory.class.getResourceAsStream("reasonerFactory.properties");
			
			properties.load(inputStream);
			
			inputStream.close();
		} catch (FileNotFoundException e1) {
			e1.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
		return properties;
	}
}
