/*
* Copyright (C) 2013, FZI Forschungszentrum Informatik
*
* Modifications to the initial code base are copyright of their
* respective authors, or their employers as appropriate. Authorship
* of the modifications may be determined from the ChangeLog placed at
* the end of this file.
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 3.0 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/
package de.fzi.owllink.reasoner.server.owllinkserver;

import org.semanticweb.owlapi.owllink.server.OWLlinkHTTPXMLServer;
import org.semanticweb.owlapi.owllink.server.OWLlinkServer;

import de.fzi.owllink.reasoner.server.entities.Owner;
import de.fzi.owllink.reasoner.server.entities.ReasonerType;
import de.fzi.owllink.reasoner.server.entities.ServerState;
import de.fzi.owllink.reasoner.server.httpxmlserver.StopableOWLlinkHTTPXMLServer;

/**
 * 
 * @author Marcel Weigel
 *
 */
public class OwlLinkServerAdapterImpl implements OwlLinkServerAdapter {
	private final OwlLinkServerMetadata owlLinkServerMetadata;
	
	private final StopableOWLlinkHTTPXMLServer owlLinkHttpXmlServer;
	
	public OwlLinkServerAdapterImpl(String host, int port, ReasonerType reaonserType, Owner owner, StopableOWLlinkHTTPXMLServer owlLinkHttpXmlServer) {
		this.owlLinkServerMetadata = new OwlLinkServerMetadata(host, port, reaonserType, owner);
		this.owlLinkHttpXmlServer = owlLinkHttpXmlServer;
		
		changeState(ServerState.Stopped);
	}
	
	public OwlLinkServerAdapterImpl(String host, int port, ReasonerType reaonserType, Owner owner, OWLlinkServer owlLinkServer) {
		this.owlLinkServerMetadata = new OwlLinkServerMetadata(host, port, reaonserType, owner);
		StopableOWLlinkHTTPXMLServer owlLinkHttpXmlServer = null;
		if(owlLinkServer instanceof StopableOWLlinkHTTPXMLServer) {
			owlLinkHttpXmlServer = (StopableOWLlinkHTTPXMLServer) owlLinkServer;
		}
		this.owlLinkHttpXmlServer = owlLinkHttpXmlServer;
		
		changeState(ServerState.Stopped);
	}

	public OwlLinkServerMetadata getOwlLinkServerMetadata() {
		return owlLinkServerMetadata;
	}

	public OWLlinkHTTPXMLServer getOwLlinkHTTPXMLServer() {
		return owlLinkHttpXmlServer;
	}

	public void start() {
		if(!checkState(ServerState.Stopped)) {
			return;
		}
		changeState(ServerState.Starting);
		
		try {
			Thread.sleep(500);
		} catch (InterruptedException e1) {}

		try {
			this.owlLinkHttpXmlServer.run();
			if(this.owlLinkHttpXmlServer.isStarted()) {
				changeState(ServerState.Started);
			} else {
				changeState(ServerState.Stopped);
			}
		} catch (Exception e) {
			changeState(ServerState.Stopped);
		}
	}

	public void stop() {
		ServerState lastServerState = owlLinkServerMetadata.getServerState();
		if(!checkState(ServerState.Started)) {
			return;
		}
//		try {
//			this.owlLinkHttpXmlServer.stop();
//		} catch (InterruptedException e2) {
//			e2.printStackTrace();
//		}
		
		changeState(ServerState.Stopping);

		try {
			Thread.sleep(500);
		} catch (InterruptedException e1) {}
		
		try {
			this.owlLinkHttpXmlServer.shutDown();
			
			changeState(ServerState.Stopped);
		} catch (Exception e) {
			changeState(lastServerState);
		}	
	}
	
	private void changeState(ServerState serverState) {
		this.owlLinkServerMetadata.setServerState(serverState);
	}
	
	private boolean checkState(ServerState serverState) {
		return owlLinkServerMetadata.getServerState() == serverState;
	}

	@Override
	public boolean equals(Object obj) {
		if(obj == null)
			return false;
		
		if(super.equals(obj)) 
			return true;
		
		if(obj instanceof OwlLinkServerAdapterImpl) {
			OwlLinkServerAdapterImpl owlLinkServer = (OwlLinkServerAdapterImpl) obj;
			return owlLinkServer.getOwlLinkServerMetadata().equals(this.owlLinkServerMetadata);
		}
		return false;
	}
	
	@Override
	public int hashCode() {
		int hash = 7;
		hash = 31 * hash + (this.owlLinkServerMetadata == null ? 0 : this.owlLinkServerMetadata.hashCode());
		return hash;
	}

	public boolean isStarted() {
		return this.owlLinkServerMetadata.getServerState() == ServerState.Started;
	}

	public boolean isStopped() {
		return this.owlLinkServerMetadata.getServerState() == ServerState.Stopped;
	}
}
