/*
* Copyright (C) 2013, FZI Forschungszentrum Informatik
*
* Modifications to the initial code base are copyright of their
* respective authors, or their employers as appropriate. Authorship
* of the modifications may be determined from the ChangeLog placed at
* the end of this file.
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 3.0 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/
package de.fzi.owllink.reasoner.server.owllinkserver;

import java.util.Date;

import de.fzi.owllink.reasoner.server.entities.Owner;
import de.fzi.owllink.reasoner.server.entities.ReasonerType;
import de.fzi.owllink.reasoner.server.entities.ServerState;


/**
 * 
 * @author Marcel Weigel
 *
 */
public class OwlLinkServerMetadata {

	private final String id;
	private final String host;
	private final int port;
	private final ReasonerType reasonerType;
	private final Owner owner;
	private ServerState serverState;
	private Date initDate;
	private Date startDate;
	
	public OwlLinkServerMetadata(String host, int port, ReasonerType reasonerType, Owner owner) {
		this.id = createId(host, port);
		this.host = host;
		this.port = port;
		this.reasonerType = reasonerType;
		this.owner = owner;
		this.serverState = ServerState.NotInitialized;
		this.initDate = new Date();
		this.startDate = null;
	}
	
	public OwlLinkServerMetadata(String host, int port, ReasonerType reasonerType, Owner owner, Date initDate, Date startDate, ServerState serverState) {
		this.id = createId(host, port);
		this.host = host;
		this.port = port;
		this.reasonerType = reasonerType;
		this.owner = owner;
		this.serverState = serverState;
		this.initDate = initDate;
		this.startDate = startDate;
	}
	
	private String createId(String host, int port) {
		return String.format("%s:%04d", host, port);
	}
	
	public String getId() {
		return id;
	}
	
	public String getHost() {
		return host;
	}

	public int getPort() {
		return port;
	}

	public ServerState getServerState() {
		return serverState;
	}
	
	public Date getInitDate() {
		return initDate;
	}
	
	public Date getStartDate() {
		return startDate;
	}
	
	public ReasonerType getReasonerType() {
		return reasonerType;
	}

	public Owner getOwner() {
		return owner;
	}

	void setServerState(ServerState serverState) {
		if(serverState == ServerState.Started) {
			this.startDate = new Date();
		} else if(serverState == ServerState.Stopped) {
			this.startDate = null;
		}
		this.serverState = serverState;
	}

	public boolean isStarted() {
		return serverState == ServerState.Started;
	}
	
	@Override
	public boolean equals(Object obj) {
		if(obj == null)
			return false;
		
		if(super.equals(obj)) 
			return true;
		
		OwlLinkServerMetadata olsm = (OwlLinkServerMetadata) obj;
		return this.host.equals(olsm.host) &&
				this.port == olsm.port &&
				this.reasonerType.equals(olsm.reasonerType) &&
				this.owner.equals(olsm.owner);
	}
	
	@Override
	public int hashCode() {
		int hash = 7;
		hash = 31 * hash + (this.host == null ? 0 : this.host.hashCode());
		hash = 31 * hash + this.port;
		hash = 31 * hash + (this.reasonerType == null ? 0 : this.reasonerType.hashCode());
		hash = 31 * hash + (this.owner == null ? 0 : this.owner.hashCode());
		return hash;
	}
	
	@Override
	public String toString() {
		return String.format("%s[host=%s, port=%04d, reasonerType=%s, owner=%s]", OwlLinkServerMetadata.class.getName(), this.id, this.port, this.reasonerType.getName(), this.owner.getName());
	}
	
}
