/*
* Copyright (C) 2013, FZI Forschungszentrum Informatik
*
* Modifications to the initial code base are copyright of their
* respective authors, or their employers as appropriate. Authorship
* of the modifications may be determined from the ChangeLog placed at
* the end of this file.
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 3.0 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/
package de.fzi.owllink.reasoner.server.properties;

import java.util.HashMap;
import java.util.Map.Entry;
import java.util.Properties;
import java.util.Set;

import de.fzi.owllink.reasoner.server.manager.ConfigurationException;

/**
 * 
 * @author Marcel Weigel
 *
 */
public class PropertyReader {
    
    private Properties properties;
    
    private HashMap<String, String> propertyMap;

    public PropertyReader(Properties properties) throws ConfigurationException {
    	if(properties == null) {
    		throw new ConfigurationException("The properties parameter ist null.");
    	}
        if(properties.entrySet().isEmpty()) {
        	throw new ConfigurationException("The entry set from the properties parameter ist empty.");
        }
        this.properties = properties;
        
        this.propertyMap = new HashMap<String, String>();
        
    	loadPropertyMap(properties);
    }
    
    private void loadPropertyMap(Properties properties) {
        Set<Entry<Object, Object>> propertySet = this.properties.entrySet();
        
        for (Entry<Object, Object> entry : propertySet) {
			this.propertyMap.put((String) entry.getKey(), (String) entry.getValue());
		}
        

    }

    public String getProperty(String propertyName) {
    	if(!this.propertyMap.containsKey(propertyName)) {
    		throw new PropertyNotFoundException(String.format("Cannot find property: %s.", propertyName));
    	}
    	return this.propertyMap.get(propertyName);
    }

	public Set<String> getProperties() {
		return this.propertyMap.keySet();
	}
}
