package de.fzi.owllink.reasoner.server.reasoner;

import java.lang.reflect.Field;

import org.semanticweb.owlapi.owllink.server.AbstractOWLlinkReasonerConfiguration;
import org.semanticweb.owlapi.owllink.server.serverfactory.OWLlinkServerSetupException;
import org.semanticweb.owlapi.reasoner.IndividualNodeSetPolicy;
import org.semanticweb.owlapi.reasoner.OWLReasonerConfiguration;
import org.semanticweb.owlapi.reasoner.OWLReasonerFactory;
import org.semanticweb.owlapi.vocab.OWL2Datatype;

import de.fzi.owllink.reasoner.server.entities.Capability;
import de.fzi.owllink.reasoner.server.entities.Version;
import de.fzi.owllink.reasoner.server.httpxmlserver.StopableOWLlinkHTTPXMLServer;

public class StopableHermiTServerFactory extends ServerFactoryAbst {
	public static final String FACTORY_CLASSNAME = "org.semanticweb.HermiT.Reasoner$ReasonerFactory";
    public static final String HERMIT_REASONERFACTORY = "org.semanticweb.HermiT.Configuration";

    public StopableHermiTServerFactory() {
		super("Hermit", new Version(1, 3, 8, 1099), new Capability());
	}

    public StopableOWLlinkHTTPXMLServer createServer(int port) {
       OWLReasonerConfiguration configuration = null;
        try {
            Class<?> reasonerFactoryClass = Class.forName(HERMIT_REASONERFACTORY);
            configuration = (OWLReasonerConfiguration) reasonerFactoryClass.newInstance();
            Field field = reasonerFactoryClass.getDeclaredField("individualNodeSetPolicy");
            field.set(configuration, IndividualNodeSetPolicy.BY_SAME_AS);

        } catch (Exception e) {
            System.err.println("Can't set individualNodeSetPolicy to SAME_AS");
        }

        AbstractOWLlinkReasonerConfiguration config = new AbstractOWLlinkReasonerConfiguration(configuration);
        config.setSupportedDatatypes(OWL2Datatype.XSD_LONG.getIRI(),
                OWL2Datatype.XSD_INT.getIRI(),
                OWL2Datatype.XSD_NON_POSITIVE_INTEGER.getIRI(),
                OWL2Datatype.XSD_NON_NEGATIVE_INTEGER.getIRI(),
                OWL2Datatype.XSD_SHORT.getIRI(),
                OWL2Datatype.OWL_REAL.getIRI());
        try {
            Class<?> factoryClass = Class.forName(FACTORY_CLASSNAME);
            OWLReasonerFactory factory = (OWLReasonerFactory) factoryClass.newInstance();
            StopableOWLlinkHTTPXMLServer server = new StopableOWLlinkHTTPXMLServer(factory, config, port);
            return server;
        } catch (ClassNotFoundException e) {
            throw new OWLlinkServerSetupException(e);
        } catch (InstantiationException e) {
            throw new OWLlinkServerSetupException(e);
        } catch (IllegalAccessException e) {
            throw new OWLlinkServerSetupException(e);
        }
    }
}
