package de.fzi.owllink.reasoner.server.reasoner;

import org.semanticweb.owlapi.model.OWLRuntimeException;
import org.semanticweb.owlapi.owllink.server.AbstractOWLlinkReasonerConfiguration;
import org.semanticweb.owlapi.reasoner.IndividualNodeSetPolicy;
import org.semanticweb.owlapi.reasoner.OWLReasonerFactory;
import org.semanticweb.owlapi.reasoner.SimpleConfiguration;
import org.semanticweb.owlapi.vocab.OWL2Datatype;

import de.fzi.owllink.reasoner.server.entities.Capability;
import de.fzi.owllink.reasoner.server.entities.Version;
import de.fzi.owllink.reasoner.server.httpxmlserver.StopableOWLlinkHTTPXMLServer;

public class StopablePelletServerFactory extends ServerFactoryAbst {

    public StopablePelletServerFactory() {
		super("Pellet", new Version(0, 0, 0, 0), new Capability());
	}

	public StopableOWLlinkHTTPXMLServer createServer(int port) throws OWLRuntimeException {
        SimpleConfiguration configuration = new SimpleConfiguration() {
            @Override
            public IndividualNodeSetPolicy getIndividualNodeSetPolicy() {
                return IndividualNodeSetPolicy.BY_SAME_AS;
            }
        };
        AbstractOWLlinkReasonerConfiguration config = new AbstractOWLlinkReasonerConfiguration(configuration);
        config.setSupportedDatatypes(OWL2Datatype.XSD_LONG.getIRI(),
                OWL2Datatype.XSD_INT.getIRI(),
                OWL2Datatype.XSD_NON_POSITIVE_INTEGER.getIRI(),
                OWL2Datatype.XSD_NON_NEGATIVE_INTEGER.getIRI(),
                OWL2Datatype.XSD_SHORT.getIRI(),
                OWL2Datatype.OWL_REAL.getIRI());
        try {
            Class<?> c = Class.forName("com.clarkparsia.pellet.owlapiv3.PelletReasonerFactory");
            OWLReasonerFactory factory = (OWLReasonerFactory) c.newInstance();
            StopableOWLlinkHTTPXMLServer server = new StopableOWLlinkHTTPXMLServer(factory, config, port);
            return server;
        } catch (Exception e) {
            throw new OWLRuntimeException(e);
        }
    }
}
