package de.fzi.owllink.reasoner.server.owllink;

import static org.junit.Assert.*;

import java.io.File;
import java.net.MalformedURLException;
import java.net.URISyntaxException;
import java.net.URL;

import org.junit.After;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import org.semanticweb.owlapi.apibinding.OWLManager;
import org.semanticweb.owlapi.model.OWLClass;
import org.semanticweb.owlapi.model.OWLDataFactory;
import org.semanticweb.owlapi.model.OWLOntology;
import org.semanticweb.owlapi.model.OWLOntologyCreationException;
import org.semanticweb.owlapi.model.OWLOntologyManager;
import org.semanticweb.owlapi.owllink.OWLlinkHTTPXMLReasonerFactory;
import org.semanticweb.owlapi.owllink.OWLlinkReasoner;
import org.semanticweb.owlapi.owllink.OWLlinkReasonerConfiguration;
import org.semanticweb.owlapi.owllink.server.OWLlinkHTTPXMLServer;
import org.semanticweb.owlapi.owllink.server.OWLlinkServer;
import org.semanticweb.owlapi.owllink.server.serverfactory.OWLlinkServerFactory;
import org.semanticweb.owlapi.reasoner.Node;
import org.semanticweb.owlapi.reasoner.OWLReasoner;
import org.semanticweb.owlapi.reasoner.OWLReasonerFactory;
import org.semanticweb.owlapi.reasoner.structural.StructuralReasonerFactory;
import org.semanticweb.owlapi.util.Version;
import org.semanticweb.HermiT.Reasoner;

import uk.ac.manchester.cs.factplusplus.owlapiv3.FaCTPlusPlusReasonerFactory;
import uk.ac.manchester.cs.owl.owlapi.OWLDataFactoryImpl;

import de.fzi.owllink.reasoner.server.httpxmlserver.StopableOWLlinkHTTPXMLServer;
import de.fzi.owllink.reasoner.server.reasoner.StopableFaCTServerFactory;
import de.fzi.owllink.reasoner.server.reasoner.StopableHermiTServerFactory;
import de.fzi.owllink.reasoner.server.reasoner.StopablePelletServerFactory;
import de.fzi.owllink.reasoner.server.reasoner.StopableStructuralServerFactory;
import de.fzi.owllink.reasoner.server.reasoner.ReasonerTest;

public class OwlLinkTest {
	
	private OWLDataFactory df = new OWLDataFactoryImpl();
	
	private final String base = "http://www.pizza.com/ontologies/pizza.owl";
	
	private static OWLOntologyManager owlOntologyManager;

	@BeforeClass
	public static void setUpBeforeClass() throws Exception {
	}

	@Before
	public void setUp() throws Exception {
	}

	@After
	public void tearDown() throws Exception {
	}
	
	private static OWLOntology getEmptyOntology() {
		OWLOntologyManager owlOntologyManager = OWLManager.createOWLOntologyManager();
		OWLOntology owlOntology = null;
		try {
			owlOntology = owlOntologyManager.createOntology();
		} catch (OWLOntologyCreationException e) {
			e.printStackTrace();
		}
		return owlOntology;
	}
	
	private static OWLOntology getPizzaOntology() {
		owlOntologyManager = OWLManager.createOWLOntologyManager();
		OWLOntology owlOntology = null;
		try {
			URL url = ReasonerTest.class.getClassLoader().getResource("de/fzi/owllink/reasoner/server/reasoner/pizza.owl");
			File file = new File(url.toURI());
			owlOntology = owlOntologyManager.loadOntologyFromOntologyDocument(file);
		} catch (OWLOntologyCreationException e) {
			e.printStackTrace();
		} catch (URISyntaxException e) {
			e.printStackTrace();
		}
		return owlOntology;
	}
	
	@Test
	public void reasonerStructuralTest() throws MalformedURLException, InterruptedException {
		OWLReasonerFactory reasonerFactory = new StructuralReasonerFactory();
		OWLlinkServerFactory owlLinkServerFactory = new StopableStructuralServerFactory();
		
		testReasonerVsLinkReasoner(reasonerFactory, owlLinkServerFactory);
	}
	
	@Test
	public void reasonerHermitTest() throws MalformedURLException, InterruptedException {
		OWLReasonerFactory reasonerFactory = new org.semanticweb.HermiT.Reasoner.ReasonerFactory();
		OWLlinkServerFactory owlLinkServerFactory = new StopableHermiTServerFactory();
		
		testReasonerVsLinkReasoner(reasonerFactory, owlLinkServerFactory);
	}
	
	@Test
	public void reasonerFaCTTest() throws MalformedURLException, InterruptedException {
//		OWLReasonerFactory reasonerFactory = new FaCTPlusPlusReasonerFactory();
//		OWLlinkServerFactory owlLinkServerFactory = new StopableFaCTServerFactory();
//		
//		testReasonerVsLinkReasoner(reasonerFactory, owlLinkServerFactory);
	}
	
	@Test
	public void reasonePalletTest() throws MalformedURLException, InterruptedException {
//		OWLReasonerFactory reasonerFactory = new com.clarkparsia.pellet.owlapiv3.PelletReasonerFactory();
//		OWLlinkServerFactory owlLinkServerFactory = new StopablePelletServerFactory();
//		
//		testReasonerVsLinkReasoner(reasonerFactory, owlLinkServerFactory);
	}
	
	private void testReasonerVsLinkReasoner(OWLReasonerFactory reasonerFactory, OWLlinkServerFactory owlLinkServerFactory) throws InterruptedException, MalformedURLException {
		OWLOntology ontology = getPizzaOntology();
		
		OWLReasoner reasoner = reasonerFactory.createNonBufferingReasoner(ontology);
		
		System.out.printf("ReasonerName[%s]\n", reasoner.getReasonerName());
		Version version = reasoner.getReasonerVersion();
		System.out.printf("ReasonerVersion[major=%d, minor=%d, patch=%d, build=%d]\n", version.getMajor(), version.getMinor(), version.getPatch(), version.getBuild());
		
		Node<OWLClass> node = reasoner.getBottomClassNode();
		
		assertNotNull(node);
		
		final String address = "localhost";
		final int port = 4242;
		
		OWLlinkServer owlLinkHttpXmlServer = owlLinkServerFactory.createServer(port);
		
		owlLinkHttpXmlServer.run();
		
		Thread.sleep(100);
		
		URL reasonerUrl = new URL(String.format("http://%s:%04d", address, port));

		OWLlinkReasonerConfiguration owlLinkreasonerConfiguration = new OWLlinkReasonerConfiguration(reasonerUrl);
		
		OWLlinkHTTPXMLReasonerFactory owlReasonerFactory = new OWLlinkHTTPXMLReasonerFactory();

		OWLlinkReasoner owlLinkReasonerBuffered = owlReasonerFactory.createNonBufferingReasoner(ontology, owlLinkreasonerConfiguration);
		
		Node<OWLClass> nodeLinkBuffered = owlLinkReasonerBuffered.getBottomClassNode();
		
		assertEquals(node, nodeLinkBuffered);
		
		OWLlinkReasoner owlLinkReasoner = owlReasonerFactory.createReasoner(ontology, owlLinkreasonerConfiguration);
		
		Node<OWLClass> nodeLink = owlLinkReasoner.getBottomClassNode();
		
		assertEquals(node, nodeLink);
		
		owlLinkHttpXmlServer.stop();
	}

}
