package de.fzi.owllink.reasoner.server.properties;

import static org.junit.Assert.*;

import java.io.ByteArrayInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;
import java.util.Set;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import de.fzi.owllink.reasoner.server.manager.ConfigurationException;
import de.fzi.owllink.reasoner.server.properties.PropertyNotFoundException;
import de.fzi.owllink.reasoner.server.properties.PropertyReader;

public class PropertyReaderTest {
	
	PropertyReader propertyReader;
	
	String[][] propertiesStringArray = new String[][] { {"Structural", "de.fzi.rest.owllink.server.manager.reasoner.StructuralFactory"},
														{ "Hermit", "de.fzi.rest.owllink.server.manager.reasoner.HermitFactory" },
														{ "FaCPlusPlus", "de.fzi.rest.owllink.server.manager.reasoner.FaCPlusPlusFactory" },
														{ "Blub", "de.fzi.rest.owllink.server.manager.util.ServerState" }};

    @Before
    public void setUp() throws ConfigurationException {
    	System.out.println(">>>>> JUnit Test Started >>>>>");
    	this.propertyReader = new PropertyReader(getProperties());
    }
    
	private Properties getProperties() {
		Properties properties = new Properties();
		try {
			String propertiesString = getPropertiesString();
			
			InputStream inputStream = new ByteArrayInputStream(propertiesString.getBytes("UTF-8"));
	      
			properties.load(inputStream);
			
			inputStream.close();
		} catch (FileNotFoundException e1) {
			e1.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
		return properties;
	}
	
	private String getPropertiesString() {
		StringBuilder sb = new StringBuilder();
		for(int i=0; i < propertiesStringArray.length; i++) {
			sb.append(propertiesStringArray[i][0]).append("=").append(propertiesStringArray[i][1]).append("\n");
		}
		return sb.toString();
	}

    @After
    public void tearDown() {
		System.out.println("<<<<< JUnit Test Ended <<<<<");
    }

	@Test
	public void testPropertyReader() {
		assertNotNull(this.propertyReader);
	}
	
	@Test
	public void testPropertyReaderFileNotFoundException() {
		try {
			new PropertyReader(null);
		} catch (ConfigurationException e) {
			System.err.println("Fehler: " + e);
		}
	}

	@Test
	public void testGetProperty() {
		for(int i=0; i < propertiesStringArray.length; i++) {
			String className = this.propertyReader.getProperty(propertiesStringArray[i][0]);
			
			assertEquals(className, propertiesStringArray[i][1]);
		}
	}
	
	@Test(expected=PropertyNotFoundException.class)
	public void testGetPropertyPropertyNotFoundException() {
		this.propertyReader.getProperty("PropertyNotExist");
	}

	@Test
	public void testGetProperties() {
		Set<String> classNames = this.propertyReader.getProperties();
		
		assertEquals(classNames.size(), 4);
	}

}
