package de.fzi.owllink.reasoner.server.reasoner;

import static org.junit.Assert.*;

import java.io.File;
import java.net.URISyntaxException;
import java.net.URL;

import org.junit.After;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import org.semanticweb.owlapi.apibinding.OWLManager;
import org.semanticweb.owlapi.model.IRI;
import org.semanticweb.owlapi.model.OWLClass;
import org.semanticweb.owlapi.model.OWLDataFactory;
import org.semanticweb.owlapi.model.OWLOntology;
import org.semanticweb.owlapi.model.OWLOntologyCreationException;
import org.semanticweb.owlapi.model.OWLOntologyManager;
import org.semanticweb.owlapi.reasoner.Node;
import org.semanticweb.owlapi.reasoner.NodeSet;
import org.semanticweb.owlapi.reasoner.OWLReasoner;
import org.semanticweb.owlapi.reasoner.OWLReasonerFactory;
import org.semanticweb.owlapi.reasoner.structural.StructuralReasonerFactory;

import uk.ac.manchester.cs.factplusplus.owlapiv3.FaCTPlusPlusReasonerFactory;
import uk.ac.manchester.cs.owl.owlapi.OWLDataFactoryImpl;

public class ReasonerTest {
	
	private OWLDataFactory df = new OWLDataFactoryImpl();
	
	private final String base = "http://www.pizza.com/ontologies/pizza.owl";
	
	private static OWLOntologyManager owlOntologyManager;

	@BeforeClass
	public static void setUpBeforeClass() throws Exception {
	}

	@Before
	public void setUp() throws Exception {
	}

	@After
	public void tearDown() throws Exception {
	}
	
	private static OWLOntology getPizzaOntology() {
		owlOntologyManager = OWLManager.createOWLOntologyManager();
		OWLOntology owlOntology = null;
		try {
			URL url = ReasonerTest.class.getClassLoader().getResource("de/fzi/owllink/reasoner/server/reasoner/pizza.owl");
			File file = new File(url.toURI());
			owlOntology = owlOntologyManager.loadOntologyFromOntologyDocument(file);
		} catch (OWLOntologyCreationException e) {
			e.printStackTrace();
		} catch (URISyntaxException e) {
			e.printStackTrace();
		}
		return owlOntology;
	}

	@Test
	public void testStructural() {
		OWLReasonerFactory reasonerFactory = new StructuralReasonerFactory();
		OWLOntology ontology = getPizzaOntology();
		
		OWLReasoner reasoner = reasonerFactory.createNonBufferingReasoner(ontology);
		
		System.out.println("ReasonerName: " + reasoner.getReasonerName());
		
		Node<OWLClass> node = reasoner.getBottomClassNode();
		
		assertNotNull(node);
	}
	
	@Test
	public void testHermit() {
		OWLReasonerFactory reasonerFactory = new org.semanticweb.HermiT.Reasoner.ReasonerFactory();
		OWLOntology ontology = getPizzaOntology();
		
		OWLReasoner reasoner = null;
		try {
			reasoner = reasonerFactory.createNonBufferingReasoner(ontology);
		} catch (java.lang.AbstractMethodError e) {
			System.out.println(e.getMessage());
			e.printStackTrace();
		}
		
		System.out.println("ReasonerName: " + reasoner.getReasonerName());
		
		Node<OWLClass> node = reasoner.getTopClassNode();
		
		assertNotNull(node);
	}
	
	@Test
	public void testFaCtPlusPlus() {
//		FaCTPlusPlusReasonerFactory reasonerFactory = new FaCTPlusPlusReasonerFactory();
//		OWLOntology ontology = getPizzaOntology();
//		
//		OWLReasoner reasoner = null;
//
//		reasoner = reasonerFactory.createReasoner(ontology);
//
//		
//		System.out.println("ReasonerName: " + reasoner.getReasonerName());
//		
//		Node<OWLClass> node = reasoner.getTopClassNode();
//		
//		assertNotNull(node);
	}

}
