/*
* Copyright (C) 2013, FZI Forschungszentrum Informatik
*
* Modifications to the initial code base are copyright of their
* respective authors, or their employers as appropriate. Authorship
* of the modifications may be determined from the ChangeLog placed at
* the end of this file.
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 3.0 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/
package de.fzi.owllink.rest.commons.parser;

import de.fzi.owllink.reasoner.server.entities.Owner;
import de.fzi.owllink.reasoner.server.entities.ReasonerType;
import de.fzi.owllink.reasoner.server.entities.ServerState;
import de.fzi.owllink.reasoner.server.owllinkserver.OwlLinkServerMetadata;
import de.fzi.owllink.rest.commons.xml.XmlOwlLinkServerMetadata;
import de.fzi.owllink.rest.commons.xml.XmlOwner;
import de.fzi.owllink.rest.commons.xml.XmlReasonerType;
import de.fzi.owllink.rest.commons.xml.XmlServerState;

/**
 * 
 * @author Marcel Weigel
 *
 */
public class OwlLinkServerMetadataParser {

	private OwlLinkServerMetadataParser() {
	}
	
	public static XmlOwlLinkServerMetadata getXmlOwlLinkServerMetadata(OwlLinkServerMetadata olsm) {
		XmlOwlLinkServerMetadata xmlOwlLinkReasonerServerMetadata = new XmlOwlLinkServerMetadata();
		xmlOwlLinkReasonerServerMetadata.setHost(olsm.getHost());
		xmlOwlLinkReasonerServerMetadata.setPort(olsm.getPort());
		XmlServerState serverState = ServerStateParser.getXmlServerState(olsm.getServerState());
		xmlOwlLinkReasonerServerMetadata.setXmlServerState(serverState);
		xmlOwlLinkReasonerServerMetadata.setInitDate(olsm.getInitDate());
		xmlOwlLinkReasonerServerMetadata.setStartDate(olsm.getStartDate());
		XmlReasonerType xmlReasonerType = ReasonerTypeParser.getXmlReasonerType(olsm.getReasonerType());
		xmlOwlLinkReasonerServerMetadata.setXmlReasonerType(xmlReasonerType);
		XmlOwner xmlOwner = OwnerParser.getXmlOwner(olsm.getOwner());
		xmlOwlLinkReasonerServerMetadata.setXmlOwner(xmlOwner);
		return xmlOwlLinkReasonerServerMetadata;
	}
	
	public static OwlLinkServerMetadata getOwlLinkServerMetadata(XmlOwlLinkServerMetadata xolsm) {
		ServerState serverState = ServerStateParser.getServerState(xolsm.getXmlServerState());
		ReasonerType reasonerType = ReasonerTypeParser.getReasonerType(xolsm.getXmlReasonerType());
		Owner owner = OwnerParser.getOwner(xolsm.getXmlOwner());
		return new OwlLinkServerMetadata(xolsm.getHost(), xolsm.getPort(), reasonerType, owner, xolsm.getInitDate(), xolsm.getStartDate(), serverState);
	}
	
}
