/*
* Copyright (C) 2013, FZI Forschungszentrum Informatik
*
* Modifications to the initial code base are copyright of their
* respective authors, or their employers as appropriate. Authorship
* of the modifications may be determined from the ChangeLog placed at
* the end of this file.
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 3.0 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/
package de.fzi.owllink.rest.commons.parser;

import de.fzi.owllink.reasoner.server.entities.Capability;
import de.fzi.owllink.reasoner.server.entities.ReasonerType;
import de.fzi.owllink.reasoner.server.entities.Version;
import de.fzi.owllink.rest.commons.xml.XmlCapability;
import de.fzi.owllink.rest.commons.xml.XmlReasonerType;
import de.fzi.owllink.rest.commons.xml.XmlVersion;

/**
 * 
 * @author Marcel Weigel
 *
 */
public class ReasonerTypeParser {

	private ReasonerTypeParser() {
	}
	
	public static XmlReasonerType getXmlReasonerType(ReasonerType reasonerType) {
		XmlReasonerType xmlReasonerType = new XmlReasonerType();
		xmlReasonerType.setId(reasonerType.getId());
		xmlReasonerType.setName(reasonerType.getName());
		XmlVersion xmlVersion = VersionParser.getXmlVersion(reasonerType.getVersion());
		xmlReasonerType.setXmlVersion(xmlVersion);
		XmlCapability xmlCapability = CapabilityParser.getXmlCapability(reasonerType.getCapability());
		xmlReasonerType.setXmlCapability(xmlCapability);
		return xmlReasonerType;
	}
	
	public static ReasonerType getReasonerType(XmlReasonerType xmlReasonerType) {
		Version version = VersionParser.getVersion(xmlReasonerType.getXmlVersion());
		Capability capability = CapabilityParser.getCapability(xmlReasonerType.getXmlCapability());
		return new ReasonerType(xmlReasonerType.getId(), xmlReasonerType.getName(), version, capability);
	}
	
}
