/*
* Copyright (C) 2013, FZI Forschungszentrum Informatik
*
* Modifications to the initial code base are copyright of their
* respective authors, or their employers as appropriate. Authorship
* of the modifications may be determined from the ChangeLog placed at
* the end of this file.
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 3.0 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/
package de.fzi.owllink.rest.jetty.server.resource;

import java.net.HttpURLConnection;

import javax.ws.rs.DELETE;
import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.Request;
import javax.ws.rs.core.UriInfo;

import de.fzi.owllink.rest.jetty.server.dao.ServerDao;

/**
 * 
 * @author Marcel Weigel
 *
 */
public class ActiveResource {
	
	@Context
	UriInfo uriInfo;
	@Context
	Request request;

	int port;

	public ActiveResource(UriInfo uriInfo, Request request, int port) {
		this.uriInfo = uriInfo;
		this.request = request;
		this.port = port;
	}

	/**
	 * Diese Operation erlaubt es einen bereits gestartet OwlLinkServer zu stoppen. Diese 
	 * Operation schlgt fehl wenn der OwlLinkServer bereits schon gestoppt worden ist.
	 * 
	 *  Return 200: Ok, der OwlLinkServer wurde gestoppt.
	 *  Return 404: Angeben OwlLinkServer Id existiert nicht.
	 *  Return 409: Der OwlLinkServer ist schon gestoppt.
	 *  Return 500: Interner Fehler.
	 */
	@DELETE
	public void deleteActive() 
	{
		if (!ServerDao.instance.getModel().isOwlLinkServerRegistered(this.port)) {
			throw new WebApplicationException(HttpURLConnection.HTTP_NOT_FOUND);
		}
		if (!ServerDao.instance.getModel().isOwlLinkServerStarted(this.port)) {
			throw new WebApplicationException(HttpURLConnection.HTTP_BAD_REQUEST);
		}

		try {
		ServerDao.instance.getModel().stopOwlLinkServer(this.port);
		} catch(Exception e) {
			throw new WebApplicationException(HttpURLConnection.HTTP_INTERNAL_ERROR);
		}

		if (ServerDao.instance.getModel().isOwlLinkServerStarted(this.port)) {
			throw new WebApplicationException(HttpURLConnection.HTTP_INTERNAL_ERROR);
		}

		throw new WebApplicationException(HttpURLConnection.HTTP_OK);
	}
}
