package de.fzi.owllink.rest.viewer.controller;

import java.awt.Color;
import java.awt.Image;
import java.awt.Window;
import java.awt.Dialog.ModalityType;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.awt.event.WindowEvent;
import java.awt.event.WindowListener;
import java.util.ArrayList;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.Set;

import javax.swing.ImageIcon;
import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JPanel;
import javax.swing.SwingUtilities;
import javax.swing.border.EmptyBorder;

import de.fzi.owllink.reasoner.server.entities.ReasonerType;
import de.fzi.owllink.reasoner.server.owllinkserver.OwlLinkServerMetadata;
import de.fzi.owllink.rest.client.OwlLinkRestClient;
import de.fzi.owllink.rest.viewer.listener.IOwlLinkServerActionListener;
import de.fzi.owllink.rest.viewer.listener.IRestServerActionListener;
import de.fzi.owllink.rest.viewer.listener.ModelChangedListener;
import de.fzi.owllink.rest.viewer.model.RestViewerModel;
import de.fzi.owllink.rest.viewer.model.RestViewerModelImpl;
import de.fzi.owllink.rest.viewer.view.RestViewerPanelImpl;
import de.fzi.owllink.rest.viewer.view.RestViewerView;
import de.fzi.owllink.rest.viewer.view.dialog.CreateOwlLinkServerDialog;
import de.fzi.owllink.rest.viewer.view.dialog.CreateRestServerDialog;
import de.fzi.owllink.rest.viewer.view.i18n.International;
import de.fzi.owllink.rest.viewer.view.loader.ImageLoader;

public class RestViewerFrame extends JFrame implements IOwlLinkServerActionListener,
IRestServerActionListener, WindowListener, ModelChangedListener {
	
	private static final long serialVersionUID = 41827359542409459L;
	
	private RestViewerModel restViewerModel;
	
	private RestViewerView restViewerView;
	
	private CreateOwlLinkServerDialog createServerDialog;
	private CreateRestServerDialog createConnectionDialog;

	
	public RestViewerFrame() {
		super();
		
		this.restViewerView = new RestViewerPanelImpl(this, this);
		this.restViewerModel = new RestViewerModelImpl(this, this.restViewerView);
		
		initUI();
		
		addWindowListener(this);
	}

	private void initUI() {
		setTitle(International.getString("main_frame_title"));
		
		Image frameIamge = ImageLoader.laodImage("fzi.png");

		setIconImage(frameIamge);

		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		
		setResizable(false);
		setLocationRelativeTo(null);  
		
		setDefaultCloseOperation(EXIT_ON_CLOSE);
		
		initToolbar();
		initContextPanels();
		pack();
		setVisible(true);
	}
	
	private void initToolbar() {
        JMenuBar menubar = new JMenuBar();
        menubar.setBackground(new Color(70, 70, 70));

        JMenu owllinkMenu = new JMenu(International.getString("menu_owllink"));
        owllinkMenu.setBorder(new EmptyBorder(0, 5, 0, 5));
        owllinkMenu.setMnemonic(KeyEvent.VK_S);

        JMenuItem addServerMenuItem = new JMenuItem(International.getString("menu_item_add_owllink_server"));
        addServerMenuItem.setMnemonic(KeyEvent.VK_E);
        addServerMenuItem.setToolTipText(International.getString("menu_item_add_owllink_server_tooltip"));
        addServerMenuItem.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent event) {
            	openCreateServerDialog();
            }
        });
        
        owllinkMenu.add(addServerMenuItem);
        
		ImageIcon refreshIcon = ImageLoader.laodImageIcon("refresh.png");
		
        JMenuItem refreshServerMenuItem = new JMenuItem(International.getString("menu_refresh"), refreshIcon);
        refreshServerMenuItem.setMnemonic(KeyEvent.VK_R);
        refreshServerMenuItem.setToolTipText(International.getString("menu_refresh_tooltip"));
        refreshServerMenuItem.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent event) {
//            	refreshOwlLinkServerPanel(restViewerModel.getAllIdMetadatasPairs());
            }
        });
        owllinkMenu.add(refreshServerMenuItem);
        
        menubar.add(owllinkMenu);
        
        JMenu restMenu = new JMenu(International.getString("menu_rest"));
        restMenu.setBorder(new EmptyBorder(0, 5, 0, 5));
        restMenu.setMnemonic(KeyEvent.VK_C);
        
        JMenuItem restMenuItemAddServer = new JMenuItem(International.getString("menu_item_add_rest_server"));
        restMenuItemAddServer.setMnemonic(KeyEvent.VK_A);
        restMenuItemAddServer.setToolTipText(International.getString("menu_item_add_rest_server_tooltip"));
        restMenuItemAddServer.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent event) {
            	openRestServerDialog();
            }
        }); 
        restMenu.add(restMenuItemAddServer);
        
        menubar.add(restMenu);
        
        JMenu languageMenu = new JMenu(International.getString("menu_language"));
        languageMenu.setBorder(new EmptyBorder(0, 5, 0, 5));
        
        JMenuItem languageEnglishMenuItem = new JMenuItem(International.getString("menu_item_language_english"));
        languageEnglishMenuItem.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent event) {
            	changeLanguage("en");
            }
        });
        languageMenu.add(languageEnglishMenuItem);
        
        ImageIcon tickIcon = ImageLoader.laodImageIcon("tick.png");
        
        JMenuItem languageGermanMenuItem = new JMenuItem(International.getString("menu_item_language_german"), tickIcon);
        languageGermanMenuItem.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent event) {
            	changeLanguage("de");
            }
        });
        languageMenu.add(languageGermanMenuItem);
        
        JMenuItem languageFrenchMenuItem = new JMenuItem(International.getString("menu_item_language_french"));
        languageFrenchMenuItem.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent event) {
            	changeLanguage("fr");
            }
        });
        languageMenu.add(languageFrenchMenuItem);
        
        JMenuItem languageSpanishMenuItem = new JMenuItem(International.getString("menu_item_language_spanish"));
        languageSpanishMenuItem.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent event) {
            	changeLanguage("es");
            }
        });
        languageMenu.add(languageSpanishMenuItem);
        
        menubar.add(languageMenu);

        setJMenuBar(menubar);
	}
	
	private void initContextPanels() {
		
		setContentPane((JPanel)this.restViewerView);
		
		this.restViewerView.refreshRestServerPanel(new ArrayList<OwlLinkRestClient>());
	}

	public void doServerStartAction(String host, int port) {
		this.restViewerModel.startServer(host, port);
	}
	
	public void doServerStopAction(String host, int port) {
		this.restViewerModel.stopServer(host, port);
	}
	
	public void doServerDeleteAction(String host, int port) {
		this.restViewerModel.deregistreServer(host, port);
	}
	
	public void doRestServerSelected(String restServerId) {
		this.restViewerModel.restClientSelected(restServerId);
		
		this.restViewerView.selectRestServerPanel(restServerId);
	}

	public void doAllRestServersUnselected() {
		this.restViewerModel.restClientUnselected();
		
		this.restViewerView.unselectAllRestServerPanel();
	}
	
	public void doRestServerDeleteAction(String restServerId) {
		this.restViewerModel.deleteRestClient(restServerId);
	}

	private void openCreateServerDialog() {
        if (this.createServerDialog == null) {
            Window topWindow = SwingUtilities.getWindowAncestor((JPanel)this.restViewerView);
            this.createServerDialog = new CreateOwlLinkServerDialog(topWindow, International.getString("dialog_create_owllink_server_title"), ModalityType.APPLICATION_MODAL, this.restViewerModel.getRestClientIds(), this.restViewerModel.getReasonerTypes());
            this.createServerDialog.pack();
            this.createServerDialog.setLocationRelativeTo(topWindow);
            this.createServerDialog.setResizable(false);
            this.createServerDialog.setVisible(true);
        } else {
        	this.createServerDialog.refreshLabels();
        	this.createServerDialog.setVisible(true);
        }
        if(this.createServerDialog.isOk()) {      	
        	ReasonerType reasonerType = this.createServerDialog.getSelectedReasonerType();
        	
        	String restServerId = this.createServerDialog.getSelectedRestServerId();
        
        	this.restViewerModel.registreServer(restServerId, reasonerType);
        }

        this.createServerDialog.reset();
    }
	
	private void openRestServerDialog() {
        if (this.createConnectionDialog == null) {
            Window topWindow = SwingUtilities.getWindowAncestor((JPanel)this.restViewerView);
            this.createConnectionDialog = new CreateRestServerDialog(topWindow, International.getString("dialog_create_rest_server_title"), ModalityType.APPLICATION_MODAL);
            this.createConnectionDialog.pack();
            this.createConnectionDialog.setLocationRelativeTo(topWindow);
            this.createConnectionDialog.setResizable(false);
            this.createConnectionDialog.setVisible(true);
        } else {
        	this.createConnectionDialog.refreshLabels();
        	this.createConnectionDialog.setVisible(true);
        }
        if(this.createConnectionDialog.isOk()) {
        	String address = this.createConnectionDialog.getAddress();
	        int port = this.createConnectionDialog.getPort();
	        
	        this.restViewerModel.addRestClient(address, port);
        }
        
        this.createConnectionDialog.reset();
	}

	public void windowActivated(WindowEvent e) {

	}

	public void windowClosed(WindowEvent e) {
		
	}

	public void windowClosing(WindowEvent e) {
	}

	public void windowDeactivated(WindowEvent e) {

	}

	public void windowDeiconified(WindowEvent e) {

	}

	public void windowIconified(WindowEvent e) {

	}

	public void windowOpened(WindowEvent e) {
	}
	
	public void changeLanguage(String languagePrefix) {
		if(languagePrefix.equals("en")) {
			Locale.setDefault( new Locale("en") );
		} else if(languagePrefix.equals("de")) {
			Locale.setDefault( new Locale("de") );
		} else if(languagePrefix.equals("fr")) {
			Locale.setDefault( new Locale("fr") );
		} else if(languagePrefix.equals("es")) {
			Locale.setDefault( new Locale("es") );
		}
		
		International.loadBundle();
		
		setTitle(International.getString("main_frame_title"));
		
		getJMenuBar().getMenu(0).setText(International.getString("menu_owllink"));
		getJMenuBar().getMenu(0).getItem(0).setText(International.getString("menu_item_add_owllink_server"));
		getJMenuBar().getMenu(0).getItem(0).setToolTipText(International.getString("menu_item_add_owllink_server_tooltip"));
		getJMenuBar().getMenu(0).getItem(1).setText(International.getString("menu_refresh"));
		getJMenuBar().getMenu(0).getItem(1).setToolTipText(International.getString("menu_refresh_tooltip"));
		getJMenuBar().getMenu(1).setText(International.getString("menu_rest"));
		getJMenuBar().getMenu(1).getItem(0).setText(International.getString("menu_item_add_rest_server"));
		getJMenuBar().getMenu(1).getItem(0).setToolTipText(International.getString("menu_item_add_rest_server_tooltip"));
		getJMenuBar().getMenu(2).setText(International.getString("menu_language"));
		getJMenuBar().getMenu(2).getItem(0).setText(International.getString("menu_item_language_english"));
		getJMenuBar().getMenu(2).getItem(1).setText(International.getString("menu_item_language_german"));
		getJMenuBar().getMenu(2).getItem(2).setText(International.getString("menu_item_language_french"));
		getJMenuBar().getMenu(2).getItem(3).setText(International.getString("menu_item_language_spanish"));
		
		ImageIcon tickIcon = ImageLoader.laodImageIcon("tick.png");
		getJMenuBar().getMenu(2).getItem(0).setIcon(null);
		getJMenuBar().getMenu(2).getItem(1).setIcon(null);
		getJMenuBar().getMenu(2).getItem(2).setIcon(null);
		getJMenuBar().getMenu(2).getItem(3).setIcon(null);
		
		if(languagePrefix.equals("en")) {
			getJMenuBar().getMenu(2).getItem(0).setIcon(tickIcon);
		} else if(languagePrefix.equals("de")) {
			getJMenuBar().getMenu(2).getItem(1).setIcon(tickIcon);
		} else if(languagePrefix.equals("fr")) {
			getJMenuBar().getMenu(2).getItem(2).setIcon(tickIcon);
		} else if(languagePrefix.equals("es")) {
			getJMenuBar().getMenu(2).getItem(3).setIcon(tickIcon);
		}
		
		this.restViewerView.refreshLabels();
	}

	public void restClientsModifiered( List<OwlLinkRestClient> owlLinkRestClients ) {
		this.restViewerView.refreshRestServerPanel(owlLinkRestClients);
		pack();
	}

	public void reasonerModifiered( Map<String, Set<OwlLinkServerMetadata>> idMetadataPairList ) {
		this.restViewerView.refreshOwlLinkServerPanel(idMetadataPairList);
		pack();
	}

}
