package de.fzi.owllink.rest.viewer.model;

import java.util.ArrayList;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import de.fzi.owllink.reasoner.server.entities.Owner;
import de.fzi.owllink.reasoner.server.entities.ReasonerType;
import de.fzi.owllink.reasoner.server.owllinkserver.OwlLinkServerMetadata;
import de.fzi.owllink.rest.client.OwlLinkRestClient;
import de.fzi.owllink.rest.client.OwlLinkRestClientImpl;
import de.fzi.owllink.rest.viewer.listener.ModelChangedListener;
import de.fzi.owllink.rest.viewer.model.monitor.RestServerMonitor;
import de.fzi.owllink.rest.viewer.view.RestViewerView;

public class RestViewerModelImpl implements RestViewerModel {

	private List<OwlLinkRestClient> owlLinkRestClients;
	
	private String selectedRestClientId;
	private Owner owner;
	
	private RestServerMonitor restServerMonitor;
	private ModelChangedListener modelChangedListener;
	private RestViewerView view;
	
	public RestViewerModelImpl(ModelChangedListener modelChangedListener, RestViewerView restViewerView) {
		this.selectedRestClientId = null;
		this.owner = new Owner("RestViwer"); 
		
		this.owlLinkRestClients = new ArrayList<OwlLinkRestClient>();
		this.view = restViewerView;
		this.modelChangedListener = modelChangedListener;
		this.restServerMonitor = new RestServerMonitor(restViewerView, this);
	}
	
	public void addRestClient(String host, int port) {
		OwlLinkRestClientImpl owlLinkRestClientImpl = new OwlLinkRestClientImpl(host, port);
		this.owlLinkRestClients.add(owlLinkRestClientImpl);
	}
	
	public void deleteRestClient( String restClientId ) {
		this.restServerMonitor.lockThreadStart();

		removeRestServer(restClientId);
	
		this.restServerMonitor.lockThreadEnd();
	} 
	
	public Set<String> getAllRestClientIds() {
		Set<String> restServerIds = new LinkedHashSet<String>();
		for(OwlLinkRestClient restClient : this.owlLinkRestClients) {
			restServerIds.add(restClient.getId());
		}
		return restServerIds;
	}
	
	private void removeRestServer(String restClientId) {
		for(int i=0; i<this.owlLinkRestClients.size(); i++) {
			if(this.owlLinkRestClients.get(i).getId().equals(restClientId)) {
				this.owlLinkRestClients.remove(i);
			}
		}
	}
	
	private OwlLinkRestClient getOwlLinkRestClient(String restClientId) {
		for(OwlLinkRestClient owlLinkRestClient : this.owlLinkRestClients) {
			if(owlLinkRestClient.getId().equals(restClientId)) {
				return owlLinkRestClient;
			}
		}
		return null;
	}
	
	public OwlLinkServerMetadata getOwlLinkServerMetadata( String restClientId, int port ) {
		OwlLinkRestClient owlLinkRestClient = getOwlLinkRestClient(restClientId);
		if(owlLinkRestClient != null) {
			for(OwlLinkServerMetadata owlLinkServerMetadata : owlLinkRestClient.getAllOwlLinkServerMetadatas()) {
				if(owlLinkServerMetadata.getPort() == port) {
					return owlLinkServerMetadata;
				}
			}
		}
		return null;
	}

	public Set<OwlLinkServerMetadata> getOwlLinkServerMetadatas( String restClientId ) {
		OwlLinkRestClient owlLinkRestClient = getOwlLinkRestClient(restClientId);
		if(owlLinkRestClient != null) {
			if(owlLinkRestClient.isConnected()) {
				return owlLinkRestClient.getAllOwlLinkServerMetadatas();
			}
		}
		return new LinkedHashSet<OwlLinkServerMetadata>();
	}

	public Set<OwlLinkServerMetadata> getAllOwlLinkServerMetadatas() {
		Set<OwlLinkServerMetadata> owlLinkServerMetadatas = new LinkedHashSet<OwlLinkServerMetadata>();
		for(OwlLinkRestClient owlLinkRestClient : this.owlLinkRestClients) {
			owlLinkServerMetadatas.addAll(owlLinkRestClient.getAllOwlLinkServerMetadatas());
		}
		return owlLinkServerMetadatas;
	}

	public void addRestServer( String host, int port ) {
		OwlLinkRestClient owlLinkRestClient = new OwlLinkRestClientImpl(host, port);
		
		this.owlLinkRestClients.add(owlLinkRestClient);
	}

	public void registreServer( String restServerId, ReasonerType reasonerType ) {
		try {
			OwlLinkRestClient owlLinkRestClient = getOwlLinkRestClient(restServerId);
			
			owlLinkRestClient.registerOwlLinkServer(this.owner, reasonerType);
		} catch(Exception e) {
			this.view.printErrorServerRegistred(restServerId, reasonerType);
		}
	}

	public void deregistreServer( String restServerId, int port ) {
		try {
			OwlLinkRestClient owlLinkRestClient = getOwlLinkRestClient(restServerId);
			
			owlLinkRestClient.deregistreOwlLinkServer(port);
		} catch(Exception e) {
			this.view.printErrorServerDeregistred(this.restServerMonitor.getCashedMetadata(restServerId, port));
		}
	}

	public void startServer( String restServerId, int port ) {
		try {
			OwlLinkRestClient owlLinkRestClient = getOwlLinkRestClient(restServerId);
			
			owlLinkRestClient.startOwlLinkServer(port);
		} catch(Exception e) {
			this.view.printErrorServerStart(this.restServerMonitor.getCashedMetadata(restServerId, port));
		}
	}

	public void stopServer( String restServerId, int port ) {
		try {
			OwlLinkRestClient owlLinkRestClient = getOwlLinkRestClient(restServerId);
			
			owlLinkRestClient.stopOwlLinkServer(port);
		} catch(Exception e) {
			this.view.printErrorServerStop(this.restServerMonitor.getCashedMetadata(restServerId, port));
		}
	}

	public String getSelectedRestClientId() {
		return this.selectedRestClientId;
	}
	
	public boolean isRestClientSelected() {
		return selectedRestClientId != null;
	}
	
	public void restClientSelected(String restClientId) {
		this.selectedRestClientId = restClientId;
		
		this.restServerMonitor.selectedRestServerHasChanges();
	}
	
	public void restClientUnselected() {
		this.selectedRestClientId = null;
		
		this.restServerMonitor.selectedRestServerHasChanges();
	}

	public String[] getRestClientIds() {
		String[] restClientIds = new String[this.owlLinkRestClients.size()];
		for(int i=0; i<this.owlLinkRestClients.size(); i++) {
			restClientIds[i] = this.owlLinkRestClients.get(i).getId();
		}
		return restClientIds;
	}

	public ReasonerType[][] getReasonerTypes() {
		ReasonerType[][] reasonerTypes = new ReasonerType[this.owlLinkRestClients.size()][];
		
		for(int i=0; i<this.owlLinkRestClients.size(); i++) {
			Set<ReasonerType> reasonerTypeSet = this.owlLinkRestClients.get(i).getAvailableReasonerTypes();
			ReasonerType[] reasonerTypesForServer = new ReasonerType[reasonerTypeSet.size()];
			int k=0;
			for(ReasonerType reasonerType : reasonerTypeSet) {
				reasonerTypesForServer[k++] = reasonerType;
			}
			reasonerTypes[i] = reasonerTypesForServer;
		}
		return reasonerTypes;
	}

	public boolean isRestServerConnected( String restClientId ) {
		return getOwlLinkRestClient(restClientId).isConnected();
	}

	public boolean existRestServer( String restServerId ) {
		for(OwlLinkRestClient owlLinkRestClient : this.owlLinkRestClients) {
			if(owlLinkRestClient.getId().equals(restServerId)) {
				return true;
			}
		}
		return false;
	}

	public void refreshRestServerPanel() {
		this.modelChangedListener.restClientsModifiered(this.owlLinkRestClients);
	}
	
	public void refreshReasonerPanel(Map<String, Set<OwlLinkServerMetadata>> owlLinkServerMetatdataMap) {
		this.modelChangedListener.reasonerModifiered(owlLinkServerMetatdataMap);
	}
}
