package de.fzi.owllink.rest.viewer.view;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.GridLayout;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;
import java.util.Set;

import javax.swing.BorderFactory;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;

import de.fzi.owllink.reasoner.server.entities.ReasonerType;
import de.fzi.owllink.reasoner.server.owllinkserver.OwlLinkServerMetadata;
import de.fzi.owllink.rest.client.OwlLinkRestClient;
import de.fzi.owllink.rest.viewer.listener.IOwlLinkServerActionListener;
import de.fzi.owllink.rest.viewer.listener.IRestServerActionListener;
import de.fzi.owllink.rest.viewer.view.i18n.International;
import de.fzi.owllink.rest.viewer.view.panel.ColoredConsolePane;
import de.fzi.owllink.rest.viewer.view.panel.OwlLinkHeaderPanel;
import de.fzi.owllink.rest.viewer.view.panel.OwlLinkServerPanel;
import de.fzi.owllink.rest.viewer.view.panel.RestHeaderPanel;
import de.fzi.owllink.rest.viewer.view.panel.RestServerPanel;

public class RestViewerPanelImpl extends JPanel implements RestViewerView {

	private static final long serialVersionUID = -5525741447746608668L;
	
	private ColoredConsolePane console;
	
	private JPanel owlLinkServerPanel;
	private JPanel restServerPanel;
	
	private OwlLinkHeaderPanel owlLinkheaderPanel;
	private RestHeaderPanel restHeaderPanel;
	
	
	private List<RestServerPanel> restServerPanels;
	private List<OwlLinkServerPanel> owlLinkServerPanels;
	
	private IOwlLinkServerActionListener owlLinkServerActionListener;
	private IRestServerActionListener restServerActionListener;
	
	public RestViewerPanelImpl(IOwlLinkServerActionListener owlLinkServerActionListener, IRestServerActionListener restServerActionListener) {
		this.owlLinkServerPanels = new ArrayList<OwlLinkServerPanel>();
		this.restServerPanels = new ArrayList<RestServerPanel>();
		
		this.owlLinkServerActionListener = owlLinkServerActionListener;
		this.restServerActionListener = restServerActionListener;
		
		initContextPanels();
	}
	
	private void initContextPanels() {
		
		JPanel restServerLabelPanel = new JPanel();
		restServerLabelPanel.setBackground(new Color(120, 120, 120));
		restServerLabelPanel.setPreferredSize(new Dimension(200, 20));
		restServerLabelPanel.setBorder(BorderFactory.createMatteBorder(0, 0, 1, 0, new Color(50, 50, 50)));
		restServerLabelPanel.setLayout(null);
		
		JLabel restServerPanelLabel = new JLabel(International.getString("main_frame_heading_label_rest_server"));
		restServerPanelLabel.setForeground(Color.LIGHT_GRAY);
		restServerPanelLabel.setBounds(0, 0, 100, 20);
		restServerLabelPanel.add(restServerPanelLabel);
		
		JPanel owlLinkServerLabelPanel = new JPanel();
		owlLinkServerLabelPanel.setBackground(new Color(120, 120, 120));
		owlLinkServerLabelPanel.setPreferredSize(new Dimension(200, 20));
		owlLinkServerLabelPanel.setBorder(BorderFactory.createMatteBorder(0, 0, 1, 0, new Color(50, 50, 50)));
		owlLinkServerLabelPanel.setLayout(null);
		
		JLabel owlLinkServerPanelLabel = new JLabel(International.getString("main_frame_heading_label_owllink_server"));
		owlLinkServerPanelLabel.setForeground(Color.LIGHT_GRAY);
		owlLinkServerPanelLabel.setBounds(0, 0, 100, 20);
		owlLinkServerLabelPanel.add(owlLinkServerPanelLabel);
		
		this.restServerPanel = new JPanel();
		this.restServerPanel.setBackground(new Color(80, 90, 80));
		
		this.restHeaderPanel = new RestHeaderPanel(this.restServerActionListener);
		this.restServerPanel.add(this.restHeaderPanel);
		
		JScrollPane scrollPaneRestServerContext = new JScrollPane(this.restServerPanel);
		scrollPaneRestServerContext.setPreferredSize(new Dimension(200, 400));
		scrollPaneRestServerContext.setBorder(BorderFactory.createMatteBorder(0, 0, 0, 1, new Color(50, 50, 50)));
		
		this.owlLinkServerPanel = new JPanel();
		this.owlLinkServerPanel.setBackground(new Color(70, 70, 70));
		
		JScrollPane scrollPaneOwlLinkServerContext = new JScrollPane(this.owlLinkServerPanel);
		scrollPaneOwlLinkServerContext.setPreferredSize(new Dimension(650, 400));
		scrollPaneOwlLinkServerContext.setBorder(BorderFactory.createEmptyBorder());

		this.console = new ColoredConsolePane();
		this.console.setEditable(false);
        
        JScrollPane scrollPaneConsole = new JScrollPane(this.console);
        scrollPaneConsole.setPreferredSize(new Dimension(520, 110));
        scrollPaneConsole.setBorder(BorderFactory.createEmptyBorder());

        setLayout(new GridBagLayout());
		GridBagConstraints c = new GridBagConstraints();
		
		this.owlLinkheaderPanel = new OwlLinkHeaderPanel();
		
		c.fill = GridBagConstraints.HORIZONTAL;
		c.gridx = 0;
		c.gridy = 0;
		add(restServerLabelPanel, c);	
		
		c.gridx = 1;
		c.gridy = 0;
		add(owlLinkServerLabelPanel, c);
		
		c.fill = GridBagConstraints.VERTICAL;
		c.gridx = 0;
		c.gridy = 1;
		c.gridheight = 2;
		add(scrollPaneRestServerContext, c);	
		
		c.gridx = 1;
		c.gridy = 1;
		c.gridheight = 1;
		add(this.owlLinkheaderPanel, c);
		
		c.gridx = 1;
		c.gridy = 2;
		add(scrollPaneOwlLinkServerContext, c);		

		c.fill = GridBagConstraints.HORIZONTAL;
		c.gridx = 0;
		c.gridy = 3;
		c.gridwidth = 2;
		add(scrollPaneConsole, c);
	}

	public void viewOwlLinkServerPanels(String host, List<OwlLinkServerMetadata> owlLinkServerMetadatas) {
		for(OwlLinkServerMetadata owlLinkServerMetadata : owlLinkServerMetadatas) {
			viewOwlLinkServerPanel(host, owlLinkServerMetadata);
		}
	}
	
	private void viewOwlLinkServerPanel(String host, OwlLinkServerMetadata olsm) {
		OwlLinkServerPanel owlLinkServerPanel = new OwlLinkServerPanel(host, olsm, this.owlLinkServerActionListener);
	
		owlLinkServerPanel.setBounds(0, this.owlLinkServerPanels.size() * 50, 600, 50);
		
		add(owlLinkServerPanel);
		this.owlLinkServerPanels.add(owlLinkServerPanel);
	}
	
	public void clear() {
		for(OwlLinkServerPanel owlLinkServerPanel : this.owlLinkServerPanels) {
			owlLinkServerPanel.removeAll();
		}
		
		this.owlLinkServerPanels.clear();
		removeAll();
	}
	
	public void refreshRestServerPanel(List<OwlLinkRestClient> restServers) {
		this.restServerPanel.removeAll();
		this.restServerPanels.clear();
		
		this.restServerPanel.add(this.restHeaderPanel);
		
		int rows = restServers.size() < 8 ? 8 : restServers.size();
		this.restServerPanel.setLayout(new GridLayout(rows, 1));
		
		for(OwlLinkRestClient restServer : restServers) {
			RestServerPanel restServerPanel = new RestServerPanel(restServer.getId(), 
					restServer.getHost(), restServer.getPort(), this.restServerActionListener);
			
			if(restServer.isConnected()) {
				restServerPanel.connected();
			} else {
				restServerPanel.disconnected();
			}
			
			this.restServerPanel.add(restServerPanel);
			this.restServerPanels.add(restServerPanel);
		}
		repaint();
	}

	public void refreshOwlLinkServerPanel(Map<String, Set<OwlLinkServerMetadata>> metadatasList) {
		this.owlLinkServerPanel.removeAll();
		this.owlLinkServerPanels.clear();
		
		int allMetadataCount = 0;
		for(Set<OwlLinkServerMetadata> owlLinkServerMetadatas : metadatasList.values()) {
			allMetadataCount +=  owlLinkServerMetadatas.size();	
		}
		
		int rows = allMetadataCount < 10 ? 10 : allMetadataCount;
		this.owlLinkServerPanel.setLayout(new GridLayout(rows, 1));
		
		for(Entry<String, Set<OwlLinkServerMetadata>> pair : metadatasList.entrySet()) {
			for(OwlLinkServerMetadata metadata : pair.getValue()) {
				OwlLinkServerPanel serverPanel = new OwlLinkServerPanel(pair.getKey(), metadata, this.owlLinkServerActionListener);
				
				this.owlLinkServerPanel.add(serverPanel);
			}
		}
		repaint();
	}
	
	public void selectRestServerPanel(String restServerId) {
		for (RestServerPanel restServerPanel : this.restServerPanels) {
			if(restServerPanel.getRestServerId().equals(restServerId)) {
				restServerPanel.select();
			} else {
				restServerPanel.unselect();
			}
		}
	}	

	public void refreshLabels() {
		this.owlLinkheaderPanel.refreshLabels();
		
		for(OwlLinkServerPanel serverPanel : this.owlLinkServerPanels) {
			serverPanel.refreshLabels();
		}
		
		this.restHeaderPanel.refreshLabels();
	}
	
	public void printServerRegistred(OwlLinkServerMetadata metadata) {
		log(String.format(International.getString("console_log_actor_server_id"), metadata.getId()), String.format(International.getString("console_log_regist_server"), metadata.getId(), metadata.getReasonerType().getName(), metadata.getPort(), " -- "));
	}
	
	public void printServerStateChanged(OwlLinkServerMetadata metadata) {
		log(String.format(International.getString("console_log_actor_server_id"), metadata.getId()), String.format(International.getString("console_log_server_state_changed"), metadata.getServerState().toString()));
	}
	
	public void printServerDeregistred(OwlLinkServerMetadata metadata) {
		log(String.format(International.getString("console_log_actor_server_id"), metadata.getId()), String.format(International.getString("console_log_deregist_server"), metadata.getId(), metadata.getReasonerType().getName(), metadata.getPort(), " -- "));
	}
	
	public void printErrorServerRegistred( String restServerId, ReasonerType reasonerType ) {
		error(International.getString("console_log_actor_server"), String.format(International.getString("console_error_fail_regist_server"), restServerId, reasonerType.getName(), reasonerType.getVersion()));
	}

	public void printErrorServerDeregistred(OwlLinkServerMetadata metadata) {
		error(String.format(International.getString("console_log_actor_server_id"), metadata.getId()), String.format(International.getString("console_error_deregist_server"), metadata.getId(), metadata.getReasonerType().getName(), metadata.getPort(), " -- "));
	}
	
	public void printErrorServerStart(OwlLinkServerMetadata metadata) {
		error(String.format(International.getString("console_log_actor_server_id"), metadata.getId()), International.getString("console_error_start_server"));
	}
	
	public void printErrorServerStop(OwlLinkServerMetadata metadata) {
		error(String.format(International.getString("console_log_actor_server_id"), metadata.getId()), International.getString("console_error_stop_server"));
	}
	
	public void log(String source, String action) {
		SimpleDateFormat s = new SimpleDateFormat(International.getString("local_date_time_format"));
		if(this.console == null) {
			return;
		}
		this.console.setEditable(true);
		this.console.append(Color.GRAY, s.format(new Date()));
		this.console.append(Color.BLACK, " [");
		this.console.append(Color.BLUE, source);
		this.console.append(Color.BLACK, "] " + action + "\n");
		this.console.setEditable(false);
	}
	
	public void error(String source, String action) {
		SimpleDateFormat s = new SimpleDateFormat(International.getString("local_date_time_format"));
		if(this.console == null) {
			return;
		}
		this.console.setEditable(true);
		this.console.append(Color.GRAY, s.format(new Date()));
		this.console.append(Color.BLACK, " [");
		this.console.append(Color.BLUE, source);
		this.console.append(Color.BLACK, "] ");
		this.console.append(Color.RED, action + "\n");
		this.console.setEditable(false);
	}

	public void unselectAllRestServerPanel() {
		for (RestServerPanel restServerPanel : this.restServerPanels) {
			restServerPanel.unselect();
		}
	}
	
}
