/*
* Copyright (C) 2013, FZI Forschungszentrum Informatik
*
* Modifications to the initial code base are copyright of their
* respective authors, or their employers as appropriate. Authorship
* of the modifications may be determined from the ChangeLog placed at
* the end of this file.
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 3.0 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/
package de.fzi.owllink.rest.viewer.view.dialog;

import java.awt.Dimension;
import java.awt.Window;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;
import de.fzi.owllink.reasoner.server.entities.ReasonerType;
import de.fzi.owllink.rest.viewer.view.i18n.International;

/**
 * 
 * @author Marcel Weigel
 *
 */
public class CreateOwlLinkServerDialog extends JDialog {

	private static final long serialVersionUID = 958075372253838079L;
	
	private static final Dimension DIALOG_SIZE = new Dimension(280, 115);
    private JPanel dialogPanel = new JPanel();
    private ReasonerType[][] reasonerTypes;
    private String[] restServerIds;
    
    private JLabel reasonerLabel;
    private JLabel restServerLabel;
    
    private JButton canselButton;
    private JButton okButton;
    
	private JComboBox<String> reasonerComboBox;
	private JComboBox<String> restServerComboBox;
    
    private boolean isOk = false;

    public CreateOwlLinkServerDialog(Window topWindow, String title, ModalityType applicationModal, String[] restServerIds, ReasonerType[][] reasonerTypes) {
    	super(topWindow, title, applicationModal);
    	
    	this.restServerIds = restServerIds;
    	this.reasonerTypes = reasonerTypes;
    	
    	initUI();
    }
    
	private void initUI() {
    	dialogPanel.setLayout(null);
    	dialogPanel.setPreferredSize(DIALOG_SIZE);
    	
    	this.restServerLabel = new JLabel(International.getString("dialog_create_owllink_server_label_restserver"));
    	this.restServerLabel.setBounds(10, 48, 75, 25);
    	dialogPanel.add(this.restServerLabel);
    	
    	restServerComboBox = new JComboBox<String>();
    	restServerComboBox.setBounds(80, 45, 200, 30);
    	
    	if(this.restServerIds == null || this.restServerIds.length == 0) {
    		restServerComboBox.addItem(International.getString("dialog_create_owllink_server_combobox_empty"));
    	} else {
    		for(String restServerId : this.restServerIds) {
    			restServerComboBox.addItem(restServerId);
        	}
    	}
    	
    	restServerComboBox.addActionListener (new ActionListener () {
    	    public void actionPerformed(ActionEvent e) {
    	    	refreshReasonerComboBox();
    	    }
    	});

    	restServerComboBox.setPreferredSize(new Dimension(100, 30));
    	dialogPanel.add(restServerComboBox);
    	
    	this.reasonerLabel = new JLabel(International.getString("dialog_create_owllink_server_label_reasoner"));
    	this.reasonerLabel.setBounds(10, 10, 75, 25);
    	dialogPanel.add(this.reasonerLabel);
    	
    	reasonerComboBox = new JComboBox<String>();
    	reasonerComboBox.setBounds(80, 7, 200, 30);
    	
    	refreshReasonerComboBox();

    	reasonerComboBox.setPreferredSize(new Dimension(100, 30));
    	dialogPanel.add(reasonerComboBox);
    	
    	this.canselButton = new JButton(International.getString("dialog_abort"));
    	this.canselButton.setBounds(133, 85, 90, 30);
    	this.canselButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
            	dispose();
            }
          });
    	dialogPanel.add(canselButton);
    	
    	this.okButton = new JButton(International.getString("dialog_ok"));
    	this.okButton.setBounds(231, 85, 50, 30);
    	this.okButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
            	isOk = true;
            	dispose();
            }
          });
    	dialogPanel.add(this.okButton);
    	
    	getContentPane().add(dialogPanel);
    }
    
	private void refreshReasonerComboBox() {
    	this.reasonerComboBox.removeAllItems();
    	
    	int index = this.restServerComboBox.getSelectedIndex();
    	
    	if(this.reasonerTypes == null || this.reasonerTypes.length == 0) {
    		this.reasonerComboBox.addItem(International.getString("dialog_create_owllink_server_combobox_empty"));
    	} else {
    		for(ReasonerType reasonerType : this.reasonerTypes[index]) {
        		this.reasonerComboBox.addItem(reasonerType.getName());
        	}
    	}
    }
    
    public void reset() {
    	this.restServerComboBox.setSelectedIndex(0);
    	
    	this.isOk = false;
    	
    	refreshReasonerComboBox();
    }
    
    public boolean isOk() {
    	return this.isOk;
    }

	public void refreshLabels() {
		setTitle(International.getString("dialog_create_owllink_server_title"));
		
		this.reasonerLabel.setText(International.getString("dialog_create_owllink_server_label_reasoner"));
		this.canselButton.setText(International.getString("dialog_abort"));
		this.okButton.setText(International.getString("dialog_ok"));
		
		refreshReasonerComboBox();
	}

	public String getSelectedRestServerId() {
		int indexRest = this.restServerComboBox.getSelectedIndex();
		return this.restServerIds[indexRest];
	}

	public ReasonerType getSelectedReasonerType() {
		int indexRest = this.restServerComboBox.getSelectedIndex();
		int indexReasoner = this.reasonerComboBox.getSelectedIndex();
		
		return this.reasonerTypes[indexRest][indexReasoner];
	}
}
