/*
* Copyright (C) 2013, FZI Forschungszentrum Informatik
*
* Modifications to the initial code base are copyright of their
* respective authors, or their employers as appropriate. Authorship
* of the modifications may be determined from the ChangeLog placed at
* the end of this file.
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 3.0 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/
package de.fzi.owllink.rest.viewer.view.dialog;

import java.awt.Dimension;
import java.awt.Window;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

import de.fzi.owllink.rest.viewer.view.i18n.International;

/**
 * 
 * @author Marcel Weigel
 *
 */
public class CreateRestServerDialog extends JDialog {

	private static final long serialVersionUID = 6583358528678267269L;
	
	private static final Dimension DIALOG_SIZE = new Dimension(280, 82);
	private JPanel dialogPanel = new JPanel();
	
	private JLabel addressLabel;
	private JLabel portLabel;
	
	private JButton canselButton;
	private JButton okButton;
	
	private JTextField addressTextFild;
	private JTextField portTextFild;
	
	private boolean isOk = false;
	
	public CreateRestServerDialog(Window topWindow, String title, ModalityType applicationModal) {
    	super(topWindow, title, applicationModal);
    	
    	initUI();
    	
        this.dialogPanel.setPreferredSize(DIALOG_SIZE);
    }

	private void initUI() {
    	dialogPanel.setLayout(null);
    	dialogPanel.setPreferredSize(DIALOG_SIZE);
    	
    	this.addressLabel = new JLabel(International.getString("dialog_create_rest_server_label_address"));
    	this.addressLabel.setBounds(10, 10, 50, 25);
    	dialogPanel.add(this.addressLabel);
    	
    	addressTextFild = new JTextField();
    	addressTextFild.setBounds(55, 10, 130, 30);
    	addressTextFild.setBorder(BorderFactory.createCompoundBorder(addressTextFild.getBorder(), BorderFactory.createEmptyBorder(5, 5, 5, 5)));
    	dialogPanel.add(addressTextFild);
    	
    	this.portLabel = new JLabel(International.getString("dialog_create_rest_server_label_port"));
    	this.portLabel.setBounds(200, 10, 40, 25);
    	dialogPanel.add(this.portLabel);
    	
    	portTextFild = new JTextField();
    	portTextFild.setBounds(225, 10, 50, 30);
    	portTextFild.setBorder(BorderFactory.createCompoundBorder(portTextFild.getBorder(), BorderFactory.createEmptyBorder(5, 5, 5, 5)));
    	dialogPanel.add(portTextFild);
    	
    	this.canselButton = new JButton(International.getString("dialog_abort"));
    	this.canselButton.setBounds(130, 48, 90, 30);
    	this.canselButton.addActionListener(new ActionListener(){
            public void actionPerformed(ActionEvent e){
            	dispose();
            }
          });
    	dialogPanel.add(this.canselButton);
    	
    	this.okButton = new JButton(International.getString("dialog_ok"));
    	this.okButton.setBounds(228, 48, 50, 30);
    	this.okButton.addActionListener(new ActionListener(){
            public void actionPerformed(ActionEvent e){
            	isOk = true;
            	dispose();
            }
          });
    	dialogPanel.add(this.okButton);
    	
    	getContentPane().add(dialogPanel);
	}
	
	public void reset() {
		this.addressTextFild.setText("");
		this.portTextFild.setText("");
		
		this.isOk = false;
	}
	
	public boolean isOk() {
    	return this.isOk;
    }
	
	public void refreshLabels() {
		setTitle(International.getString("dialog_create_rest_server_title"));
		
		this.addressLabel.setText(International.getString("dialog_create_rest_server_label_address"));
		this.portLabel.setText(International.getString("dialog_create_rest_server_label_port"));
		this.canselButton.setText(International.getString("dialog_abort"));
		this.okButton.setText(International.getString("dialog_ok"));
	}

	public String getAddress() {
		return this.addressTextFild.getText();
	}

	public int getPort() {
		int port = -1;
    	try {
    		port = Integer.parseInt(this.portTextFild.getText());
    	} catch(Exception e) {
    	}
		return port;
	}
}
