package de.fzi.owllink.rest.viewer.view.panel;

import java.awt.Color;
import java.awt.Cursor;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;

import javax.swing.BorderFactory;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;

import de.fzi.owllink.reasoner.server.entities.ServerState;
import de.fzi.owllink.reasoner.server.owllinkserver.OwlLinkServerMetadata;
import de.fzi.owllink.rest.viewer.listener.IOwlLinkServerActionListener;
import de.fzi.owllink.rest.viewer.view.i18n.International;
import de.fzi.owllink.rest.viewer.view.loader.ImageLoader;

public class OwlLinkServerPanel extends JPanel implements ActionListener {
	
	private static final long serialVersionUID = -5196641101697154799L;
	
	private JLabel hostLabel;
	private JLabel portLabel;
	private JLabel serverStateLabel;
	private JLabel initDateLabel;
	private JLabel startDateLabel;
	private JLabel reasonerTypeLabel;
	private JLabel ownerLabel;
	
	private JButton startButton;
	private JButton deleteButton;
	
	private DateFormat df = new SimpleDateFormat("dd/MM/yyyy HH:mm:ss");
	private final Color backgroundColor = new Color(70, 70, 70);
	
	private IOwlLinkServerActionListener owlLinkServerActionListener;
	
	private String host;
	private OwlLinkServerMetadata owlLinkServerMetadata;
	
	public OwlLinkServerPanel(String host, OwlLinkServerMetadata owlLinkServerMetadata, IOwlLinkServerActionListener owlLinkServerActionListener) {
		this.owlLinkServerActionListener = owlLinkServerActionListener;
		this.owlLinkServerMetadata = owlLinkServerMetadata;
		this.host = host;
		
		createAndAddLabel(owlLinkServerMetadata.getId(), 0, 140);
//		createAndAddLabel(owlLinkServerMetadata.getName(), 50, 140);
		createAndAddLabel(owlLinkServerMetadata.getReasonerType().getName(), 190, 80);
		createAndAddLabel(owlLinkServerMetadata.getOwner().getName(), 280, 80);
		createAndAddLabel(host, 370, 120);
		createStateLabel(460, 80);
		createStartStopButton(535, 60);
		createDeleteButton(605, 15);
		
		setLayout(null);
		setPreferredSize(new Dimension(500, 40));
		setBackground(this.backgroundColor);
		setBorder(BorderFactory.createEmptyBorder(8,3,8,3));
	}
	
	private void createAndAddLabel(String text, int x, int width) {
		JLabel label = new JLabel(text);
		label.setForeground(Color.WHITE);
		label.setBorder(BorderFactory.createEmptyBorder(10,10,10,10));
		label.setPreferredSize(new Dimension(50, 40));
		label.setBounds(x, 10, width, 20);
		add(label);
	}
	
	private void createStateLabel(int x, int width) {
		JLabel label = new JLabel(owlLinkServerMetadata.getServerState().toString());
		label.setForeground(Color.WHITE);
		if(owlLinkServerMetadata.getServerState() == ServerState.Stopped) {
			label.setForeground(Color.RED);
		}
		switch(owlLinkServerMetadata.getServerState()) {
			case Stopped:
				label.setForeground(Color.RED);
				break;
			case Stopping:
				label.setForeground(Color.ORANGE);
				break;
			case Started:
				label.setForeground(Color.GREEN);
				break;
			case Starting:
				label.setForeground(Color.ORANGE);
				break;
			default:
				label.setForeground(Color.GRAY);
				break;
		}
		
		label.setBorder(BorderFactory.createEmptyBorder(10,10,10,10));
		label.setPreferredSize(new Dimension(50, 40));
		label.setBounds(x, 10, width, 20);
		add(label);
	}
	
	private void createStartStopButton(int x, int width) {
		if(owlLinkServerMetadata.getServerState() == ServerState.Stopped) {
			this.startButton = new JButton(International.getString("owllink_server_panel_button_start"));
			this.startButton.setActionCommand("Start");
		} else if(owlLinkServerMetadata.getServerState() == ServerState.Started) {
			this.startButton = new JButton(International.getString("owllink_server_panel_button_stop"));
			this.startButton.setActionCommand("Stop");
		} else {
			this.startButton = new JButton("--");
			this.startButton.setActionCommand("--");
		}
		
		this.startButton.setBorder(BorderFactory.createEmptyBorder(10,10,10,10));
		this.startButton.setCursor(new Cursor(Cursor.HAND_CURSOR));
		this.startButton.setBackground(new Color(70, 70, 70));
		this.startButton.addActionListener(this);
		this.startButton.setBounds(x, 10, width, 25);
		add(this.startButton);
	}
	
	private void createDeleteButton(int x, int width) {
		ImageIcon image = ImageLoader.laodImageIcon("bin.png");
		this.deleteButton = new JButton(image);
		
		this.deleteButton.setBorder(BorderFactory.createEmptyBorder(10,10,10,10));
		this.deleteButton.setCursor(new Cursor(Cursor.HAND_CURSOR));
		this.deleteButton.setBackground(new Color(70, 70, 70));
		this.deleteButton.addActionListener(this);
		this.deleteButton.setActionCommand("Delete");
		this.deleteButton.setToolTipText(International.getString("owllink_server_panel_button_delete_server_tooltip"));
		this.deleteButton.setBounds(x, 15, width, 15);
		add(this.deleteButton);
	}

	public void actionPerformed(ActionEvent e) {
		if(e.getActionCommand().equals("Start")) {
			this.owlLinkServerActionListener.doServerStartAction(this.host, this.owlLinkServerMetadata.getPort());
		} else if (e.getActionCommand().equals("Stop")) {
			this.owlLinkServerActionListener.doServerStopAction(this.host, this.owlLinkServerMetadata.getPort());
		} else if (e.getActionCommand().equals("Delete")) {
			this.owlLinkServerActionListener.doServerDeleteAction(this.host, this.owlLinkServerMetadata.getPort());
		}
	}
	public void refreshLabels() {
		if(owlLinkServerMetadata.getServerState() == ServerState.Stopped) {
			this.startButton.setText(International.getString("owllink_server_panel_button_start"));
		} else if(owlLinkServerMetadata.getServerState() == ServerState.Started) {
			this.startButton.setText(International.getString("owllink_server_panel_button_stop"));
		} else {
			this.startButton.setText("--");
		}
		
		this.deleteButton.setToolTipText(International.getString("owllink_server_panel_button_delete_server_tooltip"));
	}
	
	

}
