/*
* Copyright (C) 2013, FZI Forschungszentrum Informatik
*
* Modifications to the initial code base are copyright of their
* respective authors, or their employers as appropriate. Authorship
* of the modifications may be determined from the ChangeLog placed at
* the end of this file.
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 3.0 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/
package de.fzi.owllink.rest.viewer.view.panel;

import java.awt.Color;
import java.awt.Cursor;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

import javax.swing.BorderFactory;
import javax.swing.JLabel;
import javax.swing.JPanel;

import de.fzi.owllink.rest.viewer.listener.IRestServerActionListener;
import de.fzi.owllink.rest.viewer.view.i18n.International;
import de.fzi.owllink.rest.viewer.view.loader.ImageLoader;


/**
 * 
 * @author Marcel Weigel
 *
 */
public class RestHeaderPanel extends JPanel implements MouseListener {

	private static final long serialVersionUID = -6657872064124541018L;
	
	private IRestServerActionListener serverActionListener;
	
	private JLabel shwoAllLabel;
	private JLabel imageLabel;
	
	private Color backgroundColor = new Color(70, 70, 70);
	
	private Color selectedBackgroundColor = new Color(90, 90, 90);
	private Color fontColor = new Color(196, 180, 90);
	
	private boolean isSelected = false;

	public RestHeaderPanel(IRestServerActionListener serverActionListener) {
		
		this.serverActionListener = serverActionListener;
		
		initUI();
	}
	
	private void initUI() {
		setLayout(null);
		setPreferredSize(new Dimension(180, 40));
		setBackground(backgroundColor);
		setBorder(BorderFactory.createMatteBorder(0, 0, 1, 0, new Color(50, 50, 50)));
		addMouseListener(this);
		setCursor(new Cursor(Cursor.HAND_CURSOR));
		
		this.shwoAllLabel = new JLabel(International.getString("rest_server_panel_label_all_server"));
		this.shwoAllLabel.setForeground(fontColor);
		this.shwoAllLabel.setFont(new Font("Arial", Font.BOLD, 16));
    	this.shwoAllLabel.setBounds(50, 15, 150, 25);
    	add(this.shwoAllLabel);
    	
    	this.imageLabel = new JLabel(ImageLoader.laodImageIcon("allservers.png"));
    	this.imageLabel.setBounds(5, 10, 35, 35);
		add(this.imageLabel);
	}

	public void mouseClicked(MouseEvent e) {
    	this.serverActionListener.doAllRestServersUnselected();
    }
    
    public void mousePressed(MouseEvent e){}
    public void mouseReleased(MouseEvent e){}

    public void mouseEntered(MouseEvent e)
    {
        setBackground(selectedBackgroundColor);
    }

    public void mouseExited(MouseEvent e)
    {
    	if(this.isSelected) {
    		return;
    	}
        setBackground(backgroundColor);
    }
    
	public void select() {
		setBackground(this.selectedBackgroundColor);
		
		this.isSelected = true;
	}
	
	public void unselect() {
		setBackground(this.backgroundColor);
		
		this.isSelected = false;
	}
	
	public void refreshLabels() {
		this.shwoAllLabel.setText(International.getString("rest_server_panel_label_all_server"));
	}
}
