/*
* Copyright (C) 2013, FZI Forschungszentrum Informatik
*
* Modifications to the initial code base are copyright of their
* respective authors, or their employers as appropriate. Authorship
* of the modifications may be determined from the ChangeLog placed at
* the end of this file.
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 3.0 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/
package de.fzi.owllink.rest.viewer.view.panel;

import java.awt.Color;
import java.awt.Cursor;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

import javax.swing.BorderFactory;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;

import de.fzi.owllink.rest.viewer.listener.IRestServerActionListener;
import de.fzi.owllink.rest.viewer.view.i18n.International;
import de.fzi.owllink.rest.viewer.view.loader.ImageLoader;

/**
 * 
 * @author Marcel Weigel
 *
 */
public class RestServerPanel extends JPanel implements MouseListener, ActionListener {
	
	private static final long serialVersionUID = -1794870618756678130L;
	
	private IRestServerActionListener serverActionListener;
	
	private String restServerId;
	
	private String address;
	
	private int port;
	
	private JLabel imageLabel;
	
	private JLabel idLabel;
	private JLabel addressLabel;
	private JButton deleteButton;
	
	private Color backgroundColor = new Color(70, 70, 70);
	private Color hoverBackgroundColor = new Color(90, 90, 90);
	private Color selectedBackgroundColor = new Color(196, 180, 90);
	
	private boolean isSelected = false;

	public RestServerPanel(String restServerId, String address, int port, IRestServerActionListener serverActionListener) {
		
		this.restServerId = restServerId;
		
		this.address = address;
		
		this.port = port;
		
		this.serverActionListener = serverActionListener;
		
		initUI();
	}

	private void initUI() {
		setLayout(null);
		setPreferredSize(new Dimension(180, 40));
		setBackground(backgroundColor);
		setBorder(BorderFactory.createMatteBorder(0, 0, 1, 0, new Color(50, 50, 50)));
		addMouseListener(this);
		setCursor(new Cursor(Cursor.HAND_CURSOR));
		
		this.idLabel = new JLabel(this.address);
		this.idLabel.setForeground(Color.WHITE);
		this.idLabel.setFont(new Font("Arial", Font.BOLD, 16));
    	this.idLabel.setBounds(50, 8, 150, 25);
    	add(this.idLabel);
    	
    	this.imageLabel = new JLabel(ImageLoader.laodImageIcon("online.png"));
    	this.imageLabel.setBounds(10, 15, 25, 25);
		add(this.imageLabel);
		
		this.addressLabel = new JLabel(this.address + ":" + this.port);
		this.addressLabel.setForeground(Color.WHITE);
		this.addressLabel.setBounds(50, 24, 150, 25);
		add(this.addressLabel);
		
		ImageIcon image = ImageLoader.laodImageIcon("b_bin.png");
		this.deleteButton = new JButton(image);
		
		this.deleteButton.setBorder(BorderFactory.createEmptyBorder(10,10,10,10));
		this.deleteButton.setCursor(new Cursor(Cursor.HAND_CURSOR));
		this.deleteButton.setBackground(new Color(70, 70, 70));
		this.deleteButton.addActionListener(this);
		this.deleteButton.setActionCommand("Delete");
		this.deleteButton.setToolTipText(International.getString("owllink_server_panel_button_delete_server_tooltip"));
		this.deleteButton.setBounds(160, 17, 25, 25);
		add(this.deleteButton);
	}
	
	public String getRestServerId() {
		return this.restServerId;
	}
	
    public void mouseClicked(MouseEvent e) {
    	this.serverActionListener.doRestServerSelected(this.restServerId);
    }
    
    public void mousePressed(MouseEvent e){}
    public void mouseReleased(MouseEvent e){}

    public void mouseEntered(MouseEvent e)
    {
    	if(this.isSelected) {
    		return;
    	}
        setBackground(hoverBackgroundColor);
    }

    public void mouseExited(MouseEvent e)
    {
    	if(this.isSelected) {
    		return;
    	}
        setBackground(backgroundColor);
    }
    
    public void actionPerformed(ActionEvent e) {
		if (e.getActionCommand().equals("Delete")) {
			this.serverActionListener.doRestServerDeleteAction(this.restServerId);
		}
	}

	public void select() {
		setBackground(this.selectedBackgroundColor);
		
		this.isSelected = true;
	}
	
	public void unselect() {
		setBackground(this.backgroundColor);
		
		this.isSelected = false;
	}
	
	public void connected() {
		this.imageLabel.setIcon(ImageLoader.laodImageIcon("online.png"));
	}
	
	public void disconnected() {
		this.imageLabel.setIcon(ImageLoader.laodImageIcon("offline.png"));
	}
	
}
